#
# spec file for package terraform-provider-azurerm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         terraform-providers
%global repo            terraform-provider-azurerm
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global import_path     %{provider}.%{provider_tld}/%{namespace}/%{repo}
%global providername    azurerm

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-azurerm
Version:        3.35.0
Release:        1.6
Summary:        Terraform provider for Azure Resource Manager (AzureRM)
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-azurerm
Source:         %{repo}-%{version}.tar.xz
Source99:       terraform-provider-azurerm-rpmlintrc
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
# Terraform is not available for 32bit platforms
ExcludeArch:    %ix86 %arm
Requires:       terraform >= 1.0.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.12
%endif
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you provision servers on Azure Resource
Manager via Terraform.

%prep
%setup -q

%build
%{goprep} %{import_path}
%{gobuild} -mod=vendor ""

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
ln -s %{_bindir}/%{name}_v%{version} %{buildroot}%{_bindir}/%{name}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Mon Dec 12 2022 jkohoutek@suse.com
- Update to version 3.35.0:
  * v3.35.0
  * updating the changelog
  * tooling: fixing the github actions
  * `azurerm_kubernetes_cluster`: Support for `image_cleaner` block (#19368)
  * Chown 0755 for scripts/run-gradually-deprecated.sh (#19620)
  * v3.35.0
  * doc enhancement for `azurerm_site_recovery_replication_policy` (#19547)
  * CHANGELOG #19162
  * New resource: `azurerm_sentinel_data_connector_microsoft_threat_protection` (#19162)
  * `azurerm_spring_cloud_gateway_route_config` - order defaults to -1 to differenciate 0 and not set (#18162)
  * GHA - Limit CreateUpdate check to newly added files only (#19601)
  * Doc update for azurerm_databricks_access_connector with identity block (#19618)
  * pr review: fix nil checks
  * Update for #19527
  * `azurerm_kubernetes_cluster` - support for the `network_plugin_mode` `ebpf_data_plane` properties (#19527)
  * Fix doc of `azurerm_machine_learning_computer_cluster` `ssh`
  * updating to include #19602
  * Update for #19546
  * `azurerm_kubernetes_cluster` `azurerm_kubernetes_cluster_node_pool` - support for the `custom_ca_trust_enabled` property (#19546)
  * id fix
  * make whitespace
  * post mege cleanup
  * update golangci.yml
  * fix linting
  * Update changelog for #19580
  * `data.azurerm_sentinel_alert_rule_template`: Set custom ID rather than using ID returned from API (#19580)
  * dependencies: updating to `v0.20221207.1121859` of `github.com/hashicorp/go-azure-sdk`
  * contributor docs - add section on schema design (#19559)
  * r/stream_analytics_output_blob: `batch_min_rows` is now an integer
  * Update changelog for #19586
  * `azurerm_mssql_elasticpool` - Prevent `license_type` from being configured in specific scenarios (#19586)
  * dependencies: updating to version `v0.20221202.1180026` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #19564
  * updating to include #19537
  * updating to include #19528
  * updating to include #19578
  * Update for 19396
  * `azurerm_kubernetes_cluster`: Support for CSI arguments (#19396)
  * CHANGELOG #19576
  * New resource `azurerm_digital_twins_time_series_database_connection` (#19576)
  * CHANGELOG #19334
  * New Resource `azurerm_network_manager` (#19334)
  * CHANGELOG #19082
  * New Resource - `azurerm_vmware_netapp_volume_attachment` (#19082)
  * media: fixing the state migration to parse case-insensitively
  * Update for #19574
  * Bug Fix - `azurerm_virtual_desktop_workspace_application_group_association`- Association should not remove the tags (#19574)
  * Update for #19573
  * `azurerm_lb_probe` - Support property `probe_threshold`  (#19573)
  * azurerm_vmware_private_cloud and azurerm_vmware_cluster adding new skus to validation - #19 (#19565)
  * `azurerm_vpn_server_configuration` - update `nil` check for `radius` (#19566)
  * Fixes duplicated ForceNew statements in document. (#19570)
  * Lint
  * azurerm_spring_cloud_active_deployment - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_container_deployment - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_java_deployment - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_storage - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_service - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_gateway_route_config - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_gateway_custom_domain - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_gateway - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_configuration_service - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_custom_domain - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_certificate - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_build_deployment - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_builder - a  state migration to work around the previously incorrect id casing
  * Update CHANGELOG.md
  * `azurerm_firewall_policy` - support for `explicit_proxy` and `auto_learn_private_ranges_mode` properties (#19313)
  * azurerm_spring_cloud_api_portal_custom_domain - a  state migration to work around the previously incorrect id casing
  * Lint
  * azurerm_spring_cloud_api_portal - a  state migration to work around the previously incorrect id casing
  * Update CHANGELOG.md
  * `azurerm_spring_cloud_gateway_route_config` - support for the `filters`, `predicates` and `sso_validation_enabled` properties (#19493)
  * azurerm_spring_cloud_app_*_association - a  state migration to work around the previously incorrect id casing
  * azurerm_spring_cloud_app - a  state migration to work around the previously incorrect id casing
  * azurerm_api_management // New property `security.tls_rsa_with_aes256_gcm_sha384_ciphers_enabled` (#19472)
  * Update CHANGELOG.md
  * new resource: `azurerm_spring_cloud_application_live_view` (#19495)
  * Update CHANGELOG.md
  * `azurerm_key_vault` - fix two kv in different sub issue (#19531)
  * Update CHANGELOG.md
  * `azurerm_app_service_connection` - fix the secret type issue. (#19519)
  * Update CHANGELOG.md
  * `azurerm_lb` - Fix adding/removing a frontend configuration forces recreation of loadbalancer issue (#19548)
  * CHANGELOG #19553
  * `azurerm_mssql_virtual_machine` - support manual schedule `days_of_week` (#19553)
  * Fix wrong Azure FrontDoor SP name to `Microsoft.Azure.Cdn` (#19560)
  * Correct field name from `auth_config` to `authentication` on documentation example for `azurerm_postgresql_flexible_server_active_directory_administrator` (#19555)
  * r/media_services_account: fixing the Resource ID segment to match the validation function (#19557)
  * Typo in sftp_enabled of `azurerm_storage_account` documentation (#19552)
  * Update changelog for #19524
  * `azurerm_iothub_x` - a  state migration to work around the previously incorrect id casing (#19524)
  * Update changelog for #19513
  * `azurerm_monitor_smart_detector_alert_rule` - a  state migration to work around the previously incorrect id casing (#19513)
  * Update changelog for #19512
  * `azurerm_frontdoor_rules_engine` - a state migration to work around the previously incorrect id casing (#19512)
  * Update changelog for #19525
  * `azurerm_kusto_*` - a  state migration to work around the previously incorrect id casing (#19525)
  * Update changelog for #19511
  * `azure_healthcare_*` - a  state migration to work around the previously incorrect id casing (#19511)
  * Update changelog for #19507
  * `azurerm_container_registry_webhook` - a  state migration to work around the previously incorrect id casing (#19507)
  * Update changelog for #19506
  * `azurerm_automation_webhook`/`azurerm_automation_source_control` - a state migration to work around the previously incorrect id casing (#19506)
  * `dependencies` - update `proximityplacementgroups` to `2022-03-01`
  * springcloud: adding a state migration for `buildpackBindings` -> `buildPackBindings` (#19482)
  * Changelog for #19499
  * Update for #19516
  * `azurerm_automation_software_update_configuration` - fix nil tag in tagsSetting causes create error (#19516)
  * Fixes inconsistency `Required`, `Optional` and `ForceNew` properties between code and document. (#19514)
  * update code
  * fix deprecated SetId style
  * fix
  * fix code
  * fix
  * skip purge if purge protect enabled
  * v3.34.0
  * Docs: azurerm_redis_cache - private_static_ip_address requires subnet_id (#19518)
  * Update for #19494
  * fix issue 19490 (#19494)
  * Update changelog #19492
  * `azurerm_monitor_autoscale_setting` - a  state migration to work around the previously incorrect id casing (#19492)
  * Update changelog for #19489
  * `azurerm_iot_security_solution` - a  state migration to work around the previously incorrect id casing (#19489)
  * Update changelog for #19487
  * `data.azurerm_sentinel_alert_rule_template` and `azurerm_sentinel_automation_rule` - a  state migration to work around the previously incorrect id casing (#19487)
  * Update changelog for #19486
  * `azurerm_sql_active_directory_administrator` - a  state migration to work around the previously incorrect id casing (#19486)
  * Update changelog for #19485
  * `azurerm_synapse_integration_runtime_*` - a state migration to work around the previously incorrect id casing (#19485)
  * Update changelog for #19465
  * `azurerm_windows_virtual_machine_scale_set` Fix crash when upgrading `automatic_os_upgrade_policy` (#19465)
  * Update for #19458
  * Support Upload creation_type with uploadSizeBytes (#19458)
  * `azurerm_stream_analytics_job`: fix `job_storage_account: authentication_mode` unsupported mode issue (#19225)
  * updating to include #19484
  * Update for #19382
  * `azurerm_spring_cloud_gateway_route_config` - support for the `protocol` property (#19382)
  * Upgrade managedservices.registrationdefinitions API version from 2019-06-01 to 2022-10-01
  * updating to include #19483
  * Update changelog for #19477
  * `azurerm_synapse_linked_service` adding state migration for id (#19477)
  * synapse: refactoring to use `tombuildstuff/kermit` rather than the embedded sdk
  * dependencies: updating to `v0.20221129.1175354` of `github.com/hashicorp/go-azure-sdk`
  * apimgmt: fixing the usage
  * apimgmt: removing/regenerating
  * updating to include #19479
  * dependencies: updating to `v0.20221129.1151133` of `github.com/hashicorp/go-azure-sdk`
  * Update for #19466 and #19447
  * add state migrations
  * `azurerm_kusto_database` - allows underscores in `name` (#19466)
  * azurerm_stream_analytics_output_eventhub: Fix  issue when it's toggled to Msi (#19447)
  * Update for #19468
  * `azurerm_data_factory_linked_service_azure_file_storage` - only pass `host` and `user_id` when they're set (#19468)
  * Update for #19464
  * Fix crash around checking for existing azurerm_app_configuration_key (#19464)
  * `azurerm_site_recovery_replication_policy` - improve existing check (#19391)
  * dependencies: updating to `v0.20221128.1190504` of `github.com/hashicorp/go-azure-sdk` (#19462)
  * portal: adding a todo
  * Update for #19422
  * `data.azurerm_api_management` - Support  property `tenant_access` (#19422)
  * Update a standard logic app with correct stack settings (#19399)
  * updating to include #19453
  * Update for #19446
  * `azurerm_storage_management_policy` - Support `rule.actions.base_blob.{tier_to_cool_after_days_since_creation_greater_than|tier_to_archive_after_days_since_creation_greater_than|delete_after_days_since_creation_greater_than}` (#19446)
  * Update documentation Guide "new resource" (#19413)
  * Update for #19428
  * azurerm_storage_account - adds support for enabling SFTP (#19428)
  * cognitive: removing the old Resource ID since this is no longer used
  * apimanagement: removing a duplicate Resource ID with the same key
  * dependencies: updating to `v0.20221128.1124937` of `github.com/hashicorp/go-azure-sdk`
  * Updating based on eaa2d83b
  * updating to include #19445
  * Update for #19395
  * `streamanalytics` - switch to `hashicorp/go-azure-sdk` (#19395)
  * Update for #18568
  * Fix currentStack is being reset when other site_config values are changed. (#18568)
  * Update for #19425
  * `azurerm_monitor_activity_log_alert` - fix action webhook (#19425)
  * Update for #19285
  * `media`: refactoring to use `hashicorp/go-azure-sdk` (#19285)
  * `springcloud` - update sdk to 2022-11-01-preview
  * Fix a typo in service_principal_client_certificate.html
  * update nginx deployment document (#19434)
  * v3.33.0
  * updating changelog
  * Changelog for #18918
  * Updating based on c49f7025
  * update for #19418
  * `azurerm_storage_account` - Check `blob_properties.0.versioning_enabled` and `is_hns_enabled` (#19418)
  * Update for #19298
  * `azurerm_storage_account` - fix crash in multichannel checking (#19298)
  * Update for #19419
  * `azurerm_mysql_flexible_server` - expand max value for the `iops` property (#19419)
  * Update changelog for #19386
  * `azurerm_spring_cloud_app` - `ingress_settings` (#19386)
  * Docs : Fix  wrong description of `attachment_status` property for  ` Data Source: azurerm_public_ips` (#19400)
  * Doc Fix: `azurerm_private_dns_resolver_virtual_network_link`  - `dns_forwarding_ruleset_id` (#19415)
  * Doc Fix: `azurerm_kubernetes_cluster` - updating `api_server_authorized_ip_ranges` description (#19403)
  * updating to include #19412
  * dependencies: updating to `v0.20221122.1115312` of `github.com/hashicorp/go-azure-sdk`
  * Update changelog for #19378
  * `azurerm_cdn_frontdoor_rule` - allow `cache_duration` to be `null` if `cache_behavior` is set to `HonorOrigin` (#19378)
  * `azurerm_sentinel_automation_rule` - improve acctest (#19387)
  * Docs: `healthcare_dicom` and `healthcare_fhir_service` (#19392)
  * Docs: Fix wrong description of `azurerm_mssql_database_extended_auditing_policy` (#19390)
  * Including #19384
  * Doc: Fix incorrect import spec for azurerm_postgresql_flexible_server_active_directory_administrator
  * Add placeholder for custom set function
  * Update changelog for #19371
  * `azurerm_cognitive_account` - Support property `dynamic_throttling_enabled` (#19371)
  * updating to include #19325
  * updating to include #19357
  * including #19357 fixes #19296
  * Update golangci-lint
  * Custom runners for slow/intensive workflow jobs
  * Disable tflint workflow until https://github.com/bflad/tfproviderlint/issues/255 is fixed
  * Custom runner for golint workflow
  * Update & tidy workflows
  * Ensure tflint exits on error
  * Update changelog for #19352
  * `azurerm_servicebus_subscription_rule` - `correlation_filter` with empty attributes no longer crashes (#19352)
  * `azurerm_mssql_server_resource`, `azurerm_mssql_server_resource`: fix client name spelling (#19363)
  * Fix build error
  * Apply suggestions from code review
  * updating to include #19362
  * gofmt
  * tooling: updating to Go 1.19.3
  * update changelog for #19269
  * `azurerm_postgresql_flexible_server` - support for `authentication`, `azurerm_postgresql_flexible_server_active_directory_administrator` - add new resource (#19269)
  * update changelog for #19336
  * `data.azurerm_databricks_workspace` - support for "storage_account_identity" property (#19336)
  * updating to include #19303
  * updating to include #19340
  * refactor: updating `FluidRelay` to use a MetaClient
  * updating to include #19344
  * update kusto_database_principal_assignment.html.markdown (#19354)
  * Tool: generate typed SDK model for a given resource's schema
  * Update changelog for #19338
  * `azurerm_monitor_alert_processing_rule_action_group`, `azurerm_monitor_alert_processing_rule_suppression` - add `monitor_condition` in AtLeastOneOf #19338
  * v3.32.0
  * doc: Updated list of Premium SKUs (#19350)
  * `azurerm_virtual_network_gateway`: fix AccTest for public ip resource with zones (#19305)
  * update changelog for #19337
  * fix update for instances (#19337)
  * serialize tests including `azurerm_security_center_subscription_pricing`
  * Update for #19348
  * `azurerm_app_service_public_certificate` - add custom poller to ensure `Create` is complete before `Read` (#19348)
  * update changelog for #19286
  * `azurerm_storage_blob_inventory_policy` - support for deleted blobs in inventory policy via include_deleted property on filters (#19286)
  * fix evaluation_frequency to Required in 4.0 (#19342)
  * updating to include #19319
  * upgrade cognitive service sdk to 2022-10-01
  * adding `azurerm_log_analytics_solution` to acctests of `azurerm_iot_security_solution`
  * `springcloud` - update sdk to 2022-09-01-preview
  * `azurerm_security_center_server_vulnerability_assessment` and `azurerm_security_center_server_vulnerability_assessment_virtual_machine` - adding pricing tier in test config
  * fix app gateway WAF_v2 sku need waf configuration from network 2022-05-01 (#19304)
  * fix acctet TestAccMariaDbServer_createPointInTimeRestore,TestAccMsSqlDatabase_createPITRMode,TestAccMsSqlDatabase_scaleReplicaSet (#19297)
  * [Documentation:] `azurerm_databricks_access_connector` - update private preview to public preview (#19288)
  * change to ResourceSequentialTest for serial test cases (#19314)
  * dependencies: updating to `v0.20221116.1175352` of `github.com/hashicorp/go-azure-sdk`
  * Fix workspace_id resource case problem
  * docs(cosmosdb/mongo): shard_key is optional (#19306)
  * dependencies: updating to `v0.20221116.1125307` of `github.com/hashicorp/go-azure-sdk`
  * possible fix for git error
  * `TestAccSecurityCenterWorkspace` - run acctest in sequence.
  * `TestAccSecurityCenterSetting` - run acctest in sequence.
  * Docs: add possible value list of property for 43 resource (#19271)
  * Docs: Fix document possible value missed of 45 resources (#19270)
  * `azurerm_security_center_assessment` - adding arguments for acctest
  * upgrade plugin-sdk/v2 to v2.24.1
  * Highlight the important `skip_service_principal_aad_check` note (#19295)
  * Update kubernetes_cluster.html.markdown (#19290)
  * CHANGELOG #19164
  * `azurerm_eventhub_namespace` - fix `zone_redundant` property for namespace (#19164)
  * CHANGELOG #19163
  * `azurerm_service_fabric_managed_cluster`: update the definition of `active_directory` to List (#19163)
  * `azurerm_mssql_database` - Fix acctest failure for test case`TestAccMsSqlDatabase_elasticPool` (#19083)
  * CHANGELOG #19222
  * `azurerm_storage_account` - Support for `sas_policy` (#19222)
  * CHANGELOG #19227
  * `azurerm_synapse_firewall_rule` - ensure the firewall is ready (#19227)
  * CHANGELOG #19263
  * `azurerm_orchestrated_virtual_machine_scale_set` - fix issue with no image is specified (#19263)
  * `azurerm_monitor_aad_diagnostic_setting` - serialize test cases (#19267)
  * Updating based on bc2c4b32
  * Update changelog for #19249
  * add java 17 for windows web app (#19249)
  * Update for #19273
  * `azurerm_security_center_subscription_pricing`: Upgrade API, add `subplan` argument (#19273)
  * Docs: Fix wrong name for forwarding_rule_state of azurerm_private_dns_resolver_forwarding_rule (#19264)
  * go mod tidy/vendor
  * storage: refactoring to use api version 2022-05-01
  * r/data_factory_linked_service_azure_databricks: updating the import
  * README
  * updating to include #19265
  * update explanation
  * upgrade containerservice sdk to 2022-09-02-preview
  * adding ISE deprecated
  * `Maintenance` - fix failed tests (#19247)
  * Simplify sample for `azurerm_cosmosdb_sql_role_assignment` (#19251)
  * Fixed the failing test.
  * Update CHANGELOG.md
  * `azurerm_federated_identity_credential`: fix docs (#19254)
  * pass CI
  * Tool: generate schema snapshot for state migration
  * `azurerm_postgresql_flexible_server` - remove `Standard_E96ds_v5` and `Standard_E104ids_v5` since they're not ready (#19246)
  * Added support for auto_rotation of SQL MI CMK key rotation.
  * Added new resource `azurerm_mssql_managed_instance_transparent_data_encryption` for managing TDE in SQL managed instance. Added `customer_managed_key` in `azurerm_mssql_managed_instance` data source. Added support for UserAssigned identities into `azurerm_mssql_managed_instance` resource and data source.
* Tue Nov 15 2022 Jan Kohoutek <jkohoutek@suse.com>
- Update of the .spec file:
  * import_path changed to reflect actual github.com tree
  * install changed to have links targeted to the versioned binaries, not twisted otherwise
* Mon Nov 14 2022 jmason@suse.com
- Update to version 3.31.0:
  * v3.31.0
  * azurerm_postgresql_flexible_server - support new SKUs for Postgresql Flexible Server (#19245)
  * fix cors flatten for windows/ linux web/ function app (#19141)
  * Update broken link for keda in kubernetes_cluster.html.markdown (#19243)
  * CHANGELOG #19232
  * azurerm_linux_web_app , azurerm_windows_web_app, azurerm_linux_function_app, azurerm_windows_function_app - Add support for .NET 7 in app service resources (#19232)
  * `azurerm_backup_container_storage_account` - fix a potential panic (#19229)
  * `azurerm_logic_app_standard` - fix the UserAssigned Identity (#19228)
  * docs `azurerm_scheduled_query_rules_alert` - add location required property (#19224)
  * add `azurerm_monitor_data_collection_rule` example (#19223)
  * CHANGELOG #19206
  * `azurerm_public_ip` - support for the `ddos_protection_mode` and `ddos_protection_plan_id` properties (#19206)
  * CHANGELOG #19199
  * New resource: `azurerm_federated_identity_credential` (#19199)
  * CHANGELOG #19184
  * `azurerm_disk_encryption_set` - add `federated_client_id` property (#19184)
  * `vm/vmss` - move validation between `source_image_id` and `source_image_reference` to schema (#19230)
  * Fix comments of community and shared gallery id (#19233)
  * Fixed typo in obsolete warning message for azurerm_container_group (#19239)
  * Remove note about NAT gateway outbound type being public preview
  * Changelog for #17245
  * goimports
  * updating to include #19178
  * including #19178 fixes #19103
  * Rename feature flag
  * Doc: Fix the incorrect import spec for automation source control (#19211)
  * Doc: fix incorrect casing of iot central app related resources (#19210)
  * Doc: fix incorrect casing of dns zone related resources
  * `azurerm_public_ip_prefix`: skip `TestAccPublicIpPrefix_prefixLength24` (#19060)
  * updating to include #19180
  * adding #19180 fixes #19097
  * [Documentation] `azurerm_frontdoor` - add migration tool link to deprecation notice block (#19201)
  * updating to include #19175
  * adding #19175 fixes #19174
  * `azurerm_private_dns_resolver_dns_forwarding_ruleset` Fix wrong property/field name in Docs. (#19198)
  * Auto PR: Regenerating based on (395c63528b405c4f407d836b95907096d9f129e9) (#19197)
  * `azurerm_servicebus_queue`: adding wait function for property update. (#19092)
  * `azurerm_sentinel_alert_rule_nrt` - Add support for `techniques` (#19142)
  * Update private_dns_resolver_inbound_endpoint.html.markdown (#19167)
  * Update private_dns_resolver_forwarding_rule.html.markdown (#19181)
  * updating to include #19193
  * dependencies: updating to `v0.20221108.1145701` of `github.com/hashicorp/go-azure-sdk`
  * `azurerm_cosmosdb_account` - Support `EnableMongo16MBDocumentSupport` capability (#19187)
  * update more possible vaules for property data_location (#19186)
  * corrected resource name for azurerm_attestation_provider
  * go mod tidy/vendor
  * r/managed_disk: support for Expand Without Downtime
  * Updating based on 39b6fcde
  * updating to include #19161
  * Update for #19150
  * added new resource azurerm_stream_analytics_stream_input_eventhub_v2 (#19150)
  * fmt
  * Update sentinel API to 2022-10-01-preview
  * `azurerm_disk_encryption_set` - update the doc of `identity` (#19159)
  * CHANGELOG #19093
  * `azurerm_sentinel_alert_rule_fusion` - support for `source`block (#19093)
  * CHANGELOG #19123
  * `azurerm_mssql_virtual_machine` - support `sql_instance_setting` (#19123)
  * `azurerm_security_center_setting` - `setting_name` supports `WDATP_EXCLUDE_LINUX_PUBLIC_PREVIEW` and `SENTINEL` (#19126)
  * CHANGELOG #19142
  * `azurerm_container_registry_token_password` - Make `password{1|2}.0.expiry` to be `ForceNew` (#19140)
  * CHANGELOG #19124
  * Upgrade network API version from `2021-08-01` to `2022-05-01` (#19124)
  * v3.30.0
  * Update CHANGELOG.md
  * CHANGELOG #19095
  * [Bug:] `azurerm_cdn_frontdoor_firewall_policy` - expose `AnomalyScoring` in `override` `rule` `action` for DRS 2.0 (#19095)
  * CHANGELOG #19120
  * `azurerm_stream_analytics_job`: add support for `job_storage_account` (#19120)
  * CHANGELOG #19115
  * `azurerm_mssql_virtual_machine` - support `system_db_on_data_disk_enabled` (#19115)
  * `azurerm_application_gate_way` - fix `url_path_map` constraint (#19101)
  * CHANGELOG #19114
  * `azurerm_monitor_diagnostic_setting` - support `partner_solution_id` (#19114)
  * Auto PR: Regenerating based on (50636834399e4bf1bd110bc8fabdf40834134c0c) (#19133)
  * docs:  `azurerm_key_vault_` add features toggle notes (#19117)
  * updating to include #19111
  * Update for #18999
  * Trying to fix Issue #18971 (#18999)
  * remove useless tag
  * CHANGEOG #18605
  * Allow Virtual Machine Scale Sets to have both Rolling upgrade mode and Automatic OS Upgrade (#18605)
  * new resource: azurerm_mssql_managed_instance_security_alert_policy (#18985)
  * CHANGELOG #19091
  * `azurerm_*_virtual_machine_scale_set` - support for `StandardSSD_ZRS` `PremiumV2_LRS` `Premium_ZRS` storage account type (#19091)
  * CHANGELOG #19098
  * `azurerm_virtual_machine_extension` `azurerm_virtual_machine_scale_set_extension` `azurerm_*_virtual_machine_scale_set` - support `protected_settings_from_key_vault` (#19098)
  * `azurerm_windows_function_app_slot`, `azurerm_linux_function_app_slot`: fix runtime scale not being set (#18532)
  * CHANGELOG #18988
  * `azurerm_api_management` - fix `subnet_id` case sensitivity (#18988)
  * CHANGELOG #19028
  * new resource: `azurerm_private_dns_resolver_forwarding_rule` (#19028)
  * CHANGELOG #19081
  * azurerm_postgresql_flexible_server_database: remove the resource from state file when this resource is deleted from outside (#19081)
  * CHANGELOG #19084
  * azurerm_mssql_database -  fix persistent diff, `license_type` no longer returned by API (#19084)
  * TestCase: Fix TestAccAzureRMServiceFabricCluster_manualClusterCodeVersion (#19090)
  * New Resource: `azurerm_kubernetes_fleet_manager` (#19111)
  * updating to include #19108
  * dependencies: updating to `v0.20221102.1171058` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #19107
  * dependencies: updating to `v0.47.0` of `github.com/hashicorp/go-azure-helpers`
  * updating to include #19105
  * dependencies: updating to `v0.20221101.1170513` of `github.com/hashicorp/go-azure-sdk`
  * containers: spiking out the generated logic by hand
  * containers: renaming the new Containers Client
  * Docs: data.azurerm_management_group requires name or display_name in example (#19089)
  * `VirtualMachineScaleSetTerminationNotificationSchema` - add feature flag for `ConflictsWith` (#19049)
  * Update for #18892
  * webpubsub: refactoring to use go-azure-sdk (#18892)
  * Update for #19070
  * dependencies: upgrade IoTHub devices to 2022-04-30-preview (#19070)
  * `azurerm_container_connected_registry` - fix failed testcases (#18958)
  * CHANGELOG #19073
  * `azurerm_function_app_host_keys` - support for `webpubsub_extension_key` (#19073)
  * Update CHANGELOG.md
  * CHANGELOG #19029
  * new resource: `azurerm_private_dns_resolver_virtual_network_link` (#19029)
  * CHANGELOG #19030
  * `azurerm_eventhub_namespace_disaster_recovery_config`: fixing breaking pair logic (#19030)
  * CHANGELOG #19026
  * `azurerm_application_gateway` - data source - add backend_address_pool attribute (#19026)
  * CHANGELOG #19071
  * `virtual_network_gateway_connection` - set `authorization_key` from state (#19071)
  * CHANGELOG #18609
  * `azurerm_mssql_server_microsoft_support_auditing_policy` - New resource (#18609)
  * `azurerm_vpn_gateway_connection`: fix `TestAccVpnGatewayConnection_customRouteTable` routing table (#18887)
  * `azurerm_network_connection_monitor` &`azurerm_network_watcher`: `TestAccNetworkWatcher` set delete os disk of virtual machine (#18899)
  * `azurerm_kubernetes_cluster` - Fix `http_proxy_config` AccTests (#19077)
  * `azurerm_mariadb_server` and `azurerm_mysql_flexible_server` - Fix acc test failures for `TestAccMariaDbServer_createPointInTimeRestore` and `TestAccMySqlFlexibleServer_updateMaintenanceWindow` (#19064)
  * `azurerm_app_configuration_feature` - add feature name validation (#19063)
  * Fix acctest `*VirtualMachine_orchestratedWithPlatformFaultDomain` (#19074)
  * fix permissions on Pull Request Triage
  * `azurerm_kubernetes_cluster` - Fix tests (#19058)
  * Update for #19057
  * `azurerm_kubernetes_cluster` - Make sure `auto_scaler_profile.expander` is not empty (#19057)
  * updating to include #19038
  * Fix incorrect import directives in document (#19059)
  * Update changelog for #18338
  * `azurerm_policy_set_definition`/`azurerm_policy_definition` - Reverse the order of policies lookup to favour builtin (#18338)
  * Use Page Blob in tests of Gallery Application Version (#19050)
  * doc: Fix setting name for remote_debugging_enabled (#19052)
  * Update after v3.29.1 release
  * `azurerm_kubernetes_cluster` - nil check `publicNetworkAccess` (#19048)
  * Fix min value (#19035)
  * provider: updating usages of `zones.Expand` -> `zones.ExpandUntyped` and `zones.Flatten` -> `zones.FlattenUntyped`
  * dependencies: updating to v0.46.0 of `hashicorp/go-azure-helpers` / `v0.20221028.1081410` of `hashicorp/go-azure-sdk`
  * Update for #19032
  * `azurerm_app_configuration_keys` - fix nil pointer error of `label` (#19032)
  * Fix link to goto top level resource (#19031)
  * Update for #18667
  * `azurerm_kubernetes_cluster` - support for the `web_app_routing` property (#18667)
  * Updating based on bcd335b9
  * v3.29.0
  * CHANGELOG #18525
  * `azurerm_disk_encryption_set` - `identity` support for `UserAssigned` and `SystemUserAssgined` identity (#18525)
  * Update changelog for #19007
  * `azurerm_synapse_workspace`: enable user assigned managed identity (#19007)
  * CHANGELOG #17825
  * new resources: azurerm_datadog_monitor_tag_rule azurerm_datadog_monitor_sso_configuration (#17825)
  * `azurerm_mssql_database` - read maintenance configuration only if database is not in elastic pool (#18321)
  * `azurerm_mysql_flexible_server ` - Fix AccTest failure for resource azurerm_mysql_flexible_server (#18937)
  * `azurerm_monitor_log_profile` - fix test config dependency resource (#19011)
  * CHANGELOG #19012
  * new resource: `azurerm_private_dns_resolver_dns_forwarding_ruleset` (#19012)
  * CHANGELOG #19014
  * `azurerm_linux_virtual_machine_scale_set` `azurerm_windows_virtual_machine_scale_set` - rename `gallery_applications` (#19014)
  * Update CHANGELOG.md
  * CHANGELOG #18789
  * New resources: `azurerm_iothub_device_update_account` `azurerm_iothub_device_update_instance` (#18789)
  * CHANGELOG #18966
  * `azurerm_monitor_data_collection_rule` -  correctly support streams (#18966)
  * updated to include #18906
  * including #18906 fixes #18889 and #19008
  * CHANGELOG #19020
  * `appconfiguration/sdk`: Fix pagination logic (#19020)
  * fix: markdownlint documentation (#18972)
  * stop using beta.kubernetes.io/os (#19021)
  * Update for #18967
  * `azurerm_kubernetes_cluster`: Add support for KEDA Autoscaler (#18967)
  * Update for #18986
  * new resource: `azurerm_private_dns_resolver_outbound_endpoint` (#18986)
  * Update for #19009
  * `azurerm_data_factory_dataset_parquet` - mark `path` as optional (#19009)
  * `azurerm_automation_webhook`: remove a AccTest case with uri property (#18992)
  * Update for #18994
  * `dependency` - update `compute` to `2022-08-01` (#18994)
  * CHANGELOG #18523
  * `azurerm_mssql_server_transparent_data_encryption` - Support for autorotation of KV keys (#18523)
  * `azurerm_service_fabric_managed_cluster` - fix a bug in `custom_fabric_setting` (#18987)
  * `azurerm_virtual_network_gateway_connection` - fix the panic caused by bgp peering address (#18989)
  * CHANGELOG #18983
  * new resource: `azurerm_private_dns_resolver_inbound_endpoint` (#18983)
  * CHANGELOG #18957
  * `azurerm_snapshot` - switch to go-azure-sdk (#18957)
  * CHANGELOG #18996
  * `azurerm_netapp_volume`: set snapshot Id when `create_from_snapshot_resource_id` is specified (#18996)
  * Update for #17166
  * Add api_management_gateway_hostname_configuration (#17166)
  * `azurerm_managed_disk` - add log and remove feature flag in state migration (#18993)
  * AcceptanceTesting: extend TC config to allow tests to be run in DevTest subscription (#18997)
  * Update for #18991
  * azurerm_managed_disk: allow to set logical_sector_size, disk_iops_read_write, disk_mbps_read_write, disk_iops_read_only and disk_mbps_read_only when storage_account_type is PremiumV2_LRS (#18991)
  * `azurerm_managed_disk` - remove old parse/validate (#18990)
  * Update for #18959
  * `azurerm_stream_analytics_stream_input_eventhub` - Mark `shared_access_policy_key` and `shared_access_policy_name` as optional (#18959)
  * [Documentation]: Rebrand the old FrontDoor resources as `classic` and the new CDN FrontDoor resources as `standard/premium` (#18961)
  * `document` - Fix `source_resource_id` description in `azurerm_managed_disk` (#18984)
  * CHANGEOG #18978
  * `customproviders` - switch to `hashicorp/go-azure-sdk` (#18978)
  * CJHANGELOG #18962
  * `azurerm_postgresql_server`: allow to set `public_network_access_enabled` when the PITR is enabled (#18962)
  * Support for more OS SKUs (Windows2019/Windows2022/CBLMariner/Marine) AKS NodePool SKU (#18976)
  * Update for #18960
  * `azurerm_monitor_scheduled_query_rules_alert_v2` - add `evaluation_frequency`, `window_duration`, `mute_actions_after_alert_duration`, and `query_time_range_override`validation and doc (#18960)
  * Update for #18968
  * Dependencies: update to go-azure-helpers v0.45.0 (#18968)
  * fix: optional sticky_settings block (#18964)
  * `azurerm_site_recovery_replicated_vm` - update disks sdk (#18963)
  * Updating based on c59fdb46
  * Update for #18705
  * `azurerm_kubernetes_*` - Upgrade to go-azure-sdk (#18705)
  * `azurerm_mssql_virtual_machine` - fix `manual_schedule` descriptions (#18955)
  * CHANGELOG #18923
  * `azurerm_mssql_virtual_machine` - add support for `assessment` (#18923)
  * Auto PR: Regenerating based on (0ad85b60ecad383c413f74dd1a763c051f364c20) (#18953)
  * CHANGELOG #18762
  * New Resource: `azurerm_nginx_certificate` (#18762)
  * CHANGELOG #18729
  * `azurerm_servicebus_namespace_disaster_recovery_config`: support alias_authorization_rule_id (#18729)
  * Deprecate Resource: azurerm_cosmosdb_notebook_workspace (#18529)
  * CHANGELOG #18761
  * New Resource: `azurerm_nginx_configuration` (#18761)
  * refactor: removing utils/compare (#18952)
  * refactor: removing the `resourceid` package (#18950)
  * refactor: removing usages of the legacy `azure` schema types (#18951)
  * CHANGELOG #17449
  * `azurerm_hdinsight_kafka_cluster`, `azurerm_hdinsight_spark_cluster`, `azurerm_hdinsight_interactive_query_cluster`, `azurerm_hdinsight_hbase_cluster`, `azurerm_hdinsight_hadoop_cluster` - add support for `compute_isolation_properties` property (#17449)
  * `azurerm_express_route_circuit`: fix AccTest of `azurerm_express_route_port` (#18910)
  * VHANGELOG #18805
  * `azurerm_postgresql_server` - Fixed issue with creating Postgres server in `Replica` mode (#18805)
  * dependencies: updating to `v0.20221024.1162143` of `github.com/hashicorp/go-azure-sdk` (#18949)
  * CHANGELOG #18853
  * `azurem_logic_app_standard` - support for the scm related site config (#18853)
  * CHANGELOG #18905
  * `azurerm_disk_pool` `azurerm_disk_pool_iscsi_target` `azurerm_disk_pool_iscsi_target_lun` `azurerm_disk_pool_managed_disk_attachment` - Remove registration for `Microsoft.StoragePool` and add deprecation message for affected resources (#18905)
  * CHAGELOG #18934
  * `azurerm_logic_app_action_http` - support for the `queries` property (#18934)
  * `azurem_private_link_service` - update `visibility_subscription_ids` validation to allow any alias (#18946)
  * CHANGELOG #18689
  * windows_function_app & linux_function_app - Add support for Java 17 (#18689)
  * Update CHANGELOG.md
  * `azurerm_key_vault_certificate` - allow new versions of key vault certs to be imported (#18848)
  * Auto PR: Regenerating based on (44b7f96869ed6479f6db6eea114cf4e80bc38901) (#18943)
  * Update azurerm_private_endpoint resource documentation (#18944)
  * updating to include #18928
  * Updating based on 1c9d7d40
  * Update for #18850
  * `azurerm_synapse_workspace` - remove sql password requirement for synapse (#18850)
  * `azurerm_monitor_autoscale_setting` - add email string validation (#18931)
  * Docs: Use correct Resource Name in FrontDoor Route sample (#18932)
  * Update for #18760
  * `azurerm_[linux|windows]_function_app` and `azurerm_[linux|windows]_function_app_slot` add storage_account (#18760)
  * `azurerm_point_to_site_vpn_gateway`: fix AccTest use default table id of virtual hub (#18912)
  * `azurerm_public_ip`: fix AccTest `domain_name_label` has to be lowercase (#18929)
  * disks: refactoring to use `go-azure-sdk` instead of an embedded Resource Manager SDK
  * disks: refactoring/vendoring the sdk from `go-azure-sdk`
  * authorization: adding TODOs for Role Assignment
  * resource: implementing resourceids.Id
  * billing: implementing resourceids.Id
  * desktopvirtualization: implementing resourceids.Id
  * internal/identity: removing this package since it's no longer used (#18926)
  * Fix typo on docs (#18924)
  * keyvault: implementing resourceids.Id
  * monitor: implementing resourceids.Id
  * policy: implementing resourceids.Id
  * portal: implementing resourceids.Id
  * network: generating the ID for ApplicationGatewayPrivateLinkConfiguration
  * securitycenter: implementing the resourceids.Id interface
  * storage: implementing the resourceids.Id interface
  * synapse: implementing the resourceids.Id interface
  * web: ensuring that certificate_binding implements the resourceids.Id interface
  * CHANGELOG #18473
  * new resource: `azurerm_private_dns_resolver ` (#18473)
  * azurerm_automation_runbook - support python2 python3 values into validation (#18921)
  * Upgrade Automation/Runbook API version from `2020-01-13-preview` to `2019-06-01` (#18213)
  * CHANGELOG #17785
  * Updated API version of `container_group` from `2021-03-01` to `2021-10-01` (#17785)
  * fix: remote debugging argument is not expected here (#18916)
  * restore bandwidth 10 gbps (#18909)
  * Update for #18898
  * Update for #18903
  * Data source: `azurerm_storage_management_policy` add supports for the `tier_to_archive_after_days_since_last_tier_change_greater_than` (#18898)
  * add halting on Azure Disk Pools preview's warning (#18900)
  * [New Data Source:] `azurerm_cdn_frontdoor_firewall_policy` (#18903)
  * v3.28.0
  * Update CHANGELOG.md
  * Fix for accurate granularities on doc (#18890)
  * CHANGELOG #17810
  * azurerm_cosmosdb_account - primary_sql_connection_string, secondary_sql_connection_string, primary_readonly_sql_connection_string, secondary_readonly_sql_connection_string (#17810)
  * `azurerm_managed_disk` - add state upgrader from V0 to V1 to fix ID issue (#18885)
  * Update for #18684
  * windows_function_app & linx_function_app - Add VS2022 to remote_debugging_version (#18684)
  * `azurerm_app_configuration` - fix error msg and complement docs (#18863)
  * Update for #18871
  * `azurerm_recovery_services_vault` - fix a bug in update which caused soft_delete_enabled prop lost (#18871)
  * `iothub` - Update test location to fit Device Update resource (#18884)
  * aadb2c: refactoring to use the MetaClient within go-azure-sdk
  * `azurerm_security_center_contact` - remove an abandon source to fix test (#18882)
  * Update for #18876
  * Data Source: `azurerm_linux_function_app` - fix missing error on data source not found (#18876)
  * Update for #18872
  * Modified `azurerm_storage_account` to allow setting CMK for Premium-tier services. (#18872)
  * Update for #18859 #18862 #18858 #18857
  * New resource: `azurerm_sentinel_data_connector_iot` (#18862)
  * Update for #18874
  * added RequestBodyJsonArgNames (#18874)
  * New resource: `azurerm_sentinel_data_connector_dynamics_365` (#18859)
  * New resource: `azurerm_sentinel_data_connector_office_365_project` (#18858)
  * New resource: `azurerm_sentinel_data_connector_office_power_bi` (#18857)
  * Allow php version 8.1 (#18867)
  * Update for #18860
  * fix validation of subscription id of target of automation softeware update configuration (#18860)
  * fix zones of public ip (#18828)
  * Update for #18856
  * remove resource_group_name in resource control example (#18861)
  * New resource: `azurerm_sentinel_data_connector_office_irm` (#18856)
  * Update for #18799
  * `azurerm_network_security_{group|rule}` - Setting correct casing `protocol` to state (#18799)
  * Update for #18766
  * `azurerm_firewall_policy_rule_collection_group` - limit dnat rule destination port max number to 1 (#18766)
  * [Documentation:] `azurerm_cdn_frontdoor_custom_domain` and `azurerm_cdn_frontdoor_profile` - add better descriptions for some fields which maybe confusing (#18851)
  * `azurerm_storage_account` - Refactor the service access based on the kind and sku tier (#17274)
  * Update for #18836
  * `azurerm_[linux|windows]_function_app` and `azurerm_[linux|windows]_function_app_slot` fix `app_settings` diff when `vnet_route_all_enabled = true` (#18836)
  * Update for #18680
  * `azurerm_windows_function_app`, `azurerm_linux_function_app`: remove hasChange condition during creation (#18680)
  * updating to include #18833
  * Update for #18822
  * update subnet.html.markdown and subnet_resource.go with "Microsoft.LabServices/labplans" (#18822)
  * Allow AMD sku for azurerm_mysql_flexible_server (#18816)
  * dependencies: updating to `v0.20221018.1075906` of `github.com/hashicorp/go-azure-sdk`
  * refactor: updating analysisservices to use a metaclient
  * dox fix (#18823)
  * Update for #16603
  * Added client certificate exclusion paths app service setting (#16603)
  * CHANGELOG #18824
  * [Bug:] `azurerum_cdn_frontdoor_route` - fixes panic on import due to incorrect casing returned by the API (#18824)
  * updating to include #18749
  * including #18749 fixes #18747
  * Update to include #18817
  * including #18817 fixes #18769
  * Update changelog for
  * `azurerm_eventhub_namespace` - ignore case for `network_rulesets.x.virtual_network_rule.x.subnet_id` (#18818)
  * CHANGELOG #18792
  * `azurerm_storage_management_policy` - Support for `tier_to_archive_after_days_since_last_tier_change_greater_than` (#18792)
  * `azurerm_sentinel_data_connector_aws_s3` - fix import (#18806)
  * add script to calculate pandora sdk stats (#18782)
  * add make resource-count (#18783)
  * corrected typo in docs (#18808)
  * Docs: Provide format for point in time restore parameter on the databases (#18803)
  * Remove "profile" from "azurerm_cdn_frontdoor_custom_domain" (#18804)
  * Docs: Fix incorrect parameter description for data resource `azurerm_cosmosdb_sql_role_definition` (#18797)
  * `azurerm_container_group` - Fix `volume` block error message (#18798)
  * Update for #18765
  * `azurerm_fluid_relay_server` - add `primary_key` and `secondary_key` properties (#18765)
  * fix TestAccAppConfigurationDataSource_basic (#18794)
  * Docs: fix `azurerm_nginx_deployment` import id (#18790)
  * Docs: fix automation software update configuration `timezone` typo (#18791)
  * CHANGELOG #18774
  * `azurerm_storage_account`: Add support for `immutability_policy` argument (#18774)
  * fix: Removed invalid storage_account_type value (#18777)
  * fixing #18105 (#18668)
  * update go-azure-sdk to v0.20221014.1215546 (#18785)
  * Minor edit to Redis Cache documentation (#18775)
  * Updating based on 1ad7913b
  * updating to include #18759
  * Update for #18251
  * `azurerm_windows_web_app` - correct parsing of docker configuration from WindowsFxVersion (#18251)
  * `storage`: introduce `ResourceManager` meta client
  * Update for #18763
  * add new attribtue service endpoint (#18763)
  * Update for #18709
  * New resource: `azurerm_databricks_access_connector` (#18709)
  * [Test Case]: Fix acctest for Log Analytics Workspace Data Source (#18758)
  * app service: add notes to the usage of virtual network properties (#18738)
  * fix plural usage of custom domain in description
  * Update resource "azurerm_stack_hci_cluster" with latest sdk
  * v3.27.0
  * Correct description
  * Fix typo
  * updated to include #18600
  * including #18600 fixes #18598 #18613 and #18656
  * CHANGELOG #17714
  * `azurerm_app_configuration` - support for the `encrption`, `local_auth_enabled`, `public_network_access_enabled`, `purge_protection_enabled`,and `soft_delete_retention_days` properties (#17714)
  * CHANGELOG #18588
  * `azurerm_mssql_database` - support for the `import` property. (#18588)
  * CHANELGO #18670
  * `azurerm_hdinsight_hadoop_cluster`, `azurerm_hdinsight_hbase_cluster`, `azurerm_hdinsight_interactive_query_cluster`, `azurerm_spark_cluster`: add supoort for `script_actions` (#18670)
  * CHANELOG #18699
  * `azurerm_spring_cloud_connection`,` azurerm_app_service_connection`: fix inaccurate storage blob resource id (#18699)
  * `azurerm_logic_app_standard` - fix acctest (#18722)
  * Fix broken AccTests - `azurerm_api_management` (#18735)
  * `dependencies`: updating to `v0.20221013.1082942` of `github.com/hashicorp/go-azure-sdk` (#18740)
  * CHANGELOG #18742
  * `azurerm_kubernetes_cluster` - add `workload_identity_enabled` property (#18742)
  * App Service: Fixes asserts for 2 test failures (#18748)
  * Update changelog for #18728
  * New DataSource: `data.azurerm_cosmosdb_sql_database` and `data.azurerm_cosmosdb_sql_role_definition` (#18728)
  * Update changelog for #18746
  * `azurerm_firewall_policy_rule_collection_group`- add `Mssql` as an option for `type` validation (#18746)
  * `azurerm_app_service_connection`, `azurerm_spring_cloud_connection`: Fix undetected provisioning failures (#18745)
  * CHANGELOG #18744
  * `azurerm_linux_web_app`, `azurerm_linux_web_app_slot`: add python 3.10 support in linux web app (#18744)
  * sticky_settings should use "Windows Web App" (#18750)
  * `azurerm_hpc_cache` - fix acc test (#18713)
  * Auto PR: Regenerating based on (1bac120eaa1eb9cc74d733093a90d65e20fc83ab) (#18737)
  * dependencies: updating to `v0.20221013.1033649` of `github.com/hashicorp/go-azure-sdk` (#18730)
  * [COMPLIANCE] Update MPL 2.0 LICENSE (#18727)
  * r/communication_service: adding a state migration to fix #17532 (#18704)
  * CHANGELOG #18708
  * New resource: `azurerm_sentinel_data_connector_office_atp` (#18708)
  * `azurerm_servicebus_namespace`: add namespace status wait when updating auth rule" (#18706)
  * CHANGE #18696
  * `azurerm_data_factory_integration_runtime_azure_ssis` - support Elastic Pool (#18696)
  * dns: adding state migrations/removing the case-insensitive workarounds (#18692)
  * Use Schema() instead of SchemaEnforceLowerCase() (#18720)
  * CHANGELOG #18716
  * Bump Hamilton to v0.50.0 and go-azure-helpers to v0.44.0 (#18716)
  * CHANGELOG #18317
  * New resource: `azurerm_orbital_contact_profile` (#18317)
  * CHANGELOG #18491
  * `azurerm_stream_analytics_output_servicebus_queue`: add support for `authentication_mode` (#18491)
  * `vm/vmss` - fix unexpected set of `source_image_reference` (#18671)
  * CHANGELOG #18510
  * New Resource: `azurerm_nginx_deployment` (#18510)
  * `data\azurerm_virtual_machine_scale_set` - fix `version` in `public_ip_address` (#18674)
  * CHANGELOG #17961
  * `automation_runbook` - add support of `draft` and `log_activity_trace` properties (#17961)
  * Added sku_name to ensure example can be copy-paste (#18710)
  * `azurerm_iotcentral_application` - fix default `display_name` (#18586)
  * Docs - `azurerm_firewall` and `azurerm_firewall_policy` add `Basic` sku_tire (#18665)
  * CHANGELOG #18702
  * `azurerm_dedicated_hardware_security_module`  - Support the `management_network_profile` property (#18702)
  * CHANGELOG #18472
  * Enhance - `azurerm_api_management_api` - support `contact`, `license` (#18472)
  * `azurerm_app_service_connection`: changing default behavior of `vnet_solution` (#18431)
  * updating to include #18700
  * `azurerm_iothub_dps_certificate` - Fix `name` validation (#18694)
  * fix acc test TestAccAzureRMDnsAAAARecord_RecordsToAlias (#18693)
  * fix set identity and clusterid
  * Update for #18130
  * fix: AKS use currentOrchestratorVersion if orchestratorVersion is missing (#18130)
  * update to use disks package instead of compute
  * Fix `*_extensionsAutomaticUpgradeWithServiceFabricExtension` (#18669)
  * azurerm_spring_cloud_connection, azurerm_app_service_connection: renaming documentation name (#18672)
  * Update changelog for #18660
  * `azurerm_logic_app_workflow` - can now be updated when associated with `integration_service_environment_id` (#18660)
  * v3.26.0
  * updating to include #18654 and #18629
  * Update for #16741
  * `kubernetes_cluster` `kubernetes_cluster_node_pool` - `message_of_day` `scale_down_mode` `workload_runtime`  `load_balancer_profile/managed_outbound_ipv6_count` (#16741)
  * Updating based on 04fed301
  * Update for #16657
  * `kubernetes_cluster` -`pod_cidrs`/`service_cidrs` (#16657)
  * GHA: update env var for gh cli in workflow (#18647)
  * fix clients_gen.go after accidental removal of import (#18646)
  * `azurerm_cdn_frontdoor` - Add CDN FrontDoor example configurations (#16671)
  * loadtest: refactoring
  * refactor: updating `user_assigned_identity` to be a typed resource
  * Warn about using 'service' as a diagnostic name (#18627)
  * msi: adding an auto-registration file
  * github actions: adding `contents: read` as required
  * updating to include #18630
  * dependencies: updating to `v0.43.0` of `github.com/hashicorp/go-azure-helpers`
  * updating to include #18628
  * automation: support for auto-Service and Client registration
  * dependencies: updating to v0.20221004.1155444 of github.com/hashicorp/go-azure-sdk
  * Remove warning about OIDC feature flag needing to be registered (#18625)
  * updating to include #18601
  * `azurerm_managed_disk` `azurerm_snapshot`: Deprecate `enabled` in `encryption_settings` (#15317)
  * Handle gone gracefully in read for azurerm_mssql_server_dns_alias (#18619)
  * CHANGELOG #18436
  * `azurerm_batch_pool` - support node_deallocation_method dynamic_vnet_assignment_scope  source_port_ranges (#18436)
  * CHANGELOG #18396
  * `azurerm_linux/windows_function_app_slot` - Read correct appsettings (#18396)
  * CHANGELOG #18589
  * New resource `azurerm_iotcentral_application_network_rule_set` (#18589)
  * `azurerm_iotcentral_application` - fix `sku` `template` and update method (#18590)
  * `azurerm_key_vault_key` - remove `oct` from docs and code (#18608)
  * docs: add consumption tier example to apim docs (#18604)
  * Fix bug in sample for ACR geo replications (#18602)
  * dependencies: updating to v0.42.0 of github.com/hashicorp/go-azure-helpers
  * document: removing addition word in `servicebus_namespace_network_rule_set` doc (#18592)
  * v3.25.0
  * Update CHANGELOG.md
  * Fix `TestAccOrchestratedVirtualMachineScaleSet_publicIPSkuName` (#18570)
  * Add ForceNew to name of azurerm_iothub_route (#18565)
  * Updating to include #18231
  * Updating to include #18231 fixes #18063 #18249 #18333 #18370 #18470 #18551
  * fix typo
  * data source `azurerm_client_config` `azurerm_public_maintenance_configurations` `azurerm_public_ips` - Use static id instead of timestamp (#18526)
  * CHANGELOG #18566
  * `r/azurerm_healthcare_fhir` - `public_network_access_enabled` added (#18566)
  * `azurerm_orchestrated_virtual_machine_scale_set` - set `network_inter… (#18569)
  * CHANGELOG #18571
  * `azurerm_healthcare_fhir_service` - `oci_artifact` support (#18571)
  * CHANGELOG #18539
  * `azurerm_automation_software_update_configuration` - fix windows update classification use a comma separate string (#18539)
  * CHANGELOG #18508
  * Enhance: `azurerm_api_management` - Support `additional_location.gateway_disabled`, `certificate_source`, `certificate_status` (#18508)
  * Docs: fix missing word in index file (#18572)
  * docs: update default value for `prevent_deletion_if_contains_resources` (#18573)
  * CHANGELOG #18406
  * `azurerm_linux_virtual_machine` `azurerm_windows_virtual_machine` - support for `gallery_applications` (#18406)
  * [hot-fix] `azurerm_log_analytics_linked_storage_account` - add StateUpgraders in schema (#18556)
  * TestCase: Fix TC for Log Analytics Data Source Windows Event (#18559)
  * CHANGELOG #18564
  * `azurerm_iotcentral_application` - support for `identity` and `public_network_access_enabled` (#18564)
  * Changelog for #18335
  * Update to go-azure-helpers v0.41.0
  * `azurerm_eventhub_namespace`: update docs (#18555)
  * tooling: bumping to v3 of the checkout github action
  * CHANGELOG #18557
  * Dependencies: update `go-azure-sdk` to `v0.20220921.1082044` (#18557)
  * CHANGELOG #18419
  * Data source: `azurerm_key_vault_certificate_data` - fix PEM private key block header for EC keys (#18419)
  * Updating documentation based on actual arguments for data_protection_backup_instance_blob_storage (#18451)
  * `azurerm_express_route_xxx` - set all bandwith of express route connection 1 gbps (#18442)
  * CHANGELOG #18521
  * `d/azurerm_databricks_workspace` - Add `location` (#18521)
  * Enhacne - `azurerm_api_management_logger` - Recreate if `resource_id` changed (#18527)
  * `azurerm_monitor_data_collection_rule_association` - fix example config in doc (#18536)
  * `azurerm_automation_schedule` - fix computed `interval` property value exists in CustomizeDiff (#18538)
  * `azurerm_eventhub_namespace`: remove zone redundant restrictions from premium namespace (#18542)
  * CHANGELOG #18116
  * `azurerm_log_analytics_linked_storage_account` - fix `data_source_type` case sensitivity (#18116)
  * CHANGELOG #17999
  * azurerm_storage_account  - support for the `multichannel_enabled` property (#17999)
  * `azurerm_automation_module` - support update existing global automation module version (#18434)
  * `compute` - ensure `azurerm_marketplace_agreement` cleaned up before vm/vmss test (#18522)
  * `azurerm_subscription_policy_assignment` - `allowed location policy` in subscription assignment should contain all location in AccTest (#18428)
  * CHANGELOG #18469
  * Enhance - all machine learning resource - bump API to `v2022-05-01` (#18279)
  * `comupte` - fix `health_probe_id` update and network tests (#18392)
  * CHANGELOG #18469
  * `azurerm_virtual_hub_bgp_connection` - support for `virtual_network_connection_id` property (#18469)
  * `azurerm_windows_function_app`, `azurerm_linux_function_app`: add usage tips (#18512)
  * `azurerm_linux_function_app_slot`: remove `resource_group_name` property (#18524)
  * Correct VM image definition identifier validation (#18421)
  * Docs: Fix wrong attributes in azurerm_data_protection_backup_instance_blob_storage (#18457)
  * Run 'go mod vendor'
  * Rename '*token_path' to '*token_file_path'
  * Add ability to specify path to OIDC token
  * docs: Update tense in resource_group note (#18530)
  * `compute` - fix tests with `ZRS` storage type (#18520)
  * `azurerm_dev_test_lab`: Deprecate `storage_type` (#18461)
  * `azurerm_application_gateway` - fix T`estAccApplicationGateway_sslCertificateManualChangeIgnoreChange` (#18492)
  * CHANGELOG #18516
  * Added support of `customer_managed_key` into `azurerm_cognitive_account` (#18516)
  * CHANGELOG #18056
  * `azurerm_data_factory_flowlet_data_flow` `azurerm_data_factory_data_flow` - support for the `rejected_linked_service` property (#18056)
  * `aurerm_public_ip` - fix AccTest failure of `TestAccPublicIpStatic_ipTags` and `TestAccDataSourcePublicIP_static` (#18384)
  * CHANGELOG #18486
  * `azurerm_orchestrated_virtual_machine_scale_set` - support for the `user_data_base64` property (#18486)
  * Docs: Fix swapped property descriptions for  `ramp_up_minimum_hosts_percent ` and `ramp_up_capacity_threshold_percent ` (#18490)
  * Fix docs for data.azurerm_automation_account (#18504)
  * Docs: Fix possible value of `threat_intel_mode` in `azurerm_firewall` resource (#18511)
  * azurerm_mssql_elasticpool: gen5 with 8-10vCPU supports 2048 GB max data size (#18517)
  * v3.24.0
  * azurerm_web_application_firewall_policy - Add missing match_variable options (#18420)
  * CHANGELOG #17671
  * `azurerm_managed_disk` - support for `PremiumV2_LRS` (#17671)
  * CHANGELOG #18025
  * azurerm_private_endpoint - support for the `custom_network_interface_name` property (#18025)
  * CHANGELOG #18467
  * ID casing fixes (#18467)
  * CHANGELOG #17006
  * New Resource: `azurerm_monitor_alert_processing_rule_action_group`, `azurerm_monitor_alert_processing_rule_suppression` (#17006)
  * CHANGELOG #17902
  * New Resource: `azurerm_automation_software_update_configuration` (#17902)
  * TestCase: Fix TCs for CosmosDB Account (#18435)
  * CHANGELOG #18438
  * `azurerm_monitor_metric_alert` - fix ordering of multi `criteria` (#18438)
  * `azurerm_linux_function_app_slot`: remove application insight restrictions. (#18477)
  * CHANGELOG #18478
  * Data Source: `azurerm_automation_account` - support of `identity` property (#18478)
  * Add missing identity_ids argument reference to cosmos account docs (#18449)
  * `azurerm_virtual_hub` - fix acc test `TestAccVirtualHub_basic` and `TestAccDataSourceAzureRMVirtualHub_basic` (#18404)
  * CHANGELOG #18405
  * Data Source: `azurerm_storage_account` - support for the `azure_files_identity_based_auth` property (#18405)
  * `compute` - remove invalid test `TestAccImage_standaloneImageZoneRedundant` (#18407)
  * CHANGELOG #18409
  * Enhance - `azurerm_api_management_api_operatio` - support config `example`,  `schema_id` and `type_name` (#18409)
  * `azurerm_marketplace_agreement` - fix acc tests (#18414)
  * `compute` - fix test `TestAccWindowsVirtualMachineScaleSet_imagesFromCapturedVirtualMachineImage` (#18423)
  * `azurerm_kusto_cluster` - add new skus to property `sku` by customer request. (#18425)
  * `azurerm_xxx_policy_assignment` - fix AccTest for checking list existance (#18427)
  * `windows_web_app_resource`, `linux_web_app_slot_resource`, `windows_function_app_slot_resource`, `linux_function_app_resource` - `ip_address` supports IP/CIDR range as input (#18429)
  * CHANGELOG #18430
  * `azurerm_sentinel_alert_rule_scheduled` - support for the `techniques` property (#18430)
  * CHANGELOG #18437
  * `azurerm_linux_virtual_machine` `azurerm_windows_virtual_machine` - support for `patch_assessment_mode` (#18437)
  * `azurerm_subnet_route_table_association` : Fix property `route_table_id` to use `validate.RouteTableID` validation instead of `azure.ValidateResourceID` (#18440)
  * CHANGELOG #18441
  * `virtual_machine_extension` `virtual_machine_scale_set_extension` - support for `failure_suppression_enabled` (#18441)
  * fmt
  * updating to include #18446
  * `document` - fix default value in Virtual Machine Scale Set (#18432)
  * go mod vendor
  * dependencies: updating to version `v0.20220916.1125744` of `github.com/hashicorp/go-azure-sdk`
  * cleanup: removing a file leftover from local dev
  * v3.23.0
  * CHANGELOG #18394
  * Enhance - `azurerm_api_management_api_schema` support config `components` and `definitions` (#18394)
  * `compute` - Fix acc tests (#18398)
  * `azurerm_shared_image_resource` - Fix setting default `architecture` (#18400)
  * `Consumption` - fix failed tests (#18354)
  * CHANGELOG #17731
  * `azurerm_logic_app_standard` - expose `virtual_network_subnet_id` for vNet integration (#17731)
  * CHANGELOG #18378
  * `azurerm_cosmosdb_account` - Add UserAssigned identity support (#18378)
  * CHANGELOG #18045
  * New Data Source: `private_dns_zone_virtual_network_link` (#18045)
  * CHANGELOG #18037
  * azurerm_*_policy_remediation - should use policy_definition_reference_id in favor of policy_definition_id  Fix (#18037)
  * CHANGELOG #17104
  * azurerm_batch_pool's  support user_assigned_identity_id (#17104)
  * User-assigned managed identity support for Logic Apps Standard (#18109)
  * Added Resource naming restrictions to docs (#18150)
  * `azurerm_postgresql_flexible_server`: limit max storage size for azure flexible server to 16TB (#18166)
  * `azurerm_disk_pool_iscsi_target_lun_resource` `azurerm_disk_pool_iscsi_target_resource` `azurerm_disk_pool_managed_disk_attachment_resource` - Extend create and delete timeouts (#18339)
  * `azurerm_[linux|windows]_function_app_slot` remove incorrect schema constraint (#18343)
  * `azurerm_firewall` - fix AccTest `TestAccFirewall_withZones` (#18359)
  * `azurerm_application_insights_analytics_item` - fix failed test case `TestAccApplicationInsightsAnalyticsItem_multiple` (#18379)
  * Make location required in `azurerm_network_watcher_flow_log` (#18364)
  * `azurerm_automation_webhook` - fix missing `URI` of request body when `uri` provided (#18380)
  * `azurerm_consumption_budget_subscription` - fix notification keys (#18385)
  * Features: log_analytics_workspace block change default value for permanently_delete_on_destroy flag (#18390)
  * invert disk type matching logic to be more explicit
  * Docs: Add a note about flow log overwriting existing storage lifecycle management rules (#18369)
  * Update changelog for #18348
  * `azurerm_netapp_volume`: add extra validation when `data_protection_snapshot_policy.0. snapshot_policy_id` is empty (#18348)
  * `azurerm_firewall_nat_rule_collection` - fix AccTest `TestAccFirewallNatRuleCollection_multipleRules` (#18353)
  * `azurerm_monitor_private_link_scoped_service` - support `Data Collection endpoint` for the `linked_resource_id` property (#18356)
  * `azurerm_application_insights` - fix failed test case `TestAccApplicationInsights_disableGeneratedRule` (#18357)
  * `azurerm_application_insights_api_key` - fix failed test case `TestAccApplicationInsightsAPIKey_no_permission` (#18358)
  * CHANGELOG #18226
  * `azurerm_batch_pool` - support `user_accounts`, `data_disks` and etc properties (#18226)
  * `azurerm_management_group` - fix failed tests (#18306)
  * CHANGELOG #18314
  * `azurerm_eventhub_namespace`: update public_network_access settings (#18314)
  * CHANGELOG #18318
  * New Datasource: `azurerm_monitor_data_collection_rule` (#18318)
  * `azurerm_resource_group_template_deployment` - fix nested resources cannot be deleted (#18319)
  * CHANGELOG #18320
  * `azurerm_automation_account` - support for the `hybrid_service_url` property (#18320)
  * `legacy` - Fix tests (#18329)
  * Argument Update: argument "authentication_mode" (#18336)
  * Fix `TestAccLinuxVirtualMachine_diskOSStorageTypePremiumZRS` (#18331)
  * `iotcentral` - Fix test locations (#18340)
  * Missing Argument - Added missing argument "database" from the argument reference in the docs of resource "azurerm_stream_analytics_output_mssql" (#18341)
  * Typo in the docs: (#18342)
  * Event Hub namespace identity attribute description update to include the support for `UserAssigned` type (#18330)
  * Fix azurerm_monitor_data_collection_rule_association documentation example (#18327)
  * Make each geo_location in example usage unique (#18332)
  * v3.22.0
  * CHANGELOG #17948
  * New Resource: `azurerm_monitor_data_collection_rule_association` (#17948)
  * CHANGELOG #18247
  * `azurerm_mssql_database` - add support for maintenance_configuration_name (#18247)
  * `azurerm_monitor_action_group` - fix `event_hub_receiver` when dependent event_hub is not in the same resource group (#17335)
  * `azurerm_container_registry` - Doc: mention the expected order of `georeplications` (#18004)
  * `Resources` - fix failed tests (#18280)
  * make terrafmt
  * CHANGELOG #15939
  * New resource: `azurerm_container_registry_token_password` (#15939)
  * CHANGELOG #17927
  * New Resource: `azurerm_automation_watcher` (#17927)
  * #18259 Added support for Node.js 18 version in linux and windows function apps. (#18283)
  * Fix use of versioned source_image_id from gallery (#18292)
  * `azurerm_spring_cloud_certificate` - fix testcase (#18207)
  * TestCase: Fix TCs for NetApp Volume (#18209)
  * TestCase: Fix TCs for CosmosDB Cassandra Table (#18229)
  * `azurerm_mssql_managed_instance` - Fix the sku.name returned from API has changed (#18278)
  * Correct the sample import resource path for azurerm_servicebus_namespace_authorization_rule (#18285)
  * CHANGELOG #18291
  * azurerm_log_analytics_solution - add state migration for ID case (#18291)
  * `azurerm_monitor_autoscale_setting` - fix failed test case (#18295)
  * `azurerm_blueprint_assignment` - fix failed tests (#18296)
  * Update CHANGELOG.md
  * `iothub` - switch `dps` to `go-azure-sdk` (#18299)
  * Fix `TestAccManagedDisk_import` (#18303)
  * Docs: Update service principal client secret docs to reflect example code (#18308)
  * Removing sql_compression_enabled as its not a vaild attribute (#18301)
  * azurerm_linux_web_app and azurerm_linux_web_app_slot: Fixing docs (#18290)
  * updating to include #18282
  * update go-azure-sdk to v0.20220907.1111434 and adjust for fixed plurals
  * `azurerm_sentinel_alert_rule_scheduled` - support for new values in `tactics` property (#18059)
  * Doc Fix: Remove HashiCorp Learn References from Overview Page (#18276)
  * Doc Fix: CosmosDB SQL Container (#18262)
  * Update changelog for #18264
  * `azurerm_synapse_sql_pool` - `name` has correct validation error message  (#18264)
  * Update for #16437
  * `kubernetes_cluster` -`gmsa` (#16437)
  * `azurerm_mssql_managed_instance_vulnerability_assessment` - Fix wrong location setting in test cases (#18246)
  * CHANGELOG #17846
  * `azurerm_hdinsight_kafka_cluster`, `azurerm_hdinsight_spark_cluster`, `azurerm_hdinsight_interactive_query_cluster`, `azurerm_hdinsight_hbase_cluster`, `azurerm_hdinsight_hadoop_cluster` - Add support for `extension` property (#17846)
  * CHANGELOG #17876
  * New Resource: `azurerm_api_management_api_tag_description` support config API tag description (#17876)
  * azurerm_windows_web_app_slot - fix zip_deploy_file on Update (#18002)
  * `azurerm_service_plan` - update the limitation of `maximum_elastic_worker_count` (#18156)
  * CHANGELOG #17860
  * New Resource: `azurerm_spacecraft` (#17860)
  * CHANGELOG #18158
  * New Resource: `azurerm_api_management_schema` support config global schema (#18158)
  * CHANGELOG #18175
  * New Resource: `azurerm_automation_source_control` (#18175)
  * `azurerm_monitor_action_group` - fix tests and doc of `itsm_receiver` (#18190)
  * CHANGELOG #17812
  * Deprecate `soap_pass_through` in favour of `api_type` (#17812)
  * `azurerm_monitor_aad_diagnostic_setting` - fix failed test (#18192)
  * CHANGELOG #18115
  * `azurerm_kubernetes_cluster` - support for the `edge_zone` property (#18115)
  * CHANGELOG #17489
  * Update Desktop Virtualization API to 2022-02-10; scheduled_agent_updates  supports scheduled_agent_updates (#17489)
  * Update changelog for #18230
  * `azurerm_mssql_database` - `license_type ` is now also Computed (#18230)
  * docs: replace azurerm_mssql_server with azurerm_mssql_failover_group in title (#18233)
  * v3.21.1
  * azurerm_log_analytics_data_export_rule - add a state migration to work around id casing (#18240)
  * CHANGELOG #18240
  * CHANGELOG #18239
  * Revert "Update ACR API version to 2022-02-01-preview and add up the new properties" (#18239)
  * v3.21.0
  * update to include properties for #17571
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * CHANGELOG #17893
  * New resource: `azurerm_automation_hybrid_runbook_worker` (#17893)
  * `azurerm_policy_definition` - expose `role_definition_ids` property if exists (#18043)
  * CHANGELOG #18043
  * Also allow "OptionalInteractiveUser" as client_certificate_mode (#18214)
  * docs: mariadb_database: use utf8mb4_unicode_520_ci (#18212)
  * WIP `azurerm_active_directory_domain_service` - Update acctest to use existing aad SP (#18216)
  * CHANGELOG #18211
  * `azurerm_stream_analytics_reference_input_mssql`: add support for `table` property (#18211)
  * `azurerm_role_definition` - Increase the continuous count of post delete checks (#18208)
  * Updating to include #18010
  * adding #18010
  * `azurerm_postgresql_flexible_server_*` - Add lock to avoid operation conflict (#18159)
  * Fix test `TestAccIotHubDPS_linkedHubs` (#18153)
  * CHANGELOG #18042
  * `azurerm_batch_pool` - support for the `mount` property (#18042)
  * CHANGELOG #17962
  * New Resource : `azurerm_api_management_gateway_host_name_configuration` (#17962)
  * updated to include #17571
  * including #17571
  * [Document]`azurerm_kubernetes_cluster_node_pool` - Add `host_group_id` information to the document. (#18217)
  * Fixed basic batch account example. (#18219)
  * `azurerm_monitor_scheduled_query_rules_alert` - Add `query_type` Enums (#18193)
  * `azurerm_logz_monitor` - fix failed tests (#18196)
  * Fix name check in windows web app (#18201)
  * Docs: Supplementary description of possible values of keyvault secret ID (#18191)
  * CHANGELOG #17456
  * `azurerm_role_assignment` - Support `scope` to be `/providers/Subscription` (#17456)
  * CHANGELOG #18154
  * `azurerm_cosmosdb_cassandra_cluster` - support for the `HoursBetweenBackups` property (#18154)
  * Policy Mode Docs (#18181)
  * remove preview comment for spot node pools and fix identity block in docs (#18180)
  * updating to include #18183
  * Update changelog for #18098
  * `log_analytics` - switch to using hashicorp/go-azure-sdk (#18098)
  * update sdk to v0.20220830.1105041, adjust casing fixes in container_group and service_fabric_managed_cluster
  * Update for #18124
  * feat(AKS): add support for spot node pools upgrades (#18124)
  * CHANGELOG #17351
  * `azurerm_hdinsight_kafka_cluster`, `azurerm_hdinsight_spark_cluster`, `azurerm_hdinsight_interactive_query_cluster`, `azurerm_hdinsight_hbase_cluster`, `azurerm_hdinsight_hadoop_cluster` - add support for `disk_encryption_properties` property (#17351)
  * CHANGELOG Fix typo
  * CHANGELOG #17926
  * Update ACR API version to 2022-02-01-preview and add up the new properties (#17926)
  * v3 Upgrade doc: adding up the change for `customer_managed_key` of `azurerm_storage_account`
  * Hotfix - Recover Mistakenly Deleted DCE Client Code (#18174)
  * CHANGELOG #17879
  * new resource azurerm_api_management_gateway_certificate_authority (#17879)
  * CHANGELOG #17881
  * New Resource: `azurerm_automation_hybrid_runbook_worker_group` (#17881)
  * CHANGELOG #18005
  * `azurerm_storage_account` - support for the `public_network_access_enabled` property (#18005)
  * Support for static IP configuration in azurerm_private_endpoint #13061 (#17864)
  * Permit additional partner_id formats (#17441)
  * `azurerm_servicebus_namespace` - Adding support of property `public_network_access_enabled`, `minimum_tls_version` (#17805)
  * CHANGELOG #15120
  * New resource: `azurerm_container_registry_task_schedule` (#15120)
  * Docs: Fix outdated reference link of `timezone` of `azurerm_automation_schedule` (#18160)
  * CHANGELOG #18151
  * `azurerm_iothub_dps` - support for `data_residency_enabled` property (#18151)
  * `azurerm_windows_function_app`, `azurerm_linux_function_app`: fix the `runtime_scale_monitoring_enabled` not being set issue (#18149)
  * CHANGELOG #18137
  * `azurerm_stream_analytics_reference_input_blob` - support for `authentication_mode` (#18137)
  * CHANGELOG #18133
  * New Resource: `azurerm_cosmosdb_sql_dedicated_gateway` (#18133)
  * CHANGELOG #18120
  * `azurerm_stream_analytics_output_cosmosdb` - support for `partition_key` property (#18120)
  * CHANGELOG #18117
  * `azurerm_stream_analytics_output_powerbi` - support for `token_user_principal_name` and `token_user_display_name` properties (#18117)
  * CHANGELOG #18096
  * `azurerm_stream_analytics_output_eventhub`, `azurerm_stream_analytics_output_mssql`, `azurerm_stream_analytics_output_servicebus_topic` - support for `authentication_mode` property (#18096)
  * CHANGELOG #16367
  * CHANGELOG @#17992
  * New Data Source: `azurerm_monitor_data_collection_endpoint` (#17992)
  * `azurerm_monitor_diagnostic_setting`: adding support for `category_group` (#16367)
  * `azurerm_web_pubsub`, `azurerm_web_pubsub_hub` resource: Migrating `id` and `web_pubsub_id` (#17823)
  * CHANGELOG #17805
  * CHANGELOG #17798
  * New Resource: `azurerm_api_management_product_tag` - Support API Management product tag (#17798)
  * CHANGELOG #17767
  * Enhance - `azurerm_redis_cache` - Recreate Redis cache when downgrade the SKU (#17767)
  * CHANGELOG #17744
  * new resource: azurerm_search_shared_private_link_service (#17744)
  * CHJANGELOG #17538
  * New Resource: `azurerm_automation_connection_type` (#17538)
  * CHANGELOG #17313
  * `policy_remediation_xxx_resource` - support for the `resource_count`, `parallel_deployments` and `failure_percentage` properties (#17313)
  * CHANGELOG #15999
  * New resource: `azurerm_sentinel_alert_rule_nrt` (#15999)
  * Update to include #16907
  * New Resource: `azurerm_spring_cloud_connection` and `azurerm_app_service_connection` (#16907)
  * Doc Fix: Cosmos SQL DB Resource name (#18170)
  * CHANGELOG #15967
  * `Dependency` New Resource - azurerm_healthcare_medtech_service (#15967)
  * Revert "Update feature request template (#18167)" (#18168)
  * Update feature request template (#18167)
  * Update changelog for #18161
  * `azurerm_spring_cloud_service` - ignore default zero value for `read_timeout_seconds` (#18161)
  * update docs for cdn_frontdoor_(firewall/security)_policy (#18163)
  * Correct resource name references in documentation (#18091)
  * For azurerm_static_site, documentation does not mention identity and principal_id access (#18125)
  * Docs: Fix wrong import command and config in  `azurerm_monitor_scheduled_query_rules_alert_v2` (#18136)
  * fix(docs):  PostgreSQL flexible server  PointInTimeRestore (#18145)
  * Update changelog for #18142
  * `azurerm_kubernetes_cluster` - `kube_config` is now set when AAD is enabled for a v1.24 cluster (#18142)
  * Removed typo space in README.md hyperlink (#18138)
  * azurerm_app_configuration: add support for public_network_access (#17549)
  * `HDInsight`: Fix autoscale related failing tests (#17795)
  * Update for #17840
  * New Resource: `azurerm_dashboard_grafana` (#17840)
  * Update for #17929
  * New Resource: `azurerm_log_analytics_query_pack_query` (#17929)
  * v3.20.0
  * Update changelog for #18041
  * `azurerm_mssql_elastic_pool` - list of values for `maintenance_configuration_name` is now correct (#18041)
  * Update changelog for #18131
  * `data.azurerm_kubernetes_cluster` - `kube_config` is now set when AAD is enabled for a v1.24 cluster (#18131)
  * Changelog for #18118
  * Add generic OIDC authentication (#18118)
  * Update changelog for #18106
  * azurerm_postgresql_flexible_server - update point_in_time_restore_time_in_utc to RFC3339 (#18106)
  * azurerm_sql_managed_instance_failover_group in docs (#18111)
  * update for #18100
  * Dependencies: update `go-azure-sdk` to `v0.20220824.1090858` (#18100)
  * Update for #18101
  * `consumption` -  switch to `hashicorp/go-azure-sdk` (#18101)
  * added missing tags property
  * Update for #18070
  * Update for #18074
  * `azurerm_kubernetes_cluster_node_pool` - nil check first element when expanding upgrade settings (#18074)
  * Update changelog for #18061
  * `azurerm_data_factory_dataset_json` - `filename` and `path` in `azure_blob_storage_location` block can now be empty (#18061)
  * CHANGELOG #17765
  * New Resource: `azurerm_backup_policy_vm_workload` (#17765)
  * CHANGELOG #17772
  * New Resource: `azurerm_monitor_scheduled_query_rules_alert_v2` (#17772)
  * Update service_principal_oidc.html.markdown
  * Add warning that OIDC auth only works in GitHub Actions
  * dependencies: update go-azure-sdk to v0.20220819.1134400 (#18046)
  * Update the document about the import id for `azurerm_servicebus_namespace_network_rule_set` (#18055)
  * cosmosdb - prevent panic (#18070)
  * v3.19.1
  * Update for #18048
  * parse resource ids insensitively in the read functions (#18048)
  * v3.19.0
  * CHANGELOG #17114
  * `azurerm_cdn_endpoint_custom_domain` - user managed https allows key vault secret (#17114)
  * CHANGELOG #16987
  * `azurerm_data_factory_data_flow` `azurerm_data_factory_flowlet_data_flow` -  `flowlet` (#16987)
  * `d/azurerm_virtual_machine_scale_set`: Add scale set instances details (#14754)
  * CHANGELOG #18035
  * App Service: fix content settings and MSI storage access (#18035)
  * wait LRO (#17448)
  * CHANGELOG #18036
  * Add data sources for every type of private DNS record (#18036)
  * CHANGELOG #16758
  * Enhacne: `azurerm_batch_account ` - storage_account_authentication_mode, storage_account_node_identit, allowed_authentication_modes (#16758)
  * `azurerm_private_endpoint` Try to add retry on creation (#16315)
  * CHANGELOG #17954
  * switch maintenance sdk to use hashicorp/go-azure-sdk (#17954)
  * `azurerm_kubernetes_cluster` - improve docs for `kubelet_identity` (#18027)
  * remove resource_discovery_mode attribute (#17008)
  * Update for #18028
  * Data Source: `azurerm_windows_web_app` - add missing schema definition for 'virtual_network_subnet_id' (#18028)
  * CHANGELOG #17651
  * `azurerm_application_gateway` - support for the `globalConfiguration` property (#17651)
  * CHANGELOG #17630
  * `azurerm_spring_cloud_app` - `public_endpoint_enabled`; `azurerm_spring_cloud_gateway_route_config`- support for the `open_api`;`azurerm_spring_cloud_service` - `log_stream_public_endpoint_enabled``read_timeout_seconds` properties (#17630)
  * Update CHANGELOG.md
  * Update CHANGELOG to include #17770
  * `azurerm_lb_backend_address_pool_address` - support for the `backend_address_ip_configuration_id` property (#17770)
  * Update CHANGELOG to include #17365
  * `azurerm_log_analytics_workspace` - support for the `cmk_for_query_forced` property (#17365)
  * Update CHANGELOG to include #17137
  * `azurerm_key_vault_access_policy` - Data source fix lowercased return values for `(key|secret|certificate)_permissions` for provider v4.0 (#17137)
  * CHANGELOG #18014
  * `azurerm_windows_function_app` and `azurerm_windows_function_app_slot` fix bug in setting value for 'WindowsFxString' (#18014)
  * Update changelog for #15782
  * Update changelog for #17986
  * `dns` - switch to `go-azure-sdk` (#17986)
  * Update for #17715
  * [New Resources:] `azurerm_cdn_frontdoor_firewall_policy` and `azurerm_cdn_frontdoor_security_policy` (#17715)
  * Update for #18015
  * Dependencies: update `go-azure-helpers` to `v0.39.1` (#18015)
  * Fix typo in doc
  * update changelog for #17700
  * dataprotection - swap to hashicorp/go-azure-sdk  (#17700)
  * Update CHANGELOG to include #17757
  * `azurerm_web_application_firewall_policy` - support for the `excluded_rule_set ` property (#17757)
  * Update changelog for #13899
  * `azurerm_application_gateway`: Support for `components` in `rewrite_rule_set.rewrite_rule.url` (#13899)
  * CHANGELOG #17756
  * `azurerm_data_factory_integration_runtime_azure_ssis` -  support for the `express_vnet_injection` property (#17756)
  * CHANGELOG #17416
  * `azurerm_batch_pool` - Added support for `identity_reference` into `container_registries` (#17416)
  * CHANGELOG #17853
  * `azurerm_active_directory_domain_service` - Support for `kerberos_armoring_enabled` and `kerberos_rc4_encryption_enabled` (#17853)
  * CHANGELOG #17635
  * new resource: azurerm_eventhub_namespace_schema_group (#17635)
  * CHANGELOG #17454
  * `azurerm_automation_account`  - support for the `encryption` and `local_authentication_enabled` property (#17454)
  * fix spring cloud enterprise tier config server failure (#17856)
  * CHANGELOG #17768
  * `azurerm_shared_image_version` - support for `blob_uri`, `storage_account_id` (#17768)
  * Migrating servicebus auth rule ID (#17824)
  * CHANGELOG #17842
  * `firewall_policy_resource` - support for the `private_ranges` and `allow_sql_redirect`  properties (#17842)
  * azurerm_postgresql_server - Fix legacy database ids handling (#17871)
  * Fix outputs for `azurerm_windows_function_app` and `azurerm_linux_function_app`, both resource and data source (#17361)
  * CHANGELOG #17116
  * `azurerm_storage_account` support for setting defaultToOAuthAuthentication (#17116)
  * Update azurerm_network_interface to correctly reflect what dynamic means in azure context (#15264)
  * CHANGELOG #17250
  * resource `azurerm_shared_image` - add architecture option. (#17250)
  * CHANGELOG #17226
  * Allow Delete eviction policy on Azure VMs (#17226)
  * CHANGELOG #16208
  * `data.azurerm_management_group` - Add new attributes: `management_group_ids`, `all_management_group_ids` and `all_subscription_ids` (#16208)
  * `azurerm_key_vault_{key,secret,certificate}`: Resource/DataSource increase read timeout from 5min to 30min (#17782)
  * `azurerm_storage_management_policy` - Relieve the rule name validation (#17973)
  * CHANGELOG #17934
  * `azurerm_automation_account` - support for the `private_endpoint_connection` property (#17934)
  * azurerm_key_vault_access_policy - Update KeyVault Access Policy Key Permissions with new parameters (#17895)
  * MSSQL size increase to 16384 (#17712)
  * azurerm_application_gateway - Mark probe.match.body as not required (#17696)
  * CHANGELOG #16595
  * `azurerm_mssql_server` - Fix `azurerm_mssql_server` automatically sets `minimum_tls_version` even if not provided issue (#16595)
  * update for #17998
  * Dependencies: bump `go-azure-sdk` to `v0.20220815.1092453` (#17998)
  * Docs: fix diagnostic_categories typo (#17995)
  * Updated for #17996
  * Dependencies: bump `go-azure-helpers` to `v0.39.0` (#17996)
  * Docs: move lb datasource to 'Load Balancer' subcategory
  * remove duplicate yaml section created by merge to main (#17993)
  * GHA: add explicit workflow permissions (#17966)
  * Updating changelog for #17616
  * dedicated hosts: refactoring to use `hashicorp/go-azure-sdk` (#17616)
  * gha - allow waiting-response to be added/removed from forked repo prs (#17985)
  * CHANGELOG #17477
  * Add data sources for every type of public DNS record (#17477)
  * `mariadb` - switch to `go-azure-sdk` (#17939)
  * swap to go-azure-sdk (#17984)
  * Revert "Update naming validation to allow length to be 1 - 128 (#17965)" (#17977)
  * Fix grammar for `waf_configuration.enabled` (#17978)
  * Add example for Private Link Scope (#17873)
  * CHANGELOG ##17552
  * azurerm_key_vault : Support public_network_access_enabled proptery for resource azurerm_key_vault (#17552)
  * bugfix: azurerm_application_gateway: unable to create private DNS record out of frontend_ip_configuration[*].private_ip_address (#17632)
  * CHANGELOG #17766
  * `d\images`: Use fixed id (#17766)
  * CHANGELOG #17790
  * mssql_elastic_pool - add support for maintenance_configuration_name (#17790)
  * fix KeyVault test: `TestAccKeyVault_softDeleteRecoveryDisabled` (#17878)
  * CHANGELOG #17904
  * `data_protection_backup_policy_postgresql_resource`: fix provider crash if given an empty criteria block (#17904)
  * `r\virtual_machine_extension` `r\virtual_machine_scale_set_extension`: Fix validation of `name` (#17941)
  * internal/services/cognitive: add kind = "OpenAI" (#17959)
  * `service_fabric_mananged_cluster_resource`: fix authentication block (#17960)
  * Fix Import As Exists Error Message of`azurerm_monitor_diagnostic_setting` (#17963)
  * CHANGELOG #17964
  * azurerm_disk_encryption_set: fix creation issue when disk encryption set and key vault in different subscriptions (#17964)
  * `cdn` `iotcentral` `network` - `documents example improvement` (#17447)
  * clarify how to associate an App Service Environment v3 with a Service Plan (#17694)
  * feat: update the Linux /window function app at v3 provider for doc and testcase (#16609)
  * Add azurerm_subnet_network_security_group_association to associate we… (#17917)
  * v3.18.0
  * azurerm_cognitive_account - update docs wrt bing search types (#17958)
  * Update naming validation to allow length to be 1 - 128 (#17965)
  * updating to include #17905
  * depednencies: updating to `v0.20220809.1122626` of `github.com/hashicorp/go-azure-sdk`
  * dependencies: updating to `v0.20220805.1100614` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17523
  * Update document for property `engine` in `azurerm_kusto_cluster` (#17695)
  * gha - fix waiting-response label (#17952)
  * Update for #16299
  * DataSource: `azurerm_blueprint_definition` - Fix `version` property output (#16299)
  * make terrafmt (#17947)
  * remove make tools from some actions (#17946)
  * CHANGELOG #17101
  * `azurerm_servicebus_subscription`: support client affine property, `azurerm_servicebus_subscription_rule`: add property `sql_filter_compatibility_level` (#17101)
  * CHANGELOG #17338
  * [azurerm_express_route_circuit_peering]- enhance - support for ipv4_enabled  gateway_manager_etag (#17338)
  * Update internal/services/storage/storage_table_entity_resource_test.go
  * Update internal/services/storage/storage_table_entity_resource_test.go
  * azure_storage_table_entity: support propoerty data types
  * CHANGELOG #15783
  * `r\site_recovery_replicated_vm`: Add support for `target_disk_encryption` (#15783)
  * Update guide-opening-a-pr.md
  * CHANGELOG #17684
  * New Resouce: `azurerm_monitor_data_collection_endpoint` (#17684)
  * update changelog for #17880
  * backup_policy_vm_resource: fix validation issue when frequency is set to Hourly (#17880)
  * add note for spring cloud enterprise sku (#17920)
  * Fix function app examples (#17908)
  * Update doc and deprecated warning in `azurerm_security_center_server_vulnerability_assessment`  with correct resource name (#17874)
  * fix doc of schduled query rule alert: import command case sensitivity
  * Update for #17464
  * `azurerm_subnet` - deprecate old enforce fields in favour of the new enable fields (#17464)
  * #17425 — use dot operator for `principal_id`. (#17923)
  * gha -add check for Get in Delete func for typed resources (#17882)
  * updated markdown for postresql_server
  * reverted to use SSL 1.2
  * fix: typo in Azure Orbital service delegation name (#17896)
  * Corrected role assignment example usage (#17894)
  * typos, note regarding lack of MSI support in vnet (#17888)
  * fix doc of schduled query rule: add `tags` (#17901)
  * build: using Go 1.18.5
  * v3.17.0
  * `d\shared_image_version`: Fix paging (#17822)
  * CHANGELOG #17887
  * `azurerm_api_management` - update `sku_name` validation to accept new Premium SKUs (#17887)
  * CHANGELOG #17194
  * updated TLS
  * updated markdown for PostgreSQL
  * changed setting to optional
  * Update to include #17194
  * `azurerm_eventhub_namespace`: support latest released properties:`local_authentication_enabled`,`public_network_access_enabled`,`minimum_tls_version` (#17194)
  * gha - fix and improvements to waiting-response (#17870)
  * `azurerm_kubernetes_cluster` - fix failed tests (#17861)
  * fix doc of data collection rule (#17857)
  * updating to include #17854
  * Network: Add support for orbitalGateway
  * add github token to wating-response labeler (#17849)
  * Updating Eventhub as the log analytics destination (#17668)
  * `r\mssql_virtual_machine`: add state refresh for `auto_patching` (#17203)
  * azurerm_subnet - support new service for delegation (#17796)
  * CHANGELOG #17737
  * Upgrade API for domain service: 2020-01-01 -> 2021-05-01 (#17737)
  * Update for #17577
  * change sku tier to not force new (#17577)
  * gha - check for d.Get in delete and new CreateUpdates (#17830)
  * Update for #17547
  * Validate shared image identifier attributes (#17547)
  * Fix test case for `azurerm_signalr_service` (#17835)
  * `azurerm_app_service_virtual_network_swift_connection` - updated documentation for associating to vNets (#17734)
  * Update for #17780
  * azurerm_log_analytics_cluster - update the validation for size_gb (#17780)
  * Update for #17836
  * Make `instances` optional since the API doesn't require this parameter. (#17836)
  * Update kubernetes_cluster_node_pool.html.markdown (#17793)
  * Docs: point `timeouts`, `operation-timeouts` and `lifecycle` links to their new place (#17819)
  * Update postgresql_flexible_server.html.markdown (#17826)
  * updating to include #17776
  * updating to include #17729
  * `d\virtual_machine_extension`: Fix `settings` to be Optional in doc
  * `azurerm_log_analytics_cluster` - enable Minimum of 500GB (#17794)
  * Fix docs typo and invalid target fqdn in azurerm_firewall_policy_rule_collection_group (#17807)
  * v3.16.0
  * Update CHANGELOG.md
  * CHANGELOG #17106
  * `r\iothub_dps_certificate`: support `is_verified` (#17106)
  * Update CHANGELOG.md
  * new resource `azurerm_kusto_cluster_managed_private_endpoint` (#17667)
  * CHANGELOG #17347
  * update automation account to use go-azure-sdk (#17347)
  * `HDInsight`: Adding support for `httpsEndpoints` and `installScriptAction` in hadoop edge node (#17655)
  * CHANGELOG #16187
  * New Resourece: azurerm_signalr_shared_private_link_resource (#16187)
  * fixing dotnet core version issue for resource `azurerm_windows_web_app` (#17285)
  * CHANGELOG #17557
  * New Resource:  azurerm_logz_sub_account_tag_rule (#17557)
  * `d\managed_disk`: Add support for `encryption_settings` (#15774)
  * CHANGELOG #17683
  * `azurerm_cognitive_account` - `custom_question_answering_search_service_key` (#17683)
  * CHANGELOG #17423
  * azurerm_bot_service_azure_bot - support streaming_endpoint_enabled (#17423)
  * CHANGELOG #17739
  * `azure_stream_analytics_stream_input_eventhub`: Add support for `authentication_mode` (#17739)
  * Update changelog for #16131
  * New Resource:  `azurerm_datadog_monitor` (#16131)
  * CHANGELOG #17685
  * New Resource: azurerm_log_analytics_query_pack (#17685)
  * Fix typo for TTL Argument Reference in dns_a_record (#17783)
  * CHANGELOG #17789
  * `azurerm_linux_function_app` and `azurerm_linux_function_app_slot` - fix casing bug in `linux_fx_string` for Node apps (#17789)
  * Remove the invalid 'FREE' SKU from app_service_plan (#17778)
  * goimports
  * Updated for #17494
  * `azurerm_linux_function_app` `azurerm_linux_function_app_slot` expose `virtual_network_subnet_id` for vNet integration (#17494)
  * Updated for #17576
  * `azurerm_windows_web_app` `azurerm_windows_web_app_slot` expose `virtual_network_subnet_id` for vNet integration (#17576)
  * Updated for #17572
  * `azurerm_windows_function_app` `azurerm_windows_function_app_slot` expose `virtual_network_subnet_id` for vNet integration (#17572)
  * GHA - add waiting-response label based on comment (#17775)
  * Updated for #17584
  * `azurerm_linux_web_app` `azurerm_linux_web_app_slot` - Documentation and test enhancements related to `virtual_network_subnet_id` argument (#17584)
  * gofmt
  * refactor: removing the legacy resource id parser for proximityplacementgroups
  * refactor: migrating `proximity_placement_group` to `hashicorp/go-azure-sdk`
  * updating to include #17707
  * ultra ssd also require restart
  * including 3.15.1
  * updating to include #17753
  * `azurerm_postgresql_server` `data.azurerm_servicebus_queue` - Fix regression around ids (#17755)
  * Fixing api_management_api_operation_policy.html.markdown
  * Update changelog for #17732
  * `azurerm_postgresql_aad_administrator`: Fix state migration (#17732)
  * dependencies: updating to use `v0.20220725.1163004` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17749
  * Documentation: `azurerm_cdn_frontdoor_origin` - Fix example usage (#17730)
  * docs: fix import command user_assigned_identity
  * Add checks to acceptance tests
  * bump go-azure-sdk to v0.20220725.1131927
  * Updated for #17719
  * eventhub: consolidating onto API Version 2021-11-01 (#17719)
  * formating
  * fix front door examples
  * updating to include #17726
  * Correct Sku names to match code
  * Remove single-use local variables
  * change storage_size_in_gb from 8192 to 16384 (#17711)
  * Update linux_web_app.html.markdown (#17718)
  * GHA - new actions to add/remove wating-response (#17708)
  * dependencies: updating to `v0.20220722.1091911` of `github.com/hashicorp/go-azure-sdk`
  * no live resize for Standard HDD
  * v3.15.0
  * Update CHANGELOG.md
  * Updating to include #17089
  * adding #17089
  * CHANGELOG.md #17595
  * domainservice: refactoring domainservice resources to using go-azure-sdk (#17595)
  * Update CHANGELOG.md
  * fix test
  * vendor
  * flip default to true
  * terrafmt
  * go mod vendor
  * Fix API version error
  * Add test for API version error
  * Update dns_ns_record.html.markdown
  * fix doc of features-block for api_management
  * Update changelog for #17625
  * `postgres` - swap to `hashicorp/go-azure-sdk` (#17625)
  * Update windows_web_app.html.markdown (#17679)
  * Fixing wrong reference for resource `azurerm_servicebus_topic` (#17673)
  * CHANGELOG #17130
  * `azurerm_storage_account` - add supports for `change_feed_retention_in_days` (#17130)
  * `azurerm_storage_account` - support disable `blob_properties.0.{delete_retention_policy|container_delete_retention_policy}` & `share_properties.0.retention_policy` (#17256)
  * CHANGELOG #17581
  * kusto_cluster_resource - allowed_fqdns, allowed_ip_ranges, outbound_network_access_restricted (#17581)
  * CHANGELOG #16578
  * New Resource - azurerm_route_server_bgp_connection, azurerm_route_server (#16578)
  * CHANGELOG #17368
  * New Resource: azurerm_application_insights_workbook (#17368)
  * CHANGELOG #15550
  * Adding shared private link resource for the Azure web pubsub resource (#15550)
  * Update go-azure-sdk to v0.20220719.1202339 (#17680)
  * Update changelog for #17342
  * New Resource: `azurerm_monitor_data_collection_rule` (#17342)
  * Changes documentation to reflect ISE network requirements
  * Import spec fix: azurerm_managed_disk (#17658)
  * Fix: Get valid API version from error code for `resource group template deployment` resource when original API version is mismatched (#15758)
  * updating to include #17645
  * adding #17653
  * Update for #17628
  * `servicebus` - switch to `go-azure-sdk` (#17628)
  * Remove callouts for PodSubnetPreview feature
  * make goimports (#17650)
  * dependencies: updating to `v0.20220715.1071215` of `github.com/hashicorp/go-azure-sdk` (#17645)
  * docs: fix up `azurerm_eventhub_authorization_rule` to stay in proper category (#17647)
  * v3.14.0
  * Migrating eventhub auth rule ID in state (#17615)
  * CHANGELOG #17554
  * Update cipher name to correct custom property (#17554)
  * azurerm_mssql_server : Fix "identity.0.identity_ids" not being accessible in dynamic "identity" block (#17556)
  * Fix azurerm storage management policy data source (#17570)
  * azurerm_postgresql_flexible_server_configuration : Clarify the usage of azure extension for PostgreSQL Flexible Server (#17580)
  * Fixing partitioning issue for premium servicebus namespace (#17599)
  * azurerm_traffic_manager_nested_endpoint, azurerm_traffic_manager_external_endpoint, azurerm_traffic_manager_azure_endpoint : Fix issue about "weight is required even with priority traffic manager profile" (#17602)
  * CHANGELOG #17524
  * azurerm_kusto_eventgrid_data_connection - support database_routing, eventgrid_resource_id, managed_identity_resource_id (#17524)
  * CHANGELOG #16652
  * azurerm_stream_analytics_output_blob - support new property authentication_mode (#16652)
  * azurerm_mssql_managed_instance_failover_group ：fix update error "Only one managed instance pair is supported" (#16798)
  * Fix free sku issue for app (#16983)
  * Update changelog for #17629
  * `azurerm_signalr_service` - Add support for `live_trace` (#17629)
  * fix: dns server order must be respected (#17427)
  * Updating changelog for #17463
  * signalr: update to use go-azure-sdk (#17463)
  * sdk: extracting the Plugin SDKv2 schema types to their own interface
  * updating to include #17614
  * azurerm_dev_test_lab_schedule: delete itself rather than a vm extension
  * Modified `azurerm_monitor_metric_alert` to detect `webhook_properties` changes (#17509)
  * CHANGELOG #17467
  * update spring sdk to 2022-05-01-preview (#17018)
  * CHANGELOG #17013
  * azurerm_[orchestrated|windows|linux]_virtual_machine_scale_set: support `placement` for os disks (#17013)
  * Docs: Fix management_group, resource_group and subscription policy exemption and remediation file names (#17594)
  * updating to include #17609
  * updating to include #17608
  * updating to include #17606
  * go mod vendor
  * compute/sshpublickeys: refactoring to use `hashicorp/go-azure-sdk`
  * go mod tidy
  * compute: refactoring `availability_set` to use `github.com/hashicorp/go-azure-sdk`
  * dependencies: updating to `v0.20220712.1111122` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17598
  * go mod vendor
  * r/legacy_dashboard: refactoring to use `go-azure-sdk`
  * updating to include #17588
  * updating to include #17590
  * go mod vendor
  * dependencies: updating to `v0.37.0` of `github.com/hashicorp/go-azure-helpers`
  * updating to include #17589
  * Update README.md
  * link contrib docs in readme and dev mds (#17591)
  * go mod vendor
  * lighthouse: refactoring to use go-azure-sdk
  * dependencies: updating to `v0.20220711.1181406` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17467
  * updating to include #17587
  * dependencies: updating to `v0.20220711.1122120` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17471
  * updating to include #17141 & cleanup
  * go mod tidy && go mod vendor
  * databricks: refactoring to use `go-azure-sdk`
  * CHANGELOG #17519
  * `azurerm_container_group` - Add supports of `http_headers` (#17519)
  * CHANGELOG.md #17525
  * CHANGELOG #17526
  * Add `database_routing` to resource kusto eventhub (#17525)
  * CHANGELOG #17526
  * Add `database_routing` to azurerm_kusto_iothub_data_connection (#17526)
  * `azurerm_subscription_policy_assignment` & `azurerm_management_group_policy_assignment` Add `UserAssignedIdentities` to the update request to fix #17082 and #16898 (#17231)
  * CHANGELOG #17300
  * `r\shared_image`: support `end_of_life_date` `disallowed_disk_types` `[max|min]_recommended_[vcpu_count|memory_in_gb]` (#17300)
  * CHANGELOG.md #17394
  * New resources `gallery_application` `gallery_application_version` (#17394)
  * Update subnet service delegation list with the support of DNS Private Resolvers. (#17574)
  * Changing QoS value and adding CreateOnDate tag (#17568)
  * CHANGELOG.md #17141
  * Bump terraform-plugin-sdk to v2.18.0 to increase the size of gRPC messages upto 256MB (#17141)
  * Doc Fix : azurerm_mssql_database - Removal of doc for deprecated extended_auditing_policy (#17487)
  * `azurerm_cognitive_account` - update document (#17535)
  * remove spring quota validation (#17422)
  * Update CHANGELOG.md
  * CHANGELOG #17298
  * update PolicyRemediation sdk to pandora sdk 2021-10-01 (#17298)
  * CHANGELOG #17496
  * `azurerm_kubernetes_cluster` `azurerm_kubernetes_cluster_node_pool` - `host_group_id` (#17496)
  * CHANGELOG #17433
  * New Resource: azurerm_application_insights_workbook_template (#17433)
  * CHANGELOG.md #17498
  * Fixing invalid LinuxFxVersion issue for linux function app (#17345)
  * CHANGELOG #17530
  * `r\[linux|windows]_virtual_machine_scale_set`: add support for `capacity_reservation_group_id` (#17530)
  * Update maintainer-changelog.md
  * Update CHANGELOG.md
  * Writing the property `default_hostname`  back to state for function apps (#17498)
  * CHANGELOG #17522
  * Add `script_content` and update `url` and `sas_token` for resource kusto script (#17522)
  * Fix incorrect import spec for `azurerm_netapp_snapshot_policy` , `azurerm_policy_management_group_policy_remediation`, etc (#17521)
  * CHANGELOG.md #17520
  * azurerm_kusto_cluster  - Add new `public_ip_address` property (#17520)
  * windows_web_app_(slot)_resource: Fix currentStack is not fetched from state when updating infrastructure using terraform. (#17490)
  * Update CHANGELOG.md
  * custom domain verification id is blank unless it's saved to the model (#17485)
  * v3.13.0
  * Update changelog for #17238
  * New Resource - `azurerm_fluid_relay_server` (#17238)
  * Update changelog for #17380
  * `azurerm_application_gateway` -  `request_routing_rule.x.priority` is optional (#17380)
  * update changelog for #17465
  * NetApp: Swap to `hashicorp/go-azure-sdk` (#17465)
  * CHANGELOG #16810
  * New Data Source: `azurerm_public_maintenance_configurations` (#16810)
  * Update storage api to 2021-09-01
  * CHANGELOG #16581
  * New Resource: azurerm_logz_sub_account (#16581)
  * Load balancer new feature - inbound NAT rule port mapping (#16000)
  * CHANGELOG #17415
  * azurerm_key_vault_certificate : fix azurerm_key_vault_certificate could not be recovered issue (#17415)
  * CHANGELOG #16984
  * `spring_cloud_deployment` - `addon_json` (#16984)
  * CHANGELOG #17111
  * `synapse_integration_runtime_azure`- `locations` supports `Auto Resolve` (#17111)
  * `azurerm_kubernetes_cluster ` - fix test cases (#17124)
  * remove validation on spring cloud route config route.uri (#17230)
  * azurerm_cosmosdb_cassandra_datacenter - support new properties (#16800)
  * Update Kusto API Version to latest (#17457)
  * Fix hashicorp#15640 making fqdns in data_factory_managed_private_endp… (#15644)
  * CHANGELOG #17236
  * `r\linux/windows_virtual_machine`: add support for `capacity_reservation_group_id` (#17236)
  * CHANGELOG #17395
  * `kubernetes_cluster/node_pool`- `capacity_reservation_group_id` (#17395)
  * CHANGELOG.md #17259
  * `azurerm_hdinsight_kafka_cluster` add support for `network` block (#17259)
  * Update changelog for #17445
  * eventhub: refactoring to use `go-azure-sdk` (#17445)
  * Update changelog for #17499
  * containerinstance: refactoring to use `hashicorp/go-azure-sdk` (#17499)
  * `d/shared_image_version`: fix `id` (#17332)
  * fix aks trusted ca (#17497)
  * Document: Fix import instruction (#17500)
  * Update for #17466
  * `azurerm_container_registry` - Data source supports `data_endpoint_enabled` (#17466)
  * updating to include #17470
  * formatting
  * updating to include #17469
  * Doc: Fix import spec for azurerm_policy_remediation
  * storage: dependencies
  * storage: refactoring `storageobjectreplication` to use `go-azure-sdk`
  * hsm: updating to API version `2021-11-30`
  * hsm: dependencies
  * hsm: refactoring to use go-azure-sdk`
  * dependencies: go mod tidy / go mod vendor
  * azurestackhci: refactoring to use go-azure-sdk
  * dependencies: updating to `v0.20220701.1073833` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17436
  * update app_configuration version to 2022-05-01
  * privatedns: vendoring
  * refactor: switching usages of the internal ID parsers
  * privatedns: removing the old resource id types
  * privatedns: fixing a bug where `zone_name` wasn't force new/todo's
  * privatedns: refactoring to use `go-azure-sdk`
  * v3.12.0
  * Update CHANGELOG.md
  * Add Contributor Documentation (#16732)
  * updating to include #17435
  * powerbi: vendoring
  * powerbi: refactoring to use `go-azure-sdk`
  * updating to include #17434
  * updating to include #17431
  * maps: vendoring
  * maps: refactoring to use `go-azure-sdk`
  * updating to include #17432
  * loadtest: vendoring
  * loadtest: refactoring to use go-azure-sdk
  * ordering
  * updating to include #v
  * mixedreality: removing the transition file, this is no longer needed
  * mixedreality: splitting the create/update function
  * mixedreality: `go mod vendor`
  * mixedreality: switching to use go-azure-sdk
  * updating to include #17430
  * updating to include #16484
  * updating to include #16368
  * updating to include #15849
  * updating to include #17419
  * documents example improvement
  * documents example improvement
  * elastic: go mod vendor
  * elastic: refactoring to use go-azure-sdk
  * msi: vendoring
  * refactor: updating `msi` to use `go-azure-sdk`
  * refactor: switching the UserAssignedIdentity usages out for `commonids`
  * Document: Fix import specification for azurerm_stream_analytics_function_javascript_udf
  * updating to include #17407
  * updating to include #16966
  * updating to include #
  * rewording the document
  * `azurerm_key_vault_{key|secret}` - Expose attributes `resource_id` and `resource_versionless_id`
  * Remove transistion file
  * Removve transition.go from communication
  * Removve transition.go from portal
  * Removve transition.go from cognitive
  * Removve transition.go from privatedns
  * Removve transition.go from iotcentral
  * Removve transition.go from disks
  * Removve transition.go from mssql
  * Removve transition.go from maps
  * Removve transition.go from notificationhub
  * Removve transition.go from video analyzer
  * Removve transition.go from msi
  * Removve transition.go from desktopvirtualization
  * Fix crash
  * Clean up
  * Swap to new sdk
  * Add azure sdk
  * updating to include #17399
  * go mod vendor
  * dependencies: updating to v0.20220628.1190740 of github.com/hashicorp/go-azure-sdk
  * portal: refactoring to account for the updated ID structures
  * dependencies: updating to `v0.20220627.1082008` of `github.com/hashicorp/go-azure-sdk`
  * updating to include #17386
  * cognitive: updating the import path for the search service
  * search: removing the embedded sdk
  * search: refactoring to use `go-azure-sdk`
  * CHANGELOG #17325
  * New Resource: azurerm_data_protection_resource_guard (#17325)
  * cleanup: removing the 3.0 feature toggle (#17414)
  * CHANGELOG #17354
  * `azurerm_linux_web_app` `azurerm_linux_web_app_slot` expose `virtual_network_subnet_id` for vNet integration (#17354)
  * CHANGELOG #17295
  * `r\shared_image_version`: add support for `disk_encryption_set_id` `end_of_life_date` `replication_mode` (#17295)
  * Sentinel data connector document: emphasize that `tenant_id` can only be the current tenant (#17411)
  * updating to include #17387
  * redisenterprise: removing the embedded sdk's
  * redisenterprise: refactoring to use go-azure-sdk
  * updating to include #17385
  * relay: removing the embedded sdk
  * relay: refactoring to use `go-azure-sdk`
  * `azurerm_key_vault` data source: cache the `vault_uri` once read
  * Update for #17084
  * AKS (`azurerm_kubernetes_cluster`, `azurerm_kubernetes_cluster_node_pool`): add support for version aliases (#17084)
  * `r\shared_image_version`: update `target_region` to list (#17391)
  * azure function app: fix `elastic_instance_minimum` not being set correctly issue (#17322)
  * `azurerm_cdn_endpoint_custom_domain` - Set to state once created (#17396)
  * CHBANGELOG.md for #17369
  * azurerm_bot_channels_registration - support streaming_endpoint_enabled (#17369)
  * CHANGELOG #16820
  * azurerm_vpn_site - support new property o365_policy (#16820)
  * `azurerm_container_group` - Support resource limit for cpu/mem/gpu (#16775)
  * CHANGELOG/md for #17076
  * `r\digital_twins_instance`: support `identity` (#17076)
  * `r\application_insights` Add validation for `workspace_id` (#15621)
  * Add role assignment to azurerm_disk_encryption_set (#17075)
  * CHANGELOG #17077
  * azurerm_bot_service_azure_bot: support new property MsaAppType (#17077)
  * CHANGELOG #16966
  * new resource `azurerm_spring_cloud_api_portal_custom_domain` (#16966)
  * azurerm_batch_account ：fix storage account id is invalid error (#16731)
  * Update changelog for #17366
  * `azurerm_private_link_service ` - add support for `fqdns` (#17366)
  * Update changelog for #17390
  * `shared_image_version`:add new `storage_account_type`: `Premium_LRS` (#17390)
  * Update changelog for #17398
  * `azurerm_data_factory_linked_service_azure_file_storage` - Fix assignment to `user_id`(#17398)
  * `loganalytics` `lighthouse` `loadbalancer` `kusto` `healthcare` `bot` `appservice` `network` `eventhub`- `docs example improvement` (#17283)
  * `azurerm_web_application_firewall_policy` Change `KNOWN-CVES` to `Known-CVEs` to fix #17214 (#17243)
  * `azurerm_spring_cloud_service` update note (#17334)
  * sqlvirtualmachine: switch to go-azure-sdk and upgrade api to 2022-02-01 (#17374)
  * fix multiple docs: keyvault enum case sensitivity (#17402)
  * Changelog for #17045
  * New resource - `azurerm_active_directory_domain_service_trust` (#17045)
  * fixing the typo for linux web app
  * Update for #17001
  * `azurerm_data_factory` - `purview_id` (#17001)
  * updating to include #17384
  * servicefabricmanaged: removing the embedded sdk
  * servicefabricmanaged: refactoring to use go-azure-sdk
  * updating to include #17382
  * go mod vendor
  * videoanalyzer: removing the embedded sdk
  * videoanalyzer: refactoring to use go-azure-sdk
  * updating to include #17381
  * updating to include #17392
  * vmware: removing the embedded sdk
  * vmware: refactoring to use go-azure-sdk
  * updating to include #17383
  * Doc Fix : azurerm_subnet - Add note to address_prefixes that "AllowMultipleAddressPrefixesOnSubnet" is currently not supported (#17109)
  * Update for #17241
  * Add length and nil check to fix #17207 (#17241)
  * update sku_name (#17284)
  * fix issue 17353 (#17364)
  * `document` Fix example for `key_vault_managed_storage_account` (#17367)
  * Replace deprecated ioutil pkg with os & io
  * updating to include #17346
  * tooling: updating the track2 check to callout go-azure-sdk
  * trafficmanager: fixing an import
  * trafficmanager: removing the embedded sdk
  * trafficmanager: refactoring to use `go-azure-sdk`
  * Update for #17209
  * Remove incorrect validation of app service sticky setting names (#17209)
  * Update for #17296
  * `azurerm_windows_web_app`, `azurerm_linux_web_app`: Fix auto heal slow request issue (#17296)
  * `azurerm_linux_function_app`: remove the property in docs (#17316)
  * v3.11.0
  * Update for #17215
  * `data.azurerm_storage_account` - add supports of `identity` (#17215)
  * Update for #17234
  * `r\iot_time_series_insights_gen2_environment`: fix `id_properties` schema (#17234)
  * updating to include #17348
  * dependencies: updating to `v0.20220623.1064317` of `github.com/hashicorp/go-azure-sdk`
  * `azurerm_data_factory_dataset_snowflake`: fix table can't be loaded
  * add missing dedicated host skus (#17312)
  * updating to include #v
  * go mod tidy
  * r/virtual_desktop_workspace_application_group_association: switching to use the patch method rather than put/post
  * ependencies: vendoring `2021-09-03-preview` of `desktopvirtualization` from go-azure-sdk rather than the Azure SDK for Go
  * desktopvirtualization: removing the Resource IDs now available in go-azure-sdk
  * migration: switching to use the ID Parsers in go-azure-sdk
  * r/virtual_desktop_workspace: refactoring to use `go-azure-sdk`
  * desktopvirtualisation: removing the unused OperationsClient
  * r/virtual_desktop_workspace_application_group_association: refactoring to use `go-azure-sdk`
  * r/virtual_desktop_scaling_plan: refactoring to use go-azure-sdk
  * r/virtual_desktop_host_pool: refactoring to use go-azure-sdk
  * r/virtual_desktop_host_pool_registration_info: refactoring to use go-azure-sdk
  * r/virtual_desktop_application: refactoring to use go-azure-sdk
  * r/virtual_desktop_application_group: refactoring to use go-azure-sdk
  * updating to include #17289
  * IoTCentral: Add and swap to embedded SDK (#16912)
  * portal: switching to go-azure-sdk (#17337)
  * updating to include #17270
  * notificationhub: switching to use go-azure-sdk (#17336)
  * updating to include #17339
  * dependencies: updating `go-azure-sdk` to `v0.20220622.1090000`
  * connections: missing reference
  * connections: removing the embedded sdk
  * connections: refactoring to use go-azure-sdk
  * confidentialledger: removing the embedded sdks
  * confidentialledger: refactoring to use go-azure-sdk
  * dependencies: removing the old azure sdk for go
  * communication: removing the (unused?) embedded sdk
  * r/communication_service: refactoring to use hashicorp/go-azure-sdk
  * updating to include #14524
  * Add ForceNew warn
  * r/cognitive_account: refactoring to use the new identity methods
  * cognitive: removing the embedded sdk
  * dependencies: switching to use the split-out Cognitive SDK in hashicorp/go-azure-sdk
  * updating to include #17146
  * attestation: removing the embedded sdk
  * dependencies: vendoring github.com/hashicorp/go-azure-sdk
  * attestation: refactoring to use go-azure-sdk
  * appconfiguration: removing the embedded sdks
  * appconfiguration: switching to use go-azure-sdk
  * analysisservices: removing the embedded sdk
  * analysisservices: refactoring to use go-azure-sdk
  * aadb2c: removing the embedded Go SDK
  * policy: refactoring to use CommonIDs rather than the AADB2C package
  * services/addb2c: migrating to use hashicorp/go-azure-sdk
  * `azurerm_kubernetes_cluster` update document (#17299)
  * Update for #17301
  * Update mysql_flexible_server_data_source.go (#17301)
  * Fix image tests with dangling os disk (#17297)
  * azurerm_mssql_elasticpool : fix elastic pool with gen5 8 cpu cannot have 2048 GB of storage issue (#17196)
  * Crash Fixes: Fix various crashes throughout the provider (#17100)
  * Test Fixes: Across various services (#17122)
  * `r\shared_image`: add `ForceNew` to `publisher``offer``sku``privacy_statement_uri`
  * hpc_cache_nfs_target
  * Fix some incorrect import instructions
  * `d\managed_disk`:add support for `network_access_policy` and `disk_access_id`
  * Use 'Workspace' not 'Workflow'
  * tweak docs
  * Added a note for `vault_key_reference` (#17102)
  * `securitycenter` - `docs example improvement` (#17151)
  * `recoveryservices` - `docs example improvement` (#17154)
  * CHANGELOG.md #16527
  * New Data Source: `azurerm_policy_assignment` (#16527)
  * Missing vnet_route_all_enabled setting in Web app (slot) resource doc (#17200)
  * Updated documentation for Databricks Workspace Resource (#17223)
  * Update servicebus_namespace_network_rule_set.html.markdown (#17225)
  * Add tracking issue for uppercase in VM (#17235)
  * `docs example improvement`-` 30 file part1` (#17237)
  * `netapp` `database` `monitor` `media` `policy` `managedapplications` `maintenance` `machinelearning` `logz` `logicapp` `loganalytics` - `docs example improvement` (#17258)
  * `network` - `docs example improvement` (#17217)
  * review: check disk type on resize
  * review: switch to feature from resource argument
  * vendor github.com/hashicorp/go-azure-helpers/resourcemanager/systemdata
  * fix imports
  * new sdk
  * sku is mandatory for resource azurerm_container_registry
  * Add support for no-downtime disk resizes.
  * updating to include #17219
  * update batch_account_data_source_test.go
  * [fix](eventgrid_system_topic_event_subscription.html):fix docs `userAssignedIdentity`
  * docs example improvement
  * Update changelog for #17201
  * `azurerm_shared_image_*` - Fix validation of `gallery_name` (#17201)
  * v3.10.0
  * Update CHANGELOG.md
  * Update changelog for #16849
  * `azurerm_applicaton_gateway` -`priority` is now required (#16849)
  * Update changelog for #16524
  * `azurerm_api_management` - Default hostname proxy configuration is no longer ignored (#16524)
  * Update changelog for #17148
  * `azurerm_key_vault_managed_hardware_security_module` - support for purging when soft deleted (#17148)
  * Update changelog for #17183
  * `azurerm_windows_function_app_x` - `custom_domain_verification_id` is now written to state file (#17183)
  * Update changelog for #17094
  * New Data Source/Resource: `azurerm_cdn_frontdoor_rule_set` (#17094)
  * state migration for servicebus namespace network rule set id (#17187)
  * update document (#17180)
  * Update CHANGELOG.md
  * reverting ##17161
  * Revert "New Resource: `azurerm_monitor_workbook` (#17161)"
  * Update changelog for #17161
  * New Resource: `azurerm_monitor_workbook` (#17161)
  * CHANGELOG #16972
  * `r\hpc_cache`: Add support for encryption key (#16972)
  * CHANGELOG #16799
  * azurerm_cosmosdb_cassandra_cluster - support new properties (#16799)
  * `azurerm_api_management` waitLRO (#16962)
  * CHANGELOG.md for #16464
  * New resources `capacity_reservation_group` and `capacity_reservation` (#16464)
  * fix batch pool data source (#16757)
  * Update changelog for #17162
  * `azurerm_application_gateway`: add default value for `backend_http_settings.0.request_timeout` (#17162)
  * docs example improvement (#17163)
  * [docs](bot):documents example improvement. (#17164)
  * docs example improvement (#17153)
  * [docs](batch):documents example improvement. (#17160)
  * `policy` -`docs example improvement` (#17156)
  * [docs](automation): docs example improvement. (#17152)
  * docs example improvement (#17157)
  * Update modules.txt with latest client
  * Update typo (#17103)
  * `synapse` - `docs example improvement` (#17108)
  * `streamanalytics` -`docs example improvement`(#17126)
  * `streamanalytics` - `docs example improvement` (#17128)
  * `web`-`docs example improvement` (#17129)
  * `storage` - `docs example improvement` (#17132)
  * `azurestackhci` - `docs example improvement` (#17133)
  * `springcloud` - `docs example improvement` (#17134)
  * `servicebus` - `docs example improvement` (#17136)
  * `attestation` - `docs example improvement` (#17131)
  * `sentinel` - `docs example improvement` (#17139)
  * add 2022-05-13 version
  * Update for #17138
  * Refactor out use of `IsNewResource` in Typed resources (#17138)
  * Remove use of `ResourceData.Timeout` and switch to context deadline (#17107)
  * Fix some incorrect import spec
  * Doc Fix: Policy (#17110)
  * Update changelog for #17115
  * `azurerm_container_group` - Double the check timeout of deletion of nic (#17115)
  * Doc Fix : azurerm_automation_job_schedule - Fix schedule_name property missing in tf doc issue (#17113)
  * Doc Fix: correct documentation for `oidc_request_url` (#17118)
  * docs example improvement (#17071)
  * fix error msgs
  * formatting
  * formatting
  * use ID in test as well
  * use ID instead of name for mgmt group
  * Update internal/services/resource/resource_group_template_deployment_data_source.go
  * Update internal/services/resource/tenant_template_deployment_data_source.go
  * Update internal/services/resource/management_group_template_deployment_data_source.go
  * Update internal/services/resource/subscription_template_deployment_data_source.go
  * Update website/docs/d/management_group_template_deployment.html.markdown
  * Update website/docs/d/management_group_template_deployment.html.markdown
  * fix plan changes
  * skip tenant test when permissions are not there
  * set id in mgmt group data source
  * docs formatting
  * add docs
  * formatting
  * add test methods
  * add test configs
  * template data sources implementation
  * v3.9.0
  * Update CHANGELOG.md
  * updating to include #17069
  * adding #17069
  * Fix a bug cause TestAccBatchPool_startTask_basic failed (#17004)
  * Update changelog for #17024
  * azurerm_synapse_role_assignment` - `role_name` now supports `Synapse Monitoring Operator` (#17024)
  * CHANGELOG #17053
  * New data source: `azurerm_app_configuration_keys` (#17053)
  * azurerm_cdn_endpoint_custom_domain - Allow Premium Verizon profile for BYOC custom domain (#17017)
  * Fix `TestAccHPCCache_directoryLDAP` (#17060)
  * azurerm_mysql_flexible_server: update validation for sku_name (#16976)
  * CHANGELOG.md #16990
  * [Enhance] azurerm_redis_cache - support config identity (#16990)
  * fix: not set management_group_id cause error in policy set resource (#16974)
  * `static_site_resource` wait LRO (#16964)
  * CHANGELOG #16940
  * `r\backup_policy_vm`: Add support for Enhanced Policy (#16940)
  * Update changelog for #17057
  * `azurerm_eventhub_authorization_rule` - extend regex char limit for `name` and doc fixes (#17057)
  * Update changelog for #16724
  * `azurerm_vpn_gateway_nat_rule` - support for `port_range` (#16724)
  * Update changelog for #17078
  * New Data Source/Resource: `azurerm_cdn_frontdoor_endpoint` (#17078)
  * `signalr` - `docs example improvement` (#17025)
  * `apimanagement`-`docs example improvement` (#17048)
  * `document`: Update `kubernetes_cluster` attributes doc (#17059)
  * CHANGELOG #17043
  * [ANF] Standard Network Feature (#17043)
  * updating to include #17061
  * Update internal/services/cdn/cdn_frontdoor_profile_data_source_test.go
  * d/cdn_frontdoor_profile: fixing the test
  * r/cdn_frontdoor_profile: clarifying attributes and arguments
  * New Data Source: `azurerm_cdn_frontdoor_profile`
  * New Resource: `azurerm_cdn_frontdoor_profile`
  * go mod vendor
  * cdn: adding the clients for CDN Frontdoor
  * updating to include #17074
  * dependencies: upgrading to v1.6.1 of github.com/hashicorp/go-getter
  * dependencies: updating to v0.33.0 of github.com/hashicorp/go-azure-helpers
  * `apimanagement`-`docs example improvement` (#17070)
  * valid value on version in image reference (#17062)
  * document improvement (#17047)
  * Update windows_web_app.html.markdown (#17051)
  * Fix azurerm_firewall docs (#17056)
  * Add missing possible subscription endpoint types (#17068)
  * Fix Event Grid Subscription documentation (#17072)
  * updating to include #17002
  * Update for #17037
  * `azurerm_web_pubsub_hub` - set `event_handler` block to `Optional` (#17037)
  * update uuid
  * document improvement
  * CHANGELOG #16911
  * New resource: azurerm_vpn_server_configuration_policy_group (#16911)
  * CHANGELOG #16922
  * `data_factory_trigger_schedule` - `pipeline` (#16922)
  * CHANGELOG #16825
  * Fix vm not turning back on after update (#16674)
  * replaced virtual_subnet_id in example (#16986)
  * azurerm_key_vault_secret : fix error when creating 16 tags for key vault secret - "Property has invalid value" (#16947)
  * `azurerm_dns_x_record` - Add disclaimer for large scale (#16988)
  * `compute` - `docs example improvement` (#17027)
  * `connections` - `docs example improvement` (#17022)
  * `appservice` - `docs example improvement` (#17021)
  * Update for #17005
  * `azurerm_kubernetes_cluster` - nil check `APIServerAccessProfile` (#17005)
  * update code per review
  * modify the inplace change to explict return for the patch function
  * Align SKU with SDK enums (#16989)
  * removes duplicate line in route table doc line (#17009)
  * docs(domainservices): 📝 document's example valiadated (#17003)
  * [feat](stream_analytics_job_schedule): wait lro (#16965)
  * `azurerm_container_registry_task` - Fix missing `authentication` when updating
  * Doc: Fix some incorrect import spec
  * v3.8.0
  * tidy changelog for release
  * `azurerm_kusto_cluster`: `4.0`: make V3 the default engine type (#16878)
  * CHANGELOG #16730
  * new resource `azurerm_spring_cloud_build_deployment` (#16730)
  * fix validation (#16981)
  * Update `examples/app-service/**` for 3.x resources (#16969)
  * fix: 🐛 Set default for week_of_year (#16946)
  * CHANGELOG #16861
  * New resource - `azurerm_mssql_server_dns_alias` (#16861)
  * azurerm_cosmosdb_account: set default_identity_type as default value when it's empty string in older cosmosdb account (#16963)
  * CHANGELOG.md #16960
  * azurerm_vpn_gateway_connection: support new property custom_bgp_address (#16960)
  * azurerm_app_configuration_key : fix "cannot use a / (slash) in the name of a label" issue (#16863)
  * `azurerm_storage_share` - Add new enum `Premium` for `access_tier` (#16842)
  * CHANGELOG #16920
  * `azurerm_active_directory_domain_service` - Add supports for `domain_configuration_type` (#16920)
  * CHANGELOGn #16841
  * `azurerm_spring_cloud_service` - `build_agent_pool_size` (#16841)
  * Doc Update: `azurerm_backup_protected_vm` - Add note about removing `source_vm_id` (#16979)
  * dependencies: upgrading to use v3 of gopkg.in/yaml (#16977)
  * CHANGELOG #16862
  * azurerm_virtual_network_gateway_connection - support egress_nat_rule_ids and ingress_nat_rule_ids (#16862)
  * `azure_spring_cloud_service`: Fix acceptance test(s) (#16970)
  * Update changelog for #16939
  * `azurerm_backup_protected_vm` - Allow the associated vm to be disassociated from the backup (#16939)
  * Update Changelog for #16955
  * Upgrade keyvault SDK (#16955)
  * Use d.GetOk for the identity property of azurerm_mssql_server (#15900)
  * CHANGELOG #16719
  * new resource `azurerm_spring_cloud_api_portal` (#16719)
  * Add example for zone-zone site recovery (#16205)
  * CHANGEL:OG #16506
  * `azurerm_mysql_server` Add update in create function to update `public_network_access_enabled` (#16506)
  * CHANGELOG #16406
  * azurerm_portal_dashboard - update dashboard name validation (#16406)
  * CHANGELOG #16721
  * new resource `azurerm_spring_cloud_gateway_route_config` (#16721)
  * `azurerm_data_factory_data_flow` - `script_lines` `transformation.dataset/linked_service` (#16728)
  * `azurerm_source_control_token` Fix #16693 by correcting `IDValidationFunc` (#16723)
  * CHANGELOG.md for #16665
  * Upgrade Bot Service API version from 2021-03-01 to 2021-05-01-preview (#16665)
  * fix: update docs for policy_definition and policy_set_definition (#16961)
  * `storage-account-html.markdown` - adds missing share_properties reference (#16953)
  * Update changelog for #16872
  * `azurerm_spring_cloud_service`: Add `zone_redundant` property (#16872)
  * Update changelog for #16918
  * `azurerm_data_factory_trigger_schedule` - `time_zone` (#16918)
  * Fixing the incorrect page_title for some document
  * Fixing the incorrect header for some document
  * Updating to include #16905 #16908 and #16916
  * Adding #16916
  * Adding #16908
  * Adding #16905
  * Test Fixes: Skip VideoAnalyzer tests (#16924)
  * Fixing minor typo in `container_group.html.markdown` (#16925)
  * Update for #16410
  * windows_function_app_slot fix slot name formatting #16305 (#16410)
  * Update for #16779
  * `azurerm_[linux|windows]_web_app` and `azurerm_[linux|windows]_web_app_slot` - add support for zip deployment (#16779)
  * Update changelog for #16866
  * `azurerm_windows_virtual_machine`: Add `ForceNew` to `timezone` (#16866)
  * CHANGELOG.md for #16817
  * azurerm_vpn_gateway - support new property bgp_route_translation_for_nat_enabled (#16817)
  * Update changelog for #16906
  * `synapse_spark_pool`-`spark_version` supports `3.2` (#16906)
  * Doc Fix: `r\virtual_network_gateway`: Add `bgp_settings` (#16880)
  * Doc Fix : azurerm_storage_share - fix issue "Storage docs missing complete access_tier coverage" (#16886)
  * docs: kubernetes maintenance window (#16887)
  * Update changelog for #16894
  * `azurerm_data_factory_managed_private_endpoint` Update DataFactoryManagedPrivateEndpointName (#16894)
  * PrivateDNS: Swap to embedded sdk (#16858)
  * oidc: fixing the formatting / cross-linking to the Azure Backend
  * v3.7.0
  * Update CHANGELOG.md
  * CHANGELOG.md #16868
  * `r\shared_image`: Fix update issue related to unchanged `eula` (#16868)
  * `azurerm_cdn_endpoint` - Enhance document for the `transforms` (#16843)
  * [Docs fix]Correct docs for resource `azurerm_linux_web_app` (#16879)
  * CHANGELOG #15913
  * `Dependency` New Resource azurerm_healthcare_fhir_service (#15913)
  * Update changelog for #16870
  * `azurerm_disk_encryption_set`: `encryption_type` supports `ConfidentialVmEncryptedWithCustomerKey` (#16870)
  * Update changelog for #16875
  * `azurerm_signalr_service`: Support `Premium_P1` SKU (#16875)
  * updating to include #16555
  * Update website/docs/guides/azure_cli.html.markdown
  * Update website/docs/guides/service_principal_oidc.html.markdown
  * Update website/docs/guides/service_principal_oidc.html.markdown
  * Update website/docs/index.html.markdown
  * updating to include #16845
  * updating to include #16847
  * Update service_principal_oidc.html.markdown
  * PrivateDNS - Add embedded sdk (#16769)
  * Purview: Add embedded sdk (#16764)
  * Update changelog for #16832
  * `azurerm_mssql_managed_instance` - add support for `maintenance_configuration_name` (#16832)
  * videoanalyzer: deprecating since this is scheduled for removal on 2022-11-30
  * refactor: switching to use the workaround client for webtests everywhere
  * applicationinsights: working around the breaking upstream api change
  * Fix the issue of Network API version of Virtual Network Gateway Nat Rule (#16839)
  * Update azurerm_application_gateway priority attribute to confirm its now mandatory (#16794)
  * Fixing error importing the deprecated resource (#16827)
  * CHANGELOG#16532
  * Redis API Upgrade - 2020-12-01 to 2021-06-01 (#16532)
  * CHANGELOG #16722
  * `azurerm_spring_cloud_app` - `addon_json` (#16722)
  * CHANGLOG.md for #15720
  * New resource: azurerm_virtual_network_gateway_nat_rule (#15720)
  * CHANGELOG #16678
  * `azurerm_container_registry` - support update replications on demand (#16678)
  * Fix TC for azurerm_cosmosdb_cassandra_cluster and azurerm_cosmosdb_cassandra_datacenter (#16752)
  * Update changelog for #16718
  * `azurerm_windows_function_app`/`azurerm_linux_function_app` - Add support for PowerShell 7.2  (#16718)
  * Doc Fix: azurerm_linux_function_app - [force_disable_content_share] property should match windows property [content_share_force_disabled] (#16796)
  * Search: Swap to embedded sdk (#16763)
  * Update Changelog for #14821
  * New Data Source/Resource: `azurerm_elasticsearch` (#14821)
  * Update Changelog for #16819
  * Make sure SKU is not null before using it (#16819)
  * removve all ThreePointOhBeta mentions
  * Update changelog for #16804
  * `azurerm_express_route_gateway` - Handle gateway connections not found error (#16804)
  * Doc Fix: `azurerm_mssql_managed_instance` Updates vcores options for Gen5 SKUs (#16770)
  * update code
  * CHANGELOG.md for #16280
  * `azurerm_spring_cloud_app` supports `identity` (#16280)
  * v3.6.0
  * Update CHANGELOG.md
  * CHANGELOG.md for #16743
  * azurerm_cosmosdb_cassandra_cluster - support new property tags (#16743)
  * azurerm_cdn_endpoint_custom_domain: add None option for tls_version (#16750)
  * CHANGELOG.md #16631
  * azurerm_cosmosdb_account : support version 4.2 to mongo_server_version property of resource azurerm_cosmosdb_account (#16738)
  * CHANGELOG #16631
  * `azurerm_virtual_network_gateway_connection` Add new feature to set `custom_bgp_addresses` (#16631)
  * CHANGELOG.md #16720
  * new resource `azurerm_spring_cloud_gateway_custom_domain` (#16720)
  * CHANGELOG.md for #14847
  * `r\linux_virtual_machine`,`r\windows_virtual_machine`: Add support for `diff_disk_settings.placement` (#14847)
  * d/servicebus_queue_authorization_rule: switching to use the right field name (#16495)
  * Documentation Improvements - Markdown formating parameters.
  * Search: Add embedded sdk (#16749)
  * `azurerm_container_registry_task` - Fix document about `registry_credential.custom.identity` (#16737)
  * `example`: Add examples for Azure Disk Encryption VM Extension and Managed Disk Property (#15356)
  * CHANGELOG #16733
  * azurerm_synapse_workspace - correctly update the property public_network_access_enabled (#16733)
  * Update documentation for `azurerm_synapse_sql_pool` resource (#16747)
  * Add information to documentation that changing vm_size of default node pool will recreate the whole cluster (#16755)
  * CHANGELOG #16439
  * New Resource azurerm_stream_analytics_output_powerbi (#16439)
  * CHANGELOG.md for #16709
  * `azurerm_container_group` - Support customer managed key encryption (#16709)
  * CHANGELOG.md for #16705
  * azurerm_mssql_managed_instance_failover_group :  Fix "The given primary field in create or update instance failover group request body is empty or invalid" error (#16705)
  * CHANGELOG.md for #16673
  * new resource `azurerm_spring_cloud_build_pack_binding` (#16673)
  * [azurerm_redis_enterprise_database] - Update Eviction Policy due to service update (#16700)
  * remove computed flag from license type (#16746)
  * [Bug fix] azurerm_express_route_gateway - Set gateway connection back on update (#16680)
  * Documentation Improvements - Localization of MSFT docs links.
  * Fix linux_web_app documentation
  * Documentation Improvements - Updated external links to HTTPS
  * Update changelog for #16690
  * `azurerm_kusto_script` - Lock kusto cluster so multiple scripts can be applied (#16690)
  * Update Changelog for #15420
  * Update for #16250
  * [New Resource] `azurerm_confidential_ledger` - Add Azure Confidential Ledger Terraform Resource (#15420)
  * azure_kubernetes_service: Add support for BYO cni #15663 (#16250)
  * Update for #16575
  * azurerm_stream_analytics_function_javascript_uda - support new property is_configuration_parameter (#16575)
  * Update for #16459
  * fix issue 16329 (#16459)
  * Corrected typo in role argument value (#16735)
  * `azurerm_storage_management_policy` - Mark `rule.filters.blob_type` as required (#16701)
  * CHANGELOG #16679
  * `r\snapshot` `d\snapshot`: Add support for `trusted_launch_enabled` (#16679)
  * Add IPv6 support to App/Function ip_restrictions (#16521)
  * Add tip to prevent gotcha around `MicrosoftWindowsServer` Publisher and using `plan` block (#16635)
  * Doc: Fix wrong command in 3.0-upgrade-guide (#16703)
  * refactor: update firewall website markdown (#16713)
  * Refactor: Remove ThreePointOhBeta from p -> r service packages (#16692)
  * Refactor: Remove `ThreePointOhBeta` from some `s` service packages (#16696)
  * Refactor: Remove `ThreePointOhBeta` from `s` -> `w` service packages (#16697)
  * CHANGELOG #16175
  * new resource `azurerm_spring_cloud_gateway` (#16175)
  * CHANGELOG #15558
  * New resource azurerm_managed_disk_sas_token to manage disk exports (#15558)
  * Refactor: Remove `ThreePointOhBeta` from `n` service packages (#16691)
  * Refactor: Remove `ThreePointOhBeta` from `m` service packages (#16689)
  * waitLRO (#16699)
  * update document (#16675)
  * Update version number azurerm_postgresql_server (#16708)
  * Update for #16579
  * azurerm_stream_analytics_function_javascript_udf - support new property is_configuration_parameter (#16579)
  * add test for tags (#16658)
  * add test for enabled/retention_policy.days (#16655)
  * add test for authorized_resource_ids/tags (#16654)
  * Update for #16360
  * `cluster_node_pool/kubernetes_cluster` remove node_labels forceNew (#16360)
  * Refactor: Remove `ThreePointOhBeta` from `k` service packages (#16688)
  * Refactor: Remove ThreePointOhBeta from k service packages (#16670)
  * Refactor: Removing ThreePointOhBeta from `h` -> `i` service packages (#16668)
  * Refactor: Remove ThreePointOhBeta from e->f packages (#16667)
  * Refactor: Removing `ThreePointOhBeta` from `d` service packages (#16666)
  * Refactor: Removing `ThreePointOhBeta` from A -> C service packages (#16661)
  * azurerm_key_vault_secret - update the example in resource document (#16676)
  * Update Changelog for #16462
  * Add access_tier attribute to storage_share  (#16462)
  * v3.5.0
  * Update CHANGELOG.md
  * Fixes minor spelling error and highlights Default with backticks (#16663)
  * docs(kubernetes_cluster): Fix failing output (#16664)
  * CHANGELOG for #16440
  * New resource - `azurerm_sentinel_data_connector_aws_s3` (#16440)
  * CHANGELOG for #16001
  * `dependencies`: Update `recoveryservices` to 2021-12-01/backup (#16001)
  * [Bug fix] Fix service bus subscription id case diff issue (#16267)
  * `azurerm_kusto_script` - Lock kusto database so multiple scripts can be applied (#16649)
  * Add support for `-` in `azurerm_data_factory_managed_private_endpoint` (#16646)
  * `azurerm_batch_pool` add test for start_task.user_identity.user_name (#16602)
  * updating to include #16659
  * dependencies: updating to `v1.5.11` of `github.com/hashicorp/go-getter`
  * CHANGELOG.md for #16431
  * data.azurerm_service_plan: fix missing setting values of “kind” and “os_type” properties issue (#16431)
  * `recovery_services_vault`: Split create and update (#16545)
  * `r\iothub` Add validation for `ip_rules.name` (#16601)
  * `notification_hub_namespace` waitLRO (#16593)
  * Update for #16640
  * switch delete mode to Delete instead of Detach (#16640)
  * Update changelog for #16639
  * New Resource: `azurerm_mssql_managed_instance_vulnerability_assessment` (#16639)
  * Documentation note to match examples (#16643)
  * Update virtual_desktop_scaling_plan.html.markdown - bad parameter ref in example (#16647)
  * Update for #16641
  * `azurerm_linux_function_app` and `azurerm_linux_function_app_slot` fix WEBSITE_RUN_FROM_PACKAGE handling from external sources (#16641)
  * CHANGELOG for #16087
  * new resource `azurerm_spring_cloud_configuration_service` (#16087)
  * Add unit test for `MergeUserAppSettings` (#16633)
  * Update changelog for #16351
  * Control cross tenant replication (#16351)
  * Update for #15740
  * fix: MergeUserAppSettings does not deduplicate merged app settings (#15733) (#15740)
  * Update for #16533
  * bump azure-go-sdk to v63.4 (#16533)
  * Documentation Improvements - Broken links, streamlining (#16620)
  * `azurerm_frontdoor` add test for `backend_pool`/`backend_pool_health_probe`/`friendly_name`/`frontend_endpoint`/`load_balancer_enabled`/`routing_rule`/`tags` (#16296)
  * Update changelog for #15938
  * `azurerm_virtual_network_gateway_connection` - Multiple `traffic_selector_policy` can now be specified (#15938)
  * Update changelog for #16523
  * `azurerm_servicebus_namespace` - `sku` can be updated to `Basic`/`Standard` without recreating the resource (#16523)
  * CHANGELOG.md for #16036
  * new resource `azurerm_spring_cloud_builder` (#16036)
  * `azurerm_storage_account` - Allow omitting optional blocks under`queue_properties` (#16557)
  * `azurerm_linux_web_app_slot` add test for site_config.scm_ip_restriction.action/ip_address/name/priority/virtual_network_subnet_id/headers.x_azure_fdid/x_fd_health_probe/x_forwarded_for/x_forwarded_host (#16564)
  * CHANGELOG.md for #15887
  * `Dependency` New Resource/Data Source  azurerm_healthcare_dicom_service (#15887)
  * Documentation Improvements - General streamlining in code blocks. (#16614)
  * Remove unneeded storage account from example (#16604)
  * Update for #16572
  * azurerm_stream_analytics_output_servicebus_queue - support new properties property_columns and system_property_columns (#16572)
  * Update for #16543
  * Add missing default values to fix #13545 (#16543)
  * add test for virtual_network_subnet_id (#16577)
  * doc: update function app naming rule (#16592)
  * Update for #16594
  * Fix validation and doc for vm/vmss `termination_notification` (#16594)
  * Update for #16561
  * Fix #16561 by correcting argument name (#16597)
  * `iothub`: Fix `default_action` values (#16598)
  * v3.4.0
  * Updating to include #16516
  * merge #16516
  * CHANGELOG.md for #15570
  * `r\linux_virtual_machine_scale_set` `r\windows_virtual_machine_scale_set`: Rename `terminate_notification` to `termination_notification` (#15570)
  * `api_management_custom_domain` waitLRO (#16544)
  * update the document of data source `azurerm_virtual_machine_scale_set` (#16580)
  * Documentation Improvements: Spelling corrections and casing (#16589)
  * `linux/windows_web_app` - Add missing level parameter for azure_blob_storage (#16591)
  * Update to include terraform registry manifest
  * Update for #16551
  * fix node pool validation and remove ThreePointOhBeta flags (#16551)
  * Update for #16546
  * `azurerm_[linux|windows]_[function|web]_app` - add support for `sticky_settings` (#16546)
  * azurerm_virtual_network_gateway - not set bgpSettings.BgpPeeringAddress when it isn't specified (#16383)
  * `azurerm_linux_function_app` add test for site_config.scm_ip_restriction.virtual_network_subnet_id (#16559)
  * CHANGELOG.md for #15835
  * `dependencies`: Upgrade sqlvirtualmachine to 2021-11-01-preview (#15835)
  * Update vendor for go-azure-helpers v0.31.1
  * Doc Fix: azurerm_public_ip_prefix - remove availability_zone for public ip prefix in tf doc as it is not supported after v3.0 (#16562)
  * Add ability to use dashes in administrator login (#16522)
  * Test Fix: Post 3.0 More quota region changes (#16556)
  * Formatting
  * Formatting
  * Apply suggestions from code review
  * CHANGELOG.md for #16548
  * azurerm_stream_analytics_job - support new property job_type (#16548)
  * Updated index on guide page adding new provider options
  * Terraform block formatting
  * Update service_principal_oidc.html.markdown
  * Update azure-go-helpers
  * Adding OIDC as auth method
  * Fix `TestAccBackupProtectedVm_*` `TestAccSiteRecoveryReplicatedVm_*` (#16552)
  * Update changelog for #16528
  * `azurerm_mssql_database` - Support for `short_term_retention_policy.0.backup_interval_in_hours` (#16528)
  * Update for #16441
  * Stream analytics output to CosmosDB (#16441)
  * Update for #15029
  * Add run command enabled parameter to AKS cluster (#15029)
  * Correct documentation of boundary conditions for azurerm_storage_share.quota property (#16550)
  * CI config - App Service Plans not available in WestUS2 currently (#16549)
  * Update for #16534
  * `azurerm_monitor_aad_diagnostic_setting` - remove validation on `log.category` (#16534)
  * Doc Fix: `linux_web_app` and `windows_web_app` - make file_system_level argument required (#16538)
  * Update changelog for #16514
  * Test Fixes - Swapping regions based on quota (#16514)
  * Doc Fix: azurerm_linux_web_app - Fix vnet_route_all_enabled property missing from azurerm_linux_web_app site config (#16531)
  * Fix dangling OS disk in `TestAccMsSqlVirtualMachine_*` (#16519)
  * Fix the document issue related with #12456 . (#16536)
  * Update mssql_server_transparent_data_encryption.html.markdown (#16512)
  * Fix docs example error in `azurerm_data_protection_backup_instance_blob_storage` (#16517)
  * Documentation Improvements: Spelling corrections and casing. (#16520)
  * Rename additional_login_params to additional_login_parameters (#16474)
  * DocumentationImprovements 2: Casing
  * DocumentationImprovements #1: Spelling corrections.
  * updating to include #16504
  * dependencies: upgrading to `v0.30.0` of `github.com/hashicorp/go-azure-helpers`
  * Update changelog for #16478
  * `azurerm_resource_policy_remediation` - Fix deletion failure due to canceling a completed remediation task (#16478)
  * updating to include #16458
  * adding example to maintenance window documentation (#16502)
  * add test for request/response
  * dependencies: updating to v0.11.26 of github.com/Azure/go-autorest
  * updating to include #16283
  * v3.3.0
  * `azurerm_cosmos_db_account` - `ip_range_filter` moved from string to List (#16017)
  * fixup changelog for release
  * `azurerm_api_management_subscription` add test for primary/secondary key (#16485)
  * `cosmosdb_account_resource` wait LRO (#15684)
  * `app_service_environment_v3_resource` wait LRO (#16279)
  * `app_service_environment_resource`wait LRO (#16278)
  * CHANGELOG.md for #16277
  * `azurerm_spring_cloud_service` supports `service_registry_enabled` (#16277)
  * CHANGELOG.md for #16118
  * `data_factory_linked_service_sql_server_resource` supports userName (#16118)
  * Update changelog for #16403
  * `azurerm_data_factory_linked_service_azure_blob_storage` - support for `storage_kind` (#16403)
  * azurerm_cosmosdb_mongo_collection: fix default_ttl_seconds=null is not reflected correctly in state issue (#16405)
  * Fix for azurerm_api_management_api_operation with default sample representations (#16273)
  * CHANGELOG.md for #16045
  * azurerm_redis_enterprise_cluster - support linked_database_id and linked_database_group_nickname (#16045)
  * Fix: Clear properties of `NetworkRuleSet` after deleting `storage account network rules` resource (#15780)
  * `azurerm_api_management_backend` add test for service_fabric_cluster.server_x509_name.issuer_certificate_thumbprint/name (#16338)
  * CHANGELOG.md for #16478
  * CHANGELOG.md for #16181
  * new resource `azurerm_spring_cloud_container_deployment` (#16181)
  * Update changelog for #16143
  * `azurerm_cdn_endpoint` -`origin.0.http/https_ports` are now set as the default values of `80`/`443` (#16143)
  * `azurerm_application_gateway` - Split the create/update methods (#16477)
  * Update property description for fqdn of azurerm_private_dns_zone (#16427)
  * CI: `validate-example` uses local built provider (#16388)
  * Update the description of the enabled property of azurerm_logic_app_workflow (#16480)
  * CHANGELOG.md for #16414
  * `azurerm_data_factory_linked_service_azure_blob_storage`: Support SP key KV reference (#16414)
  * update doc on defaults option (#16492)
  * Update for #16488
  * fix disabling of rbac (#16488)
  * `kubernetes_cluster` Remove ip_version parameter from nat_gateway_profile (#16489)
  * Fix load_balancer_sku string case sensitive (#16490)
  * Changelog for #16455
  * `azurerm_{\w+_}?policy_assignment` - ensure `name` not contains `/`
  * Update for #16389
  * Add support for columns_to_remove of azurerm_stream_analytics_output_table (#16389)
  * Doc Update: `azurerm_route*` - Update `address_prefix` to reflect service tags can be set (#16466)
  * Update for #16218
  * `azurerm_kubernetes_cluster` - add support for Defender Profile (#16218)
  * Update to Hamilton v0.44.0 and go-azure-helpers v0.28.0. Closes #16291
  * Update for #16446
  * `azurerm_[linux|windows]_web_app` fix removal of appstack block (#16446)
  * Update website/docs/r/lb.html.markdown
  * docs: updating `availability_zones` to `zones` for the LB resource
  * updating to include #16428
  * update for #16442
  * `azurerm_[windows|linux]_function_app` - refactor `app_settings` processing for updates (#16442)
  * Update for #16426
  * Update for #16409
  * `AppService` - fix bug in flattening ip_restriction shared code (#16426)
  * azurerm_stream_analytics_output_mssql - add support for new properties `max_batch_count` and `max_writer_count` (#16409)
  * updating to include #16460
  * storage: changes required for Giovanni v0.19.0
  * dependencies: updating to v0.19.0 of github.com/tombuildsstuff/giovanni
  * updating to include #16419
  * updating to include #16402
  * updating to include #16404
  * frontdoor: adding a note about api versions (#16450)
  * remove go-getter
  * Update changelog for #16430
  * `azurerm_virtual_hub_connection` - Remove ForceNew for `internet_security_enabled` (#16430)
  * Update for #16425
  * azurerm_stream_analytics_output_servicebus_topic - add support for new property system_property_columns (#16425)
  * Document on which day a week starts for postgresql_flexible_server (#16432)
  * Fix `TestAccCognitiveAccountCustomerManagedKey_complete`
  * `azurerm_linux_web_app` Add length check to fix #16400 (#16408)
  * sentinel - removing setting `etag` before updating it
  * Update doc example for azurerm_mysql_server (#16407)
  * azurerm_kusto_cluster - Fix typo MyTentantOnly to MyTenantOnly
  * `azurerm_storage_account` - Fix error when enabling identity and cmk
  * Onboard project to Releases API
  * `azurerm_storage_account` data source - Export `nfsv3_enabled`
  * `azurerm_subnet` - add up the missing part for deprecating `address_prefix`
  * Changed the database SKU from BC_Gen5_2 to S0. (#16398)
  * v3.2.0
  * tidy changeling for releases
  * build: switching to use Go 1.18.1 (#16393)
  * Function apps, note about not using FUNCTIONS_WORKER_RUNTIME (#16394)
  * clients: registering using the specific Azure Environment
  * Update changelog for #16328
  * `azurerm_postgresql_flexible_server` - allow `high_availability` blocks to be added and removed (#16328)
  * Update changelog for #16385
  * `azurerm_cdn_endpoint` - New value for `operator` of `url_path_condition`: `RegEx` and `Wildcard`. (#16385)
  * doc fix (#16387)
  * Update changelog for #16371
  * `azurerm_eventhub_namespace` - separate create and update funcs (#16371)
  * Update for #16349
  * Update changelog for #16370
  * add $superuser as option for owner and group (#16370)
  * New Resource: `azurerm_stream_analytics_job_schedule` (#16349)
  * CHANGELOG.md for #16366
  * Update radius.server_root_certificate of azurerm_vpn_server_configuration to optional (#16366)
  * CHANGELOG.md for #16369
  * `r\lb_outbound_rule` Allow `0` for `allocated_outbound_ports` (#16369)
  * CHANGELOG.md for #16313
  * Fix `data_source_type` for the resource `Log Analytics Linked Storage Account Type` (#16313)
  * Mention `se`/`st` fails if has the time offset set, in the document (#16314)
  * docs: updating the 3.0 upgrade notes for keyvault to include the casing changes (#16363)
  * CHANGELOG.md for #15731
  * New resource: `azurerm_container_connected_registry` (#15731)
  * CHANGELOG.md for #15861
  * `azurerm_sentinel_watchlist` - Add required property `item_search_key` (#15861)
  * Add property description for public_network_access_enabled of azurerm_kusto_cluster (#16362)
  * Fix svc plan SKU typo (#16364)
  * fix issue 16289
  * Fix issue - the get throughput api should not be called when cosmos account is serverless (#16281)
  * Update changelog for #16293
  * New Resources: `azurerm_*_policy_exemption` (#16293)
  * aks: raise conntrack_max limit to 1048576 (#16347)
  * CHANGELOG.md for #16204
  * add `init_container` to `azurerm_container_group` resource. (#16204)
  * `mysql_virtual_network_rule` waitLRO (#16043)
  * `mariadb_virtual_network_rule` waitLRO (#16042)
  * Fix provider URL
  * Add release script
  * Update changelog for #16312
  * Fix MySQL flexible server backup_retention_days (#16312)
  * fix issue 16337 (#16339)
  * `azurerm_api_management_api_diagnostic` add test for backend_response.data_masking.headers.mode/value/frontend_request.data_masking.query_params.mode/value (#16318)
  * `azurerm_api_management_authorization_server` - add test for client_authentication_method/description/token_body_parameter.name/value (#16324)
  * `azurerm_frontdoor_firewall_policy` add test for tags (#16316)
  * Update changelog for #16180
  * `kusto_database ` support data source `kusto_database_data_source.go` (#16180)
  * Update .goreleaser.yml
  * docs: *_virtual_machine: add note about provision_vm_agent
  * Migrate Provider Releases from TeamCity to GitHub Actions
  * docs: fix property name for `azurerm_*_policy_remediation` doc (#16303)
  * Update changelog for #16304
  * `azurerm_media_streaming_endpoint` support Standard Streaming Endpoint (#16304)
  * Update for #16288
  * rename public_network_access_enabled to better reflect that this applied to behind a vnet (#16288)
  * v3.1.0
  * pre release fixups
  * Update for #14848
  * [Bug Fix - azurerm_api_management_api_operation] -  Handling example.value none-string types (#14848)
  * CHANGELOG.md for #16258
  * Update changelog for #16268
  * add support for local_auth_enabled (#16268)
  * Update for #16270
  * Upgrade Stream Analytics API version from 2020-03-01-preview to 2020-03-01 (#16270)
  * tidy
  * go mod
  * upgrade sdk from 63.0 to 63.1 to use the monitor sdk
  * website-scaffold: generate TF configuration example from AccTest (#13985)
  * `synapse_workspace_resource`wait LRO (#16266)
  * add dynamic_container_enabled support for datafactory (#15749)
  * New resource: `azurerm_container_registry_agent_pool` (#16258)
  * Dataset blob store location path can be empty (#16169)
  * Update changelog for #16214
  * `azurerm_mssql_database` - support for property `ledger_enabled` (#16214)
  * Test Fixes: Post 3.0 (#16264)
  * Update for #16156
  * `azurerm_service_plan` - add support for `zone_balancing_enabled` (#16156)
  * `private_dns_zone_virtual_network_link` waitLRO (#15872)
  * CHANGELOG.md for #15601
  * `azurerm_servicebus_namespace` supports `customer_managed_key` (#15601)
  * CHANGELOG.md for #16229
  * azurerm_cosmosdb_sql_container: fix issue about removing analytical_storage_ttl needs to force replacement (#16229)
  * `lighthouse_assignment` waitLRO (#16041)
  * CHANGELOG.md for #16253
  * r/dedicated_host: support for the Sku's `DSv3-Type4` and `ESv3-Type4` (#16253)
  * Update mssql_server_security_alert_policy.html.markdown (#16236)
  * Test Fix: Post 3.0 (#16251)
  * TC - enable location and location rotation overrides (#16254)
  * fix for 10573 - Error during terraform apply on existing LA workspace in Free tier (#15843)
  * Update for #16088
  * `kubernetes_cluster_resource` support network_profile.ip_versions (#16088)
  * Update for #16130
  * Adding `oidc_issuer_profile` support to `azurerm_kubernetes_cluster` (#16130)
  * Update for #16192
  * `azurerm_windows_web_app` and `azurerm_windows_web_app_slot` - fix docker windowsfxversion string clobbering (#16192)
  * updating to include #16247
  * examples: updating to account for 3.0
  * tooling: updating golangci-lint to 1.45.0
  * tooling: pinning golangci to go 1.18
  * go mod vendor
  * go mod tidy
  * dependencies: updating to Go 1.18
  * Fix ordering issue
  * refactor: switching to wrap the strings.Title dependency
  * Fix `postgresql_server_key` documentation example (#16232)
  * Fixing Route Server Example (#16243)
  * Update firewall_policy_rule_collection_group.html.markdown (#16227)
  * tools: updating to v1.45.0 of golangci-lint
  * Update changelog for #16132
  * `azurerm_application_gateway` - allow `frontend_ip_configuration` blocks to be changed (#16132)
  * updating to include #16147
  * Update for #16152
  * azurerm_cosmosdb_sql_container,azurerm_cosmosdb_gremlin_graph: fix the case-insensitive issue about indexing_mode property after 3.0 release (#16152)
  * More test fixes
  * update changelog for #16215
  * update validation to allow superuser value (#16215)
  * Test Fixes - Post 3.0 (#16199)
  * [fix] Wrong reference to txt record. (#16212)
  * `azurerm_monitor_metric_alert` add dynamic_criteria.evaluation_failure_count/evaluation_total_count/ignore_data_before (#15996)
  * add test for probe (#16203)
  * Update for #16161
  * automation_account_resource: make dsc_*_access_key sensitive (#16161)
  * Fix incorrect resource referenced in header (#16207)
  * Fix `azurerm_public_ip` docs around default zone redundant behavior (#16209)
  * `spring_cloud_app_cosmosdb_association` waitLRO (#16039)
  * Update changelog for #16170
  * `azurerm_application_insights` - Remove disable logic for the Azure created Action Group (#16170)
  * Replace existing issue templates with github forms (#16159)
  * update url validation (#16186)
  * Update preview notes (#16137)
  * TC - update policy tests target, update acctest tertiary location (#16185)
  * Updated for #16080
  * `azurerm_web_application_firewall_policy` Fix #16019 by adding `KNOWN-CVES` to `ValidateWebApplicationFirewallP… (#16080)
  * docs: add case-sensitive fields for azurerm_key_vault_access_policy (#16160)
  * fix: update attribute name to match documentation (#16171)
  * Updated for #16164
  * `azurerm_windows_function_app` - fix import check for Service Plan `kind` (#16164)
  * Updated for #16149
  * `azurerm_linux_web_app_slot ` - fix `container_registry_managed_identity_client_id` validation (#16149)
  * Test Fixes: Post 3.0 Authorization -> Data Factory (#16144)
  * Update changelog for #16044
  * `dependencies` Update `digitaltwins` api version to 2020-12-01 (#16044)
  * Update changelog for #16074
  * Additional two filters, SubscriptionID and SubscriptionName, for consumption_budget_management_group resource (#16074)
  * Updated for #16129
  * `azurerm_windows_web_app` - add support for `dotnetcore` in site metadata value `current_stack` (#16129)
  * Update for #16134
  * `azurerm_linux_function_app` and `azurerm_linux_function_app_slot` remove `RequiredWith` constraints on app insights settings (#16134)
  * Upgrading go SDK from v62.3.0 to v63.0.0
  * docs: data source allow public access (#16145)
  * azurerm_mssql_database - storage_account_type remove force new (#16113)
  * Update for #15804
  * `r\cognitive_account`: Add support for `custom_question_answering_search_service_id` (#15804)
  * Update go-azure-helpers to v0.28.0
  * Remove legacy ADAL support previously hidden behind a feature flag
  * Mention free tier restrictions (#16127)
  * fix: wrong doc resource page title (#16117)
  * CI - update acctest regions based on quota expectations and re-enable region rotation (#16119)
  * Remove duplicated `os_type` in `service_plan` doc (#16122)
  * default acctests to deleting non-empty rgs so failed tests clean up (#16094)
  * Doc update: app_service_source_control incorrect variable requirements (#16082)
  * `lighthouse_definition` waitLRO (#16040)
  * docs: update default value for min_tls_version and reference to deprecated argument (#16108)
  * fix: typo on user_assigned_identity resource name (#16102)
  * service_plan example missed required os_type (#16100)
  * allow_blob_public_access in Note renamed (#16098)
  * Service Plan and Web App docs update (#16091)
  * Update mssql_database.html.markdown (#16110)
  * CHANGELOG.md for #16006
  * Bug fix `azurerm_api_management_api_operation_tag` get tag by operation (#16006)
  * `spring_cloud_custom_domain` waitLRO (#16037)
  * `spring_cloud_certificate` waitLRO (#16038)
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * v3.0.2
  * CHANGELOG.md for #16078
  * Update go-azure-helpers to v0.27.0 (#16078)
  * Update changelog for #16073
  * `azurerm_resource_group` - Wait for eventual consistency when deleting (#16073)
  * CHANGELOG.md for #16070
  * azurerm_managed_disk - mark zone as force new (#16070)
  * azurerm_cosmosdb_account - update docs and example to remove prefix (#16067)
  * CHANGELOG.md for #16066
  * `azurerm_cdn_endpoint` nil check contents of `country_codes` (#16066)
  * azurerm_api_management_gateway_api - fix docs example (#16062)
  * Fix documentation on azurerm_public_ip (#16064)
  * Add guide on how to migrate to replacement resources (#16060)
  * Update resource address of import command (#16056)
  * `azurerm_application_gateway` - update docs and upgrade guide for `match` block properties (#16053)
  * CHANGELOG.md for #16046
  * `azurerm_[linux|windows]_function_app` - fix update to storage settings when using MSI (#16046)
  * CHANGELOG.md for #16031
  * azurerm_cosmosdb_account - prevent panic (#16031)
  * Update CHANGELOG.md
  * CHANGELOG.md to include allow_blob_public_access change
  * 3.0 Doc Fix (#16025)
  * v3.0.1
  * Features block schema fixes
  * Update README.md
  * Changelog for #16021
  * Features: be explicit about all default values
  * Bugfix: default the resource group `prevent_deletion_if_contains_resources` feature flag to `true`
  * placeholder for 3.1.0
  * v3.0.0
  * `azurerm_policy_definition` - fix creation of management group policy definitions and policy tests (#16013)
  * remove extended_audit related code
  * docs: referencing v3.0
  * loadtest: renaming the test so it matches the expected syntax
  * r/api_management: adding a lifecycle test (CRUD) using consumption since it's considerably quicker
  * r/api_management: recovering only during creation
  * sql: remove tests for blob auditing policy block
  * azurerm_sql_server / azurerm_sql_database: fix up blob auditing policy removal
  * update storage config for mariadb and mysql tests for removal of storage_profile
  * fixing the build
  * cleanup: removing dead code
  * Docs: Make `identity` and `zones` documentation consistent (#16007)
  * terrafmt
  * docs: adding data sources/resources containing deprecated tags
  * r/function_app_slot: removing the deprecated `client_affinity_enabled` field
  * r/function_app: removing the deprecated fields
  * docs: further updating of the upgrade guide
  * docs: clarifying the block
  * r/network_connection_monitor: removing the deprecated fields
  * docs: misc additions to the upgrade guide
  * mssql: removing the deprecation from the migration
  * r/keyvault: removing the note about soft delete since this is now always enabled
  * r/frontdoor: updating to account for the properties being moved inside a block
  * eventgrid: removing `hybrid_connection_endpoint`
  * eventgrid: removing `eventhub_endpoint`
  * r/container_registry: `sku` is now required and can no longer be set to `Classic`
  * remove version property from redis_enterprise_cluster
  * remove 3.0 beta docs from guides
  * remove beta feedback issue template
  * data factory - remove deprecated structure_column
  * updating to include #16004
  * 3.0 test fixes for pgsql and trafficmanager (#16008)
  * r/storage_account: StorageV1 and ZRS is no longer supported
  * Fix UT for LogAnalyticsWorkspace default feature
  * splitting the Readme and Developer guides
  * Rollback issues introduced in 48d9aadb1e1397d99fe3dc535a2e7c4928f441ae
  * `web_pubsub_hub`  waitLRO (#15896)
  * update spring cloud sdk to 2022-03-01-preview (#15953)
  * Fix error message for form_parameter (#15995)
  * `azurerm_spring_cloud_java_deployment` supports `runtime_version` Java17 (#15954)
  * `spring_cloud_service` supports `E0` sku (#15957)
  * Add name validation for azurerm_mysql_firewall_rule (#15959)
  * azurerm_lb_probe: remove unused resource_group_name property (#15993)
  * `azurerm_route_table ` - Move `route` from List to Set (#15991)
  * CHANGELOG.md for #15992
  * `azurerm_cdn_endpoint` -> Rename `host_name` to `fqdn` (#15992)
  * CHANGELOG.md for #15747
  * `azurerm_security_center_server_vulnerability_assessment` - deprecate in favour of `azurerm_security_center_vm_server_vulnerability_assessment` (#15747)
  * CHANGELOG.md for #15983
  * `azurerm_security_center_setting` - Disable on Delete and RequiresImport support (#15983)
  * CHANGELOG.md for #15892
  * `azurerm_application_insights` - Disable Rule and Action Group that are automatically created when creating this resource (#15892)
  * `azurerm_key_vault_certificate` - `x509_certificate_properties.0.key_usage` swapping TypeList to TypeSet (#15988)
  * CHANGELOG.md for #15989
  * 3.0: adding missing import validators (#15989)
  * mssql test fixes (#15949)
  * remove outdated example
  * updating to include #15984
  * make fmt
  * updating to include #15901
  * fix linting
  * azurerm_lb_rule / azurerm_lb_outbound_rule: remove the deprecated resource_group_name property (#15986)
  * fix test
  * minor fix
  * updating to include #15982
  * updating to include #15933
  * fix sql auditing panic
  * remaining tests and docs
  * update subnets in tests to use prefixes
  * fix error that made it into main during GHA outage
  * test fixes
  * update cosmos throughput test for new validation - see #15978 for related change (#15985)
  * remove more tests for unsupported app versions
  * various fixes
  * various fixes
  * Fix up schema and docs, and align defaults, for soft-deleted-recover and purge-on-delete behaviors
  * terrafmt
  * remove tests for unsupported node versions
  * Update website/docs/r/storage_share.html.markdown
  * azurerm_storage_share - make quota required
  * portal: re-introducing the deprecated `azurerm_dashboard` resource
  * Update app stack versions
  * updating to include #15973
  * fix: 🐛 Adjust minimum limit of max_throughput validation (#15978)
  * `azurerm_service_plan` - remove retiring skus (#15971)
  * Update docs for 3.0 (#15974)
  * Doc FIx: log_analytics_workspace block (#15975)
  * d/kubernetes_cluster: updating to account for the identity changes
  * r/kubernetes_cluster: documenting the changes to the identity block
  * r/purview_account: documenting the identity block changes
  * r/storage_account: documenting the identity block changes
  * r/synapse_workspace: documenting the identity changes
  * r/app_service: documenting the identity changes
  * r/app_service_slot: documenting the identity changes
  * Update for #15969
  * App Service - add dotnet-isolated runtime support (#15969)
  * r/function_app: documenting the identity block changes
  * r/function_app_slot: removing/documenting the identity changes
  * r/log_analytics_cluster_customer_managed_key: updating the Exists function to check that CMK exists
  * r/portal_dashboard: updating the docs
  * docs: note about azurerm_dashboard being renamed
  * terrafmt
  * apim: updating the todo to be for 4.0
  * appconfig: handling the app configuration being deleted
  * refactor: working through todo's
  * r/eventgrid_topic: tests can now run anywhere
  * r/firewall_policy: updating the docs to account for the identity changes
  * hpccache: fixing the validation message
  * iothub: documenting the change
  * todo cleanup
  * r/log_analytics_cluster_customer_managed_key: swithcing to use the Cluster ID directly
  * machinelearning: switching to use the new identity types
  * r/mssql_server: migrating to use the new `identity` type
  * updating to include #15948
  * r/mysql_server: removing support for 5.6 (not present in the docs)
  * policy: removing an unnecessary todo
  * policy: removing the old id parser
  * TC - deactivate location shuffling for acceptance tests (#15962)
  * modify code and clean up code
  * `azurerm_vpn_site` add test for tags
  * Update for #15907
  * update function apps and app slots to correctly maintain content settings (#15907)
  * fix build
  * CHANGELOG.md for #15617
  * Added 'target_availability_zone' argument for zone-zone ASR (#15617)
  * typos and terrafmt
  * fix some linting errors
  * intial pass through deprecations
  * linting: unnecessary pointer deref (#15950)
  * CHANGELOG.md for #14759
  * azurerm_mssql_database_vulnerability_assessment_rule_baseline: fix the resource is being replaced every new tf apply issue (#14759)
  * fix tests
  * feature log_analytics_workspace/permanently_delete_on_destroy defaults to true
  * CHANGELOG.md for #15741
  * azurerm_virtual_hub - support for virtual_router_asn and virtual_router_ips properties (#15741)
  * CHANGELOG.md for #15597
  * update spring cloud sdk to 2022-01-01-preview (#15597)
  * CHANGELOG.md for #15562
  * `r\shared_image`: Add support for `support_accelerated_network` (#15562)
  * change custom_subdomain_name from optional to required (#15944)
  * Block Blob Storage: Allow infrastructure_encryption_enabled to be set for accounts of type BlockBlobStorage. (#15885)
  * `azurerm_storage_management_policy` - bug fix for `rule.actions` block (#15832)
  * CHANGELOG.md for #15897
  * azurerm_synapse_workspace_key - can not be correctly rotated (#15897)
  * updating to include #15890
  * Update changelog for #15159
  * `azurerm_local_network_gateway` : fix for `address_space` cannot be updated #15159
  * `s\recoveryservices` `s\loganalytics`: Deprecate unsupported tags (#15403)
  * Add uprade note for 15403
  * `azurerm_subnet` - Swap `service_endpoints` from TypeList to TypeSet (#15424)
  * Add upgrade guide note
  * Bugfix: correct env var for custom metadata host
  * Bugfix: ensure MSAL is always enabled
  * Fix auto_swap_slot_name missing from app_service_slot documentation (#15925)
  * Changelog for #15871
  * Add upgrade guide for this resource
  * rename `group_by` to `group_by_entities`
  * r/redis_cache: updating the todo
  * postgres: clarifying a todo
  * refactor: cleanup of unnecessary todo's
  * redis: refactoring the validate max memory policy validation function
  * portal: requires import
  * azurerm_api_management: support recovery of soft deleted instances and enable purge on deletion by default
  * add missing proxy property doc
  * updating to include #15829
  * Update internal/services/synapse/synapse_workspace_resource.go
  * Update internal/services/synapse/synapse_workspace_resource.go
  * r/linux_virtual_machine: adding an explicit type assertion
  * CI - remove spaces from cron days for `web` (#15935)
  * r/sentinal_alert_rule_scheduled: fixing the 3.0 todo's
  * rename all remaining blob access properties
  * go mod vendor
  * make generate
  * cleanup: removing remnants of datalake
  * docs: adding deprecations to the upgrade guide
  * network: removing remnants of the older tests
  * datalake: removing the Gen1 dependent resources
  * hdinsight: removing the deprecated HDInsight resources
  * apimanagement: removing the legacy `azurerm_api_management_property` resource
  * costmanagement: removing `azurerm_cost_management_export_resource_group`
  * datalake: removing deprecated resources:
  * policy: adding back in a removed function
  * trafficmanager: removing `azurerm_traffic_manager_endpoint`
  * kusto: removing `azurerm_kusto_database_principal`
  * network: removing `azurerm_packet_capture`
  * policy: removing deprecated resources `azurerm_policy_assignment` and `azurerm_virtual_machine_configuration_policy_assignment`
  * securitycenter: removing `azurerm_security_center_assessment_metadata`
  * Data factory: fix failing tests (#15931)
  * updating to include #15927
  * updating to include #15873
  * Update for #15930
  * fix issue 15898 (#15930)
  * App Service Tests: update blob access property name in template (#15911)
  * Change type of `group_by` to List
  * Add firewall note to upgrade guide
  * `azurerm_firewall_rule_x` -  change various attribute blocks from `Set` to `List` (#15008)
  * modify code
  * `azurerm_cdn_endpoint` add test for global_delivery_rule.cache_key_query_string_action/modify_request_header_action/url_redirect_action/url_rewrite_action
  * Fix: The real updated time will be equal or after the requested time for azurerm_role_definition (#15817)
  * Upgrading go SDK from v62.1.0 to v62.3.0
  * remove features flags
  * CHANGELOG.md for #15863
  * Data Source: azurerm_storage_account_sas  - support for tag and filter (#15863)
  * Support user assigned identitied in api_management_custom_domain (#15845)
  * azurerm_virtual_network - add vnet_peering_address_list as datasource output for vnet (#15153)
  * CHANGELOG.md for #14933
  * `r\linux_virtual_machine` `r\windows_virual_machine`: Add support for `termination_notification` (#14933)
  * `r\site_recovery_replicated_vm`: Fix issue of `create` depending on `update` timeout (#15501)
  * Add upgrade note for 14027 (#15916)
  * `azurerm_eventhub_namespace` - Swap TypeList to TypeSet for `network_rulesets.x.virtual_network_rule` (#14027)
  * fix: remove deprecated property from documentation (#15903)
  * update docs for app service 3.0 deprecations (#15908)
  * `azurerm_windows_web_app` - correct 32bit worker property name in docs (#15912)
  * goimports
  * tests: updating the configurations to account for edge zone requirements
  * r/storage_account: support for edge_zone
  * r/virtual_network_gateway: support for `edge_zone`
  * r/virtual_network: support for edge_zone
  * r/public_ip: support for edge_zone
  * r/network_interface: adding support for edge_zone
  * r/loadbalancer: support for edge_zone
  * r/managed_disk: support for edge_zone
  * r/windows_virtual_machine_scale_set: adding support for `edge_zone`
  * r/windows_virtual_machine: support for edge_zone
  * r/linux_virtual_machine_scale_set: support for edge_zone
  * r/linux_virtual_machine: support for Edge Zones
  * Update for #15884
  * `azurerm_windows_function_app` node version validation strings. (#15884)
  * Fix golangci-lint error
  * add missed update properties in win web and win web slot (#15883)
  * `azurerm_sentinel_alert_rule_scheduled - support for `group_by_{alert|custom}_details`, `alert_details_override`, `entity_mapping`, `custom_details`
  * CI - enable acctest distribution across subscriptions and enable location rotation (#15826)
  * Fix iothub docs (#15876)
  * fix failed testcases in Synapse
  * `spring_cloud_java_deployment_resource`   wait LRO (#15833)
  * `spring_cloud_app_redis_association_resource` wait LRO (#15836)
  * `spring_cloud_app_mysql_association_resource` wait LRO (#15838)
  * CHANGELOG.md for #15847
  * `azurerm_container_registry` - Validate `georepliactions` to ensure it does not include the location of the ACR (#15847)
  * Add lock for azurerm_cosmosdb_sql_role_assignment and azurerm_cosmosdb_sql_role_definition (#15862)
  * Update resource name (#15864)
  * Fix TC TestAccPostgreSQLServer_createPointInTimeRestore (#15870)
  * `recovery_services_vault`  waitLRO (#15877)
  * 3.0 `azurerm_policy_remediation` split into `azurerm_management_group_policy_remediation`, `azurerm_resource_policy_remediation`, `azurerm_resource_group_policy_remediation` and `azurerm_subscription_policy_remediation` (#15860)
  * updating to include #15834
  * updating to include #15889
  * dependencies: upgrdint to `v0.26.0` of `github.com/hashicorp/go-azure-helpers`
  * Moving 2.90 - 2.99 into the 2.x file
  * splitting the changelog for 2.x out
  * Update for #15874
  * `r\iothub`: Add support for identity-based `file_upload` (#15874)
  * Update for #15878
  * mark kube_config and kube_admin_config as sensitive (#15881)
  * `azurerm_kubernetes_cluster` - Allow key vault provider and open service mesh in China and Government (#15878)
  * update code
  * Update for #15793
  * update code
  * `azurerm_[linux|windows]_function_app` and `azurerm_[linux|windows]_function_app_slot` - support Key Vault Secret for storage connection string (#15793)
  * updating to include the changes from #15800
  * update code
  * New Data Source: `azurerm_key_vault_encrypted_value`
  * update code
  * Fix TC for MySql
  * common: updating the "+beta" user agent to be behind the 4.0 feature toggle
  * deps: removing unused dependencies
  * make generate
  * devspace: removing older resources
  * servicefabricmesh: removing
  * make generate
  * provider: enabling 3.0 mode
  * updating to include #15867
  * function apps: updating the read timeout to 5m
  * Update for #15831
  * New Resource: azurerm_stream_analytics_function_javascript_uda (#15831)
  * updated value
  * add comment
  * fix import a connected synapse workspace
  * log analytics cluster docs: Removed outdated capacity constraints message (#15859)
  * CHANGELOG.md for #15736
  * azurerm_cosmosdb_mongo_collection: Fix the issue that expireAfterSeconds  property could not be set to -1 (#15736)
  * change the test for identity
  * Update for #15759
  * Healthcareapi/workspace (#15759)
  * `azurerm_hdinsight_rserver_cluster` - add test for storage_account.storage_resource_id (#15498)
  * `azurerm_static_site_custom_domain` - make `validation_type` optional
  * make comment a TODO
  * 3.0 Datafactory Refactor (#15828)
  * Update for #15376
  * support user assigned identity for policy assignments (#15376)
  * `vpn_gateway` wait LRO (#15755)
  * r/log_analytics_saved_search: updating the casing of the resource ids
  * loganalytics: removing unused code
  * r/lighthouse_definition: refactoring to use an id parser
  * d/private_endpoint_connection: switching to use an id parser
  * refactor: lighthouse assignment now uses an id parser
  * r/eventgrid_event_subscription: refactoring to use an ID Parser
  * docs: fix server reference example (#15802)
  * `azurerm_static_site` - `identity` supports `SystemAssigned, UserAssigned`
  * updating to include #15797
  * bold
  * adding the 3.0 major notes section to the changelog
  * updating to include #15719
  * docs: adding missing docs for `azurerm_api_connection`
  * remove deprecated addon_profile and http_application_routing blocks from docs (#15822)
  * make generate
  * New Resource: `azurerm_api_connection`
  * New Data Source: `azurerm_managed_api`
  * connections: importing the embedded sdk
  * connections: scaffolding the new service
  * Update for #15559
  * add `delivery_property` to `azurerm_eventgrid_system_topic_event_subscription` (#15559)
  * 3.0 Various Test Fixes (#15812)
  * docs: correct long_term_retention_policy section (#15801)
  * Fix tests for 3.0 (#15788)
  * adding the changelog placeholder for 3.0
  * fix document typos error (#15798)
  * v2.99.0
  * CHANGELOG.md - pre release tidy
  * `subnet_service_endpoint_storage_policy` wait LRO (#15730)
  * `sql_virtual_network_rule_resource` wait LRO (#15764)
  * Windows VMSS: allow prefix end with dashes (#15742)
  * 3.0 Test Fixes - any test using KeyVault (#15796)
  * data.azurerm_active_directory_domain_service: correct documentation for the `replica_sets` block (#15738)
  * CHANGELOG.md for #15038
  * New Resource: azurerm_cosmosdb_sql_role_assignment (#15038)
  * CHANGELOG.md for #14983
  * Upgrade sentinel API to 2021-09-01-preview (#14983)
  * `mssql/mssql_virtual_network_rule` wait LRO (#15781)
  * CHANGELOG.md for #15757
  * Support cross region restore on azurerm_recovery_service_vault (#15757)
  * `netapp_pool`  wait LRO (#15785)
  * Address TODO items for storage package (#15739)
  * Final sweep of straightforward TODO changes for 3.0 (#15761)
  * CHANGELOG.md for #14882
  * Data Source azurerm_virtual_network  - add tags property (#14882)
  * Changelog for #15771
  * remove old resource rename doc (#15766)
  * update 'web' accTest start time and schedule (#15767)
  * Beta Fixes - Function Apps `app_settings` / `storage_uses_managed_identity` bugs (#15735)
  * Fix tests for `azurem_iothub`, `azurem_digital_twins` and `azurem_stream_analytics` (#15769)
  * docs: Typo (#15773)
  * Fixing Load Balancer documentation (#15779)
  * 3.0 Test Fixes - Postgres, keyvault, storage, eventgrid (#15727)
  * azurerm_mssql_server: make the SQL administrator optional when using AAD-only authentication
  * `azurerm_function_app_function` - (beta resource) fixes validation method on `function_id` schema item (#15763)
  * refactor: more 3.0 prep (#15718)
  * Fix schema issue with api_management_custom_domain resource (#15744)
  * adding a note around preparing for 3.0
  * Address TODO items in preparation for 3.0 beta (8/many) (#15699)
  * tests: fix tests in container package for 3.0 (#15732)
  * Update changelog for #14749
  * Support customer managed keys for azurerm_batch_account (#14749)
  * [3.0 Beta] TODO changes for netapp (#15706)
  * Changelog for #15725
  * [3.0 Beta] TODO changes for hdinsight (#15700)
  * `dependency` Fix compute vendor mod (#15729)
  * CHANGELOG.md for #15036
  * `azurerm_container_registry`: add support of `export_policy_enabled` (#15036)
  * `key_vault_resource` wait LRO (#15717)
  * Wait LRO for automation resources (#15642)
  * Fix refresh failure of removed `azurerm_logic_app_trigger_http_request` (#15519)
  * website: example of python function app (#15460)
  * Upgrade blob inventory policy API to 2021-04-01 (#14183)
  * CHANGELOG.md for #15099
  * Update Azure compute sdk version to 2021-11-01 (#15099)
  * CHANGELOG.md for #15035
  * New Resource: azurerm_cosmosdb_sql_role_definition (#15035)
  * Deprecation of `sql` package for v3.0 (#15676)
  * Bugfix: fix broken read func for mssql_managed_instance_active_directory_administrator
  * Update for #15648
  * `azurerm_kubernetes_cluster` upgrade sdk to 2022-01-02-preview (#15648)
  * Update for #15546
  * `azurerm_kubernetes_cluster` deprecate and remove `role_based_access_control` block and `private_link_enabled` (#15546)
  * r/network_security_rule: removing the locks by default in 3.0
  * updating to include #15716
  * updating the changelog
  * Updated for #15702
  * New Beta Resources: `azurerm_function_app_hybrid_connection` and `azurerm_web_app_hybrid_connection` (#15702)
  * upgrading go sdk from 61.6.0 to 62.1.0
  * add 3.0 conditional deprecations to web (#15668)
  * `azurerm_postgresql_server` - update document link (#15714)
  * Update changelog for #15656
  * `azurerm_backup_protected_vm`: Make `source_vm_id` case insensitive (#15656)
  * Update changelog for #15694
  * `azurerm_lb_nat_rule` - `frontend_port` and `backend_port` now support `0` (#15694)
  * `azurerm_network_profile` - use `future.WaitForCompletionRef`
  * `iothub_resource` - swapping custom wait logic to `future.WaitForCompletion` (#15698)
  * 3.0 Test Fixes - Purview -> Traffic Manager (#15692)
  * docs: adding the legacy vmss resource to the upgrade guide page
  * `azurerm_signalr_service` Fix #15626 by adding nil check. (#15643)
  * `azurerm_function_app_slot` - add test for headers.x_azure_fdid/x_fd_health_probe/x_forwarded_for/x_forwarded_host/service_tag/virtual_network_subnet_id (#15469)
  * `azurerm_function_app` - add test forheaders.x_azure_fdid/x_fd_health_probe/x_forwarded_for/x_forwarded_host/name/priority/service_tag/virtual_network_subnet_id (#15472)
  * Update for #15584
  * Data Source `azurerm_kubernetes_cluster` deprecate and remove `addon_profile`, `role_based_access_control` and `private_link_enabled` (#15584)
  * add sentence for forcenew behaviour on public_network_access_enabled
  * Update Changelog for #15671
  * Address TODO items in preparation for 3.0 beta (7/many) (#15671)
  * Update for #15605
  * New Beta Resource - `azurerm_function_app_function` (#15605)
  * Logic app access control disappear when modifing workflow steps (#15517)
  * `azurerm_app_service_slot`  - add test for action/name/priority/service_tag/headers.x_azure_fdid/x_fd_health_probe/x_forwarded_for/x_forwarded_host (#15500)
  * CHANGELOG.md for #15624
  * Support enabled property for azurerm_mssql_database_extended_auditing_policy and azurerm_mssql_server_extended_auditing_policy resources (#15624)
  * `azurerm_hdinsight_storm_cluster` - add test for storage_account.storage_resource_id (#15497)
  * fix(mssql): retry creating security alert policies when getting datab… (#15532)
  * Case sensitive enums fix - Containers (#15654)
  * CHANGELOG.md for #15670
  * Set key vault id on key import issue #12357 (#15670)
  * 3.0 Test Fixes - Log Analytics, HDInsight, MSSQL (#15659)
  * `azurerm_synapse_workspace_key` - update example (#15688)
  * azurerm_api_management_api_operation_policy.operation_id validation too restrictive (#15690)
  * Update changelog for #15623
  * As #15444 described, the `parameters` is updatable according to the `updateFunc` function in `assignment_base_resource.go`. (#15623)
  * Update Changelog for #15689
  * fix panic in virtual_network_gateway resources (#15689)
  * Update for #15618
  * Fix forces replacement on empty array (#15618)
  * Update for #15686
  * Bug Fix: azurerm_batch_job - Fix failure to create azurerm_batch_job with multiple properties in common_environment_properties (#15686)
  * Address TODO items in preparation for 3.0 beta (6/many) (#15442)
  * updating to include #14839
  * Remove potentially destructive setting in example (#15667)
  * Changing streaming_ingest_enabled to streaming_ingestion_enabled (#15625)
  * `appservice` / `web` - Fix tests and a few feature flag issues (#15665)
  * Update internal/features/four_point_oh.go
  * add test for azurerm_automation_runbook.tags (#14908)
  * Update internal/services/machinelearning/machine_learning_compute_instance_resource.go
  * updating to include #15637
  * updating to include #15598
  * Update doc for MySQL Flexible Server Database
  * updating to include #15603
  * features: adding a feature-flag placeholder for 4.0 and 4.0 beta
  * add test for backend
  * docs: adding a note about the azurerm backend/msal to the upgrade guide
  * Enable the case sensitive enum for 3.0-beta
  * azurerm_active_directory_domain_service: link to official LDAPS docs
  * Correct argument reference (#15652)
  * r/virtual_machine_scale_set: deprecating the legacy VM Scale Set resource
  * update changelog for #15590
  * `azurem_iothub`-  deprecate `ip_filter_rule` in favour of `network_rule_set` (#15590)
  * updating to include #15582
  * lint
  * 3.0 Test Fix: Firewall (#15596)
  * More test fixes
  * r/eventhub_namespace_customer_managed_key: fixing linting
  * add test for deliveryrule
  * generalize "subscription" for test data && resolve other comments
  * More compute test fixes
  * continued test fixes
  * start of compute test fixes
  * make fmt
  * refactor: removing `pluginsdk.DefaultImporter`
  * S -> W: adding missing import validators
  * L -> S: switching to use custom importers
  * r/kusto_database_principal: refactoring to use an import validator & removing in 3.0 mode
  * E -> K: refactoring to use import-time validation
  * r/eventhub_namespace_customer_managed_key: making the Delete function a noop in 3.0
  * r/eventhub_namespace_customer_managed_key: custom importer
  * D -> E: refactoring to use id parsers
  * refactor: A -> C now have ID validators at import time
  * apimanagement: refactoring to use id validators
  * r/mssql_managed_instance: normalizing the SystemAssigned check
  * refactor: deprecating `azure.SchemaLocationForDataSource`
  * refactor: removing usages of `azure.SchemaLocationForDataSource`
  * refactor: removing `azure.ValidateResourceGroupName`
  * fixing a merge conflict
  * refactor: switching usages of `SchemaResourceGroupNameForDataSource` to commonschema`
  * Update for #15604
  * refactor: removing the old UUID constant since this should be used via the helper
  * refactor: switching to use the new IsUUID function
  * internal/acceptance: introducing a new `IsUUID` function
  * upgrade azure sdk to 61.6.0
  * terrafmt
  * `azurerm_storage_object_replication` - supports replicating containers across subscriptions
  * add test for complete
  * terrafmt
  * `azurerm_storage_data_lake_gen2_filesystem` - add supports of `owner` and `group`
  * Update CHANGELOG.md
  * v2.98.0
  * fix tests for automation runbook (#15581)
  * `azurerm_data_factory` - add test for vsts_configuration (#15580)
  * Remove preview warning for GA kubelet identity feature (#15583)
  * CHANGELOG.md for #15529
  * azurerm_cosmosdb_mongo_collection: support to set autoscale_settings without shard_key when creating a cosmos DB mongo collection (#15529)
  * include 3.0 beta in useragent if enabled (#15577)
  * refactor: removing the old location package
  * refactor: removing usages on "github.com/hashicorp/terraform-provider-azurerm/internal/location"
  * refactor: removing the old `StateFunc` function
  * refactor: removing the old `HashCode` function
  * refactor: removing the old `DiffSuppressFunc` function
  * refactor: removing SchemaComputed
  * appservice - fixup failing tests (#15579)
  * WIP
  * embed pandora sdk: sdk/2021-04-01/objectreplicationpolicies
  * azurerm_monitor_diagnostic_setting - Update parser for case-insensitive while reading
  * Update changelog for #15561
  * `azurerm_firewall_policy` - wait for completion after calling create (#15561)
  * updating to include #15507
  * `azurerm_mssql_database`: Move hyper scale comment to the right place (#15573)
  * Update for #15246
  * New Beta Resources: `azurerm_web_app_active_slot` and `azurerm_function_app_active_slot` (#15246)
  * Update description for sku_name of azurerm_mysql_flexible_server
  * 3.0 Test Fixes for Key Vault (#15566)
  * updated displayname
  * updated complete
  * add test for complete
  * update for #15553
  * app_service Beta - complete support for `key_vault_reference_identity_id` (#15553)
  * [BUG] `azurerm_linux_virtual_machine_scale_set` - fix for issue 15516 (#15523)
  * `azurerm_api_management_diagnostic` - add test `data_masking` for backend_request/backend_responsefrontend_request/frontend_response (#15527)
  * fix: fix read error when consumption budget does not exist in azure (#15522)
  * `azurerm_monitor_metric_alert` - add test for action.webhook_properties (#15545)
  * Document globally unique constraint on azurerm_key_vault.name (#15478)
  * `document`: Fix `r\site_recovery_replicated_vm` doc example (#15506)
  * docs: add required argument to r\active_directory_domain_service example (#15520)
  * `azurerm_network_watcher_flow_log` - fix a potential panic happened during state migration (#15543)
  * Fix wrong deprecation warning for enable_disk_encryption (#15554)
  * fix public_network_access_enabled (#15510)
  * remove the deprecated addon_profile block and sub-blocks from documentation
  * Doc: Fix featuers-block link
  * go mod tidy
  * refactor: misc cleanup of the `azure` and `utils` package (#15508)
  * Add reference to purge on destroy feature flag for APIM (#15511)
  * dependencies: upgrading to `v0.18.0` of `github.com/tombuildsstuff/giovanni`
  * Update machine_learning_compute_instance_resource.go
  * refactor: updating the azure methods to call commonschema
  * refactor: removing `azure.SchemaResourceGroupNameOptionalComputed()`
  * refactor: removing `azure.SchemaResourceGroupNameSetOptional()`
  * refactor: removing `azure.SchemaResourceGroupNameOptional()`
  * refactor: removing `azure.SchemaResourceGroupNameDeprecatedComputed`
  * refactor: removing `location.SchemaWithoutForceNew()`
  * refactor: removing azure.LocationOptional()
  * make generate
  * legacy: registrating the Service Registration
  * refactor: moving the legacy vmss resource into the legacy package
  * refactor: moving the legacy vm resource into Legacy
  * compute: refactoring to use the linux vm resource
  * refactor: making the VirtualMachineResourceName public
  * r/legacy_virtual_machine_scale_set: refactoring to use the client in the legacy package
  * r/virtual_machine: refactoring to use the legacy client
  * legacy: adding a new client for the legacy resources
  * Update CHANGELOG.md
  * adding 2.98.0
  * v2.97.0
  * address issues after merging the "TODO" PRs (#15496)
  * [ANF-WI-13416925] Changing ANF resource update methods to use Update instead of CreateOrUpdate (#15491)
  * CHANGELOG.md for #15368
  * azurerm_kusto_cluster - rename enable_* to *_enabled (#15368)
  * spring cloud: custom_persistent_disks -> custom_persistent_disk (#15488)
  * `azurerm_log_analytics_data_export_rule` - Added parser importer and fixed tests (#15480)
  * Doc Update: `azurerm_traffic_manager_external_endpoint` - adding `endpoint_location` (#15485)
  * Changelog for #15203
  * Upgrade guide for 3.0 (#15358)
  * cleanup: removing the 2.x upgrade guides (#15486)
  * fix main (#15492)
  * docs: improve local account disabled section (#15489)
  * Test fixes for mssql_managed_instance_active_directory_administrator
  * MSSQL managed instance test fixes
  * Add missing resource registrations
  * New resource: azurerm_mssql_managed_instance_administrator
  * New resource: azurerm_mssql_managed_instance_failover_group
  * New resource: azurerm_mssql_managed_database
  * New data source: azurerm_mssql_managed_instance, supercedes azurerm_sql_managed_instance
  * New resource: azurerm_mssql_managed_instance, supercedes azurerm_sql_managed_instance
  * Update go-azure-helpers to v0.25.0
  * Address TODO items in preparation for 3.0 beta (5/many) (#15418)
  * fix imports issue (#15490)
  * Address TODO items in preparation for 3.0 beta (3/many) (#15340)
  * `azurerm_application_gateway` - swapping various attribute from TypeList to TypeSet (#15071)
  * Address TODO items in preparation for 3.0 beta (4/many) (#15390)
  * Adding the 3.0 beta to the changelog
  * updating to include #14181
  * Update for #15108
  * fix lint
  * add ConflictsWith for new properties and old addon_profile block and update docs
  * updating to include #15482
  * r/machine_learning_workspace: conditionally setting the user assigned identity id
  * fix #15474 by adding nil check
  * r/machine_learning_workspace: switching the Set to a List as this is a List
  * refactor: splitting the TestAccKubernetesCluster_addonProfileOMSToggle test in 2.x/3.0 mode
  * r/kubernetes_cluster: removing run_command_enabled from a test since that's outside this PR
  * r/kubernetes_cluster: updating the addons test to skip the test in 3.0 mode
  * r/kubernetes_cluster: switching the schema function to return the schema fields to add
  * fix deprecation
  * use ThreePointOhBeta flag and fix deprecation of addon_profile
  * use enum for skuTier for #15229
  * fmt
  * fix code comments
  * refactor map of addons and clarify comments
  * fix property names in deprecation messages
  * update casing
  * update tests
  * add new schema as well as expand and flatten functions
  * updating to include #15470
  * refactor: splitting the TestAccKubernetesCluster_addonProfileOMSToggle test in 2.x/3.0 mode
  * r/kubernetes_cluster: removing run_command_enabled from a test since that's outside this PR
  * r/kubernetes_cluster: updating the addons test to skip the test in 3.0 mode
  * r/kubernetes_cluster: switching the schema function to return the schema fields to add
  * fix deprecation
  * use ThreePointOhBeta flag and fix deprecation of addon_profile
  * use enum for skuTier for #15229
  * fmt
  * fix code comments
  * refactor map of addons and clarify comments
  * fix property names in deprecation messages
  * update casing
  * update tests
  * add new schema as well as expand and flatten functions
  * teamcity: enabling 3.0 beta mode
  * feature: kubernetes config sensitivity - enabled when the 3.0 beta is enabled
  * `r\virtual_machine_data_disk_attachment`: Fix panic when disk id is wrong
  * CHANGELOG.md for #15400
  * `azurerm_spring_cloud_app` supports `custom_persistent_disks` (#15400)
  * Provider - Add the missing `suppress.CaseDifference` for case-insensitive string properties (#15182)
  * `kubelet_disk_type` supports `Temporary` (#15464)
  * Doc Fix: azurerm_mssql_server_vulnerability_assessment - Add comments for the storage_account_access_key and storage_container_sas_key properties (#15465)
  * App Service Beta - fix custom values for `WEBSITE_CONTENTSHARE` and `WEBSITE_CONTENTAZUREFILECONNECTIONSTRING` in Function App resources (#15446)
  * Update changelog for #15429
  * `automation_account` - add support for `public_network_access_enabled` (#15429)
  * Update changelog for #15461
  * New resource - `azurerm_iothub_certificate` (#15461)
  * `azurerm_logic_app_standard` - add test for `ip_restriction` (#15448)
  * Update changelog for #15451
  * `azurerm_log_analytics_linked_storage_account` - correct casing for `data_source_type` when using `ingestion` (#15451)
  * `azurerm_monitor_activity_log_alert` add test for `criteria` (#15453)
  * Doc Fix: `azurerm_sql_managed_instance`  updates `license_type` to correct values (#15458)
  * updating to include #15288
  * updating to include #15181
  * r/machine_learning_workspace: refactoring to remove the error
  * updating to include #15371
  * updating the test config
  * Update changelog for #15343
  * `azurerm_iothub_dps` - support for `ip_filter_rule` block and `public_network_access_enabled` (#15343)
  * r/machine_learning_workspace: adding the missing fmt function
  * updating to include #14953
  * r/extended_locations: refactoring things spotted in PR review
  * r/machine_learning_workspace: validating the `user_assigned_identity_id`
  * d/machine_learning_workspace: documenting the exported identity block
  * support user assigned identity and customer managed key
  * format
  * format
  * support UAMI and data encryption
  * r/servicebus_namespace: exposing the identity_ids when a user assigned identity id is present
  * r/servicebus_namespace: updating to use the new identity types
  * `azurerm_servicebus_namespace` supports `identity`
  * CHANGELOG.md for #14795
  * `azurerm_mssql_outbound_firewall_rule` - New resource (#14795)
  * [Bug fix] Handle redis version upgrade state (#15372)
  * CHANGELOG.mnd for #14917
  * Add resource health to `azurerm_monitor_activity_log_alert` (#14917)
  * CHANGELOG.md for #15428
  * `azurerm_kusto_cluster` supports `public-Network-Access` (#15428)
  * azurerm_monitor_action_group: fix the format issue of the workspace_id property for itsm_receiver (#15422)
  * CHANGELOG.nmd for #15370
  * azurerm_logic_app_integration_account_map - support content type text/plain (#15370)
  * CHANGELOG.md for #15423
  * `azurerm_storage_management_policy` - add supports for `{tier_to_cool|tier_to_archive|delete}_after_days_since_last_access_time_greater_than` (#15423)
  * Common Schema for Zones [part 2] (#15405)
  * Common Schema for Zones [part 1] (#15393)
  * r/web_pubsub: bringing into line with #15187
  * Cleanup the k8s docs (#15435)
  * `example`: Fix sentinel csv watchlist item example (#15421)
  * refactor: removing the constants to
  * updating to include #15430
  * refactor: removing the old identity types
  * refactor: sorting imports
  * r/virtual_desktop_host_pool_registration_info: removing the note as we're doing a force migration
  * r/virtual_desktop_host_pool_registration_info: tests now output a UTC string which should always match
  * r/virtual_desktop_host_pool: fixing a test
  * r/virtual_desktop_host_pool: removing the `registration_info` block
  * r/virtual_desktop_host_pool: splitting the Create and Update method
  * `azurerm_iothub` - upgrade api from 2021-03-31 to 2021-07-02 (#15409)
  * r/virtual_desktop_host_pool: conditionally removing the `registration_info` block in 3.0 mode
  * removed commented lines
  * rework to handle co-existence with reg_info resource
  * Updated test case to check for token
  * Update internal/services/desktopvirtualization/virtual_desktop_host_pool_resource.go
  * Update internal/services/desktopvirtualization/virtual_desktop_host_pool_resource_test.go
  * Update virtual_desktop_host_pool_resource_test.go
  * Update AccTest to not ignore expiration time changes
  * Updated HostPool to use RetrieveRegistrationToken function in Read
  * website: splitting the Features block out to it's own page
  * features: hooking up the ThreePointOhBeta flag
  * dependencies: upgrading to v0.24.1 of github.com/hashicorp/go-azure-helpers
  * updating the changelog
  * Update for #15082
  * dependencies: upgrading to `v0.24.0` of `github.com/hashicorp/go-azure-helpers` (#15414)
  * r/application_gateway: checking if input and not the flattened object is non-nil (#15412)
  * `azurerm_logic_app_standard` - add test for enabled (#15379)
  * updated character length (#15402)
  * Update docs as AKS cluster auto upgrade is now GA
  * Fix potential deadlocks among provider level (#15396)
  * `azurerm_logic_app_action_http` - add test for body (#15377)
  * Update changelog for #15375
  * New Resource - `azurerm_spring_cloud_storage` (#15375)
  * update docs for beta source control resources (#15385)
  * Update changelog for #15386
  * `azurerm_web_application_firewall_policy` - `disabled_rules` is now optional (#15386)
  * Update mssql_virtual_machine.html.markdown (#15383)
  * Add DR as validation option (#15384)
  * update conditional schemas for tflint errors (#15391)
  * azurerm_vpn_site - Update doc example (#15374)
  * Update for #15380
  * `r\stream_analytics_cluster`: Fix `tags`
  * conditionally set key_vault_key_id to computed
  * Update CHANGELOG.md
  * second batch of 3.0 TODO items (2 of many) (#15320)
  * CHANGELOG/md tidyup
  * v2.96.0
  * Updating to include #14935
  * Updating to include #14935
  * Updating to include #14906
  * Updating to include #14906
  * Updating to include ##14796
  * fixes #14383
  * `azurerm_bastion_host` - validate subnet name (#15365)
  * CHANGELOG.md for #15360
  * `azurem_virtual_machine*` - add `StandardSSD_ZRS` and `Premium_ZRS` as `storage_account_type` options (#15360)
  * `azurerm_key_vault_certificate` - add test for certificate_policy.lifetime_action.trigger.lifetime_percentage (#15354)
  * r/windows_web_app_slot: re-adding the `KeyVaultReferenceIdentityID`
  * Update changelog for #15332
  * `azurerm_kusto_cluster` - support for `enable_auto_stop` (#15332)
  * Update for #15338
  * `data_protection_backup_instance_blob_storage.html.markdown` - add ` identity `block  (#15353)
  * linting
  * r/linux_function_app: adding tests covering the identity block
  * r/linux_function_app_slot: adding tests covering the identity block
  * r/linux_web_app: adding tests for the identity block
  * tests: example -> test
  * r/linux_web_app_slot: adding tests for identity end to end
  * r/windows_function_app: adding tests covering identity
  * r/windows_function_app_slot: adding tests for identity
  * r/windows_web_app: adding tests covering the identity lifecycle
  * appservice: implementing the expand/flatten functions
  * r/windows_web_app_slot: adding a test covering identity end to end
  * fmt
  * use key_vault_key_id instead
  * appservice: refactoring to use the common identity schema
  * appservice/legacy: refactoring the identity types to use the common schema in 3.0
  * r/static_site: refactoring to use the common identity schema
  * identity: fixing up a couple of schema bugs
  * CHANGELOG.md for #15329
  * New resource: `azurerm_disk_pool_iscsi_target_lun` (#15329)
  * fix: fix bug where properties on route were not updated (#15257)
  * `azurerm_cosmosdb_account` - add test for tags (#15315)
  * Update changelog for #15349
  * New Data Sources `azurerm_site_recovery_fabric`, `azurerm_site_recovery_protection_container`, and `azurerm_site_recovery_replication_policy` (#15349)
  * `azurerm_cosmosdb_cassandra_table `- add test for autoscale_settings.max_throughput/default_ttl/throughput (#15331)
  * CHANGELOG.md for #15016
  * `azurerm_network_watcher_flow_log`: the `name` property can now be configured for new resources. (#15016)
  * Fix TestAccSnapshot_fromUnmanagedDisk (#15318)
  * `azurerm_policy_assignment` Add convert check to avoid panic and fix #15218 (#15333)
  * DOC: fix invalid JSON in parameter definition of azurerm_resource_group_policy_assignment (#15335)
  * refactor: consistent identity blocks - machine learning (#15341)
  * Update changelog for #15344
  * `azurerm_data_factory` - refactor: consistent identity blocks (#15344)
  * updating to include #15337
  * switch order in if/else
  * set managed lb when unlinking outbound ip addresses or prefixes and clarify docs
  * r/application_gateway: `type` is now required
  * fixing up pr comments
  * Update internal/services/containers/kubernetes_cluster_network_resource_test.go
  * Update internal/services/containers/kubernetes_cluster_auth_resource_test.go
  * d/api_management: refactoring to use the common identity schema
  * r/api_management: refactoring to use the common identity schema
  * r/app_configuration: refactoring to use the common identity schema
  * r/batch_account: refactoring to use the common identity schema
  * r/batch_pool: refactoring to use the common identity schema
  * r/blueprint_assignment: refactoring to use the common identity schema
  * r/cognitive_account: refactoring to use the common identity schema
  * Update provisioningservices api from 2018-01-22  to 2021-10-15 (#15321)
  * r/disk_encryption_set: switching to use the common identity schema
  * virtual_machine: refactoring to use the common identity schema
  * r/orchestrated_virtual_machine_scale_set: refactoring to use the common identity schema
  * vmss: refactoring to use the common identity schema types
  * r/container_registry: fixing the build
  * updating to include #15330
  * `azurerm_firewall` - workaround the destroy failure
  * Update changelog for #15326
  * New Data Source: `azurerm_portal_dashboard` (#15326)
  * Migrate APIM to `sku` block, and add zones and public IP support (#14660)
  * r/container_group: refactoring to use the common identity schema
  * r/container_registry: switching to use the common identity schema
  * r/container_registry_task: switching to use the common identity types
  * d/kubernetes_cluster: refactoring to use the new identity schema when the beta is enabled
  * r/kubernetes_cluster: conditionally switching over to the new identity schema
  * r/cosmosdb_account: refactoring to use common identity schema
  * r/data_lake_store: refactoring the Expand method to use the None type
  * r/data_share_account: refactoring to use the common identity schema
  * eventgrid: refactoring so that the identity blocks are consistent
  * r/firewall_policy: refactoring to use the common identity schema
  * r/purview_account: refactoring to use common schema for resource group/location
  * goimports
  * d/application_gateway: refactoring to use the common schema types
  * r/application_gateway: refactoring to use the common identity types
  * r/express_route_port: refactoring to use the common schema
  * r/search_service: fixing a missing type conversion
  * r/sql_managed_instance: linking the feature-request for user assigned identity
  * d/postgresql_server: refactoring to use the common identity types
  * r/postgresql_server: refactoring to use common schema
  * r/purview_account: refactoring the `identity` block to be behaviourally consistent
  * r/recovery_services_vault: switching to use common schema
  * d/search_service: refactoring to use the common schema
  * r/search_service: refactoring to use the common schema
  * d/sql_managed_instance: updating to use the common schema for identity
  * d/sql_server: updating to use the common identity types
  * r/sql_server: updating to use the common identity types
  * Update changelog #14827
  * Add `Network ACL` for the resource `Web Publishing Subscription` (#14827)
  * 3.0 Pre-release cleanup of TODO items [1/many]
  * r/logic_app_standard: removing unused code
  * updating to include #15316
  * iothub: switching to use the common identity schema
  * kusto: switching to use the common schema
  * loganalytics: refactoring to use the common identity schema
  * logic: refactoring to use the common identity schema
  * r/media_services_account: switching to use the common schema
  * d/mssql_server: refactoring to use the common schema
  * r/mssql_server: refactoring to use the common schema
  * d/mysql_server: refactoring to use the common schema
  * r/mysql_server: refactoring to use common schema
  * updating to include #15312
  * consistency
  * updating to include #15314
  * fix issue 15066
  * Fix test config format
  * dependencies: upgrading to v0.23.1 of github.com/hashicorp/go-azure-helpers
  * fix bug and add regression test case for 15229
  * Update for #15301
  * New Beta Resource: `azurerm_app_service_source_control_slot` (#15301)
  * Update for #15297
  * Update docs to to declare orchestration mode
  * `azurerm_service_plan` fix name of `worker_count` property in docs (#15286)
  * `azurerm_flexible_server` - Fix `administrator_login` validation (#15280)
  * azurerm_key_vault_secret - update doc example
  * Linting, add docs note on new behavior in v3.0
  * azurerm_api_management: drop the `remove_samples_on_create` feature flag and make it a 3.0 behaviour
  * azurerm_api_management: move the `remove_samples_on_create` property to provider features
  * azurerm_api_management: support the `remove_samples_on_create` property
  * check for existing keys in import check
  * update for #15291
  * `azurerm_app_service_active_slot` - fix regression in ID set in creation of new resource (#15291)
  * rename `ThreePointOhBetaResources` to `ThreePointOhAppServiceResources` (#15293)
  * Update for #15162
  * update code
  * apply review comments
  * updating to include #15287
  * build: fixing the schema linting
  * update code
  * fmt
  * update code
  * update code
  * sort imports
  * add identity
  * add identity
  * dependencies: updating to v0.23.0 of github.com/hashicorp/go-azure-helpers
  * fixing typo beat -> beta
  * CHANGELOG.md for #14366
  * New resource: `azurerm_sentinel_watchlist_item` (#14366)
  * tfschema linting fix
  * remove space for tflint directives due to https://github.com/bflad/tfproviderlint/issues/251
  * make whitespace & fumpt
  * Update changelog for #15254
  * `azurerm_application_insights` - Add support for `force_customer_storage_for_profiler` (#15254)
  * make goimports
  * Linting Fix (#15271)
  * Update changelog for #15072
  * `azurerm_automation_account` - Support for managed identity (#15072)
  * updating to include 2.96.0
  * fmt
  * remove intermediate functionOutputProps variable
  * add docs
  * output functions typed resource
  * v2.95.0
  * apimanagement: make subscription_required optional with default value of true (#14118)
  * `azurerm_private_endpoint` Try add internal lock when private connection resource id is cosmosdb account id to fix #14364 (#14398)
  * CHANGELOG.md for #14980
  * Update backup api from 2019-05-13 to 2021-07-01;  allows Zone Redundant storage for azurerm_recovery_services_vault. storage_mode_type (#14980)
  * Update changelog for #15178
  * New Resource: `azurerm_traffic_manager_azure_endpoint`, `azurerm_traffic_manager_external_endpoint`, and `azurerm_traffic_manager_nested_endpoint` (#15178)
  * doc: storage_account_id clarification (#15226)
  * Refactor beta [windows|linux] function app slots for ID (#15231)
  * Update for #14946
  * Support for azurerm_container_group data source (#14946)
  * Update website/docs/r/storage_account.html.markdown
  * r/static_site: fixing the identity test
  * r/synapse_workspace: updating the tests to work in both 2.x and 3.0 mode
  * r/storage_account: handling the identity type being different in the Storage API's
  * Update postgresql_server.html.markdown
  * Fix for issue 15161
  * add example on how to attach acr to aks
  * r/storage_account: only specifying the User Assigned Identities block when the field has a value
  * r/stream_analytics_job: fixing an issue when creating a resource with no identity
  * tools/generator-services: the same label can be present in multiple packages
  * bump testing default version to TF 1.1.5
  * Update dns_zone.html.markdown
  * Fix #14845 by listing hybrid connection's access keys if listing access keys of relay failed. (#15118)
  * CHANGELOG.md for #15098
  * `azurerm_container_group`: fix parallel provision failure given the same `network_profile_id` (#15098)
  * CHANGELOG.md for #14975
  * New resource `azurerm_disk_pool_iscsi_target` base on `azurerm_disk_pool` on pr #14675 (#14975)
  * CHANGELOG.md for #15039
  * support storage_resource_id for azurerm_hdinsight_hbase_cluster, azurerm_hdinsight_hadoop_cluster,azurerm_hdinsight_spark_cluster and azurerm_hdinsight_interactive_query_cluster resources (#15039)
  * `azurerm_mysql_server` - add test for infrastructure_encryption_enabled/public_network_access_… (#15004)
  * CHANGELOG.md for #14936
  * `azurerm_[linux|windows]_virtual_machine`: Add support for `dedicated_host_group_id` (#14936)
  * labels: adding tooling
  * regenerating
  * services: adding github labels for single-service packages
  * recoveryservices: combining the two resource id generation files
  * regenerate
  * Update for #15229
  * linting
  * assign updated value to skuTier variable
  * nil check sku in update
  * linting
  * tools/generator-services: noting that the labels file is now generated
  * service/addb2c: implementing the label interface
  * tooling: generating Github Labels for Services based on the interface being implemented
  * refactor: updating to workaround the breaking changes in v0.22.0 of github.com/hashicorp/go-azure-helpers
  * updating to include #15194
  * Updated for #14940
  * New Beta Resources - `azurerm_linux_function_app_slot` and `azurerm_windows_function_app_slot` (#14940)
  * goimports
  * dataprotection: refactoring a hidden usage of SystemAssigned
  * refactor: fixing cast errors which weren't flagged
  * identity: removing the System Assigned type
  * r/sql_managed_instance: switching to use the common identity schema
  * r/enenthub_namespace: removing an unused type alias
  * r/policy_assignment: refactoring to use the common identity schema
  * r/spring_cloud_app: refactoring to use the common identity type and using the future during deletion
  * r/eventhub_namespace: switching to use the new identity schema
  * updating to include #15180
  * Update internal/features/three_point_oh.go
  * Updated for #14613
  * New (Beta) Resource: `azurerm_windows_web_app_slot` (#14613)
  * updating to include #15207
  * Update for #15209
  * Update changelog for #15183
  * `azurerm_web_pubsub_hub` - Modify the logic of `auth.0.managed_identity_id` now accepts UUIDs (#15183)
  * 'azurerm_eventhub_namespace' - add test for network_rulesets.ip_rule.action (#15158)
  * Update changelog for #15199
  * New Data Source: `azurerm_logic_app_standard` (#15199)
  * linting: add missing assignment
  * correct property name in deprecation info
  * apply deprecation info to the correct property in docs
  * fix deprecation of management_group_name
  * dependencies: upgrading github.com/hashicorp/go-azure-helpers to v0.22.0
  * refactor: updating the schema used by existing resources
  * r/storage_account: refactoring to use the common identity type
  * streamanalytics: refactoring to use the common identity types
  * videoanalyzer: switching to use the common schema type
  * synapse/workspace: `identity` is now required in 3.0 in line with other resources
  * r/static_site: switching to using the new identity method name
  * d/function_app: refactoring to use the common identity types
  * r/storage_account: changing the tls default in the beta
  * redis: changing the tls default in the beta
  * postgres: changing the tls default in the beta
  * policy: removing the deprecated resource in the beta
  * mysql: changing the tls default in the 3.0 beta
  * mssql: switching the feature flags to use the beta
  * loadbalancer: removing backend_address when the beta is enabled
  * kusto: refactoring to use the beta flag
  * keyvault: removing the `soft_delete_enabled` flag when the Beta is enabled
  * iothub: switching over to using the Beta flag
  * disks: removing the deprecated resource when the Beta is enabled
  * devspace: removing when the Beta is enabled
  * costmanagement: removing the deprecated resource in the beta / fixing an inverted removal
  * provider: removing skip_credentials_validation / enabling msal when the Beta is enabled
  * provider/features: the Key Vault Items flags are now feature-flagged on the ThreePointOhBeta functionality
  * features: ThreePointOhBetaResources - also picking from ThreePointOhBeta
  * new feature flag: ThreePointOhBeta
  * state migration for case conversion of ID element
  * updating to include #15141
  * Fix Minor Typo
  * updating to include #15174
  * update code
  * update code
  * New Data Source: azurerm_subscription_locations
  * `azurerm_storage_share` - fix re-create error
  * fix frontdoor resource group name being treated as location
  * Update signalr_service.html.markdown
  * Fix capacity typo in Web PubSub example
  * fix doc missing sensitive = true issue
  * updated config
  * updated complete
  * v2.94.0
  * Update CHANGELOG.md
  * Changelog for #14403
  * `webpubsub` - Moved web_pubsub into signalr package (#15145)
  * Always use MSAL tokens in v3
  * Traffic Manager: Swap to embedded sdk (#15114)
  * `use_msal` defaults to true in v3.0
  * typo
  * Update internal/services/web/static_site_resource.go
  * add test for blank line
  * `azurerm_static_site` - fix Free tier creation error
  * more fixes
  * Fixing linting errors
  * add test for tags
  * Update servicebus_subscription_rule.html.markdown
  * Update docs kust cluster assign include name (#15129)
  * Update changelog for #15123
  * `azurerm_api_management_backend` Fix crash around `backend_credentials` (#15123)
  * update order prop in docs (#15126)
  * Update changelog for #15119
  * `data.image_source` - Fix regression around id (#15119)
  * fixing the Resource ID for `api_management_policy` when this was provisioned using version `2.92.0` of the Azure Provider (#15060)
  * Update changelog for #15019
  * #15018 Added partition key property to event hub input resource (#15019)
  * Update changelog for #14134
  * New resource: `azurerm_virtual_desktop_host_pool_registration_info` #14134
  * go mod vendor
  * Apply suggestions from code review
  * Documentation for `use_msal` provider property and related changes
  * Support for v2 auth tokens (i.e. MSAL)
  * Update go-azure-helpers to v0.20.0
  * goimports
  * Clarify what the endpoint_uri property should be
  * Update changelog for #15088
  * updating to include #15040
  * `azurerm_eventhub` - seperate update and create and add check for sku (#15088)
  * Update changelog for #14731
  * Update changelog for #14731
  * New resource: `web pubsub` (#14731)
  * Update for #15084
  * `azurerm_app_service_slot`: Add storage_account block option (#15084)
  * updated withTags
  * log analytics free sku docs and extra check (#15057)
  * Update changelog for #15074
  * `azurerm_bastion_host` - Fix crash by adding nil check for `copy_paste_enabled (#15074)
  * r/redis_enterprise_*: fixing the import resource name
  * r/kubernetes_cluster: fixing a missing formatting segment
  * d/azurerm_public_ips: Update the "Example Usage" (#15089)
  * updating to include #15062
  * r/dedicated_host: adding a missing formatting placeholder
  * updating to include #15085
  * updating to include #15043
  * updating to include #15080
  * Updated azurerm_kubernetes_cluster documentation
  * terrafmt
  * `azurerm_template_deployment`: fix delete bug`
  * add docs
  * add acctests
  * add cmk schema with expand and flatten functions
  * Update Azure Go Sdk to 61.3.0
  * Update example to align with official documents
  * r/dedicated_host: refactoring to use id formatters throughout
  * r/kubernetes_cluster: refactoring to use an id parser all the way through
  * r/kubernetes_cluster_node_pool: refactoring to use id parsers throughout
  * refactor: switching to use the ID Formatter ID where it exists
  * `lintignore`ing current lint errors
  * regen sdk
  * fix availability check request data
  * Update changelog for #15009
  * New Data Source :`azurerm_linux_function_app` (#15009)
  * Update CHANGELOG.md for #15054
  * azurerm_dev_test_lab: normalize the `key_vault_id` (#15054)
  * add test for timezone
  * Update for #15017
  * add test for timezone
  * Update CHANGELOG.md
  * v2.93.0
  * update code
  * Update CHANGELOG.md
  * service bus public network access (#14967)
  * Added purge_protection to Databricks DBFS example
  * refactor: updating to account for the changes to Tags in hashicorp/go-azure-helpers v0.21.0
  * clients/builder: defaulting to ADAL for now until #14403 is merged
  * dependencies: updating to v0.21.0 of github.com/hashicorp/go-azure-helpers
  * add tet for azurerm_recovery_services_vault
  * update kusto sdk to 2021-08-27
  * add test for tags
  * Update changelog for #15007
  * fix(services/storage/file): change at the `content_md5` attribute will now trigger recreation; set content length of share file when updating properties to prevent clearing of byte range. (#15007)
  * Update changelog for #14967
  * Documentation updates - Azure Front Door and  WAF (#15022)
  * Update changelog for #14705
  * `iothub`: Support Identity-Based Endpoint (#14705)
  * Fix bug that missing Etag when updating azurerm_resource_group_cost_management_export and azurerm_subscription_cost_management_export resource
  * Adding traffic manager embedded sdk
  * updated encryptedUpdate
  * updated encryptedUpdate
  * updated encryptedUpdate
  * updated encryptedUpdate
  * dox fix: remove the wrong description of index_policy for resource azurerm_cosmosdb_gremlin_graph (#15006)
  * Update for #14964
  * Data Sources: `azurerm_linux_web_app` and `azurerm_windows_web_app` - use correct model type (#15005)
  * updated value
  * add test for encrypted
  * remove length check in DS for AppInsightsInstrumentationKey, AppInsightsConnectionString and HealthCheckEvictionTime
  * Update website/docs/d/windows_function_app.html.markdown
  * remove check on AppInsightsInstrumentationKey, AppInsightsConnectionString and HealthCheckEvictionTime
  * use DS model
  * add test for encrypted
  * add test for encrypted
  * add test for encrypted
  * updated complete
  * `azurerm_loadbalancer_rule` - add test for load_distribution
  * clean up code
  * `azurerm_lb_probe` - add test for interval_in_seconds/number_of_probes
  * `azurerm_purview_account` - add test for public_network_enabled/tags
  * add test for description
  * updating to include #14996
  * updating to include #14896
  * length check all references of SiteConfig in unpackWindowsFunctionAppSettings
  * length check SiteConfig for ApplicationStack
  * Update for #14844
  * `azurerm_linux_function_app` fix #14812 by using length check for SiteConfig and ApplicationStack. (#14844)
  * updating to include #14987
  * Update security_center_automation_resource_test.go
  * updating to include #14911
  * updated unit test to also test the new source types
  * Update website/docs/d/logic_app_workflow.html.markdown
  * Update website/docs/r/logic_app_workflow.html.markdown
  * Update website/docs/d/logic_app_workflow.html.markdown
  * updating to include #14961
  * Update for #14982
  * updating to include #14828
  * updating to include #14976
  * updated tags
  * updated fmt
  * azurerm_private_dns_zone_virtual_network_link - add test for registration_enabled
  * updated fmt
  * updated docuementation to reflect new source types
  * azurerm_dashboard - add test for tags
  * added new validations for source
  * update code
  * update code
  * azurerm_bastion_host - support new properties
  * add test for public_network_access_enabled/tags
  * clean up code with make terrafmt
  * clean up code for style
  * `azurerm_firewall_application_rule_collection` - add test rule.fqdn_tags
  * updated test for tags
  * `azurerm_machine_learning_compute_instance` - add protection code and validation
  * add test for tags
  * add test for azurerm_user_assigned_identity.tags
  * update markdown for azurerm_api_management_identity_provider_aadb2c to reference api_management_name instead of id
  * Fix resource docs based on datasource fix
  * Fix review comments
  * Docs
  * `d/azurerm_mysql_flexible_server` - New Datasource
  * Id Parsers: Various Resources (#14974)
  * Doc Fix: `azurerm_virtual_desktop_scaling_plan` - Fix wrong block name `hostpool_reference` -> `host_pool` used in example (#14960)
  * `azurerm_machine_learning_compute_cluster` - add test for tags/description (#14962)
  * Update changelog for #14968
  * `azurerm_bastion_host` - support for `scale_units` (#14968)
  * `r/iothub_dps`: Normalize location and linked hub location (#14963)
  * fix docs subcat
  * terrafmt
  * amend docs
  * add missing prop and fix wording
  * add windows function app data source docs
  * remove comments
  * register data source
  * add test
  * add windows function app data source
  * add computed schemas for windows function app
  * update complete test
  * add complete value
  * upgrade container registry API from 2020-11-01-preview to 2021-08-01-preview
  * ID Parsers: Network (#14954)
  * ID Parsers: compute resources (#14934)
  * v2.92.0
  * CHANGELOG.md for #14879
  * azurerm_aadb2c_directory: fix broken import support (#14879)
  * CHANGELOG.md for #14864
  * storage account rename infrastructure_encryption to infrastructure_en… (#14956)
  * CHANGELOG.md for #14268
  * New resource `azurerm_disk_pool_managed_disk_attachment` based on New Resource `azurerm_disk_pool` on pr #14675 (#14268)
  * CHANGELOG.md for #14865
  * Add managed_resources block to purview_account 14814 (#14865)
  * Added infrastructure_encryption to azurerm_storage_account (#14864)
  * remove germany from teamcity (#14926)
  * Update changelog for #14942
  * `azurerm_iothub` - export `event_hub_events_namespace` and add a fallback route by default (#14942)
  * Update changelog for #14943
  * `azurerm_iothub_dps` - updating default `allocation_weight`  (#14943)
  * Update Changelog for #14944
  * use the correct parser function for event hub rule IDs (#14944)
  * update complete
  * updated complete test
  * Adding Id Parsing to various resources (#14930)
  * frontdoor - regen embedded sdk (#14927)
  * clean up code for test again
  * small readme update (#14928)
  * CHANGELOG.md for #14910
  * fix typo in `azurerm_log_analytics_workspace` argument: reservation_capcity_in_gb_per_day to reservation_capacity_in_gb_per_day (#14910)
  * CHANGELOG.md for #14718
  * `r\azurerm_recovery_services_vault` #13178 Support for customer-managed keys (CMK) for azurerm_recovery_services_vault (#14718)
  * Test-Data_Protection (#14913)
  * Test-Data_Lake (#14890)
  * Update Changelog for #14924
  * only force ForceMongo when kind is set to mongo (#14924)
  * ID Parser: batch/containers/cosmosdb (#14905)
  * Update for #14915
  * Update Changelog for #14916
  * Add state migration for case conversion of ID element (#14916)
  * add infra encryption enabled to test
  * remove infra encryption enabled check for cmk
  * Update Changelog for #14900
  * Fix panic when removing git repos (#14900)
  * add test for "	azurerm_disk_pool.tags"and"azurerm_storage_disks_pool.tags"
  * fix linting issue
  * bugfix
  * fixing a typo
  * push changes
  * CHANGELOG.md for #14711
  * new resource: azurerm_api_management_api_tag #14453 (#14711)
  * CHANGELOG.md for #14433
  * upgrade eventgrid  to 2021-12-01; azurerm_eventgrid_domain support for   local_auth_enabled, auto_create_topic_with_first_subscription, auto_delete_topic_with_last_subscription (#14433)
  * azurerm_logic_app_standard - update example document for the sku property (#14909)
  * Fix tests for `azurerm_stream_analytics_function_javascript_udf` (#14902)
  * `TimeSeriesInsights`: Update SAS Key to Sensitive (#14888)
  * update azurerm_automation_dsc_configuration.log_verbose (#14830)
  * update azurerm_application_insights_web_test.description/retry_enabled/tags (#14829)
  * Test for `azurerm_automation_module.module_link` (#14892)
  * Update changelog for #14883
  * `azurerm_mysql_server_key` - Fix issue when checking for existing resource on create (#14883)
  * Update Changelog for #14656
  * Support storing audit data in storage account that is behind a firewall and VNet (#14656)
  * ID Parser: various resources (#14885)
  * adding a test for systemassigned identity
  * Update changelog for #14880
  * add oozie.db.schema.name to oozie-site (#14880)
  * Update Changelog for #14898
  * Fix type issue in migration logic (#14898)
  * drop abandoned file
  * adding docs
  * adding docs
  * add test for azurerm_firewall.sku_tier
  * clean up code
  * Update changelog for #14857
  * `azurem_cosmosdb_mongo_collection` - check for "_id" in index keys (#14857)
  * `azurerm_app_service_source_control` - (beta) bring docs inline with resource changes (#14870)
  * add test for azurerm_automation_variable_int.encrypted
  * Add comment on kube_admin_config for local accounts
  * dependencies: upgrading to v61.1.0 of github.com/Azure/azure-sdk-for-go
  * CHANGELOG.md for #14771
  * azurerm_monitor_action_group: support for the `event_hub_receiver` block (#14771)
  * add test for azurerm_automation_variable_bool.encrypted
  * Update for #14628
  * v2.91.0
  * CHANGELOG.md tidy
  * CHANGELOG.md for #14784
  * servicebus related resources: reference parent resource ID (#14784)
  * CHANGELOG.md for #14797
  * azurerm_application_gateway - support new property enableFips (#14797)
  * Add validation for storage_account_name in the databricks workspace resource (#14809)
  * CHANGELOG/.md for #14836
  * `azurerm_iot_fallback_route` - Added support for `source` property (#14836)
  * CHANGELOG.md for #14838
  * `azurerm_mysql_server` - Allow 16TB `storage_mb` configuration (#14838)
  * make generate (#14840)
  * CHANGELOG.md for #14825
  * HDInsight: Support network property for azurerm_hdinsight_hbase_cluster resource (#14825)
  * Test-Service_Bus (#14824)
  * Update for #14815
  * `azurerm_linux_function_app` - fix filtering of app_settings for `WEBSITE_CONTENTSHARE` and `WEBSITE_CONTENTAZUREFILECONNECTIONSTRING` (#14815)
  * Updated for #13283
  * `azurerm_cdn_endpoint_custom_domain` - add supports for HTTPS (#13283)
  * Update for #13097
  * New resource `azurerm_app_service_slot_custom_hostname_binding` (#13097)
  * Fix Colon After Notes (#14819)
  * CHANGELOG.md for #14675
  * New Resource: `azurerm_disk_pool` (#14675)
  * Test time series insights (#14782)
  * CHANGELOG.md for #14799
  * azurerm_storage_management_policy: handle unexpected deletion of the referenced storage account (#14799)
  * updating to include #14739
  * Update for #14805
  * `azurerm_app_service_environment_v3` - fix for default value of `allow_new_private_endpoint_connections` (#14805)
  * Unused import
  * Make identity purely computed
  * Update website/docs/d/sql_managed_instance.html.markdown
  * Update website/docs/d/sql_managed_instance.html.markdown
  * Update website/docs/d/sql_managed_instance.html.markdown
  * Update website/docs/d/sql_managed_instance.html.markdown
  * Update website/docs/d/sql_managed_instance.html.markdown
  * Update internal/services/sql/sql_managed_instance_data_source.go
  * Update for #14803
  * Update for #14787
  * updating to include #14753
  * r/consumption_budget_subscription: adding a v2 state migration
  * Set resource id (facepalm)
  * add test for azurerm_stream_analytics_job.stream_analytics_cluster_id
  * refactor: switching to check the response is not found rather than the ID is non-null where a Resource ID Formatter is present (#14793)
  * docs(website/application_gateway): add the latest supported OWASP ruelset 3.2 (#14794)
  * Fix test failure
  * Apply suggestions from code review
  * switch to a hard deprecation for proxy property
  * Fix connection_string
  * New resource
  * Update for #14687
  * use gateway property in tests
  * Update for #14386
  * add test for azurerm_firewall_network_rule_collection.rule.description (#14758)
  * Updated error message to provide the solution
  * add test for azurerm_firewall_nat_rule_collection.rule.description (#14757)
  * add test for azurerm_firewall_application_rule_collection.rule.description (#14760)
  * Fix crash in 14698 (#14740)
  * CHANGELOG.md for #14738
  * `r/azurerm_virtual_network_gateway_connection`: Add support for `connection_mode` argument (#14738)
  * Correct the description of the name field. (#14764)
  * Correct name field description. (#14763)
  * Corrected the name description. (#14765)
  * Corrected name description. (#14766)
  * Calculate DS id
  * update code
  * fix crashing on import of specific resource type
  * Admin password isn't stored
  * Fix ds name in test
  * typofix
  * Add docs
  * New datasource: `azurerm_sql_managed_instance`
  * CHANGELOG.md for #14724
  * New resource: `azurerm_load_test` (#14724)
  * CHANGELOG.md for #14708
  * `d/azurerm_shared_image_version`: Add semver sorting option (#14708)
  * `azurerm_iothub_dps`- set `apply_allocation_policy` to true and remove ForceNews from `linked_hub` (#14697)
  * CHANGELOG.md for #14689
  * `azurerm_spring_cloud_certificate` supports `certificate_content` (#14689)
  * Added Premium Page Blob Account Kind Information (#14700)
  * fix to fqdn behaviour on backend pool (#14685)
  * tools/generator-resource-id: removing a rogue reference to the local resourceid package (#14722)
  * `r\azurerm_stream_analytics_output_table` Fix #14709 by adding nil check (#14725)
  * github: updating the titles (#14723)
  * r/kusto_cluster: de-referencing the pointer
  * updating to include #14715
  * issue14556 fix expensive sku in elasticpool doc
  * update doc
  * fix #12817 by loose `file_upload_limit_in_mb` to 4000.
  * d/netapp_snapshot_policy: refactoring to use an id formatter
  * kusto: refactoring to use an id formatter
  * postgres: refactoring to use an id formatter
  * storgae: refactoring to use an id formatter
  * Fix document of iothub servicebus topic and queue endpoint (#14704)
  * loadbalancer: refactoring to use an ID Formatter
  * machinelearning: refactoring to use an ID Formatter
  * sql: refactoring to use ID Formatters
  * Fixed databricks workspace document (#14693)
  * Updated lock duration (#14692)
  * Update changelog for #14690
  * IotHub Endpoints: deprecate `iothub_name` in favour of `iothub_id` (#14690)
  * updating to include #14688
  * gocritic ignore
  * sdk: updating the deprecated resource definition
  * Fix mod tidy issue.
  * Upgrading azure-go-sdk from 60.0.0 to 60.2.0 in order to enable encryption for RecoveryVault (need the latest version sdk for recoveryservices)
  * fix: fix subscription id on subscription budget resource
  * Changelog for #14671
  * Throwing an error for property `default_action` of the resource `servicebus_namespace_network_rule_set` (#14664)
  * CHANGELOG.md for #14661
  * azurerm_postgresql_flexible_server - support new property `geo_redundant_backup_enabled` (#14661)
  * CHANGELOG.md for #14659
  * azurerm_recovery_services_vault: support storage_mode_type property (#14659)
  * Adds `startsWith` as an operator for `dynamic_criteria` in `azurerm_monitor_metric_alert` (#14683)
  * r/virtual_network: removing the DDOS Protection Plan from the example
  * Added high-cost note (#14681)
  * make whitespace & goimports
  * New resource and data source: azurerm_aadb2c_directory
  * Changed ingestion to Ingestion (#14677)
  * updating to include #14365
  * disks: registering the client
  * r/storage_disks_pool: refactoring the validation to use the new disks package
  * disks: scaffolding the service package
  * disks: adding the embedded sdk
  * go mod tidy
  * update spring cloud sdk version
  * updating to include #14667
  * r/data_factory_dataset_binary: defining the missing DatasetCompression constants inline
  * updating to include #14354]
  * updating to include #14666
  * dependencies: upgrading to v60.0.0 of github.com/Azure/azure-sdk-for-go
  * dependencies: upgrading to v60.0.0 of github.com/Azure/azure-sdk-for-go
  * dependencies: upgrading to v2.10.1 of github.com/hashicorp/terraform-plugin-sdk
  * updating to include #14164
  * make generate (#14663)
  * fix typos in docs (#14662)
  * CHANGELOG.md for #14188
  * Add support for `azurerm_virtual_desktop_scaling_plan` (#14188)
  * CHANGELOG.md for #13888
  * `compute`: Add `user_data` to VM & VMSS resources (#13888)
  * Docs: Add ASEv3 example (#13582)
  * CHANGELOG.md for #14413
  * azurerm_application_gateway - key_vault_secret_id, force_firewall_policy_association (#14413)
  * CHANGELOG.md for #14121
  * `r\managed_disk`: Add support for `gallery_image_reference_id` (#14121)
  * go: updating to use Go v1.17.5 (#14654)
  * fix imports
  * update vendor
  * splitting to release 2.89.0
  * updating / splitting the changelog
  * update network sdk package
  * update network sdk package
  * go mod vendor, post rebase
  * revert pointless operation
  * Set vpn protocol to OpenVpn for multiple auth test
  * remove routes before deleting hub
  * Handle the resource going away during deletion gracefully
  * remove code added prematurely
  * use new network SDK (2021-05-01)
  * swap SDK versions in vendor dir
  * Update CHANGELOG.md
  * Use identity from common schema
  * `r\iothub`: Support managed service identity
  * v2.90.0
  * remove computed
  * `azurerm_consumption_budget_*` refactor into base and scoped resources (#14592)
  * CHANGELOG.md for #14007
  * azurerm_logic_app_workflow - support open_authentication_policy (#14007)
  * CHANGELOG.md for #14566
  * new resource: azurerm_maps_creator (#14566)
  * CHANGELOG.md for #14648
  * azurerm_blueprint_assignment  - Added lock_exclude_actions (#14648)
  * Doc Fix: blueprint_assignment.html.markdown (#14651)
  * CHANGELOG.md for #14230
  * Support for azurerm_netapp_snapshot_policy (#14230)
  * Update changelog for #14460
  * `azurerm_container_group`: support for `ip_address_type = None` (#14460)
  * Update changelog for #14527
  * New Resource: `azurerm_vpn_gateway_nat_rule` (#14527)
  * Update changelog for #14341
  * New Resource: `azurerm_synapse_workspace_sql_aad_admin` (#14341)
  * CHANGELOG.md for #14412
  * new resource "azurerm_synapse_sql_pool_workload_classifier" (#14412)
  * Update changelog for #14518
  * `azurerm_xyz_policy_assignment` add support for `non_compliance_message` (#14518)
  * CHANGELOG.md for #14632
  * `azurerm_iothub_endpoint_eventhub` - deprecate `iothub_name` in favour of `iothub_id` (#14632)
  * CHANGELOG.md for #14646
  * `azurerm_signalr` - Add support for property `live_trace_enabled` (#14646)
  * CHANGELOG.md for #14643
  * `r\azurerm_cosmosdb_account` Fix #14439 and #14630 by setting default value to `default_identity_type` when API return a nil. (#14643)
  * add `make pr-check` and make generate check error message more clear (#14650)
  * Fixed #12408: Import Correction (#14649)
  * CHANGELOG.md for #14546
  * azurerm_iothub - Add support for cloud_to_device block (#14546)
  * CHANGELOG.md for #14638
  * `azurerm_function_app` - address app_settings on create rather than just on update (#14638)
  * CHANGELOG.md for #14607
  * Add lock for the write operation of azurerm_postgresql_flexible_server_configuration (#14607)
  * CHANGELOG.md for #14619
  * Add lock for the write operation of azurerm_postgresql_configuration (#14619)
  * azurerm_iothub  - Fix iothub `encoding` and `file_name_format` schema (#14508)
  * `azurerm_app_service_environment_v3` remove preview note from docs (#14623)
  * Update Changelog for #14484
  * Fix failing test (#14647)
  * new data source azurerm_app_configuration_key (#14484)
  * azurem_signalr - check serviceMode is not empty (#14590)
  * increase timeouts
  * set apim id correctly
  * updating to include #14635
  * upgrade SDK version
  * Update changelog for #14583
  * `azurerm_application_gateway ` - support for private link configuration (#14583)
  * Update changelog for #14614
  * `azurerm_marketplace_agreement` - Fix crash when the import check triggers (#14614)
  * update docs
  * Updated link that leads to incorrect section (#14631)
  * Fix issue #14381 (#14603)
  * updating to include #14627
  * dependencies: upgrading to v0.19.1 of github.com/hashicorp/go-azure-helpers
  * add gateway property and deprecate proxy property
  * Update Changelog for #14533
  * New resource: `azurerm_container_registry_task` (#14533)
  * Update for #14610
  * `enforce_private_link_endpoint_network_policies` and `enforce_private_link_service_network_policies` are not conflict to each other anymore as schema shows.
  * dependencies: updating github.com/hashicorp/go-azure-helpers to v0.19.0
  * Update changelog for #13648
  * `data.azurerm_function_app_host_keys` - support for `signalr_extension_key` and `durabletask_extension_key` (#13648)
  * updating to include #14596
  * sdk: updating to handle deprecations in the plugin sdk
  * set data_factory_name to computed
  * set data_factory_name to optional
  * update docs
  * go mod vendor
  * deprecate data_factory_name
  * dependencies: updating github.com/hashicorp/terraform-plugin-sdk
  * [Document]`r\azurerm_private_link_service` The `network_interfaces` attribute seems never existed. The nearest `network_interface_ids` was removed at 9f53e4e61844d347658bc335213ab720aa98b130 .
  * CHANGELOG.md for #14362
  * azurerm_cosmosdb_account - support create_mode and restore (#14362)
  * CHANGELOG.md for #14312
  * Upgrade Api Management from 2020-12-01 to 2021-08-01 (#14312)
  * Update doc with full address of standby_availability_zone for azurerm_postgresql_flexible_server (#14587)
  * azurerm_data_factory_integration_runtime_azure_ssis - updated docs with new pricing tier options (#14593)
  * Doc Fix: `azurerm_windows_virtual_machine` - remove out of date `patch_mode` note (#14589)
  * Added SQL MI Private Endpoint Info because it was missing. (#14595)
  * updating to include #14502
  * [Document]`r\azurerm_api_management_api_version_set` Fix #14576 by adding `name` and `api_management_name`'s validation messages to document. (#14585)
  * change "api_server_authorized_ip_ranges" to computed+optional
  * Fix #12001 by correct document `resource_type` from "Required" to "Optional".
  * r/redis_enterprise_database: making the linter happy
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * `azurerm_virtual_hub_ip` - Make `public_ip_address_id` required for new instance and ForceNew (#14438)
  * goimports
  * Feature/#14570 asev3 doc typo (#14571)
  * kubernetes support scale_down_mode workload_runtime and public_network_access_enabled
  * v2.89.0
  * [Bug fix] - fix the `key_vault_managed_hardware_security_module` resource destruction timeout issue[GH issue #14163] (#14505)
  * CHANGELOG.md for #14528
  * `r\shared_image` Add support for `trusted_launch_enabled` (#14528)
  * `azurerm_kubernetes_cluster` allow Azure Policy addon for Azure Government (#14554)
  * fix: write the ID to terraform state for the management_lock_resource (#14544)
  * CHANGELOG.md for #14371
  * azurerm_vpn_gateway_connection - support routing.propagated_route_table.labels, vpn_link.connection_mode and traffic_selector_policy (#14371)
  * CHANGELOG.md for #14376
  * Change PostgreSQL password after instance was promoted from Replica to Default mode (#14376)
  * Update for #14411
  * BUG: remove eroneous validate (#14553)
  * Update changelog for #13974
  * New Resource: `azurerm_sql_managed_instance_failover_group`:  (#13974)
  * refactor: rename management_group_name to management_group_id
  * update linter config and remove lintignores (#14547)
  * Improve documentation around Azure Portal and Azure filter range
  * Amended example in doc as incorrect (#14543)
  * Update for #14538
  * App Service Beta - property consistency renames carried from 14247 and 14305 (#14538)
  * Update for #14305
  * New Beta Resource: `azurerm_linux_web_app_slot` (#14305)
  * Update for #14247
  * New Beta resource: `azurerm_windows_function_app` (#14247)
  * More relevant / standard route_table name
  * Unify managed disk test name
  * Update: Containers in security center pricing (#14511)
  * Update `azurerm_function_app` `storage_account_access_key` docs (#14517)
  * [Document] `r\azurerm_kubernetes_cluster_node_pool` Fix incorrect subnet description (#14504)
  * fmt and goimport
  * remove test wrappers, make tests public and rebase
  * Update for #14308
  * default enableSecretRotation in expand func
  * Update changelog for #14360
  * azurerm_signalr_service - deprecate features block in favour of connectivity_logs_enabled, messaging_logs_enabled and service_mode (#14360)
  * Update for #14491
  * `azurerm_app_service_environment_v3` - allow updating of `tags` (#14491)
  * Update for #14492
  * Remove invalid validation from azurerm_firewall_policy_rule_collection_group (#14503)
  * Fix #12884 by change eventhub name length upper limitation from 50 to 256. (#14494)
  * redisenterprise: refactoring to use the embedded sdk
  * fix(lb_rule): change typo rsource to resource (#14500)
  * sdk: embedding the redisenterprise sdk
  * Update changelog for #14104
  * New Resource: `azurerm_sql_managed_instance_active_directory_administrator` (#14104)
  * Rename identity block to secret_identity
  * Update for #14177
  * update deprecation message
  * set no_proxy to type set since ordering isn't preserved and add note on ignore changes for the field in docs
  * NetApp: Fix returned name in netapp_volume datasource (#14490)
  * Fix example code in resource document. (#14486)
  * Modified the casing
  * update TODO message, deprecate property in synapse
  * mssql: reintroducing the Restorable Dropped Database ID
  * code changes since PR opened
  * update docs
  * refactor: subscription id validation now comes from commonids
  * mssql: removing dead code
  * r/mssql_database_vulnerability_assessment_rule_baseline: refactoring to use id parsers
  * monitor: scheduled query rules log now uses an insensitive parser too
  * monitor: scheduled query rules gets an insensitive parser
  * monitor: refactoring metric alert to use an id parser
  * monitor: autoscale settings gets an insensitive parser
  * monitor: refactoring activity log alert to use an insensitive parser
  * monitor: refactoring to use an insensitive id parser
  * loganalytics: refactoring to use a single id formatter/parser
  * r/eventgrid_system_topic_event_subscription: fixing a rogue usage
  * deprecate data_factory_name
  * goimports
  * Update for #14462
  * Update resource_group_policy_assignment.html.markdown
  * making requested changes
  * Update resource_group_policy_assignment.html.markdown
  * `azurerm_linux_virtual_machine_scale_set` - add test case for ilpip (#14480)
  * Remove interpolation syntax. Deprecated as of Terraform 0.12+. (#14483)
  * CHANGELOG.md for #14391
  * `azurerm_data_fatory_trigger_schedule` - Fix `schedule` for `frequency = "Month/Week"` (#14391)
  * updating to include #14432
  * updating to include #14429
  * Update changelog for #14123
  * `azurerm_sql_managed_instance`: Support for `storage_account_type` (#14123)
  * r/container_group: switching over to using an id formatter/parser
  * datalake: working around the upstream api https://github.com/Azure/azure-rest-api-specs/issues/16962
  * datalake: changes required from the updated sdk
  * datalake: updating the embedded sdk
  * frontdoor: fixing an incorrect unit test
  * frontdoor: fixing a bug with the wrong parser being specified
  * devtestlabs: using the correct parser for schedules
  * frontdoor: refactoring to use the generated id parsers
  * eventgrid: refactoring to use a generated id parser
  * devtest: refactoring the windows vm migration to use an insensitive parser
  * devtest: refactoring virtual network to use a case insensitive parser
  * devtest: refactoring policy to use an insensitive id parser
  * devtest: refactoring virtual machine to use an insensitive parser
  * r/devtestlabs_schedule: refactoring to use an insensitive id parser
  * r/dev_test_lab: refactoring to use the insensitive id parser
  * firewall: refactoring to use an id parser
  * datafactory: refactoring to use the id parsers
  * databoxedge: refactoring to use an id formatter/parser
  * r/container_group: switching to use an id parser
  * r/orchestrated_vmss: refactoring to use an id parser
  * cdn: case-insensitive parsers for Endpoint/Profile
  * applicationinsights: refactoring Web Test ID to use an insensitive parser
  * applicationinsights: refactoring SmartDetectionRule to use a case insensitive parser
  * applicationinsights: refactoring to use a case insensitive parser for components
  * applicationinsights: updating the state migration to use an insensitive id parser
  * apimanagement: generating the Resource Id for NotificationRecipientUser
  * CHANGELOG.md for #14372
  * `service/netapp`: Various additions (#14372)
  * CHANGELOG.md for #14287
  * azurerm_key_vault_certificate - support versionless_id, versionless_secret_id (#14287)
  * `r/azurerm_storage_object_replication` Fix #14454 by adding a nil check. (#14475)
  * CHANGELOG.md for #13825
  * `r/azurerm_managed_disk`: Add support for `hyper_v_generation` property (#13825)
  * Add retry for APIM subscription creation 412 error code (#14414)
  * updating to include #14430
  * Fix order of properties
  * changelog from 2.88.1
  * Update automation_account_resource.go
  * Automation datasource initialization
  * Bugfix: parse User Assigned Identity ID insensitively
  * Update for #14464
  * Update automation_account_resource.go
  * Automation datasource initialization
  * Update for #14458
  * add docs and fmt
  * Modified the docs
  * Modified the docs
  * use different email for each test case
  * `r\iothub_endpoint_storage_container`: Fix `file_name_format` Schema
  * document: fix ACR bad example
  * v2.88.0
  * formatting
  * CHANGELOG.md for #14445
  * `azurerm_subscription` - add support for setting and updating tags (#14445)
  * eventhub_namespace - Correct the default capacity specified as 2. (#14441)
  * make generate
  * tools/generator-resource-id: refactoring to use the Go Azure Helpers ID Parser
  * tooling: switching to bash
  * github actions: triggering whenever there's a change to the `./.github` folder
  * scripts: removing the brackets
  * Move virtual machine extension snippet in docs to example (#14446)
  * scripts: adding an import-check for Track2 of the Azure SDK for Go
  * add requires import test
  * added custom importer
  * Update website/docs/r/mssql_server_extended_auditing_policy.html.markdown
  * Update website/docs/r/mssql_database_extended_auditing_policy.html.markdown
  * Fixed the casing
  * Fixed #13775-Docs updated
  * linting
  * `azurerm_synapse_sql_pool_extended_auditing_policy` - Fix fmt issue
  * Update for #14419
  * fix check in test and rename test case
  * frontdoor: code changes required for the updated sdk
  * Fix docs, rename identity block
  * frontdoor: updating the embedded sdk
  * msi: code changes needed for the updated sdk
  * msi: updating the embedded sdk
  * databricks: updating the embedded sdk
  * d/cdn_profile: refactoring to use an id formatter
  * d/eventgrid_topic: switching to use an id formatter
  * d/hdinsight_cluster: refactoring to use an id formatter
  * d/maintenance_configuration: refactoring to use an id formatter
  * r/sql_administrator: refactoring to use id formatters
  * r/sql_database: refactoring to use an id formatter
  * r/sql_failover_group: refactoring to use an id formatter
  * r/sql_firewall_rule: refactoring to use an id formatter
  * d/sql_server: refactoring to use an id formatter
  * r/sql_server: refactoring to use an id formatter
  * r/sql_virtual_network_rule: refactoring to use an id formatter
  * d/storage_account: refactoring to use an id formatter
  * r/storage_sync_cloud_endpoint: refactoring to use an id formatter
  * d/storage_sync: refactoring to use an id formatter
  * d/storage_sync_group: refactoring to use an id formatter
  * r/storage_sync_group: refactoring to use an id formatter
  * r/storage_sync: refactoring to use an id formatter
  * Update for #14368 and #14378
  * Added windows Example
  * register bot typed resource
  * azure bot kind with test
  * bot base resource
  * `azurerm_virtual_hub_ip` - Fix tests (#14408)
  * Update changelog for #14370
  * `azurerm_bastion_host` - Support for `sku` (#14370)
  * updating to include #14406
  * r/mysql_server_key: fixing the printf
  * update doc
  * `azurerm_container_group` Fix #9831 by change `dns_config.search_domains` and `dns_config.options` from `Required` to `Optional`
  * Fixing #14417
  * ip_version documentation fbug ix
  * CHANGELOG.md for #14355
  * azurerm_data_factory_managed_private_endpoint - support fqdns (#14355)
  * feat: create consumption budget management group resource
  * refactor: create funcs for notification schema differences for management groups
  * d/netapp_snapshot: refactoring to use an id formatter
  * r/netapp_snapshot: refactoring to use an id formatter
  * d/netapp_pool: refactoring to use an id formatter
  * d/netapp_account: refactoring to use an id formatter
  * d/netapp_volume: refactoring to use an id formatter
  * r/stream_analytics_function_javascript_udf: refactoring to use an id formatter
  * Automation: finalize id parsers
  * r/stream_analytics_output_blob: switching to use an id formatter
  * d/stream_analytics_job: switching to use an id formatter
  * r/stream_analytics_output_eventhub: refactoring to use an id formatter
  * CHANGELOG.md for #13658
  * new resource "azurerm_synapse_sql_pool_workload_group" (#13658)
  * `azurerm_web_application_firewall_policy` fix #14322 by change `policy_settings.max_request_body_size_in_kb` length limitation from [8, 128] to [8, 2000] (#14369)
  * r/stream_analytics_output_mssql: refactoring to use an id formatter
  * `azurerm_frontdoor_rules_engine` Fix #14313 by correct validate function (#14375)
  * r/stream_analytics_output_servicebus_queue: switching to use an id formatter
  * CHANGELOG.md for #14395
  * `r/azurerm_app_service`: Add support for `client_cert_mode` parameter (#14395)
  * `azurerm_api_management` - fix tests (#14405)
  * `azurerm_kusto_cluster` - Fix VNet test (#14407)
  * r/template_deployment: adding a state migration for the legacy template deployment resource
  * resource: generating insensitive parsers for resource group template deployment id's
  * resourcegroups: adding a disclaimer about why these are being left for the moment
  * r/management_lock: switching to use a nextgen ID parser/formatter
  * r/mysql_server_key: refactoring to use an id formatter
  * d/mariadb_server: refactoring to use an id formatter
  * d/traffic_manager_geographical_location: adding a note about the use of the id
  * d/subscription: updating to use a Resource ID Formatter
  * d/synapse_workspace: refactoring to use an id formatter
  * d/recovery_services_vault: switching to use an id formatter
  * d/servicebus_namespace_disaster_recovery_config: refactoring to use an id formatter
  * r/mariadb_server: refactoring to use an id formatter
  * d/firewall: switching to use a resource id formatter
  * r/logic_app_standard: refactoring to use an id parser
  * r/monitor_aad_diagnostic_setting: fixing the id validator to use the eventhub auth rule id rather than the relay id
  * Fix acceptance test
  * fmt, terrafmt and all that good stuff
  * set fields to compute for deprecation and refactor/fix tests for data source
  * apply review comments
  * improve docs for machine learning workspace
  * tfconfigs - cleanup (#14382)
  * Update Changelog for #13748
  * mssql_db: add support for transparent data encryption (#13748)
  * revert compute and add a note on the behaviour of the fields node_taint and eviction_policy
  * update sku in test for container config
  * Add twitter block info to function_app{_slot} documentation. (#14363)
  * update docs and fix more tests
  * deprecate properties and fix tests
  * Update for #14241
  * updating to include #14361
  * `azurerm_mssql_server` - Throw error when `azuread_authentication_only = true` and `administrator_login_password` is changed (#14356)
  * refactor: switching to use ID Formatters in (some) Requires Import steps (#14338)
  * r/storage_account: populating the cache on creation
  * CHANGELOG.md for #14345
  * `azurerm_point_to_site_vpn_gateway` - Support for `internet_security_enabled` (#14345)
  * CHANGELOG>me for #14285
  * `azurerm_mysql_flexible_database` - New resource (#14285)
  * CHANGELOG.md for #13842
  * r/azurerm_linux_virtual_machine and r/azurerm_linux_virtual_machine_scale_set - secure_boot_enabled, vtpm_enabled (#13842)
  * CHANGELOG.md for #14311
  * Update storage cache sdk to 2021-09-01 (#14311)
  * Update CHANGELOG.md
  * v2.87.0
  * CHANGELOG.md for #14346
  * Add support for new properties of azurerm_cosmosdb_account (#14346)
  * CHANGELOG.md for #14258
  * New resource: `azurerm_sentinel_watchlist` (#14258)
  * `azurerm_kusto_cluster` - Fix `trusted_external_tenant` for MyTenantOnly incl default change for 3.0 (#14243)
  * CHANGELOG.md for #14239
  * [new resource] API management recipient user (#14239)
  * Fix #9454 by setting `eviction_policy` and `node_taints` as Computed (#14030)
  * Changing Postgres instance type from Default to Replica forces a new resource to be created (#14351)
  * remove unnecessary subscripiton id check
  * `azurerm_mssql_server` - Enable inline creation of `azuread_authentication_only` to allow Azure Policies (#14316)
  * CHANGELOG.nmd for #14318
  * azurerm_eventgrid_event_subscription - support queue_message_time_to_live_in_seconds and user_assigned_identity (#14318)
  * CHANGELOG.md for #14329
  * azurerm_site_recovery_replication_policy  - allow disabling of app snapshots and retention (#14329)
  * CHANGELOG.md for #14337
  * Add new resource: azurerm_app_service_public_certificate (#14337)
  * CHANGELOG.md for #14340
  * fix(firewall_policy): replace ip address range with cidr range as valid input for threat_intelligence_allowlist (#14340)
  * add azurerm_app_service_certificate_binding to example (#14335)
  * docs: backup_instance_disk: fix example (#14328)
  * Add 'optional' keyword to aks->aad->managed bool in the Docs (#14350)
  * Update for #14211
  * Fix function slot  WEBSITE_CONTENTSHARE secretly changes (#14211)
  * Update changelog for #14042
  * Read patch_mode in resourceLinuxVirtualMachineRead (#14042)
  * Update for #14288
  * `azurerm_service_plan` (beta) - add Logic App SKUs to validation. (#14288)
  * Updated for #12764
  * New Resource: `azurerm_static_site_custom_domain` (#12764)
  * docs: backup_instance_disk: add necessary identity block (#14332)
  * updated to include #14236
  * merge #14236
  * fixing lint
  * adding in a test case for trusted ca
  * Support exporting identity for AKV provider
  * Use better logic for defaults. Use existing validation
  * Address review comments
  * azurerm_dev_test - refactored with parsers and migration (#14306)
  * docs: fix wrong documentation of max_pid featore of  azurerm_kubernetes_cluster_node_pool
  * `azurerm_recovery_services_vault` Update doc modify example code to meet service side's constraint, update `name` field description (#14300)
  * Format tests
  * Added docs for AKV provider
  * Added data source
  * Fixed state file
  * [docs] Remove unsupported argument "tier" from iothub examples.
  * Added validation for secret rotation interval
  * Add test for AKV provider addon
  * Support for rotationPollInterval
  * Add support for CSI driver
  * `azurerm_eventhub_consumer_group` add state migration for resource ID (#14289)
  * Add check for existing resource when creating new resource (#14296)
  * `azurerm_frontdoor_rules_engine` - Fix panic (#14292)
  * updating to include #14275
  * azurerm_dev_test - Updating dev_test_lab and dev_test_lab_policy with parser and migration (#14274)
  * Update for #14294
  * updating to include #14261
  * uncomment compatibility level 1.2
  * Docs: Add examples of built-ins roles needed by data lake gen2
  * Clarify code and update Acceptance Test
  * Fix typo in kubernetes_cluster_node_pool resource doc
  * Update Changelog for #14131
  * New resource for Service Fabric Managed Clusters service (#14131)
  * Update Changelog for #14277
  * Swap Relay parser and validator with EventHub (#14277)
  * CHANGELOG.md for #14262
  * `azurerm_automation_rule` - add supports for `expiration` (#14262)
  * Fix acctests for `azurerm_sentinel_alert_rule_tempalte` datasource (#14263)
  * CHANGELOG.md for #14264
  * Allow creation of `azurerm_stream_analytics_stream_input_eventhub` with the default `eventhub_consumer_group_name` (#14264)
  * CHANGELOG.md for #14270
  * `azurerm_mssql_elasticpool` - Support for DC family (#14270)
  * `azurerm_synapse_workspace` - Fix nilpointer for `sql_aad_admin`
  * remove Get function, use parse method to generate id. add subscription id check for `kube rnetes_cluster_id` in `kubernetes_cluster_node_pool_resource`
  * Update for #14082
  * Update for #14229
  * switch validate import from eventhub to streamanalytics
  * internal: changes needed for v0.18.0 of github.com/hashicorp/go-azure-helpers
  * go mod vendor
  * dependencies: upgrading to v0.18.0 of github.com/hashicorp/go-azure-helpers
  * Updated app svc env v3 doc for ip (#13981)
  * cognitive: switching to use the embedded sdk (#13984)
  * CHANGELOG.md for #14199
  * `r\managed_disk`: Add support for `public_network_access_enabled` (#14199)
  * tags: remove transition file from packages that were swapped to the embedded sdk (#14215)
  * v2.86.0
  * CHANGELOG.md for #14079
  * Enchancing `azurerm_key_vault_certificate` by making `tags` updatable due to #13315 (#14079)
  * CHANGELOG.md for #14137
  * `r\managed_disk` Add support for `on_demand_bursting_enabled` (#14137)
  * F/14092 expand pricing tier options (#14113)
  * CHANGELOG.md for #14140
  * ththe azurerm_cost_management_export_resource_group has been deprecated in favour of azurerm_resource_group_cost_management_export, azurerm_subscription_cost_management_export (#14140)
  * CHANGELOG.md for #14096
  * `azurerm_container_registry` - add supports of `anonymous_pull_enabled`, `data_endpoint_enabled` and `network_rule_bypass_option` (#14096)
  * CHANGELOG.md for #14142
  * `azurerm_kubernetes_cluster` - Support for `outbound_type = "*NATGateway"` and `nat_gateway_profile` (#14142)
  * CHANGELOG.md for #14145
  * New resource `azurerm_storage_disks_pool` (#14145)
  * CHANGELOG.md #14252
  * `azurerm_stream_analytics_output_servicebus_topic` add `property_columns` attribute (#14252)
  * CHANGELOG.md for #14227
  * New attribute for `r/virtual_desktop_application_group` (#14227)
  * CHANGELOG.md for #14238
  * azurerm_backup_protected_file_share: Fix issue about file share is added to an exist storage account but it cannot be listed by Backup Protectable Items (#14238)
  * CHANGELOG.md for #14250
  * `azurerm_elastic_pool` - Support for Fsv2 family (#14250)
  * CHANGELOG.md for #14253
  * `azurerm_key_vault_managed_hardware_security_module` - extend context timeouts for create and delete. (#14253)
  * merging #14255
  * fix `redis_cache_id` issue for the resource `api_management_redis_cache` (#14208)
  * Logic App Standard: Fix tests (#14246)
  * Update for #14218
  * remove fields except Type/Optional/Required/Computed from schema snapshot
  * CHANGELOG.md for #13843
  * r/postgresql_flexible_server: `zone` and `standby_availability_zone` are no longer computed (#13843)
  * CHANGELOG.md for #14228
  * `azurerm_public_ip_prefix` - Support for `ip_version` to support `IPv6` (#14228)
  * CHANGELOG.md for #14217
  * `r\purview_account`: Add support for `managed_resource_group_name` (#14217)
  * CHANGELOG.md for #14225
  * `azurerm_key_vault_certificate` - Make `certificate_policy` optional for imported certs (#14225)
  * CHANGELOG.md for #14119
  * New Resource: azurerm_monitor_private_link_scoped_service (#14119)
  * CHANGELOG.md for #14200
  * Support new property flow_timeout_in_minutes for azurerm_virtual_network (#14200)
  * CHANGELOG.md for #14169
  * `azurerm_mssql_server` - support `azuread_authentication_only` on create (#14169)
  * CHANGELOG.md for #14172
  * `azurerm_sql_active_directory_administrator` - Support for `azuread_authentication_only` (#14172)
  * CHANGELOG.md for #13893
  * New resource: `azurerm_automation_webhook` (#13893)
  * CHANGELOG.md for #14020
  * new resource azurerm_logz_tag_rule (#14020)
  * updating to include #14237
  * adding #14237
  * modify migration schema, add unit test for migration code, add migration for `kubernetes_cluster_node_pool_resource` to correct it's `id` and `kubernetes_cluster_id`
  * Resolve comments
  * updating to include #14235
  * adding #14235
  * Update Changelog for #13607
  * State migration for storage account resource (#13607)
  * GHA - split concurrency groupings per workflow (#14232)
  * updating to include #12385
  * Update for #14080
  * fix import order
  * set default for tls to 1.2 behind threepointoh
  * azurerm_storage_account - refactoring to use parsers (#14205)
  * updating to include #13713
  * vendor: updating to account for the latest Azure SDK for Go version changes
  * Update Changelog for #13682
  * Add per-resource recovery control for soft-deleted key vault items (#13682)
  * `azurerm_mssql_server`: Fix documentation (#14223)
  * TestAccResourceProviderRegistration_feature: updating to use an available RP/features
  * TestAccResourceProviderRegistration_requiresImport: switching the RP to one which doesn't require extra T&C's
  * r/resource_provider_registration: being explicit with the new features functionality
  * azurerm_resource_provider_registration supports feature
  * Update doc
  * Add encryption type discovery to virtual machine
  * fix typo
  * fix azurerm_synapse_workspace_key doc example
  * `managed_disk`,`disk_encryption_set`: Add support of `EncryptionAtRestWithPlatformAndCustomerKeys`
  * modify migration schema, set `azurerm_kubernetes_cluster` id while read to set correct case, use parsed id as `azurerm_kubernetes_cluster_node_pool_resource`'s `kubernetes_cluster_id` while read
  * try to fix #13919, not complete yet
  * Update changelog for #14192
  * `azurerm_mssql_database`: Fix error with OnlineSecondary with auditing on Primary (#14192)
  * Update for #14202
  * App Service Beta - support for Load Balancer timeouts and VNet Route All. (#14202)
  * fixing lint issue
  * update workflows for single concurrency per PR. remove redundant 'strategy' block
  * making enhancements per pr comments
  * azurerm_log_analytics - refactoring to use parsers (#14191)
  * make fmt
  * Update internal/services/compute/windows_virtual_machine_resource.go
  * Update internal/services/compute/windows_virtual_machine_scale_set_resource.go
  * Update for #14204
  * `r/azurerm_frontdoor`: Fix incorrect validation in `backend_pool_health_probe`
  * Add usage example for `azurerm_monitor_diagnostic_setting` integration with `eventhub` (#14151)
  * Update internal/services/storage/storage_account_data_source.go
  * Update internal/services/storage/storage_account_resource.go
  * Adding embedded sdk
  * eventhub - regenerate embedded sdk  (#14156)
  * pass build
  * Update website/docs/r/storage_account.html.markdown
  * use pull_request_target without checkout of code
  * Update for 13806
  * New (Beta) Resource: `azurerm_linux_function_app` (#13806)
  * build: updating to use Go 1.17.3
  * updating to include #14083
  * Adding `http_proxy_config` to `azurerm_kubernetes_cluster` (#4)
  * CHANGELOG.md for #14160
  * Fix #14152 by adding lock to avoid parallel race error on service side (#14160)
  * CHANGELOG.md for #14120
  * azurerm_machine_learning_workspace - encryption block (#14120)
  * Updating to include #14003
  * merge #14003
  * Corrected version of compute API
  * CHANGELOG.md for 314174
  * Splitting SDK upgrade and OVMSS work into two PR's (#14174)
  * Update changelog for #14165
  * `windows_virtual_machine_scale_set`/`linux_virtual_machine_scale_set` - `source_image_reference.offer` and `source_image_reference.publisher` are now ForceNew #14165)
  * vmware - regen embedded sdk (#14133)
  * internal/acceptance: round 2
  * updating to include #14150
  * updating to include #14135
  * azurerm_api_management - refactoring remaining api_management resources to use parsers (#14148)
  * d/data_lake_store: fixing linting by ensuring all fields have defaults
  * r/data_lake_analytics_account: fixing the linting
  * internal/acceptance: fixing the linting
  * videoanalyzer: updating to the latest embedded sdk
  * regeegen part 2
  * regen embedded sdk
  * updating to include #14153
  * updating to include #14158
  * imports
  * r/private_endpoint: fixing the casing on `private_connection_resource_id` if needed
  * website: updating the resource id for signalr_service_network_acl to match the new format
  * r/signalr_service_network_acl: adding a state migration for the old -> new id
  * r/signalr_service_network_acl: updating to use the native Resource ID validator function
  * website: updating signalr_service to account for the updated resource id
  * r/signalr_service: adding a state migration for the old/new ID format
  * regen part two
  * regen embedded sdk
  * updating to include #14154
  * updating to include #14155
  * Update internal/services/relay/relay_namespace_resource.go
  * Update internal/services/relay/relay_hybrid_connection_resource.go
  * updating to include #14157
  * dependencies: removing the old azure sdk
  * `azurerm_(ms)sql_server` - removal of doc for deprecated `extended_auditing_policy`
  * datalake: goimports
  * handling the import change
  * Fix struct issue
  * moving bulk of datalake to embedded sdk
  * v2.85.0
  * CHANGELOG.md for #14052
  * `azurerm_sql_managed_instance`: Support for `identity` (#14052)
  * `managed_disk_resource`: Add `disk_iops_read_only`, `disk_mbps_read_only` (#14025)
  * Doc Fix: `azurerm_iothub_resource` doc shows correct route source option names (#14149)
  * regen part two electric boogaloo
  * regen part two electric boogaloo
  * regen part two electric boogaloo
  * `azuread`: upgrade of `azuread` components in AccTest to v2 (#14105)
  * CHANGELOG.md for #14136
  * `azurerm_mysql_flexible_server_firewall_rule`: New resource (#14136)
  * CHANGELOG.md for #13600
  * New resource: `azurerm_synapse_workspace_aad_admin` - supports setting AAD admin for synapse workspaces with CMK (#13600)
  * CHANGELOG.md for #14025
  * CHANGELOG.md for #14085
  * `azurerm_storage_encryption_scope`: Allow versionless `key_vault_key_id` (#14085)
  * CHANGELOG.md for #14098
  * New Resource: azurerm_monitor_private_link_scope (#14098)
  * CHANGELOG.md for #14097
  * azurerm_backup_protected_vm: Support exclude_disk_luns and include_disk_luns properties for backup protected VM resource (#14097)
  * updating to include #14141
  * go mod vendor
  * dependencies: upgrading github.com/hashicorp/go-azure-helpers to v0.17.1
  * Update changelog for #14124
  * `azurerm_virtual_network_gateway`: Enable configuration of an active-active zone redundant gateway with P2S (#14124)
  * Update changelog for #14093
  * `azurerm_frontdoor_resource` - route engines are no longer removed on update (#14093)
  * cognitive - regenerate embedded sdk (#14114)
  * Update for #14043
  * Update for #14125
  * remove import step from data source test
  * add threshold_type to data source schema
  * updating to include #14108
  * attestation: regenerate embedded sdk (#14112)
  * App Configuration - regenerating the embedded sdk (#14111)
  * reregen embedded sdk
  * regen embedded sdk
  * regen embedded sdk
  * Regenenerate sdk
  * Correct all references to properties
  * Correct formatting issues
  * Correct casing in website documentation
  * Use precreated ID
  * Use ID in error message
  * Use ID in error messages
  * Use ID references where appropriate
  * Use ID parser to build the Application ID
  * Remove CHANGELOG update
  * updating to include #14070
  * Fix typos and smoothen short descriptions
  * goimports
  * d/redis_cache: parsing the subnetId case-insenstively
  * r/redis_cache: parsing the subnetId insensitively
  * updating to include #14103
  * updating to include #14100
  * Update security_center_subscription_pricing.html.markdown
  * Update security_center_subscription_pricing_resource.go
  * Fix storage blob cache_control test failure (i.e. TestAccStorageBlob_cacheControl)
  * Remove stray string format from test
  * Update documentation for topic_type available values in EG system topic (#14091)
  * Remove stray parameter from data source test function
  * adding datasource
  * update import path
  * using storage 2021-01-01 for blob inventory policy
  * pass build for test code
  * fix update
  * upgrade storage sdk to 2021-04-01 (compatible way to mitigate breaking chagne of the inventory, but not working actually)
  * fix the account_kind validation
  * `azurerm_storage_account` - add supports of `{table|queue}_encryption_key_type`
  * frontdoor: swapping to embedded sdk (#13966)
  * Correct attribute reference (#14072)
  * `azurerm_key_vault_certificate`: Prevent `certificate.contents` to be empty (#14061)
  * azurm_api_management - refactoring to use parsers (#14062)
  * `azurerm_app_service_virtual_network_swift_connection`: Fix nilpointer
  * Fix tests for `azurerm_stream_analytics_output_table` (#14059)
  * Corrected all "aci-helloworld" and "aci-tutorial-sidecar" Docker image references in examples/docs (#14064)
  * CHANGELOG.md for #14035
  * azurerm_application_insights - support internet_ingestion_enabled, internet_query_enabled (#14035)
  * updating to include #14060
  * go mod vendor
  * dependencies: updating to v0.17.0 of github.com/hashicorp/go-azure-helpers & v2.8.0 of github.com/hashicorp/terraform-plugin-sdk
  * refactor: updating to account for the changes in hashicorp/go-azure-helpers#85
  * increase timeout
  * Update for 14026
  * fix tf block in test
  * Convert Bool to String in check
  * Correct test function name
  * Removed unused imports
  * azurerm_cosmosdb_cassandra_cluster: Fix import test (#14046)
  * Correct terraform formatting
  * v2.84.0
  * CHANGELOG.md for #13785
  * new resources: azurerm_cosmosdb_cassandra_datacenter, azurerm_cosmosdb_cassandra_cluster (#14019)
  * CHANGELOG.md for #14013
  * new resource `azurerm_stream_analytics_output_synapse` (#14013)
  * hpc_cache Added support for readonly SKUs (#14037)
  * CHANGELOG.md foir #14028
  * `managed_disk_resource`: Add validation for `disk_iops_read_write`, `disk_mbps_read_write` (#14028)
  * Update CHANGELOG
  * Create Batch Application data source
  * fmt and lint
  * update and format test blocks
  * docs for managed private endpoint
  * add cluster docs
  * add stream analytics cluster prop to docs
  * update resource registration
  * rename to managed private endpoint
  * complete endpoint client registration
  * Change api_management_certificate Subject attribute to reference correct certificate property
  * CHANGELOG.md for #13988
  * Add `key_vault_reference_identity_id` attribute for `azurerm_app_service_slot` (#13988)
  * CHANGELOG.md for #13934
  * key_vault_key - add the cureve, x, y, public_key_pem, public_key_openssh (#13934)
  * CHANGELOG.md for #14015
  * Add support for Integration Account with Integration Service Environment (#14015)
  * CHANGELOG.md for #13874
  * new resource "logz_monitor" (#13874)
  * CHANGELOG.md for #13465
  * update aks sdk to 2021-08-01 (#13465)
  * add endpoints client, resource id and generated parser
  * update cluster prop and refactor
  * added stream analytics cluster property
  * CHANGELOG.md for #14004
  * `azurerm_firewall_policy - add supports for the `insights` (#14004)
  * datalake: add embedded sdk
  * Fix acctest for sentinel DC (#13875)
  * CHANGELOG.md for #13820
  * azurerm_machine_learning_compute_cluster, azurerm_machine_learning_compute_cluster, azurerm_machine_learning_synapse_spark - support for local_auth_enabled (#13820)
  * CHANGELOG.md for #13967
  * `azurerm_cosmosdb_account`: Allow change of backup type from `Periodic` to `Continuous` (#13967)
  * Added support for patch_mode in resource_linux_virtual_machine. (#13866)
  * CHANGELOG.md for #13998
  * azurerm_monitor_smart_detector_alert_rule: Support additional detector types (#13998)
  * CHANGELOG.md for #13938
  * `azurerm_storage_share` - add supports for `enabled_protocol` (#13938)
  * CHANGELOG.md for #13964
  * `azurerm_logic_app_standard` - fixes error when working on private network (#13964)
  * CHANGELOG.md for #13962
  * Add  `key_vault_reference_identity_id` attribute for `azurerm_function_app` (#13962)
  * CHANGELOG.md for #13866
  * azurerm_backup_protected_file_share supplement doc: add `depends_on` for adding a protected item to a pre-e… (#13955)
  * CHANGELOG.md for #13976
  * `azurerm_firewall_policy_rule_collection_group` - add supports of `translatedFqdn` for NAT rule (#13976)
  * `azurerm_mssql_database`: Fix `storage_account_type` (#13990)
  * Update CHANGELOG.md
  * CHANGELOG.md for #13946
  * feat(storage_blob): implement control_cache (#13946)
  * azurem_mariadb - Refactoring to use parsers (#13996)
  * CHANGELOG.md for #13951
  * `azurerm_sql_managed_instance`: Support for `dns_zone_partner_id` (#13951)
  * Upgrade Azure Go SDK to v59.0.0 (#13943)
  * Updated documentation for `azurerm_frontdoor_rules_engine` (#13940)
  * CHANGELOG.md for #13971
  * azurerm_application_insights -  increase allowed validate for the daily_data_cap_in_gb property (#13971)
  * Updated documentation for `azurerm_frontdoor_rules_engine` (#13975)
  * Fix the HCL example in the sentinel documents (#13978)
  * CHANGELOG.md for #13973
  * azurerm_mssql_elasticpool  Added GP_FSv2 to sku validate function (#13973)
  * CHANGELOG.md for #13659
  * synapse_workspace supports sql_aad_admin (#13659)
  * Remove security_type from internal/services/compute/windows_virtual_machine_scale_set_resource.go
  * Update internal/services/compute/windows_virtual_machine_scale_set_other_resource_test.go
  * Update internal/services/compute/windows_virtual_machine_scale_set_resource.go
  * Update internal/services/compute/windows_virtual_machine_resource.go
  * Update internal/services/compute/windows_virtual_machine_resource.go
  * Update internal/services/compute/windows_virtual_machine_resource.go
  * Update internal/services/compute/windows_virtual_machine_scale_set_other_resource_test.go
  * Update internal/services/compute/windows_virtual_machine_resource_other_test.go
  * Update internal/services/compute/windows_virtual_machine_resource_other_test.go
  * linting: increasing the timeout to 60m
  * CHANGELOG.md for #13897
  * `r\purview_account_resource`: Deprecate `sku_name` property (#13897)
  * CHANGELOG.md for #13785
  * Upgrade Purview from 2020-12-01-preview to stable version 2021-07-01 (#13785)
  * Adding cognitive sdk
  * CHANGELOG.md for #13881
  * `azurerm_synapse_workspace_key`: deprecate `cusomter_managed_key_name` in favour of the correctly spelled `customer_managed_key_name` (#13881)
  * Update CHANGELOG-v2.md
  * Update CHANGELOG.md
  * lint and fmt
  * gha for linking milestone
  * create, read, delete and basic test
  * internal/acceptance: cleanup
  * fmt
  * testing: reworking the concept for now
  * r/resource_group: switching over to using the new ApplyStep an example
  * testing: adding an ApplyStep to the TestData func
  * frontdoor: Adding embedded sdk #13949
  * azurerm_network - refactoring network importers, create and log messages (#13945)
  * v2.83.0
  * CHANGELOG.md for #12924
  * “azurerm_spring_cloud_java_deployment” – the `cpu` and `memory_in_gb ` properties have been deprecated in favour of the `quota` block (#12924)
  * Move ignore:AT001 annotation so it's recognized (#13950)
  * `r/azurerm_monitor_autoscale_setting`: Add `ServiceAllowedNextValue` (#13944)
  * CHANGELOG.md for #13498
  * azurerm_application_gateway - support priority property (#13498)
  * CHANGELOG.md for #13942
  * Validate administrator_login in postgres flexible server (#13942)
  * CHANGELOG.md for #13936
  * azurerm_cosmosdb_account: Ignore the change of capabilities property (#13936)
  * CHANGELOG.md for #13692
  * new resource "azurerm_kusto_script" (#13692)
  * Update changelog for #13394
  * `azurerm_linux_virtual_machine_scale_set/`azurerm_windows_virtual_machine_scale_set``azurerm_virtual_machine_scale_set_extension ` - Add support for `automatic_upgrade_enabled` in extensions (#13394)
  * generate cluster id parser
  * register clusters client
  * Update for #13723
  * Remove field InvoiceSectionName from struct
  * Update website/docs/r/subscription.html.markdown
  * remove debug log from testing
  * Add `StoragePool/diskpools` to subnet's `service_delegation` allow list, get ready for DisksPool resource (#13935)
  * CHANGELOG.md for #13849
  * `r\managed_disk`: Add support for `security_type` (#13849)
  * Refactoring remaining network services to use parsers (#13920)
  * CHANGFELOG.md for #13917
  * New resource: `azurerm_iot_time_series_insights_event_source_eventhub` (#13917)
  * CHANGELOG.md for #13904
  * azurerm_firewall_policy - changing the identity will no longer create a new resource (#13904)
  * `azurerm_sql_server`: Remove deprecated value `new` from `threat_detection_policy.state` (#13905)
  * [postgres/flexible] Fix & Update SKU validation Regex (#13927)
  * CHANGELOG.md for #13817
  * azurerm_synapse_workspace - support linking_allowed_for_aad_tenant_ids, compute_subnet_id, public_network_access_enabled, purview_id,last_commit_id (#13817)
  * CHANGELOG.md for #13929
  * Prevent multiple azurerm_application_gateway.ssl_policy blocks. … (#13929)
  * CHANGELOG.md for #13906
  * azurerm_automation_schedule_resource: Changing Automation Time Helper to be 'Etc/UTC' rather than just 'UTC' (#13906)
  * Fix the application_gateway.redirect_configuration docs. Fixes #13930. (#13931)
  * add 3.0 todo note about azurerm_data_lake_store
  * Docs: Note that Azure Data Lake Store is the Data Lake Storage Gen 1 (#13921)
  * CHANGELOG.md for #13925
  * Add "Accepted" to pending state list (#13925)
  * CHANGELOG.md for #13882
  * `azurerm_vpn_gateway`: Support for `routing_preference` (#13882)
  * fix typo in docs
  * fix camel casing for analytics items and goimports
  * camel case api key section of id from azure api
  * complete webtests refactor for id parser
  * Update for #13854
  * consolidate if conditions
  * `azurerm_service_bus_queue|topic`: Support for `max_message_size_in_kilobytes` for Premium SKU (#13762)
  * Update for #13635
  * Update API version for azurerm_mysql_flexible_server_configuration (#13895)
  * Fix example usage of azurerm_data_protection_backup_policy_blob_storage in docs for azurerm_data_protection_backup_instance_blob_storage (#13850)
  * video_analyzer: use embedded sdk (#13837)
  * CHANGELOG.md for #13818
  * Upgrade API version for azurerm_mysql_flexible_server (#13818)
  * CHANGELOG.md for #13853
  * Enhancement to azurerm_servicebus_namespace_network_rule_set: Support 'allow trusted services' (#13853)
  * Fix #13647 (#13876)
  * Refactoring virtual_network* services to use parsers (#13885)
  * CHANGELOG.md for #13887
  * `azurerm_kubernetes_cluster` expose `azurePortalFqdn` (#13887)
  * CHANGELOG.md for #13859
  * `azurerm_app_configuration_key`: Support for slashes in `key` (#13859)
  * Application insights `application_type` parameter is case insensitive (#13823)
  * CHANGELOG.md for #11502
  * New Resource - `sentinel_automation_rule` (#11502)
  * Fixing the azurerm_machine_learning_inference_cluster creation with a private AKS cluster (#13845)
  * CHANGELOG.md for #13762
  * cleanup changelogs (#13891)
  * CHANGELOG.md for #13851
  * `d/azurerm_eventgrid_system_topic`: New data source (#13851)
  * Refactoring ddos_plan, security_rule and backend_address_pool to use parsers (#13855)
  * `d/azurerm_network_interface`: Support for `gateway_load_balancer_frontend_ip_configuration_id` to prevent nilpointer (#13865)
  * CHANGELOG.md for #13862
  * `azurerm_firewall_policy`: Fix import by removing potential nilpointers (#13862)
  * Documentation for kubernetes cluster node count minimum differentiating user and system pools (#13871)
  * Update changelog for #13519
  * Data Factory - Global Parameters, bug fix while reading editted or existing global parameter values (#13519)
  * Update changelog for #13840
  * add default_route_table to virtual hub (#13840)
  * update import statement in docs
  * add state migration and regenerate id parser for analytics item
  * state migration and regenerated id parsers for api key, smart detection rule, web tests
  * `azurerm_monitor_metric_alert`: Tags added to AccTests
  * register typed resource in alphabetical order
  * Update for #13869
  * `azurerm_firewall_application_rule_collection`: Make `protocol.port` required
  * docs: disable local accounts
  * Fix sku_size doc definition
  * terrafmt docs
  * fmt and lint
  * register typed resource and add docs
  * add test and registration
  * Update for 13822
  * check for blob type input data source in custom importer
  * rename refresh_rate to refresh_interval_duration
  * initial draft with typed resource
  * Updated message
  * Refactoring network services to use parsers (#13798)
  * v2.82.0
  * Update CHANGELOG.md
  * CHANGELOG.md for #13831
  * `azurerm_mysql_flexible_server_configuration`: New resource to support configuration on `mysql_flexible_server` (#13831)
  * `servicebus`: Replace API version `2018-01-01-preview` with `2021-06-01-preview` (#13760)
  * CHANGFELOG.md for #13462
  * azurerm_kubernetes_cluster support for open_service_mesh (#13462)
  * Sync the documentation of the app service slot (#13815)
  * CHANGELOG.md for #13507
  * Remove forceNew for `zone` and `standby_availability_zone` of azurerm_postgresql_flexible_server (#13507)
  * fix #13596 (#13814)
  * refactor: minor zones bugs (#13821)
  * CHANGELOG.md for #13767
  * `azurerm_container_registry` - add supports for `region_endpoint_enabled` (#13767)
  * CHANGELOG.md for #13744
  * new resource "azurerm_synapse_sql_pool_vulnerability_assessment_baseline" (#13744)
  * add web and function app documentation with slot (#13834)
  * `azurerm_mssql_database`: Fix `threat_detection_policy` options for AccTests (#13828)
  * CHANGELOG.md for #13743
  * New Resource: azurerm_virtual_hub_route_table_route (#13743)
  * CHANGELOG.md for #13812
  * Azure NetApp Files SDK updated to latest and removal of opt-in text for CRR (#13812)
  * CHANGELOG.md for #13754
  * `azurerm_mssql_server`: Support for `azuread_authentication_only` (#13754)
  * CHANGELOG.md for #13779
  * `azurerm_batch_pool`: Support for `identity` (#13779)
  * Update for 13799
  * goimports
  * remove whitespace
  * fix typo
  * add custom importer for reference blob and fix printing of *id
  * add docs
  * new resource stream analytics reference input mssql
  * Fix minor error in doc for queue_properties attribute (#13808)
  * Add support for new property ConnectionFromIPNotAllowed of azurerm_iot_security_device_group (#13768)
  * CHANGELOG.md for #13731
  * azurerm_data_factory_integration_runtime_azure  - support `AutoResolve` for the location property (#13731)
  * CHANGELOG.md for #13783
  * azurerm_iot_security_solution - support for additional_workspace, disabled_data_sources (#13783)
  * CHANGELOG.md for #13742
  * `azurerm_batch_account` - add supports for `identity` (#13742)
  * CHANGELOG.md for #13753
  * `azurerm_mssql_server`: Set `azuread_administrator` inline on creation (#13753)
  * fix psql admin name (#13746)
  * Removed note of container soft delete preview (#13807)
  * databricks: moving to use an embedded sdk (#13764)
  * Update Changelog for #13773
  * Expose a Virtual Machine's IP addresses as outputs (#13773)
  * attestation: moving to use an embedded sdk (#13800)
  * Update for #13747
  * Boolean input validaton
  * terrafmt
  * Fix and extend AccTest
  * updating to include #13797
  * Fix tests
  * `azurerm_mssql_database`: Fix for `extended_auditing_policy` for imported Secondary
  * CHANGELOG./md for #13559
  * `azurerm_lb`, `azurerm_lb_backend_address_pool`, `azurerm_network_interface` - add supports for gateway LB (#13559)
  * `azurerm_servicebus_subscription`: Support for `name="_somename_`
  * fmt
  * Resolve reference error and remove unnecessary test check
  * move property read to correct block
  * Update Changelog for #13771
  * Handle default value for Percentage appconfig feature filters (#13771)
  * Update Changelog for #13757
  * force mongoenabled for mongo34 (#13757)
  * make fmt
  * Update for #13690
  * Update website/docs/r/synapse_spark_pool.html.markdown
  * fix typo
  * Implement requested changes
  * CHANGELOG.md for #13701
  * `servicebus`: Update SDK to `2021-06-01-preview` (#13701)
  * CHANGELOG.ms for #13674
  * azurerm_lb_nat_pool: Add support for floating_ip_enabled, tcp_reset_enabled, idle_timeout_in_minutes (#13674)
  * Rename variable
  * update deps (#13751)
  * `azurerm_disk_encryption_set` support for `enable_auto_key_rotation`
  * CHANGELOG.md for #13613
  * Upgrade to v58.0.0 of `Azure/azure-sdk-for-go` (#13613)
  * Update CHANGELOG.md
  * v2.81.0
  * Update CHANGELOG.md
  * CHANGELOG.md for #13732
  * `azurerm_kubernetes_cluster` - `kube_config` and `kube_admin_config` blocks can now be marked entirely as `Sensitive` via environment variable. (#13732)
  * CHANGELOG.md for #13711
  * azurerm_function_app_slot - azurerm_function_app_slot has been deprecated as it is no longer configurable in the service API (#13711)
  * CHANGELOG.md for #13736
  * Swap calls to `GetKeyValues()` with `GetKeyValue()` (#13736)
  * CHANGELOG./md for #13678
  * New resource: azurerm_mysql_flexible_server (#13678)
  * storage_data_lake_gen2_path note about ACL inheritance (#13738)
  * `azurerm_virtual_network_dns_servers` - Add documentation (#13739)
  * CHANGELOG.md for #13680
  * azurerm_lb: Add support for SkuTier property (#13680)
  * CHANGELOG.md for #13683
  * `azurerm_mssql_server`: user_assigned_identity_ids and primary_user_assigned_identity_id (#13683)
  * Refactor `azurerm_monitor_*` to use id parser (#13644)
  * examples: fixing the formatting
  * tooling: checking that each of the examples validates via `terraform fmt`
  * examples: fixing validation issues
  * examples: removing a duplicate example
  * removing the old 'go.sum'
  * examples/app-service/functions-python: fixing the vars file
  * tooling: adding a Github Action to validate the examples are valid
  * tooling: adding a script to validate the examples in the `./examples` folder are valid
  * examples: removing the old test functionality
  * Update for #12538 and #12540
  * update test and for order inconsistency in API
  * update test and doc for order inconsistency in API
  * replace typeset with typelist and fix test
  * missed one
  * replace typeset with typelist
  * CHANGELOG.md for #13720
  * r/azurerm_app_service: Make key_vault_reference_identity_id configurable (#13720)
  * CHANGELOG.md for #13560
  * azurerm_cosmosdb_account data source - prevent panic: runtime error: index out of range (#13560)
  * update
  * Test Fix: `azurerm_security_center_*` (#13727)
  * CHANGELOG.md for #13595
  * `azurerm_eventgrid_event_subscription` : Support delivery_property (#13595)
  * CHANGELOG.md for #13622
  * Update `mssql` SDK version to `preview/v5.0` (#13622)
  * CHANGELOG.md for #13487
  * `azurerm_kusto_attached_database_configuration` supports `sharing_properties` (#13487)
  * CHANGELOG.md for #13717
  * enable_rbac_authorization in azurerm_key_vault data sources (#13717)
  * Fixed Lint issues
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * CHANGELOG.md for #13726
  * `azurerm_subnet_resource` - Lock virtual network and subnet on update (#13726)
  * fix issue: 11150 (#13669)
  * data eventgrid domain - add: access keys to docs (#13707)
  * update doc, changing `tags` will cause a re-creation (#13721)
  * Update changelog for #13710
  * `r/azurerm_security_center_workspace`: Allow creation with `Free` pricing tier (#13710)
  * update checks and make terrafmt
  * make fmt
  * Apply suggestions from code review
  * remove Set as elements are specified directly in the schema
  * remove Set as elements are specified directly in the schema
  * Fix formatting with terrafmt
  * Add support for adding MPA subscriptions
  * Add azurerm_billing_mpa_account_scope datasource
  * Update for #13718
  * rename test
  * Update sdk version for batch from 2020-03-01 to 2021-06-01
  * refactor and add documentation
  * Fixup from Acceptance Tests
  * Added additional SecurityProfile parameters for windows_virtual_machine resources
  * Update sku_name for implementation example
  * Update for #13636
  * Update website/docs/r/machine_learning_compute_cluster.html.markdown
  * fix lint
  * add acceptance test checks and fix up docs
  * Sorry that was my bad
  * Remove unnecessary resource from doc example
  * Apply suggestions from code review
  * add beta 3.0 opt in to TC for new resource tests (#13698)
  * Add possible values for the VM Priority for Azure ML Compute Cluster
  * make whitespace (#13696)
  * fix regex for cases where service contains more than one upper case char e.g. DataFactory
  * Update for #13689
  * check casing in rp part of id
  * Update for #13518
  * enhancement for synapse_spark_pool
  * add nil check to fix #13646
  * fixing TestAccDataFactoryManagedPrivateEndpoint_requiresImport
  * make fmt
  * adjust schema
  * simplify tests
  * add some more checks
  * make fmt
  * fix provide Element to TypeList
  * fix: Computed: true
  * Test Fix: `TestAccAppService_x` (#13671)
  * Rename property in tests
  * Docs
  * Address feedback
  * weblint
  * New resource: `azurerm_data_factory_linked_service_cosmosdb_mongoapi`
  * make fmt
  * fix add Computed:true to filter tag
  * simplify resourceArmConsumptionBudgetSubscriptionDataSourceRead
  * remove Optional: True
  * make fmt
  * add check for resource_group_id
  * remove Optional true
  * rename
  * Fixing #13481
  * Test Fix: More compute test fixes (#13656)
  * fix test and fix get call
  * Fixing typo - missing quote
  * Update for #13540
  * v2.80.0
  * inline function due to @stephybun code review
  * Update CHANGELOG.md
  * Add new node types to hdinsight's hardcoded validation list (#13638)
  * azurem_ application_gateway - Refactoring to use parsers (#13628)
  * CHANGELOG.md for #13653
  * add updating overprovision property (#13653)
  * CHANGELOG.md for #13444
  * New data source: `backup_policy_file_share` (#13444)
  * Refactor `azurerm_data_factory_linked_service_*` to use id parser (#13602)
  * CHANGELOG.md for #13399
  * azurerm_service_fabric_cluster - support service_fabric_zonal_upgrade_mode and service_fabric_zonal_upgrade_mode (#13399)
  * Update CHANGELOG.md
  * enhancement for kusto event hub data connection (#13488)
  * fix formatting
  * move logo
  * add tf logo to readme (#13649)
  * CHANGELOG.md for #13637
  * `r/azurerm_managed_disk`: Add support for `logical_sector_size` property (#13637)
  * Update Changelog for #13641
  * Fix type casting bug (#13641)
  * lf adjust
  * adjust spaces
  * adjusting spaces
  * Fix for #13380
  * Test Fix: `TestAccKubernetesCluster_upgrade` (#13634)
  * azurerm_firewall - Refactoring to use parsers (#13578)
  * feature for scale_in_on_delete
  * Adding comments to code that needs to be removed on v3.0 (#13588)
  * CHANGELOG>md for #13562
  * #13561 Added support for partition_key on azurerm_stream_analytics_output_eventhub. (#13562)
  * Test Fix: DDoSProtectionPlan and TestAccVirtualHub (#13633)
  * fix ShortTermRetentionPolicy retention_days (#13626)
  * Update for #13580
  * `azurerm_function_app` - fix regressions in function app storage (#13580)
  * Test Fix: Additional compute package test fixes (#13619)
  * Update for #13610
  * Update website/docs/r/site_recovery_network_mapping.html.markdown
  * Update website/docs/r/databricks_workspace.html.markdown
  * fixes typo in upgrade guide
  * fixes typos in data sources
  * fixes typos in resources
  * Update for #13500
  * `d/azurerm_public_ips`: Deprecate `attached` for `attachment_status` (#13500)
  * Fix 10822 (#13599)
  * add check for ips with natgatewaz property
  * update resource ids
  * refactor remaining datafactory resources
  * refactory datafactory pipeline
  * add pipeline parser
  * r/kubernetes_cluster: clarifying the `automatic_channel_upgrade` behaviour
  * fixing issue #13563 (#13592)
  * docs: add defaults for upgrade channel (#13594)
  * docs: improve kubernetes local account disabled documentation (#13593)
  * Update CHANGELOG.md
  * v2.79.1
  * Update changelog for #13587
  * `azurerm_managed_disk` - `max_share` is now `Computed` to account for managed disks that are already managed by Terraform (#13587)
  * refactor integration runtimes
  * Update CHANGELOG.md
  * v2.79.0
  * CHANGELOGmd for #13478
  * azurerm_mssql_database: Attempt to work around SKU change constraints for replicating databases (#13478)
  * Update changelog for #13567
  * `azurerm_consumption_*` add support for `Forecasted` threshold type (#13567)
  * Update changelog for #13571
  * `azurerm_managed_disk` - Add support for `max_shares` (#13571)
  * docs: clarifying the 3.0 overview (#13565)
  * Update changelog for #13196
  * New resource: `azurerm_logic_app_standard` (#13196)
  * CHANGELOG.md for #13520
  * `azurerm_cosmosdb_account`: Support for `mongo_server_version` changes (#13520)
  * CHANGELOG.md for #13452
  * New Resource: azurerm_app_configuration_feature (#13452)
  * Update target_resource_id (#13538)
  * CHANGELOG.md for #13549
  * azurerm_communication_service - export primary_connection_string, secondary_connection_string, primary_key, secondary_key (#13549)
  * Updated notes for Log Analytics (#13539)
  * azurem_compute - Refactoring to use parsers (#13556)
  * Update changelog for #13548
  * `azurerm_virtual_hub_connection` - Optimized state change refresh function (#13548)
  * Test Fix: Compute tests that used key vault (#13555)
  * refactor data sets to use id parsers
  * Update Changelog for #13534
  * set etag attribute when reading (#13534)
  * adjust errcheck and nil check's order
  * add nil check to fix #12163
  * Test Fix: Various Compute tests (#13524)
  * fix last link
  * K8s private-api-server easier example startup
  * Update links to the provider documentation in docs and comments.
  * Update website/docs/r/linux_virtual_machine.html.markdown
  * Update output to lowercase and no spaces
  * refactor actions and triggers
  * updating to include #13527
  * updating to include #13493 / sorting
  * Comments fixed
  * updating to include #13516
  * Add expires and not_before attribute to data.key_vault_certificate
  * fmt :)
  * `azurerm_app_configuration_key`: Documentation of  necessary permissions
  * Add not_before attribute to data.key_vault_certificate_data
  * Update for #13517
  * Update links to the provider documentation in docs and comments.
  * generate parsers and refactor workflow
  * correct imports
  * Refactor containers to use parsers
  * update diffsuppress func
  * Add support for new property of azurerm_network_connection_monitor
  * Refactor `azurerm_data_lake_*` to use id parsers #13491
  * Doc Fix: `azurerm_servicebus_subscription` - Fix incorrect 'P5M' and 'P1M' ISO8601 duration values #13499
  * Update changelog for #13440
  * `azurerm_windows_virtual_machine_scale_set`/`azurerm_linux_virtual_machine_scale_set` - define Hash function for extension block to ignore `protected_setting` (#13440)
  * convert storage account connection string to iothub connection string order
  * `azurerm_kubernetes_cluster`: Set default upgrade channel to `none` on create
  * v2.78.0
  * CHANGELOG.md fort #13324
  * API of iothub/mgmt upgraded to 2021-03-31 (#13324)
  * CHANGELOG.md for #13473
  * `azurerm_data_factory`: Support for `identity = SystemAssiged,UserAssigned` (#13473)
  * azurerm_container_group - fix image in container group tests (#13480)
  * CHANGELOG.md for #13268
  * azurerm_machine_learning_workspace - support for azurerm_machine_learning_workspace, discovery_url (#13268)
  * CHANGELOG.md for #13344
  * Update Changelog for #13483
  * Fix #13482 (#13483)
  * Update changelog for #13271
  * New Resource: `azurerm_key_vault_managed_storage_account` and `azurerm_key_vault_managed_storage_account_sas_token_definition` (#13271)
  * Fix schema_column for azurerm_data_factory_dataset_snowflake resource (#13344)
  * azurem_automation - Refactor remaining automation services to use parsers (#13476)
  * Refactor `azurerm_application_insights_analytics_*` to use id parser (#13477)
  * CHANGELOG.md for #13413
  * azurerm_kubernetes_cluster  - private_cluster_public_fqdn_enabled is no longer force new (#13413)
  * Update changelog for #13374
  * Allow empty_dir volume shared across containers in container group (#13374)
  * Update changelog for #13307
  * `azurerm_storage_account_network_rules ` - Deprecate `storage_account_name` and `resource_group_name` in favor of `storage_account_id` #13307
  * Changelog for #13446
  * Test fix
  * Wait for network provisioning state when creating or updating resources (#13355)
  * CHANGELOG.md for #13464
  * azurerm_synapse_workspace - mark tenant_id as computed (#13464)
  * CHANGELOG.md for #13249
  * New Resource: azurerm_frontdoor_rules_engine (#13249)
  * CHANGELOG.md for #13310
  * azurerm_function_app & azurerm_app_service - support for vnet_route_all_enabled (#13310)
  * Wait for network provisioning state when creating or updating resource (#13426)
  * Correct test names
  * Tidy up, variable scoping
  * Update changelog for #12952
  * New Resource: `azurerm_synapse_sql_pool_extended_auditing_policy` and `azurerm_synapse_workspace_extended_auditing_policy` (#12952)
  * CHANGELOG.md for #13454
  * Add support for signing_secret of azurerm_bot_channel_slack (#13454)
  * Updated for #13455
  * Revert 13379 (#13455)
  * update beta resources for modelobject return change in typed sdk (#13456)
  * New resource: mssql_failover_group
  * Typed SDK: DecodeDiff method for use in CustomizeDiff funcs
  * make fmt ./internal/services/consumption/schema.go
  * use data source elements functions in schema
  * Update changelog for #13421
  * `azurerm_private_endpoint_connection` - Export `network_interface` attributes from private endpoints (#13421)
  * remove superfluous general data source schema items from common schema.go
  * fix: remove Required:true for start_date.
  * use name and resource group name instead of subscription id
  * fix Computed:true blocks
  * `data_protection_backup_instance_blob_storage`: Fix example docs (#13431)
  * `azurerm_cosmosdb_account`: Add extra nil checking (#13432)
  * Correct validation for typed resource/data source model tests, don't validate is the model is nil
  * Update changelog for #13419
  * fix Computed:true blocks
  * Refactoring automation account, credentials and certificate to use parsers (#13419)
  * fix schema and make independent from schema.go
  * update schema and define data source consumption budget read function on its owninstead of taking it from schema.go file
  * `azurerm_vpn_gateway_connection`: Fix example doc
  * `azurerm_maps_account`: Fix documentation
  * fix incorrect document (#13410)
  * `policy_virtual_machine_configuration_assignment` - Remove erroneous horizontal rule in Arguments Reference (#13408)
  * Improve docs for `azurerm_log_analytics_data_export_rule` (#13423)
  * Lint: combine declaration/assigmnent
  * Pass *struct as ModelObject
  * Typed SDK: ensure we don't unintentionally skip over a *interface{}
  * CHANGELOG.md for #13269
  * Let `azurerm_storage_share_file` re-create deleted files (#13269)
  * CHANGELOG.md for #13401
  * Prevent nil pointers in `azurerm_app_service_certificate` resources (#13401)
  * Update CHANGELOG.md
  * v2.77.0
  * CHANGELOG.md for #13390
  * `azurerm_data_factory_trigger_schedule` - add support for `activated` (#13390)
  * CHANGELOG.md for #13262
  * azurerm_spring_cloud_service supports connection_string (#13262)
  * CHANGELOG.md for #13265
  * azurerm_logic_app_workflow - support for enabled & access_control (#13265)
  * Test Fix: `TestAccBackendAddressPoolAddressUpdate` (#13389)
  * CHANGELOG.md for #12833
  * azurerm_machine_learning_inference_cluster support identity, azurerm_machine_learning_compute_cluster support ssh, ssh_public_access_enabled enhancement, identity (#12833)
  * Refactored remaining recoveryservices to use parsers (#13363)
  * virtual_network_gateway: remove CustomizeDiff func (#13359)
  * CHANGELOG.md for #12850
  * Support for `purge_soft_delete_on_destroy` in `azurerm_api_management` (#12850)
  * Test Fix: `TestAccLogAnalyticsLinkedService_*` (#13366)
  * CHANGELOG.md for #13311
  * `azurerm_policy_virtual_machine_configuration_assignment`: Updated example HCL, add datasource (#13311)
  * App Service beta-3.0: missed docs and tweaks (#13322)
  * CHANGELOG.md for #13349
  * `azurerm_function_app` and `azurerm_function_app_slot` - fix `app_settings` for `WEBSITE_CONTENTSHARE` (#13349)
  * updated doc for identity block (#13384)
  * Updates var.tf formatting (#13371)
  * Test Fix: `azurerm_mysql_*` (#13370)
  * Update for #13379
  * `azurerm_app_service_certificate_binding` - rework for removal of thumbprint from service (#13379)
  * Synapse Workspace Activation with CMK (#13179)
  * Update for #13276
  * Update for #13213
  * Incorporate schema change suggestions from code review
  * Apply suggestions from code review
  * fix note in docs
  * update for #13357
  * `azurerm_app_service_managed_certificate`: Fix for empty `issue_date` (#13357)
  * fix tf linting
  * fix bad github apply
  * Apply suggestions from code review
  * replace id.String() instances in error msg with id
  * Remove var, make it a string
  * CHANGELOG.md for #13341
  * add resource "azurerm_synapse_integration_runtime_azure" (#13341)
  * [WIP] Test Fix: `postgresql` (#13354)
  * Update changelog for #13321
  * `azurerm_kubernetes_cluster_node_pool` - `os_sku` is now computed #13321
  * fix lint
  * fix import
  * remove unneccessary var assignment in tests
  * Update for #13294
  * remove unneccessary var assignments
  * Apply polling error suggestions from code review
  * refactor data sources
  * refactor tests
  * refactor resources
  * resolve conflict from rebase
  * Update changelog for #13328
  * azurem_site_recovery -  Refactored to use parser (#13328)
  * CHANGELOG.md for #13204
  * add resource "azurerm_synapse_linked_service" (#13204)
  * Add Standard and Premium SSD ZRS to Managed Disk Storage Account (#13340)
  * Update changelog for #13339
  * `azurerm_cosmosdb_sql_container`: fix crash when deleting (#13339)
  * CHANGELOG.md for #13305
  * `azurerm_lb`: Support for adding/replacing `frontend_ip_configuration` with `availability_zone` (#13305)
  * Update changelog for #13338
  * `azurerm_frontdoor` - Fix crash when cache is disabled #13338
  * CHANGELOG.md for #13264
  * add resource "azurerm_synapse_integration_runtime_self_hosted" (#13264)
  * CHANGELOG.md for #13336
  * azurerm_mssql_elasticpool - export the sku block (#13336)
  * Update changelog for #13335
  * Crash Fix: `azurerm_linux_virtual_machine_scale_set` (#13335)
  * mssql_database - support addtional sku values (#13333)
  * Refactor iothub_endpoint_* resources to use id parser (#13318)
  * docs: move local_account_disabled to correct section (#13332)
  * docs: azurerm_resource_group_template_deployment - restructure provider features block sentence (#13313)
  * docs: closes #13089
  * Refactor: `iothub_dps_*` resources to use id parser (#13304)
  * Documentation examples: Fix `unsupported block type` error for App Service Environment V3 (#13301)
  * `data.kubernetes_cluster.html.markdown`: add missing docs for `identity` block #13308
  * Update link to kubernetes provider
  * v2.76.0
  * CHANGELOG.md for #13290
  * azurerm_synapse_workspace - support for the tenant_id property (#13290)
  * CHANGELOG.md for #13287
  * New Resource: azurerm_logic_app_integration_account_agreement (#13287)
  * CHANGELOG.md for #13284
  * azurerm_kubernetes_cluster supports os_sku (#13284)
  * Update changelog for #12431
  * New Resources: `azurerm_sql_managed_instance` and `azurerm_sql_managed_database` (#12431)
  * `azurerm_app_service`: add note for `always_on` setting (#13299)
  * azurerm_site_recovery_fabric_resource - refactor to use parser (#13293)
  * CHANGELOG.md for #13289
  * Allow UTF-8 characters in SQL pool name (#13289)
  * CHANGELOG.md for #13245
  * `azurerm_stream_analytics_output_blob` support for type Parquet & batch_max_wait_time/batch_min_rows (#13245)
  * Update CHANGELOG.md for #12132
  * Replacement Service: `appservice` (#12132)
  * CHANGELOG.md for #13282
  * Dependencies: updating cdn to use API version 2021-09-01 (#13282)
  * Changelog update for #13273
  * CHANGELOG.md for #13215
  * New Resource: azurerm_logic_app_integration_account_batch_configuration (#13215)
  * mTLS support for Application Gateways (#13273)
  * Wait for provisioning state when creating or updating resource
  * Improve test case to increase chance of race condition
  * Wait for provisioning state when creating or updating resource
  * Wait for provisioning state when creating or updating resource
  * Update changelog for #13228
  * Update changelog for #13277
  * azurerm_virtual_network_gateway_resource - Allow multiple vpn auth types (#13228)
  * CHANGELOG.md for #13243
  * azurerm_data_factory_trigger_schedule supports schedule and description (#13243)
  * CHANGELOG.md for @13239
  * New Resource: azurerm_logic_app_integration_account_assembly (#13239)
  * azurerm_site_recovery_network_mapping - refactor to use parser (#13277)
  * Remove extraneous argument from documentation (#13263)
  * CHANGELOG.md for #13260
  * `d/azurerm_kubernetes_cluster`: Support `local_account_disabled` setup in data source (#13260)
  * doc: capitalize names of secret permissions (#13278)
  * don't send throttling if not set
  * Update CHANGELOG.md for #13101
  * `azurerm_app_service_certificate` - introduce argument `app_service_plan_id` for usage with ASE (#13101)
  * fix lint
  * new resource "azurerm_synapse_sql_pool_vulnerability_assessment"
  * new resource "azurerm_synapse_workspace_vulnerability_assessment"
  * new resource "azurerm_synapse_sql_pool_security_alert_policy"
  * new resource "azurerm_synapse_workspace_security_alert_policy"
  * changed test
  * fix doc
  * changes from feedback
  * Add additional operator values for query rules (#13231)
  * CHANGELOG.md for #13222
  * azurerm_data_factory_integration_runtime_azure supports cleanup_enabled, subnet_id (#13222)
  * Changelog update for #13253
  * Fix KV import with no label (#13253)
  * fix test
  * changes from feedback
  * Update for #13237
  * Improved readability of variable name
  * Update for #12951
  * fix: system topic tests
  * feat: added identity support to system topic
  * fix: update tests to use acceptance module
  * fix: rename conflicting identity functions
  * Support for `local_authentication_disabled` in `azurerm_cosmosdb_account`
  * CHANGELOG.md for #13203
  * Relax validation on `azurerm_api_management_subscription`.`subscription_id` to allow non-UUID strings. (#13203)
  * CHANGELOG.md for #12945
  * azurerm_eventgrid_event_subscription/azurerm_eventgrid_system_topic_event_subscription - support delivery_identity & dead_letter_identity (#12945)
  * CHANGELOG.md for #13190
  * azurerm_firewall_policy_rule_collection_group - support description,destination_addresses,destination_urls,terminate_tls,web_categories (#13190)
  * CHANGELOG>md for #12683
  * add resource "azurerm_data_protection_backup_instance_blob_storage" (#12683)
  * azurerm_recovery_services_vault - Refactored to use parser (#13206)
  * CHANGELOG.md for #13033
  * add: eventgrid_domain data source, test, docs (#13033)
  * CHANGELOG.md for #13188
  * Dependencies: Upgrade `cosmos` to `2021-06-15` (#13188)
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update website/docs/r/eventgrid_topic.html.markdown
  * Update CHANGELOG.md
  * v2.75.0
  * CHANGELOG.md for #13187
  * New Resource: azurerm_logic_app_integration_account_map (#13187)
  * CHANGELOG.md for #13181
  * Update `azurerm_synapse_spark_pool` to support spark 3.1 instead of 3.0 (#13181)
  * fix validation
  * fixes
  * fix lint
  * add auto_mitigate and throttle exclusion
  * change tests
  * Changelog for #13183
  * data_protection_backup_instance_postgresql: support database_credential_key_vault_secret_id (#13183)
  * fix lint
  * Support for auto-mitigate for Azure scheduled_query #13036
  * Docs: Fix env var name in docs (#13207)
  * Changelog update for #13118
  * Add appconfig key resource (#13118)
  * Updated the `allowed_methods` description
  * CHANGELOG.md for #12901
  * add resource "azurerm_cognitive_account_customer_managed_key" (#12901)
  * Changelog update for #12689
  * Handle nil values for AllowBlobPublicAccess (#12689)
  * Update for #13159
  * add todo for other linked service resources
  * apply review suggestions
  * Changelog for #12866
  * Add support for HDInsight Cluster with Enterprise Security Package (#12866)
  * Update website/docs/r/data_factory_linked_service_azure_function.html.markdown
  * CHANGELOG.md fr #13174
  * Support for `local_authentication_disabled` in `azurerm_application_insights` (#13174)
  * CHANGELOG.md for #13176
  * azurerm_policy_virtual_machine_configuration_assignment - support  assignment_type, content_uri and content_hash (#13176)
  * CHANGELOG.md for #13157
  * New resource: azurerm_logic_app_integration_account_partner (#13157)
  * add clients package
  * `service/keyvault`: Fix some acceptance tests (#13171)
  * `service/iothub`: Fix acceptance tests
  * make fmt
  * CHANGELOG.md for #12880
  * `azurerm_data_factory_linked_service_azure_blob_storage` support key_vault_sas_token (#12880)
  * CHANGELOG.md for #13123
  * `azurerm_cosmosdb_mongo_database` new data source (#13123)
  * CHANGELOG.md for #13161
  * update dataprotection api to 2021-07-01 (#13161)
  * CHANGELOG.md for #13160
  * update azure-sdk-for-go to v57.0.0 (#13160)
  * add Microsoft.PolicyInsights to required resource provider (#13156)
  * Document: update redisCache document (#13158)
  * Update app config resource docs to include identity (#13164)
  * Update changelog for #13151
  * azurerm_mssql_server - updated to use parser (#13151)
  * update docs
  * v2.74.0
  * CHANGELOG.md for #13084
  * azurerm_redis_enterprise_cluster - the tags property can now be updated (#13084)
  * CHANGELOG.md for #12313
  * "azurerm_kubernetes_cluster" and "azurerm_kubernetes_cluster_node_pool" supports property "pod_subnet_id" (#12313)
  * CHANGELOG.md for #12262
  * Support for `identity_client_id` and `certificate_information` in `azurerm_api_management` (#12262)
  * CHANGELOG.md for #13145
  * Support for `zone_redundant` in `azurerm_app_service_plan` (#13145)
  * `name` value must be globally unique across all of Azure for PostgreSQL Flexible Server (#13155)
  * CHANGELOG.md for #13149
  * azurerm_data_factory_dataset_delimited_text - support empty values for the column_delimiter, row_delimiter, quote_character, escape_character, encoding propeties (#13149)
  * update to use resourceids
  * add key_vault_key to function linked service and update acc test
  * Update for #13058
  * datasource `azurerm_app_service_environment_v3` fix missing inbound ip-addresses (#13115)
  * CHANGELOG.md for #13116
  * new resources: azurerm_relay_namespace_authorization_rule, azurerm_relay_hybrid_connection_authorization_rule (#13116)
  * CHANGELOG.md for #13117
  * `data_factory_dataset_(binary|delimited_text|json|parquet)`: Support for dynamic path and filename (#13117)
  * `service/servicefabric`: Fix acceptance tests (#13126)
  * CHANGELOG.md for #12997
  * azurerm_servicebus_ resources - support primary_connection_string_alias, secondary_connection_string_alias (#12997)
  * CHANGELOG.md for #13110
  * Update charset and collation of azurerm_postgresql_flexible_server_database to optional (#13110)
  * CHANGELOG.md for #13100
  * New Resource: azurerm_logic_app_integration_account_schema (#13100)
  * CHANGELOG.md for #13080
  * `azurerm_app_configuration`: Add support for userAssigned identity (#13080)
  * azurerm_monitor_aad_diagnostic_setting: document supported auth methods for this resource (#13092)
  * Changelog for #12769
  * `azurerm_firewall_policy` premium tier features (#12769)
  * CHANGELOG.md for #13074
  * `devtestlabs`: Upgrade API to `2018-09-15` and... (#13074)
  * make fmt
  * remove AtLeastOneOf, ExactlyOneOf from data source schemas
  * remove min and max items from data source elements where Compute is true
  * make fmt; make terrafmt
  * updating to include #13121
  * Updates the documentation to fix resource name and dimention-block. This issue was previously also discussed here: https://stackoverflow.com/a/65350839
  * update CHANGELOG.md for #13125
  * `service/springcloud`: Fix crashes in identity (#13125)
  * Lower windows version
  * `service/blueprints`: Fix acceptance tests
  * `service/containers`: Fix acceptance tests
  * `firewall_policy_rule_collection_group`: Fix DNAT acceptance tests
  * got ya!
  * More acceptance tests fixes
  * Acceptance test fix, attempt 3
  * Disable test that's failing in CI by design
  * Aceptance tests fix attempt 2
  * Fix up 2 more tests
  * Update docs
  * Acceptance tests fix, attempt 1
  * Update changelog for #13014
  * azurerm_storage_account - support for allow_shared_key_access property (#13014)
  * Add vendored package please thank you
  * Update test
  * `service/monitor: Various updates
  * drop aks policy addon preview note
  * CHANGELOG.md for #13102
  * fix (#13102)
  * Update CHANGELOG.md for #13093
  * `azurerm_private_dns_a_record` - fix regression in `name` validation and add max recordset limit validation (#13093)
  * update attribute name in error message
  * update cidr attribute name in docs
  * rename cidr attributes to cidrs
  * Add schema for consumption budget subscription
  * `internal/identity`: Fix UAI object payload (#13079)
  * Corrected msssql_database documentation for 'sku_name' (#13083)
  * Update giovanni to address #10888 (#13020)
  * Update CHANGELOG.md for #13073
  * `azurerm_app_service` - add support for `vnet_route_all_enabled` property (#13073)
  * run make fmt
  * remove validation from computed items
  * add validate cidr
  * v2.73.0
  * CHANGELOG.md for #12780
  * azurerm_kubernetes_cluster - and azurerm_kubernetes_cluster_node_pool support ultra_ssd_enabled and private_cluster_public_fqdn_enabled (#12780)
  * CHANGELOG.md for #13050
  * `azurerm_data_lake_store`: Add `identity` parameter (#13050)
  * CHANGELOG.md for #13057
  * `azurerm_logic_app_trigger_http_request` add `callback_url` as attribute (#13057)
  * CHANGELOG.md for #13029
  * `azurerm_linux_virtual_machine_scale_set` - fix potential crash in update to rolling_upgrade_policy (#13029)
  * CHANGLOG.md for #12834
  * add resource "azurerm_machine_learning_compute_instance" (#12834)
  * CHANGELOG.md for #13062
  * Data source -  azurerm_data_protection_backup_vault (#13062)
  * CHANGELOG.md for #13042
  * azurerm_private_dns_a_record_resource - currently validate the `name` property by allowing `@`s (#13042)
  * CHANGELOG.md for #13034
  * `azurerm_databricks_workspace`: Flip logic for `public_network_access_enabled` (#13034)
  * CHANGELOG.md fort #13065
  * azurerm_eventhub_namespace  - support upto 40 for maximum_throughput_units (#13065)
  * updating to include #13048
  * Update website/docs/r/sql_server.html.markdown
  * Update internal/services/sql/sql_server_resource.go
  * update docs
  * update tests
  * add ipv4 and ipv6 attributes to data source
  * updating to include #13028
  * `azurerm_sql_server`: Add `threat_detection_policy` argument
  * Update CHANGELOG.md for #12932
  * `azurerm_app_service`: Document that we support filesystem logging
  * `azurerm_app_service_environment_v3` - update for SDK supported GA changes to service (#12932)
  * Update CHANGELOG.md for #13043
  * `azurerm_kubernetes_cluster` - fix crash in update when previously configured AAD Profile is now `nil` (#13043)
  * updating to include #12950
  * change upgrade description to policy in error msg
  * Update CHANGELOG.md for #13025
  * `azurerm_databricks_workspace` - fix potential crash in Read (#13025)
  * CHANGELOG./md for #13000
  * ignore case change for aks private_dns_zone_id (#13000)
  * Change upgrade_description to upgrade_policy in service fabric docs (#13027)
  * CHANGELOG.md for #13026
  * `azurerm_servicebus_topic`: Adjust regexp for name validation (#13026)
  * CHANGELOG.md for #12984
  * azurerm_network_watcher_flow_log - correctly truncate name by ensuring it doesn't end in a - (#12984)
  * CHANGELOG.md for #13022
  * add resource "azurerm_machine_learning_synapse_spark" (#13022)
  * Changelog for #13011
  * CHANGELOG.md for #12982
  * New Resource: azurerm_logic_app_integration_account_session (#12982)
  * domain_service: document the `resource_id` attribute
  * d/application_security_group: refactoring to use the new ID Parser/Formatter
  * r/application_security_group: refactoring to use the new id parser/formatter
  * network: generating the new resource ids via `make generate`
  * network: adding the new id parser for Application Security Groups
  * CHANGELOG.md for #12999
  * Virtual hub connection lock (#12999)
  * Update CHANGELOG.md
  * CHANGELOG.md for #12849
  * Support for `azurerm_api_management_notification_recipient_email` (#12849)
  * CHANGFELOG.md for #13010
  * fix max_age_in_seconds range in storage cors settings (#13010)
  * CHANGELOG.md for #13003
  * New Resource: azurerm_logic_app_integration_account_certificate (#13003)
  * CHANGELOG.md for #12961
  * azurerm_netapp_volume - support for the snapshot_directory_visible property - Fixes #9143 (#12961)
  * CHANGELOG.md for #13002
  * Upgrade `network` package to `2021-02-01` (#13002)
  * CHANGELOG.md for #12833
  * update machine learning sdk to 2021-07-01 (#12980)
  * CHANGEL>OG.,d for #12947
  * azurerm_stream_analytics_output_eventhub - support for property_columns (#12947)
  * Fix ACR Scope Maps Examples (#13013)
  * fix sed vs gsed detection in makefile job (#13009)
  * Update for #13001
  * domain_service: export `resource_id` attribute
  * tooling: updating to use Go 1.16.7
  * update docs
  * add hostname to iothub datasource
  * Update for #12967
  * accept suggestion to split out empty params
  * updating to include #12831
  * merge #12831
  * updating the description
  * updating to include #12946
  * appconfiguration: updating the embedded sdk
  * CHANGELOG.md for #12956
  * Tags of Redis Enterprise ressources can be updated (#12956)
  * Update changelog for #12844
  * Data Source:  Adding azurerm_vpn_gateway (#12844)
  * Updating for #12970
  * Dependencies: updating `web` to use API version `2021-02-01` (#12970)
  * Update for #12969
  * Dependencies: upgrade `azure-sdk-for-go` to v56.2.0 (#12969)
  * remove old dependency
  * updating the changelog to include the placeholder for 2.73.0
  * update docs
  * v2.72.0
  * dependencies: removing the old appconfiguration sdk
  * r/resource_group: documenting the new feature toggle
  * Fix the issue of updating the maxmemory_policy property of azurerm_redis_cache (#12926)
  * Fix Panic Error #10413 - Fix segmentation fault - virtual machine scale set resource (#12962)
  * CHANGELOG.md for #12857
  * azurerm_application_insights_smart_detection_rule - Add new rules (#12857)
  * CHANGELOG.md for #12938
  * Support for System Assigned Identity in `azurerm_api_management_named_value` (#12938)
  * CHANGELOG.md for #12921
  * Bugfix: `azurerm_data_factory_dataset_delimited_text` - Ensure optional variables are set correctly (#12921)
  * fix #10946 (#12957)
  * update changelog links (#12954)
  * fix: refactor identity assignment
  * fix: PR notes
  * fix: add tests for identity_ids
  * fix: documentation
  * fix: check if input is nil
  * r/appconfiguration: updating the resource to use the latest embedded sdk codegen
  * appconfiguration: updating to the latest embedded sdk
  * managedidentity: updating to the latest embedded sdk
  * maps: updating to the latest embedded sdk
  * r/signalr_service_network_acl: switching to use the Trace constant
  * signalr: updating to the latest embedded sdk
  * vmware: updating the embedded sdk
  * eventhub: updating to use the latest codegen changes
  * eventhubs: updating to use the latest generated sdk
  * docs
  * add identity to eventgrid domain
  * identity acc tests
  * fixes
  * r/eventgrid_topic: managed identity
  * refactor: fixing the broken auto-refactor
  * vmware: refactoring the embedded sdk to include the api version
  * signalr: refactoring the embedded sdk to include a version in the path
  * relay: refactoring the embedded sdk to include a version
  * powerbi: refactoring the embedded sdk into a versioned folder
  * msi: refactoring to a versioned folder
  * maps: moving the sdk into a versioned folder
  * eventhub: moving the 2021-01-01-preview sdk's into a versioned folder
  * eventhub: moving the 2018-01-01-preview sdks into a versioned folder
  * eventhub: refactoring the 2017-04-01 sdk's into a versioned folder
  * appconfiguration: moving the data plane sdk into a versioned folder
  * appconfiguration: moving the 2020-06-01 resource manager sdk into a versioned folder
  * analysisservices: adding the version to the embedded sdk
  * removing a spurious *
  * updating to include #12657
  * pass empty string for if-none-match param when updating
  * updating to include #12911
  * teamcity: increasing the vmware parallelism to 3
  * remove invalid storage account restriction (#12936)
  * move the sdk.go
  * change type of `Type` && rename interface methods
  * pass compilation
  * Refine the ExpandedConfig field type
  * fix CI
  * vendor pandora sdk identity related types to provider
  * Update for #12883
  * Support for `dotnet_framework_version` in `azurerm_function_app` (#12883)
  * Fixing typo in servicebus_namespace_disaster_recovery_config docs (#12930)
  * further post repo move cleanup (#12931)
  * update kusto api import path and fix kusto names
  * add azure kusto api 2021-01-01
  * Update tests
  * r/resource_group: fixing comments from code review for #12657
  * terrafmt fix
  * r/video_analyzer: adding a missing explicit check
  * rename noncompliant files
  * updating to include #12879
  * fix bot_channel_web_chat example
  * add extension check
  * Apply suggestions from code review
  * updating to include #12919
  * Use EdgeModule not EdgeModules
  * feature: `resource_group.delete_nested_items_during_deletion`
  * updating to include #12896
  * r/iothub_dps: removing a crash
  * add missing operation id field to docs
  * scripts: fixing run-gradually-deprecated.sh to use the new branch name
  * bug: removing checking of futures during deletion
  * Tooling: update default tf to 1.0.3 for acctest builds (#12916)
  * Refactor
  * Add video analyzer edge module
  * Remove unused files
  * Remove files in the wrong location
  * updating to include #12665
  * Remove failing test
  * Remove unused files
  * Use correct resource name
  * Descope optional account_encryption property
  * Fix linting
  * Add tests
  * Fix issues with running resource in tests
  * Add inital draft of video_analyzer
  * Fix failing tests
  * Quick fix broken CI
  * Fix terraform
  * Use user_assigned_identity_id
  * Fix rebase issues
  * Update generated files
  * Apply suggestions from code review for resource
  * Apply suggestions from code review for resource
  * Use list for storage_accounts
  * Use correct resource name
  * Descope optional account_encryption property
  * Fix linting
  * Add docs
  * Add tests
  * Fix issues with running resource in tests
  * Add inital draft of video_analyzer
  * Add video analyzer sdk
  * remove duplicate line on cloning
  * Tooling: upgrade `golangci-lint` to v1.41.1 (#12903)
  * teamcity: updating the maven dependencies
  * teamcity: removing the provider name from the path since this is no longer present
  * Changelog for #12453
  * azurerm_logic_app_trigger_recurrence - adapt timeZone values to match azure schema and make start_time optional (#12453)
  * Update CHANGELOG.md for #12881
  * `azurerm_kubernetes_cluster` prevent nil panic when rbac config is empty (#12881)
  * Fix incorrect resource ID in Domain Service docs (#12897)
  * azurerm_key_vault_certificate_data: fix PEM private key block header
  * azurerm_key_vault_certificate_data: fix PEM private key block header
  * remove  from error messages
  * Typo fix in error messages (#12885)
  * typo: use lowercase values in azurerm_api_management_diagnostic docs (#12888)
  * Documentation improvement for azurerm_resource_group_template_deployment (#12886)
  * Docs: Add a note for MySQL/PostgreSQL AAD Admin + Managed Identities (#12887)
  * Remove typo (#12893)
  * adding an empty section for 2.72.0
  * teamcity: updating to use the hashicorp org
  * reverting to pull from `terraform-providers` org for now
  * generation: updating the path to ditch the azurerm folder now it's gone
  * refactor: updating the remaining usages of `terraform-providers`
  * update makefile for org move
  * make fmt
  * update the scripts while we're here
  * update doc references for org move
  * teamcity: updating to use the hashi org / build from the main branch
  * refactor: moving the repository to the hashicorp org / updating the Go module / import paths
  * v2.71.0
  * CHANGELOG.,md for #12788
  * Support `v6.0` for the `dotnet_framework_version` to `azurerm_app_service` (#12788)
  * CHANGELOG.md for #12359
  * azurerm_data_factory_linked_service_data_lake_storage_gen2 - don't send a secure string when using a managed identity (#12359)
  * CHANGELOG.md for #12859
  * Fix `net_ipv4_ip_local_port_range_max` range for `azurerm_kubernetes_cluster` default node pool (#12859)
  * CHANGELOG.md for #12865
  * Network Security Group | True Up Protocols (#12865)
  * fix typo on "skip_shutdown_and_force_delete" (#12864)
  * CHANGELOG.md for #12741
  * Support for `elastic_instance_minimum`, `app_scale_limit` and `runtime_scale_monitoring_enabled` in `azurerm_function_app` (#12741)
  * CHANGELOG.md for #12550
  * New Resource - `azurerm_postgresql_flexible_server_database` (#11538) (#12550)
  * CHANGELOG.md for #12535
  * New resource `azurerm_api_management_tag` (#12535)
  * Update CHANGELOG.md for #12745
  * azurerm_app_service - support for the acr_use_managed_identity_creds and acr_user_managed_identity_id properties (#12745)
  * up timeout by 10m while we investigate (#12863)
  * updating to include #12421
  * address review
  * r/template_deployment_(resource_group|subscription): fixing code review comments
  * updating to include #12845
  * updating to include #12800
  * linting
  * update testing location to work around resource creation issue in Primary (#12851)
  * Update CHANGELOG.md for #12510
  * `azurerm_static_site` - support `Standard` SKU (#12510)
  * Add Learn link to Azure provider docs (#12846)
  * CHANGELOG.md for #12762
  * kubernetes_cluster supports maintenance_config (#12762)
  * CHANGELOG.md for #12818
  * Supporting workspace mode for application_insights_resource (#12818)
  * updating to include #12667
  * updating to include #12842
  * r/notification_hub_authorization_rule: switching to use an ID parser/adding a state migration
  * CHANGELOG.md for #12820
  * azurerm_redis_cache - support replicas_per_primary, redis_version, tenant_settings (#12820)
  * r/notification_hub_namespace: refactoring to use an id parser / adding a state migration
  * r/notification_hub: adding the missing schema version
  * d/notification_hub_namespace: refactoring to use an id parser
  * d/notification_hub: refactoring to use an ID Parser
  * r/notification_hub: refactoring to use an id parser / adding a state migration
  * notificationhubs: generating insensitive parsers too
  * Redis enterprise is available in Canada Central
  * Fix issue: #12794 - normalize ssh public key output
  * updating to include #12785
  * updating to include #12829
  * updating to include #12835
  * reverting #12544
  * updating to include #12824
  * updating to include #12822
  * updating to include #12823
  * Revert "add resource "azurerm_cognitive_account_customer_managed_key" (#12544)"
  * r/signalr_service: working around a broken future api
  * dependencies: removing the Azure SDK for Go SignalR SDK
  * signalr: refactoring to use the embedded sdk
  * signalr: embedding the 2020-05-01 sdk
  * add free and fsv2 to mssql database sku validation
  * make terrafmt
  * Updated to include #12799
  * merge #12799
  * CHANGELOG.md for #12746
  * New Resource: azurerm_bot_channel_line (#12746)
  * Update container_registry.html.markdown
  * Update container_registry.html.markdown
  * Add type checking to flatten of `azurerm_managed_application` (#12825)
  * Update script to use the new georeplications
  * Update changelog for #12775
  * azurerm_public_ip_resource - Added sku_tier property (#12775)
  * Update azurerm/internal/services/apimanagement/api_management_subscription_resource.go
  * make fmt
  * 4482 fix all apis subscriptions
  * r/private_dns_zone: fixing a crash during deletion
  * r/postgresql_database: working around a crash in the Azure SDK
  * r/local_network_gateway: fixing a crash where the `LocalNetworkAddressSpace` block was nil
  * fix dependencies txt for databricks
  * Typo Fix - Wrong max RU number.
  * CHANGELOG>,d for #12804
  * update machine learning sdk to 2021-04-01 (#12804)
  * Update CHANGELOG.md for #12808
  * `azurerm_linux_virtual_machine_scale_set` - fix crash in checking for latest image (#12808)
  * updating to include #12543
  * fixes #11158 and #7799
  * CHANGELOG.md for #12782
  * Support for `operation_name_format` in `azurerm_api_management_api_diagnostic` (#12782)
  * CHANGELOG.md for #12496
  * New resource - azurerm_cdn_endpoint_custom_domain (http only) (#12496)
  * CHANGELOG.md for #12386
  * "azurerm_kubernetes_cluster" - supports property "local_account_disabled" (#12386)
  * CHANGELOG.md for #12790
  * azurerm_virtual_machine_extension - publisher change should force new resource (#12790)
  * updating to include #12792
  * updating to include #12787
  * updating to include #12781
  * update read for active slot after api change
  * dependencies: removing the Azure SDK for Go powerbidedicated sdk
  * powerbi: refactoring to use the embedded sdk
  * powerbi: adding the embedded sdk
  * update azure-sdk-for-go to v56.0.0
  * CHANGELOG.md for #12588
  * new resource "azurerm_data_factory_data_flow" (#12588)
  * CHANGELOG.md for #12544
  * add resource "azurerm_cognitive_account_customer_managed_key" (#12544)
  * CHANGELOG.md for #12314
  * `azurerm_logic_app_workflow` - add supports for `workflow_parameters` (#12314)
  * CHANGELOG.md for #12747
  * update containerservice to 2021-05-1 (#12747)
  * v2.70.0
  * CHANGELOG.md for #12693
  * New Data Source: `azurerm_storage_share` (#12693)
  * Fix windows function app slots on premium plans (#12778)
  * CHANGELOG.md for #12735
  * New Resource: azurerm_bot_channel_direct_line_speech (#12735)
  * Updated changelog for #12696
  * azurerm_firewall_polcy - Added new property private_ip_ranges (#12696)
  * updating to include #12772
  * changelog cleanup/consistency
  * updating to include #12771
  * r/analysis_services_server: fixing the test state check
  * IOT-hub DeviceConnectionStateEvents routing added (#12477)
  * CHANGELOG.md for #12682
  * New Resource: azurerm_bot_channel_alexa (#12682)
  * CHANGELOG.md for #12685
  * "azurerm_data_factory_pipeline" - supports "concurrency", "elapsed_time_metric_duration" and "run_dimension" (#12685)
  * CHANGELOG.md for #12767
  * Add `encryption_in_transit_enabled` to `hdinsight_spark_cluster` and `hdinsight_interactive_query_cluster` (#12767)
  * dependencies: removing the Azure SDK for Go AnalysisServices SDK
  * r/analysis_services_server: refactoring to use the embedded sdk
  * analysisservices: embedding the sdk for 2017-08-01
  * Add auxiliary_tenant_ids (#12765)
  * updating to include #12761
  * relay: updating the embedded sdk
  * dependencies: removing the Azure SDK for Go Relay SDK
  * r/app_service_hybrid_connection: switching to use the embedded relay sdk
  * relay: updating the embedded sdk
  * update
  * update
  * updating to include #12751
  * update
  * update
  * Update subnet.html.markdown (#12759)
  * relay: re-introducing the Track1 SDK for the moment to workaround a bug
  * r/relay_hybrid_connection: refactoring to use the embedded sdk
  * r/relay_namespace: refactoring to use the embedded sdk
  * relay: vendoring the embedded 2017-04-01 sdk
  * Update changelog for #12738
  * azurerm_automation_certificate - Allow exportable property to be set (#12738)
  * updating to include #12736
  * make generate
  * vendor: removing the old vmware sdk
  * vmware: removing final usages on the parse package
  * vmware: refactoring the shared logic out
  * r/vmware_private_cloud: refactoring to use the embedded sdk
  * teamcity: limiting the vmware tests to 1 for now
  * r/vmware_express_route_authorization: refactoring to use the embedded sdk
  * r/vmware_cluster: refactoring to use the embedded sdk
  * vmware: vendoring the embedded sdk
  * updating to include #12743
  * CHANGELOG.md for #12644
  * `azurerm_data_factory_trigger_blob_event`: Support for activation (#12644)
  * CHANGELOG.md for #12676
  * Bugfix: `azurerm_data_factory_dataset_binary` - Make blob path/filename optional (#12676)
  * Removing http_listener_ids and path_based_rule_ids properties from docs - WAF (#12678)
  * update
  * update
  * CHANGELOG.md for #12437
  * new resource "azurerm_data_factory_trigger_tumbling_window" (#12437)
  * Changelog for #12705
  * add ip_addresses field to data_azurerm_storage_account_sas (#12705)
  * identity: the type needs to be exported since this is used elsewhere
  * r/cdn_endpoint: fixing a crash when the future is nil
  * splitting the changelog up to 2.69.0
  * splitting the changelog
  * identity: adding a base type for the constant that we can reference elsewhere
  * vendored sdk: changes necessary for that to work
  * update
  * Update CHANGELOG.md for #12635
  * Dependencies: Upgrade `web` (App Service) API to `2021-01-15` (#12635)
  * update
  * Note for accessing Identity exports
  * CHANGELOG.md for #12713
  * New Resource: azurerm_bot_channel_sms (#12713)
  * CHANGELOG.,d for #12617
  * add resource "azurerm_data_protection_backup_instance_disk" (#12617)
  * CHANGELOG.md for #12709
  * New Resource: azurerm_bot_channel_facebook (#12709)
  * CHANGELOG.md for #12448
  * new resource "azurerm_data_factory_trigger_custom_event" (#12448)
  * update docs - make the dns_prefix in azurerm_kubernetes_cluster to be… (#12724)
  * updating to include #12716
  * appconfiguration: vendoring the embedded data plane sdk for appconfig
  * updating to include #12715
  * maps: refactoring to use the embedded sdk
  * maps: refactoring to use the ID Parsers from the SDK
  * maps: refactoring to use the existing ID Parser
  * maps: vendoring the embedded accounts sdk
  * dependencies: removing the old azure sdk for managed identity
  * msi: adding an alias since this is commonly used across the codebase
  * msi: porting over to use the embedded sdk
  * msi: vendoring the embedded sdk
  * Update active_directory_domain_service.html.markdown
  * `azurerm_eventgrid_event_subscription` docs: Add missing newline (#12712)
  * Update active_directory_domain_service.html.markdown
  * `r/logic_app_workflow`: add extra nil checking
  * Add reference to official databricks provider
  * dependencies: removing the old eventhubs sdk
  * r/eventhub_namespace: removing the old azure sdk usage
  * eventhubs: removing direct usages on the Azure SDK for Eventhub
  * fix whitespace
  * remove venv
  * add node-image to auto upgrade channel
  * new changes
  * make fmt
  * make fmt
  * Remove changes in .gitignore again
  * Remove changes in .gitignore again
  * Reuse ResourceGroup schema for data source
  * Add support for Consumption Budget Subscription level data source
  * Make a budget data source on resource group level
  * Update .gitignore to ignore any shell scripts
  * add cycle for full match
  * terrafmt
  * make fmt
  * test passes
  * fix more linter errors
  * fix linter errors
  * update
  * make fmt and fix schema bugs
  * fix website lint
  * make fmt
  * update docs
  * update interface
  * Add support for azurerm_consumption_budget data source
* Wed Mar 30 2022 Dirk Müller <dmueller@suse.com>
- exclude build for 32bit targets
* Thu Jul 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.69.0
  FEATURES:
  * **New Data Source** `azurerm_active_directory_domain_service` (#10782)
  * **New Resource** `azurerm_active_directory_domain_service` (#10782)
  * **New Resource** `azurerm_active_directory_domain_service_replica_set` (#10782)
  * **New Resource** `azurerm_api_management_gateway_api` (#12398)
  * **New Resource** `azurerm_batch_job` (#12573)
  * **New Resource** `azurerm_bot_channel_web_chat` (#12672)
  * **New Resource** `azurerm_data_factory_managed_private_endpoint` (#12618)
  * **New Resource** `azurerm_data_protection_backup_policy_blob_storage` (#12362)
  * **New Resource** `azurerm_signalr_service_network_acl` (#12434)
  * **New Resource** `azurerm_virtual_network_dns_servers` (#10782)
  ENHANCEMENTS:
  * dependencies: Updgrading to `v55.6.0` of `github.com/Azure/azure-sdk-for-go` (#12565)
  * `azurerm_api_management_named_value` - the field `secret_id` can now be set to a versionless
    Key Vault Key (#12641)
  * `azurerm_data_factory_integration_runtime_azure_ssis` - support for the `public_ips`,
    `express_custom_setup`, `package_store`, and `proxy` blocks (#12545)
  * `azurerm_data_factory_integration_runtime_azure_ssis` - support for the `key_vault_password`,
    and `key_vault_license` blocks (#12659)
  * `azurerm_bot_channels_registration` - support for the `cmk_key_vault_url`, `description`,
    `icon_url`, and `isolated_network_enabled` (#12560)
  * `azurerm_data_factory_integration_runtime_azure` - support for the `virtual_network_enabled`
    property (#12619)
  * `azurerm_eventgrid_event_subscription` - support for the `advanced_filtering_on_arrays_enabled`
    property (#12609)
  * `azurerm_eventgrid_system_topic_event_subscription` - support for the
    `advanced_filtering_on_arrays_enabled` property (#12609)
  * `azurerm_eventhub_namespace` - support for Azure Event Hubs Namespace Premium tier (#12695)
  * `azurerm_kubernetes_cluster` - support for downgrading `sku_tier` from `Paid` to `Free`
    without recreating the Cluster (#12651)
  * `azurerm_kusto_eventgrid_data_connection` - Add supported `data_format` APACHEAVRO, ORC,
    PARQUET, TSVE and W3CLOGFILE to validation function. (#12687)
  * `azurerm_postgresql_flexible_server` - support for the `high_availability` block (#12587)
  BUG FIXES:
  * `data.azurerm_redis_cache` - fix a bug that caused the data source to raise an error (#12666)
  * `azurerm_application_gateway` - return an error when ssl policy is not properly configured  (#12647)
  * `azurerm_data_factory_linked_custom_service` - fix a bug causing `additional_properties` to be
    read incorrectly into state (#12664)
  * `azurerm_eventhub_authorization_rule` - fixing the error "empty non-retryable error received"
    (#12642)
  * `azurerm_machine_learning_compute_cluster` - fix a crash when creating a cluster without specifying
    `subnet_resource_id` (#12658)
  * `azurerm_storage_account` - fixed account_replication_type validation (#12645)
- For changes from 2.44.0 through 2.68.0, see CHANGELOG-v2.md and CHANGELOG.md shipped with the package
* Fri Jan 15 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.43.0:
  * Update CHANGELOG.md for #10055
  * azurerm_cosmosdb_account: enable_analytical_storage (#10055)
  * Update CHANGELOG.md for #10190
  * r/advanced_threat_protection: adding a state migration to ensure
    the ID has a `/` prefix (#10190)
  * update error message && construct id regardless response (reduce a GET call)
  * sentinel opt-in resourceid
  * update CHANGELOG>md for #-7020
  * new data source: azurerm_sentinel_alert_rule_template (#7020)
  * update CHANGELOG.md for #10159
  * `azurerm_cosmosdb_gremlin_graph`: Expose `default_ttl` (#10159)
  * update CHANGELOG.md for #10125
  * azurerm_mssql_virtual_machine: fix tests and persistent diff, use relative
    expiry for service principal password (#10125)
  * update changelog.md for #10170
  * `azurerm_role_definition` - address eventual consistency issues in update and delete (#10170)
  * update CHANGELOG.md for #10169
  * azurerm_eventhub_namespace: Expose trusted_service_access_enabled in … (#10169)
  * refactor apimanagement: generators (part 1) (#9929)
  * Test Shim: Network A->E (#10184)
  * Refactor: Move Compute tests into main compute package (#10180)
  * Test Shim: Compute (#10161)
  * update CHANGELOG.md for #10070
  * azurerm_data_factory_dataset_delimited_text: Add `compression_type` (#10070)
  * updating to include #10126
  * updating to include #10105
  * updating to include #1016210162
  * firewall service tests - refactor to CheckWithClient / DisappearsStep (#10127)
  * update CHANGELOG.md for #10033
  * azurerm_synapse_workspace: Adding sql_identity_control_enabled (#10033)
  * update CHANGELOG.md for #10032
  * data_factory_linked_service_sql_server: support `key_vault_password` (#10032)
  * update CHANGELOG.md for #9541
  * azurerm_databricks_workspace - changing the sku no longer forces a new resource unless it is required (#9541)
  * Make  data source return parsed ID
  * Test Shim: Compute Linux Virtual Machine (#10142)
  * Update CHANGELOG.md for #10134
  * `azurerm_role_assignment` - fix race condition in read after create (#10134)
  * sorting alphabetically
  * update doc
  * updating to include #10104
  * Update network_service_tags.html.markdown
  * Document how to use the locally compiled Azure provider (#10119)
  * Fix import ordering
  * Fix formatting
  * Remove validation from field that is only used as output
  * Move imports in attempt to beat the linter to the check.
  * Fix bug where I returned nil instead of err.
  * Add parsing and validation of user assigned identity for kusto_cluster
  * Add parsing and validation of user assigned identity for kubernetes_cluster
  * Add parsing and validation of user assigned identity for container_group
  * Add parsing and validation of user assigned identity for virtual_machine
  * Add parsing and validation of user assigned identity for virtual_machine_scale_set
  * Add parsing and validation of user assigned identity for blueprint_assignment
  * Add parsing and validation of user assigned identity for api_management
  * loadbalancer: removing unused methods
  * fix import generator
  * r/hdinsight_kafka_cluster: switching the AAD Client to come from Authorization
  * stop gen
  * updating to include #10031
  * tests: threading through the err to the message
  * r/loadbalancer_backend_address_pool: switching to use a Disappears/Destroy step
  * r/loadbalancer_nat_pool: updating to use a Disappears/Destroy func
  * r/loadbalancer_nat_rule: switching to use a Disappears/Destroy func
  * r/loadbalancer_outbound_rule: switching to use a Disappears/Destroy step
  * r/load_balancer_probe: switching to use a Disappears/Destroy func
  * r/loadbalancer_rule: refactoring to use a Destroy func
  * generate parsers
  * Update azurerm/internal/services/monitor/monitor_diagnostic_setting_resource.go
  * update doc
  * r/stream_analytics_function_javascript_udf: refactoring to use the ID Parser/Validator
  * streamanalytics: generating the Function ID Parser/Validator
  * r/stream_analytics_job: switching to use the ID Parser/validator
  * streamanalytics: generating the Streaming Job ID parser
  * r/stream_analytics_output_mssql: refactoring to use the ID parser
  * r/stream_analytics_output_servicebus_queue: refactoring to use the ID parser
  * r/stream_analytics_output_eventhub: refactoring to use the ID Parser
  * r/stream_analytics_output_blob: refactoring to use the ID parser
  * r/stream_analytics_output_servicebus_topic: refactoring to use the Resource ID parser
  * streamanalytics: generating the Output ID parser
  * fix test case, examples and support more event source
  * Firewall Service - add missing generated parsers (#10103)
  * Test Shim: DataFactory (#10114)
  * Add os_disk_type to AKS cluster docs (#10113)
  * remove comment
  * fix application_gateway_resource identity_ids case-sensistivity
  * Merging #10115
  * Update changelog for #9605
  * `azurerm_data_factory` - Add support for `public_network_enabled` for Data Factories #9605
  * r/key_vault_certificate_issuer: removing the disappearsWhenParentKeyVaultDeleted test (#10092)
  * r/security_center_automation: switching to check the state which is sufficient (#10106)
  * mysql: removing direct usages on `acceptance.AzureProvider` from `mysql` (#10109)
  * refactor: removing direct usages on `acceptance.AzureProvider` from `postgres` (#10108)
  * kusto: removing the dependency on `acceptance.AzureProvider` by using a Check func (#10111)
  * Fix linting error
  * Add parsing and validation of user assigned identity for virtual machines
  * Add validation of user assigned identities
  * Parse user assigned identity when reading
  * handle legacy metadata
  * r/function_app: removing some unnecessary checks
  * `azurerm_log_analytics_cluster_customer_managed_key` disable
    test until referenced go-autorest PR is resolved (#10094)
  * r/function_app: refactoring to use a check func
  * r/storage_account_customer_managed_key: refactoring to remove usage on acceptance.AzureProvider
  * r/storage_blob: refactoring to remove usage on acceptance.AzureProvider
  * r/storage_sync_cloud_endpoint: switching to use the updated test pattern
  * r/monitor_log_profile: switching to use a DisappearsStep
  * update CHANGELOG.md for #9922
  * Event Grid support for inbound ip filter (#9922)
- from version 2.42.0
  * update CHANGELOG.md for #9957
  * "azurerm_spring_cloud_app" - supports property `https_only`, `is_public`, `persistent_disk` (#9957)
  * refactor: removing some direct usages on `acceptance.AzureProvider` (#10089)
  * Test Shim Image
  * Replaced deprecated resource with new resource (#10085)
  * update CHANGELOG.md for #10088
  * r/key_vault: defaulting `soft_delete_enabled` on to match the updated API behaviour (#10088)
  * Update CHANGELOG.md for #9609
  * Add support for service tags to ip_restriction for function_app and app_service (#9609)
  * Update CHANGELOG.md for #9162
  * Add fields for App Service and App Service Slot (#9162)
  * Update CHANGELOG.md for #8828
  * azurerm_kubernetes_cluster - add support for network_mode (#8828)
  * Lint: Fixing linting issues around a variety of tests (#10076)
  * update CHANGELOG.md for #9047
  * `azurerm_subscription(s)` - support for `tags` (#9047)
  * update CHANGELOG.md for #9842
  * New resource/Data Source: azurerm_ssh_public_key (#9842)
  * update CHANGELOG.md for #10062
  * Fixed resource provider names for Blueprint and FHIR (#10062)
  * test shim: compute a -> d
  * updating to include the batch api version from 10036
  * gofumpt: re-enabling now the upstream cert's been fixed
  * updating to include #10042
  * r/security_center_setting: working around a breaking change in the response
  * compute: adding the missing arg to the tests
  * vendoring the updated batch changes
  * r/linux|windows_virtual_machine: opting-out of the force-delete for now
  * synapse: working around breaking type changes
  * securitycenter: updating the generated constant names
  * eventhub: updating the constant names
  * r/(linux_|windows)virtual_machine: conditionally opting into Force Deletion
  * attestation: updating the API reference to use the stable api version
  * dependencies: upgrading github.com/Azure/azure-sdk-for-go to v49.2.0
  * tooling: disabling gofumpt temporarily
  * key vault related test fix-ups - part 1 (#10060)
  * update CHANGELOG.md for #9889
  * New resource - `azurerm_disk_access` (#9889)
  * update CHANGELOG.md for 10050
  * New data source: `azurerm_eventgrid_domain_topic` (#10050)
  * r/postgresql_firewall_rule: Add name validaton (#10047)
  * azurerm_web_application_firewall_policy: add REQUEST-944-APPLICATION-… (#10046)
  * update CHANGELOG.md for #9976
  * azurerm_kubernetes_cluster - parse oms log_analytics_workspace_id to ensure correct casing (#9976)
  * update CHANGELOG.md for #8064
  * Retrieve Subscription Tags via data source (#9456)
  * udpate CHANGELOG.md for #8064
  * azurerm_hdinsight_kafka_cluster: support rest proxy (#8064)
  * Test Shim: Cosmos #10045
  * batch: removing the unused error from expandPoolNetworkSecurityGroupRule
  * r/analysisservices_server: fixing the broken Suspend test
  * Update CHANGELOG.md for #10051
  * `azurerm_role_assignment` fix crash in retry logic (#10051)
  * updating to include #10049
  * devspace: assigning a usage so the resource struct is still valid
  * batch: conditionally setting the `PublicIPAddressConfiguration` if unspecified
  * batch: un-exporting the flatten function
  * batch: fixing a couple of tests
  * updating to include #10035
  * teamcity: removing `devspaces` from the list
  * r/devspace: deprecating `azurerm_devspace_controller`
  * devspace: these tests can no longer be run
  * azurerm_availability_set: Update docs to reflect ForceNew
  * update CHANGELOG.md for #10036
  * azurerm_batch_pool: add support for public_address_provisioning_type (#10036)
  * false positive linting issue in `azurerm_resource_group` data source (#10037)
  * dependencies: upgrading to v0.15.1 of github.com/tombuildsstuff/giovanni
  * update CHANGELOG.md for #9490
  * Raise limit of destination_ports of network_rule_collection for azurerm_firewall_policy_rule_collection_group (#9490)
  * fix gofmt issue
  * update CHANGELOG.md for #9928
  * New Resource: `azurerm_data_factory_linked_service_synapse` (#9928)
  * update CHANGELOG.md for #8564
  * azurerm_sentinel_alert_rule_scheduled: support incident configuration (#8564)
  * Make AppGw identity_ids case-insensitive
  * Adding description to ADF managed IR docs (#10028)
  * update CHANGELOG.md for #8850
  * `azurerm_cdn_endpoint` - `delivery_rule` condition optional `match_values` (#8850)
  * update CHANGELOG.md for #9548
  * azurerm_storage_account  - allow hns when `account_tier` is `Premium` (#9548)
  * update CHANGELOG.md for #10017
  * `azurerm_synapse_workspace` - Add support for `managed_resource_group_name` (#10017)
  * update CHANGELOG.md for #8690
  * `azurerm_cosmosdb_mongo_collection` - correctly read the `_id` index back when mongo 3.6 (#8690)
  * update CHANGELOG>md for #9829
  * New resource: azurerm_sentinel_alert_rule_fusion (#9829)
  * update CHANGELOG.md for #9069
  * azurerm_function_app - make `pre_warmed_instance_count` computed to use azure's default (#9069)
  * update CHANGELOG.md for #9836
  * azurerm_container_group - support `volume.empty_dir` (#9836)
  * azurerm_monitor_diagnostic_setting name validation (#10014)
  * test shim: web (#9995)
  * azurerm_key_vault - Correct 'managecontacts' casing and permissions usage (#10006)
  * update CHANGELOG.md for #9902
  * CDN endpoint: Test for Premium_Verizon, optional values fix (#9902)
  * update CHANGELOG.md for #9992
  * New resource: `azurerm_media_streaming_locator` (#9992)
  * update CHANGELOG.md for #9797
  * Support new properties `alert_rule_template_guid` and `display_name_exclude_filter`
    for azurerm_sentinel_alert_rule_ms_security_incident (#9797)
  * update CHANGELOG.md for #9749
  * `azurerm_cosmosdb_table` doesn't call get throughput api when cosmos account is serverless (#9749)
  * update CHANGELOG.md for #9934
  * `azurerm_data_factory_linked_service_azure_file_storage` - Add support for `file_share` (#9934)
  * update CHANGELOG.md for #10005
  * `azurerm_traffic_manager_profile` - add traffic view support (#10005)
  * Fix App Service documentation for Linux plans (#9024)
  * update CHANGELOG.md for #9712
  * azurerm_sentinel_alert_rule_scheduled - support alert_rule_template_guid (#9712)
  * update CHANGEL:OG.md for #8753
  * `azurerm_application_gateway` - set correct WAF_v2 `file_upload_limit_mb` (#8753)
  * Documentation update for VM Boot Diagnostics using Managed Storage Account (#9817)
  * Fix LAW capitalization in security_center_workspace (again) (#9931)
  * Function app example: Replace storage account connection string with name/access key (#9997)
  * update CHANGELOG.md for #10000
  * Add Standard_D4a_V4 VM type for HDInsight clusters (#10000)
  * Test Shim: API Management (#9999)
  * Test Shim: Hadoop (#9998)
  * test shim: firewall (#9994)
  * move eventgrid tests (#9993)
  * Refactor: Migrate storage tests (#9864)
  * update CHANGELOG.md for #9966
  * azurerm_cosmosdb_account: include key vault id in update requests to work with azure policies (#9966)
  * Test Shim: IotHub (#9991)
  * Test Shim: KeyVault (#9986)
  * Minor change in servicebus_subscription.html.markdown (#9985)
  * Test Shim: Monitor (#9973)
  * Test Shim: Log Analytics (#9974)
  * Test shim: media & lighthouse (#9952)
  * Test Shim: Recovery Services  (#9969)
  * test shim: event hub (#9968)
  * Update CHANGELOG.md
  * update CHANGELOG.md for #9884
  * Increase limit from 1 to 10 for `application_security_group` in `network_security_rule` (#9884)
  * Updating to include #6868
  * Fix for #6730
  * TestShim: MySQL (#9948)
  * mssql: acceptance test shims and fixes (#9938)
  * Updating to include #9951
  * Adding #9951
  * Updating to include #9950
  * Adding #9950
  * Test Shim: Netapp (#9926)
  * Updating azurerm_storage_share_file documentation (#9940)
  * mssql: fix import for mssql_server_security_alert_policy
  * re-enable nightly testing
  * disable overnight testing
  * updating to include #9914
  * Update code
  * update code
  * Updating to include #9932
  * Merging #9932
  * update CHANGELOG.md for #9933
  * Data Source: azurerm_databricks_workspace: support for `tags` (#9933)
  * Test Shim: Postgres #9924
- from version 2.41.0
  * web/app-service: fixing the Exists function
  * updating to include #9911
  * mssql: add missing resource ID parsers and tidy up function naming
  * r/key_vault_secret: adding purge protection
  * Update CHANGELOG.md for #9897
  * `azurerm_linux_virtual_machine` - Normalise SSH keys (#9897)
  * r/monitor_diagnostic_setting: adding validation/rewriting the
    StorageAccountID/EventHubAuthorizationRuleID fields too
  * r/monitor_diagnostic_setting: validating the Log Analytics Workspace ID is a LAW ID
  * r/monitor_diagnostic_setting: normalising the field `log_analytics_workspace_id`
  * r/key_vault_certificate: adding import/recover permissions for the tests
  * r/hdinsight: removing a stray } from the docs
  * r/key_vault: enabling soft delete by default
  * r/key_vault_key & secret: updating the tests to use templates & enable soft-delete
  * keyvault/key & secret: updating the examples
  * r/key_vault_certificate: adding soft delete to the example
  * r/key_vault_certificate: enabling soft-delete for the tests by default
  * Update CHANGELOG.md for #9859
  * New resource: `azurerm_media_job` (#9859)
  * r/key_vault_certificate: and to the docs
  * r/key_vault_certificate: adding the purge permission to the tests
  * r/key_vault_certificate: refactoring the tests to use a template where possible
  * keyvault: quoting the ID to handle escape on shells
  * github: adding links to the Discuss forum rather than a question template
  * r/key_vault_certificate: adding a ForceNew
  * website: updating the features block
  * keyvault/nested-item: updating the docs
  * key-vault/nested-item: moving the wayward func
  * keyvault/nested-items: reusing the `purge_soft_delete_on_destroy` feature flag
  * keyvault/nested-resources: purging during deletion
  * Rename HDInsightCluster to Cluster
  * Update azurerm/internal/services/hdinsight/resourceids.go
  * Updating to include #9410
  * Merge #9410
  * Add TC to support recreating vhub connection with same name
  * Move private dns over to the new test shim
  * minor update docs
  * add link to lighthouse documentation
  * Generators
  * Update changelog for #9852
  * New Resource: `azurerm_eventgrid_system_topic_event_subscription` (#9852)
  * eventgrid_system_topic: supplement docs (#9888)
  * r/keyvault: fixing a bug where application id couldn't be an empty string
  * updating to include #8631
  * Also set "upns" part of "subject_alternative_names"
  * Read DNS names and Emails from certificate data if not found in SDK object
  * Acceptance tests: fix CheckDestroyedFunc
  * updating to include #9853
  * Update azurerm/internal/services/loganalytics/migration/workspace_v1_to_v2.go
  * Update changelog for #9871
  * `azurerm_app_service` - Add support for `outbound_ip_address_list`
    and `possible_outbound_ip_address_list` (#9871)
  * Doc Fix: app_service_managed_certificate.html.markdown #9881
  * loadbalancer service tests shim (#9879)
  * tooling: updating to Go 1.15.5
  * update CHANGELOG.md for #9487
  * `azurerm_traffic_manager_profile` - support for new field `max_return` and
    support for `traffic_routing_method` to be `MultiValue` (#9487)
  * load balancer tests - refactor out implementation code (#9856)
  * move tests: storage (#9837)
  * fix a number of acc tests
  * test shim: kusto (#9841)
  * r/private_dns_txt_record: fixing the test data
  * updating to include #9848
  * privatedns: removing the unused subscription id argument
  * tooling: adding a gradually deprecated check for relying on the Azure Resource ID's
  * r/private_dns_aaaa: fixing a typo
  * r/storage_management_policy: removing the test dependency on ParseAzureResourceId
  * r/private_dns_a_record: actually saving the changes this time
  * d/private_dns_zone: removing a direct usage on ParseAzureResourceId
  * r/private_dns_a_record: switching to use the Resource ID Formatter/Parser
  * r/private_dns_aaaa_record: switching to use the Resource ID Formatter/Parser
  * r/private_dns_cname_record: switching to use the Resource ID Formatter/Parser
  * r/private_dns_mx_record: switching to use the Resource ID Formatter/Parser
  * r/private_dns_ptr_record: switching to use the Resource ID Formatter/Parser
  * r/private_dns_srv_record: switching to use the ID Formatter
  * r/private_dns_txt_record: switching to use the id formatter/parser
  * r/private_dns_zone_virtual_network_link: switching to use the Resource ID Formatter/Parser
  * d/private_dns_zone: switching to use a Resource ID Formatter
  * privatelink: support for enhanced import validation for all resources
  * privatedns: generating the Resource ID Formatters/Parsers
  * r/private_dns_zone: switching to use the ID Formatter/Parser & enhanced import validation
  * r/log_analytics_workspace: force-upgrading the resource id's
  * r/iot_time_series_insights_gen2_environment: exposing `data_access_fqdn`
  * docs(virtual-machines): fix link vm sizing doc
  * move tests: firewall and loadbalancer
  * removing the unused `subscriptionId` argument placeholder/some todo's
  * resource-ids: updating the method signature for the hand-rolled ones
  * regenerating
  * resourceid: removing the subscriptionId argument from the interface
  * generator: removing the subscription id argument from the generator
  * Fix typo
  * security center: refactoring from the pr comments
  * splitting out the 2.40 - 2.31 changes to the other file
  * copying over 2.31 - 2.40
  * updating to include #7913
  * Update loadbalancer resources to generated IDs (#9805)
  * shim tests
  * media: switch a typeset to a typelist (#9828)
  * test shim: relay (#9825)
  * run go generate to fix synapse (#9827)
  * test shim: redis
  * make fmt
  * shim tests
  * rename functions
  * add checkAdvancedThreatProtectionIsFalse
  * fix tests
  * shim testS
  * update CHANGELOG.md for #9260
  * new resource - "azurerm_synapse_managed_private_endpoint" (#9260)
  * update CHANGELOG.md for #9537
  * New resource: `azurerm_media_streaming_endpoint` (#9537)
  * rename functions
  * shim tests
  * rename functions
  * Broken link in AzureAD migration guide (#9813)
  * Test Shim: Service Bus (#9792)
  * Updating CHANGELOG.md for #8966
  * azurerm_subnet - support for `service_endpoint_policy` (#8966)
- from version 2.40.0
  * r/media_asset: switching to use a Resource ID Formatter
  * r/sentinel_alert_rule_ms_security_incident: normalizing the log analytics workspace id
  * r/managed_application_definition: fixing the test exists func
  * r/relay_hybrid_connection: fixing an incorrect `name` set
  * r/sentinel_alert_rule_scheduled: using the Log Analytics Workspace ID from the Formatter
  * clarifying the sdk upgrade from #9764
  * r/servicebus_subscription_rule: fixing argument ordering
  * r/servicebus_topic_authorization_rule: fixing the resource id
  * batch: fixing the exists function
  * removing #8966 since this hasn't been merged yet
  * kusto: switching the delete function to use the same Resource ID Parser
  * updating to include #9802
  * updating the resource name to account for #9134
  * Update website/docs/r/stack_hci_cluster.html.markdown
  * r/media_services_account: fixing the `TestAccMediaServicesAccount_multiplePrimaries` test
  * r/media_services_account: fixing the requires import test
  * resource-id: adding a formatter implementation check into the hand-maintained implementations
  * loganalytics: removing the superflurous `subscriptionId` argument from the ID func
  * r/media_transform: making the fields case-sensitive since this is a new resource
  * r/media_services_account: adding tests for requires import
  * r/media_transform: adding tests for requires import
  * r/media_transform: switching to use a Resource ID Formatter in the Create & Requires Import
  * media: regenerating the updated ID Formatter
  * updating to include #9663
  * frontdoor: fixing the resource id casing to match the behaviour
  * re-generating with the loganalytics PR changes
  * Update CHANGELOG.md for #9701
  * regenerating the ID Parsers to include the updated description
  * generator: outputting the type name and sorting the segments to match the ID
  * `azurerm_app_service_managed_certificate` - create certificate in service plan resource group (#9701)
  * remove vendor path from linter
  * update code
  * Switch loganalytics to generated resourceids (#9764)
  * Allow allow_blob_public_access and min_tls_version on azurerm_storage_account in USGovernmentCloud (#9540)
  * update CHANGELOG.md for #9540
  * update CHANGELOG.md for #8966
  * update CHANGELOG.md for #8540
  * New resource `azurerm_storage_sync_cloud_endpoint` (#8540)
  * Test Shim: Spring Cloud (#9787)
  * Updating Types
  * Apply suggestions from code review
  * updating to include #9783
  * client: opting-out of the Azure SDK for Go's validation
  * dependencies: upgrading to v0.3.1 of github.com/Azure/go-autorest
  * updating to include #9771
  * firewall: fixing the import
  * missing changes from 9415 (#9780)
  * Update CHANGELOG.md for #9415
  * New Resource: azurerm_app_service_certificate_binding (#9415)
  * update code
  * Refactor: Azure Stack HCI Cluster
  * regenerating
  * teamcity: generating the build configuration for the new service package
  * firewall: splitting the validate funcs out
  * network: moving the firewall validate/parse functions
  * firewall: lifting & shifting out to it's own package
  * update CHANGELOG.md for #9134
  * New resource: `azurerm_hci_cluster` (#9134)
  * d/user_assigned_identity: switching to use the ID Formatter
  * r/user_assigned_identity: switching to use the Resource ID Formatter/Parser
  * teamcity: generating the new package
  * network: removing the now unnecessary loadbalancers section
  * loadbalancers: ditching the `lb` prefix since this is superflurous
  * network => loadbalancer
  * loadbalancer: moving the validate function out
  * loadbalancers: switching over to use the loadbalancers client
  * network: removing the lifted&shifted resources
  * loadbalancers: lifting & shifting the resource ids
  * loadbalancers: moving the existing data sources/resources over
  * loadbalancers: scaffolding a new package
  * adjusting the message for #9750
  * servicebus: fixing code review comments
  * redis: fixing unit/linting failures
  * refactor: using a non-not found non-error to signify it's present
  * r/redis_linked_server: validation that the `linked_redis_cache_id` is a redis cache id
  * r/redis_cache: validating the subnet id and parsing using the networking parser
  * r/redis_linked_server: switching to use a Resource ID Formatter/Parser
  * r/redis_firewall_rule: support for enhanced import validation
  * r/redis_firewall_rule: switching to use an ID Formatter/Parser
  * address linting issues
  * fix typo
  * shim tests
  * rename functions
  * shim tests
  * rename functions
  * shim tests
  * rename functions
  * Example sku fails in with terraform cli version 14 (#9763)
  * Update changelog for #9406
  * New Resource: `azurerm_storage_share_file`  (#9406)
  * updating to include #9750
  * fixes #8208
  * r/redis_cache: enhanced import validation
  * r/redis_cache: switching to use the Resource ID Formatter/Parser
  * Move test file to main directory
  * Apply suggestions from code review
  * d/redis_cache: switching to use a Resource ID Formatter
  * redis: splitting the validation functions out
  * redis: moving max_memory_policy out
  * redis: moving the firewall rule name into the validate package
  * r/relay_hybrid_connection: refactoring to use the Resource ID Parser
  * r/relay_namespace: switching to use the ID Parser
  * updating to include #9735
  * Apply suggestions from code review
  * r/stream_analytics_stream_input_iothub: fixing the delete
  * refactor: moving the parser into the parse folder
  * r/advanced_threat_protection: switching to use an ID Formatter
  * tools: updating the Resource ID Generator to parse the multiple segments
  * r/servicebus_namespace_network_rule_set: switching to use a resource id formatter
  * d/servicebus_namespace: switching to use the ID formatter
  * d/namespace_authorization_rule: switching to use the id formatter
  * r/servicebus_namespace_authorization_rule: switching to use the ID
    Formatter/Parser and Enhanced Import Validation
  * r/servicebus_namespace: switching to use the resource id parser/formatter
  * d/servicebus_queue: switching to use the Resource ID Formatter
  * r/servicebus_queue_authorization_rule: using the ID Formatter/Parser and enhanced import validation
  * r/servicebus_queue: switching to use a Resource ID Formatter, Parser and adding Enhanced Import Validation
  * servicebus: splitting out the migration code
  * r/servicebus_subscription: switching to use the id formatter/parser & enhanced import validation
  * d/servicebus_subscription: switching to use the ID Formatter
  * d/servicebus_topic_authorization_rule: switching to use the id formatter
  * r/servicebus_subscription_rule: switching to use the resource id parser/enhanced validation
  * tooling: handling resource id's containing multiple subscription segments
  * r/servicebus_topic_authorization_rule: using the ID Parser & enhanced import validation
  * r/servicebus_topic: switching to use the ID Parser & enhanced import validation
  * servicebus: generating the Resource ID Parser for ServiceBus Topic
  * helpers: renaming the file so we have a place for deprecated logic
  * servicebus: making the internal methods internal-only
  * servicebus: moving most of the servicebus helpers into the internal helper file
  * servicebus: moving the Topic Name validate func
  * servicebus: moving the Authorization Rule validation logic
  * servicebus: moving the validation rule for Subscription Name
  * servicebus: moving the validate name method
  * r/stream_analytics_stream_input_iothub: fixing a typo
  * streamanalytics: re-generating with the new generator
  * r/stream_analytics_stream_input_eventhub: refactoring to use a Resource ID Formatter/Parser
  * r/stream_analytics_stream_input_blob: refactoring to use a Resource ID Parser
  * r/stream_analytics_reference_input_blob: switching to use an ID Parser
  * r/stream_analytics_stream_input_iothub: updating to use an ID Parser
  * r/stream_analytics_stream_input_iothub: switching to use the ID Parser
  * streamanaltyics: generating the Resource ID Formatter/Parser for Stream Input
  * r/recovery_services_vault: fixing the test name to make the linter happy
  * removing the todo
  * generator-resource-id: filename support cascaded uppercase runes
  * make fmt yet again
  * address linting issues
  * fix tests
  * generated code updated
  * shim tests
  * rename functions
  * fix function names
  * fix tests
  * Refactor: Migrate servicefabric tests (#9743)
  * Refactor: Migrate servicefabricmesh test (#9742)
  * move tests: servicebus
  * move tests: sentinel
  * move tests: security centre
  * move tests: resource
  * move tests: search test
  * move tests: relay test
  * move tests: redis test
  * move tests: recovery test
  * move tests: package test
  * move tests: package eventhub
  * move app platform -> springcloud
  * move tests: package apimanagement
  * update CHANGELOG.md for #9676
  * azurerm_security_center_automation - support "description", "tags" (#9676)
  * Update changelog for #9739
  * `azurerm_postgresql_server` - Fix issue when specifying empty threat detection list attributes (#9739)
  * Update changelog for #9702
  * New resource `azurerm_digital_twins_endpoint_servicebus`  (#9702)
  * update CHANGELOG.md for #9387
  * New Resource: azurerm_media_asset (#9387)
  * network: removing a superflurous call with subscriptionId
  * storage: removing the dependency on subscriptionId
  * desktopvirtualization: removing the superflurous subscriptionId call
  * cdn: removing the superflurous subscriptionId call
  * resource-ids: generating error message helper functions
  * generator/resource-id: using slashes to better match the existing convention
  * generator/resource-id: outputting human-readable segments
  * updating to include #9690
  * trafficmanager: removing the 'Endpoints' suffix during parsing
  * updating to include #9692
  * bot: removing the split-out test
  * Update changelog for #9727
  * `azurerm_app_service`: Support PHP version 7.4 #9727
  * d/traffic_manager_profile: switching to use a Resource ID Formatter/Parser
  * r/traffic_manager_endpoint: switching to use a combination Resource ID parser for the moment
  * r/traffic_manager_profile: switching to use an ID Parser/Formatter
  * trafficmanager/endpoint: generating the Resource ID's
  * r/traffic_manager_endpoint: adding a todo this needs splitting
  * trafficmanager: generating the Resource ID Parser/Validator for Profile
  * updating to include #7951
  * loganalytics: moving to the validate function directly
  * loganalytics/workspace: moving the name validation into the validate package
  * r/log_analytics_workspace: fixing the test reference
  * loganalytics/workspace: fixing the package name
  * make fmt
  * fix tests
  * move hdinsight tests
  * move hpc cache tests
  * move package iothub tests
  * move package iottimeseriesinsights tests
  * move keyvault tests
  * move kusto tests
  * move lighthouse tests
  * move log analytics tests
  * docs: describing how to generate Resource ID Formatters, Parsers and Validators
  * docs: updating the versions
  * gha: removing the unneeded failfast
  * r/bot_channel_directline: handling this being created by default behind the scenes
  * bugfix -> enhancement
  * sorting alphabetically
  * r/bot_channel_directline: switching to use a Resource ID Parser
  * r/bot_channel_email: refactoring to use a Resource ID Parser
  * r/bot_channel_ms_teams: switching to use a Resource ID Parser
  * r/bot_channel_slack: switching to use a Resource ID Parser
  * r/bot_connection: `bot_name` is now ForceNew
  * bot: generating the Resource ID Formatter / Parser for Bot Channel
  * r/bot_channels_registration: switching to use the ID Parser
  * r/bot_channels_registration: validating the bot type during import
  * r/bot_web_app: validating the Kind during import
  * r/bot_connection: switching to use a Resource ID parser
  * r/bot_web_app: support for Enhanced Import Validation
  * r/bot_web_app: threading the ID Parser through the Delete
  * r/bot_web_app: threading the ID Parser through the Update
  * r/bot_web_app: threading the Parse function through the Read
  * r/bot_web_app: threading the Bot Service ID through the Create
  * bot: generating the Resource ID Formatter/Parser for Bot Service
  * gha/gencheck: updating the trigger path
  * teamcity: re-generating using the updates sort order
  * generator: sorting based on the Service Display Name
  * github: adding a check to ensure the generation is consistent
  * generator: re-generating the TC services
  * generator/services: updating the generator to handle conflicting packages
  * updating to include #9689
  * move privatedns tests
  * move powerbi hub tests
  * move postgres hub tests
  * move notification hub tests
  * Move netapp tests
  * Move mysql tests
  * Move mssql tests
  * Move monitor tests
  * fix test package name
  * update CHANGELOG.md for #9496
  * add partition_key_version attribute to resource azurerm_cosmosdb_sql_container (#9496)
  * migrate signalr tests
  * rename files
  * Update changelog for #9696
  * `azurerm_kusto_cluster` - Add support for `engine` (#9696)
  * Update changelog for #9694
  * `azurerm_postgresql_server` - Add ForceNew to `geo_redundant_backup_enabled` (#9694)
  * Update changelog for #9670
  * `azurerm_iothub` - Add support for `min_tls_version` #9670
  * Add default value for compression of 'None'
  * r/app_service_hybrid_connection: updating to use a resource id parser
  * Copypaste typo
  * azurerm_recovery_services_vault: Support for `identity` block
  * azurerm_kusto_eventhub_data_connection: Support for `compression` property
  * validators: re-generating based on the latest generator
  * rename resource functions
  * Added Attribute details for key_vault_certificate.html.markdown
  * migrate test cases
  * rename functions
  * migrate test cases
  * r/provider_registration: highlighting the recommendation to auto-register RP's
  * r/provider_registration: renaming to match the convention
  * r/provider_registration: fixing the import error
  * r/provider_registration: switching to be a typed resource
  * sdk: support for custom importers
  * resource: hooking up the Typed Service Registration
  * r/resource_provider_registration: updating the docs
  * r/provider_registration: updating the tests
  * r/provider_registration: updating the tests
  * r/provider_registration: refactoring and support for enhanced validation
  * resource: noting the RP ID Parser isn't generated for now
  * client/builder: enhanced validation for Resource Providers
  * resourceproviders: support for enhanced validation
  * resource: adding a Resource ID Parser for Resource Providers
  * New Resource: `azurerm_resource_provider_registration`
  * managementgroups: fixing comments from code review
  * updating to include #9671
  * rename files
  * Updating to include #9673
  * rename the resource functions
  * Partial fix: #9211
  * migrate test cases
  * migrate the left two files
  * rename the last two files
  * migrate spark pool
  * rename spark pool
  * migrate sql pool
  * rename sql pool
  * migrate test for workspaces
  * rename worspace
  * fix resource id generator on windows
- from version 2.39.0
  * update CHANGELOG.md for #9649
  * Allow for evenhub dedicated clusters with bigger than 1 capacity (#9649)
  * Documents default value for `ftps_state` argument.
  * Fix crash in signalar
  * Update changelog for #9616
  * New Resource: `azurerm_iot_time_series_insights_gen2_environment` (#9616)
  * rebase and update docs
  * wrong checkExists
  * tweaked final segment name
  * removed setting location, since it's not in schema anyway
  * advisor: tests need to start TestAcc to be picked up
  * web: moving the tests up a level
  * fixing the build
  * relay: generating the Resource ID's
  * relay: refactoring
  * use func for nilable location
  * fix panic in traffic_manager_profile datasource
  * `azurerm_api_management_custom_domain` fix docs for import of resource (#9657)
  * remove unnecessary line
  * including acceptance tests
  * analysisservices: fixing the broken assertion error
  * validate: generating to fix the application insights web test id stutter
  * generator: not suffixing validate id functions with `_id` since this is superflurous
  * validators: fixing conflicts with hand written code
  * validate: generating the new validate funcs
  * validators: generating the existing validation functions
  * generator/resource-id: enabling the generation of ID Validate functions
  * sdk: documenting the update method a little better
  * sdk: support for Deprecated resources
  * web: splitting the validate funcs to enable generation
  * updating to include #9651
  * Update azurerm/internal/services/securitycenter/resource_arm_security_center_workspace.go
  * Fix LAW capitalization
  * Fix go.sum
  * Add ResourceWithUpdate to consumer group
  * eventhub: hooking up the typed registration
  * fixing the test
  * eventhub: converting Consumer Group to q Typed Resource
  * utils: adding the normalize nilable string func
  * example: removing the package
  * start of encode/decode
  * Split out validation in eventhub_resource
  * fix test package names
  * update CHANGELOG.md for #9457
  * azurerm_media_services_account - support for 'identity', 'tags' and 'storage_authentication' (#9457)
  * Updating to include #9489
  * Partial fix for #9211
  * Start of resource wrapper
  * updating documentation
  * revert deleted file
  * include some validations
  * r/app_service_managed_certificate: updating the name of the requires import test
  * migrate app service plan tests
  * rename app service plan files
  * migrate tests in function app and related data source
  * rename another impacted data source file
  * rename function app files
  * migrate app service and app service slot and function slot tests
  * rename app service and related files
  * migrate test for hybrid connection resource
  * rename hybrid connection file
  * migrate managed certificate test
  * rename managed certificate file
  * migrate certificate order resource and data source tests
  * rename certificate order files
  * migrate certificate resource and data source tests
  * rename files for app service certificate
  * migrate test for environment resource and data source
  * rename files for app_service_environment resource and data source
  * provider: removing `Supported` from the front of the TypedServiceRegistration
  * include support for differents presets
  * synapse: splitting the workspace validators
  * synapse: splitting SqlPool
  * synapse: Big Data Pool -> Spark Pool to match the validator
  * synapse: renaming Firewall to match the generated code
  * synapse: renaming to match the convention
  * storage: prefixing with Storage to match the other validators
  * storage: renaming the ShareName validator to match the convention
  * storage: renaming the queue file to match the convention
  * storage: renaming encryption scope
  * storage/keyvault: moving the key vault child id parser into the keyvault package
  * storage: renaming account id
  * storage: updating account ip rule to match the convention
  * servicebus: removing the `Servicebus` prefix from the validate func to match the convention
  * servicebus: removing the unused namespace id validation func
  * servicebus: splitting the validate funcs
  * resource: renaming the files to match the convention
  * privatedns: splitting the validate funcs to enable generation
  * powerbi: ditching the PowerBI prefix
  * powerbi: splitting the validate files
  * postgresql: ditching the `Postgresql` prefix
  * postgresql: splitting the validate funcs
  * policy: renaming to match the convention
  * network: splitting the vpn site validators
  * network: renaming vpn gateway
  * network: renaming virtualwan
  * network: splitting and renaming the virtual network validators
  * network: matching the generated names
  * network: renaming the ValidateVirtualHubValidate func
  * network: renaming the subnet id validator
  * network: renaming PublicIpAddressID to match the convention
  * network: renaming to match the convention
  * network: splitting the network connection monitor validate funcs
  * network: renaming the nat gateway id validator
  * network: renaming load balancer file
  * network: splitting the firewall policy validate functions to enable generation
  * r/private_link_service: retrieving the private link service once it's finished
  * r/private_endpoint: updating the timeout
  * frontdoor_firewall_policy: removing dead code
  * fix error messages
  * fix linting
  * shim tests
  * rename functions
  * move tests
  * hsm: updating the test package name
  * iotcentral: fixing the package name
  * fix pacakge name
  * rename file
  * test shim: hsm
  * r/private_endpoint: ensuring we remove the old private dns zone group if it's no longer specified
  * r/private_endpoint: adding enhanced import validation
  * r/private_endpoint: pulling the list of Private DNS Zone Groups from Azure during update
  * r/private_endpoint: fixing a typo
  * r/private_endpoint: refactoring the Create now Update is split out
  * r/private_endpoint: splitting the Create and Update
  * r/private_endpoint: passing in the private ip address rather than mutating the flattened block
  * r/private_endpoint: switching to look up the Private DNS Zone Groups
  * r/private_endpoint: switching to use the ID Parser during the read
  * r/private_endpoint: refactoring to lookup the Private DNS Zone Group which is created
  * network: moving the Private DNS Zone Group parser
  * r/private_endpoint: refactoring
  * r/function_app_slot: fixing the importer parser name
  * app_service_virtual_network_swift_connection: updating to match the API response
  * app_service_slot_virtual_network_swift_connection: updating to match the response
  * dns/ptr_record: fixing the build
  * tests: fixing the code review comments
  * rename resource files
  * correctly name data source fileS
  * rename data source files
  * rename datasource tests
  * rename functions
  * move tests
  * updating api version
  * Update cosmosdb_sql_database.html.markdown
  * include transform support
  * mysql: splitting the validate funcs
  * mssql: ditching the 'mssql' prefix
  * mssql: splitting to match the convention
  * msi: renaming to match the convention
  * monitor: renaming to match the convention
  * mariadb: updating to match the convention
  * maps: renaming to match the convention
  * managementgroup: splitting the validate funcs
  * managedapplications: splitting the validate functions
  * maintainence: renaming to match the convention
  * machinelearning: renaming
  * logic: splitting the validate funcs to match the convention
  * logic: switching to use the Subnet ID validator directly
  * loganalytics: splitting to support generating these
  * keyvault: renaming to match the convention
  * iottimeseriesinsights: renaming to match the convention
  * iothub: splitting the files to match the convention
  * iothub: removing an unused func
  * iotcentral: splitting out the validate funcs
  * apimanagement: fixing the build after the generation/refactor
  * apimanagement: generating the Policy ID
  * apimanagement: renaming the Policv ID funcs to match the generated names
  * apimanagement: generating the Logger Resource ID
  * apimanagement: renaming logger to match the upcoming generated id
  * apimanagement: generating the Diagnostic Resource ID
  * apimanagement: renaming to match the generated name
  * apimanagement: generating the Custom Domain ID
  * apimanagement: renaming Custom Domain to match the upcoming generated version
  * apimanagement: generating the ApiVersionSet ID
  * apimanagement: renaming the ApiVersionSetId to match the generated name
  * apimanagement: generating the ApiManagement Service ID
  * apimanagement: renaming to match the upcoming generated name
  * apimanagement: regenerating ApiDiagnostic
  * apimanagement: updating ApiDiagnostic to match the upcoming generated resource id
  * Update changelog for #9215
  * New resource: `azurerm_api_management_policy` (#9215)
  * test shim: dev test labs (#9581)
  * test shim: virtual desktops (#9579)
  * test shim: healthcare (#9587)
  * test shim: eventgrid (#9585)
  * test shim: digital twins (#9582)
  * test shim: dev space (#9580)
  * applicationinsights: fixing a broken refactor
  * hsm: renaming to match the convention
  * hpccache: splitting and renaming the files
  * frontdoor: renaming and splitting the files
  * eventhub: renaming & removing deadcode
  * dns: renaming to match the convention
  * digitaltwins: renaming to match the convention
  * devtestlabs: renaming to match the convention
  * desktopvirtualization: ditching the prefix
  * desktopvirtualization: renaming the files
  * datashare: removing the Datashare prefix
  * datashare: splitting the validation funcs
  * datalake: updating to match the convention & ditching the DataLake prefix
  * customproviders: renaming to match the convention
  * containers: renaming to match the convention
  * containers: adding a check if the duration isn't a string
  * compute: renaming the validate files to match the convention
  * blueprints: removing the `Blueprints` prefix
  * blueprints: removing the unused func
  * automation: refactoring/splitting and renaming the validate funcs
  * attestation: refactoring/renaming
  * appplatform: splitting and renaming the spring cloud service
  * appplatform: updating the spring cloud validator
  * applicationinsights: renaming webtestid
  * applicationinsights: splitting and renaming Component ID
  * appconfiguration: renaming the validate func
  * apimanagement: renaming the LoggerID validate func
  * updated description and note about certificate rotation
  * migrate test for data source geographical location
  * test shim: iot central
  * rename geographical location data source test file
  * migrate test for profile resource and data source
  * rename profile resource and data source test files
  * migrate test for endpoint resource
  * rename traffic manager endpoint resource test filename
  * rename resource and data source files
  * test shim: add RunTestsInSequence and shim role assignment tests (#9570)
  * Update doc for fallback_route of azurerm_iothub (#9550)
  * Update data source doc for sku of azurerm_public_ip (#9549)
  * azurerm_storage_data_lake_gen2_path: Fix error message (#9561)
  * skip vhub tests for IP Configurations and BGP (#9571)
  * golangci-lint: bumping the timeout to 30m
  * generator/resource-id: support for generating ID Validate functions
  * generator/resource-id: handling when a folder does not exist
  * refactor: moving the validate functions into the validate package
  * web: generating the Hybrid Connection ID Parser
  * web: moving the source control token validate func
  * web: moving Hybrid Connection into parsers
  * web: updating hybrid connection to match the generated names
  * web: removing an unused validate func
  * web: generating the Certificate ID
  * web: moving Certificate into parsers
  * web: removing the unused validate func
  * web: generating the ID Formatters/Parsers for Certificate Order
  * web: updating Certificate Order to match the pattern
  * web: fixing a broken refactor
  * web: generating the App Service Slot ID Formatter/Parser
  * web: moving App Service Slot into the parser
  * web: generating the ID for App Service Plan
  * web: generating an ID Parser for Function App
  * web: generating the App Service Environment parser
  * web: generating the ID parser for App Service
  * web: generating the function app slot parser
  * web: generating the ID parser for slot_virtual_network_swift_connection
  * web: generating virtual_network_swift_connection
  * web: updating to use the generated names
  * web: updating to use the generated names
  * servicebus: regenerating using the latest generator
  * servicebus: generating the Resource ID Formatters/Parsers
  * servicebus: ditching the ServiceBus prefix
  * servicefabricmesh: regenerating using the latest generator
  * servicefabric: regenerating using the latest generator
  * servicefabricmesh: switching to generating the resource id formatters/parsers
  * servicefabricmesh: updating to use the generated resource names
  * servicefabric: generating the resource id formatters/parsers
  * servicefabric: renaming `ServiceFabricCluster` to `Cluster`
  * signalr: regenerating with the latest generator
  * signalr: switching to use a generated resource id formatter/parser
  * signalr: updating to use the generated names
  * sql: regenerating using the latest generator
  * validate: removing the unused DatabaseID function
  * r/sql_administrator: switching to use the generated Parse function
  * sql: generating the Resource ID Formatter/Parser for AD Administrator
  * r/sql_elasticpool: refactoring to remove the crashes
  * r/sql_elasticpool: switching to use the ID Parser
  * sql: generating an ID Parser for ElasticPool
  * r/sql_failover_group: switching to use the ID Parser
  * sql: generating the ID Formatter/Parser for Failover Group
  * sql: switching to use the ID Parser for VirtualNetworkRule
  * sql: generating the VirtualNetworkRule Resource ID formatter/parser
  * r/sql_firewall_rule: switching to use the formatter/parser func
  * sql: generating a Resource ID Formatter/Parser for FirewallRules
  * r/sql_server: refactoring to use the ID Formatter/Parser
  * sql: generating the Resource ID for SQL
  * sql: generating the Resource ID Formatter/Parser for Database
  * sql: updating to use the generated resource id names
  * storage: regenerating
  * storage: fixing the build errors from signature changes
  * storage: generating the Resource ID Formatters/Parsers
  * storage: updating to use the generated names
  * synapse: updating with the latest generator changes
  * synapse: fixing the build
  * synapse: generating the remaining Resource ID formatters/parsers
  * synapse: removing the `Synapse` prefix
  * synapse: removing the nested workspace object
  * synapse: renaming Workspace
  * synapse: renaming the Sql Pool parser
  * synapse: renaming the Spark Pool parser
  * synapse: fixing the build
  * synapse_role_assignment: updating to match the pattern
  * synapse: generating the Firewall Rule ID Formatter/Parser
  * synapse: refactoring Firewall Rule to match the generated pattern
  * resource-ids: regenerating to include the updated ResourceID/Subscription logic
  * generator/resource-id: validating the Subscription ID and Resource ID aren't empty if required
  * resources: generating the Resource ID Formatters/Parsers
  * resources: updating the types to match the upcoming generated names
  * tools: adding goimports to `make tools`
  * generator/resource-id: refactor to use ioutil.TempFile instead of custom file name generation
  * fix acctest errors introduced by test shimming
  * updating to include #9532
  * postgresql: bug fixing from acctests
  * postgresql/database: updating to use the ID Parser
  * postgres: switching to use a generated Resource ID Parser
  * postgresql: switching to generate the Configuration ID & adding enhanced import validation
  * postgresql: adding enhanced import validation to `azurerm_postgresql_firewall_rule`
  * postgres: generating a Resource ID Parser for Firewall Rule
  * postgresql_virtual_network_rule: support for enhanced import validation
  * postgresql_virtual_network_rule: switching to use the ID Parser
  * postgres: generating a resource id parser for virtual network rule
  * postgresql_server_key: switching to use a generated Resource ID Func
  * postgresql_server: switching to use a generated resource id func
  * postgres: renaming to match the generated type names
  * updating to include #9530
  * updating to include #9529
  * Update CHANGELOG.md for #9524
  * `azurerm_keyvault_certificate` - add `3072` to allowed values (#9524)
  * r/databricks_workspace: switching to use the RG Parser directly
  * r/cosmosdb_account: switching to use the ID Parser
  * r/application_insights_web_test: switching to use the Component ID directly
  * update CHANGELOG.md for #9522
  * r/cdn_profile: using the parse method during the delete
  * azurerm_traffic_manager_profile - allow upto `2147483647`for the `ttl` property (#9522)
  * search: generating the Service Resource ID Formatter/Parser funcs
  * test shim: automation service (#9511)
  * test shim: blueprints (#9514)
  * test shim - databricks (#9521)
  * cdn: update test names (#9515)
  * test shim: cognitive (#9517)
  * rename custom provider functions (#9519)
  * powerbi_embedded: switching to use a generated Resource ID func
  * powerbi: refactoring
  * r/dashboard: support for enhanced import validation
  * portal: refactoring dashboard to use the id parser
  * portal: generating the Dashboard ID Parser
  * r/notification_hub_namespace: enhanced import validation
  * r/notification_hub_authorization_rule: enhanced import validation
  * r/notification_hub_authorization_rule: switching to use the ID Parser
  * notificationhubs: adding a ID Parser for Notification Hub Authorization Rule
  * r/notification_hub_namespace: switching to use the ID Parser
  * notificationhubs: generating a parser for Namespace
  * notificationhub: generating the resource id parser
  * removing the unused subscriptionId param
  * normalize function names in some A services (#9512)
  * privatedns: generating the resource id funcs
  * network: fixing the build
  * network: VPN -> Vpn for consistency
  * network: generating the VPN Site & VPN Site Link ID parsers
  * network: generating the VPN Connection/Gateway ID Parsers
  * network: splitting VPN Site & VPN Site link
  * network: splitting VPN Gateway/VPN Connection & renaming to match the generated type name
  * network: generating the Virtual WAN ID Parser
  * network: generating the Security Partner Provider ID parser
  * network: ditching the Virtual Hub prefix from Security Partner Provider
  * network: generating the Virtual Hub Route Table ID Parser
  * network: virtual hub route table -> hub route table to match the generated name
  * network: generating the Virtual Hub IP Configuration parser
  * network: updating the virutal hub id parser to match the generated name
  * network: generating the Hub Virtual Network Connection ID Parser
  * network: fixing the build and/or adding placeholders to do so
  * network: updating virtual hub connection to match the upcoming generated parser name
  * network: generating the BGP Connection ID Parser
  * network: generating the Virtual Hub ID parser
  * network: generating the Virtual Network Resource ID Parser
  * network: generating the Subnet ID
  * netowrk: generating the route filter id parser
  * route filter: updating the struct name to match the upcoming generated type
  * network: generating the Public IP Address parser
  * PublicIPAddress -> PublicIpAddress to match the generated type name
  * generator/resource-ids: handling `sses` as a suffix
  * network: generating the private endpoint parser
  * network: splitting the Private DNS package out from the Network Parser
  * network: generating the ID Parser/Formatter for NICs
  * network: generating the ID Group parsers
  * network: moving the Route Filter parser into the parse package
  * network: moving the IP Group parser up
  * network: generating the Packet Capture parser
  * network: renaming the Packet Capture parser to match the generated name
  * network: switching to generate the Connection Monitor/Network Watcher parsers
  * network: renaming the Connection Monitor struct to match the generated name
  * network: generating the NAT Gateway Resource ID Formatter/Parser
  * network: fixing the load balancer resources
  * network: generating the Load Balancer ID Formatters & Parsers
  * network: renaming the Load Balancer parsers to match the generated names
  * network: generating the Resource ID Funcs for Firewall Policy
  * network/firewall_policy_rule_collection: updating to match the generated names
  * network: splitting firewall policy into two files
  * netapp: fixing the refactor
  * netapp: switching to use a generated ID Formatter/Parser func
  * netapp: updating to use the generated names
  * synapse: linting
  * Update document for azurerm_monitor_diagnostic_setting (#9516)
  * update resource/datasource function names
  * fix rg name
  * test shim: batch service
  * fix CHANGELOG.md typo
- from version 2.38.0
  * cleanup CHANGELOG.md for release
  * update CHANGELOG.md for #9308
  * support multiple Radius Server for vpn_server_configuration_resource (#9308)
  * mysql: switching to use generated resource ids
  * mysql: ditching the `MySql` prefix
  * mssql: fixing up the refactoring misses
  * mssql: generating the resource ids
  * mssql: updating the other resource id parsers to match the upcoming generated names
  * mssql/recoverable_database: renaming to match the generated names
  * mssql/elastic_pool: ditching the prefix/updating the field names
  * mssql/database_extended_auditing_policy: switching to use the upcoming generated names
  * mssql/database: renaming to match the upcoming generated fields
  * mssql: splitting out the ID Parsers to one file per type
  * msi: switching to use a generated resource id
  * msi: renaming the id parser
  * monitor: switching to use a generated resource id func
  * monitor: ditching the `monitor` prefix from the files
  * mixedreality: generating the resource ids funcs for Spatial Anchors Account
  * media: generating the resource ids
  * media: media service account -> media service
  * mariadb/server: switching to use the generated resource id func
  * mariadb: updating to use the generated name
  * maps: switching to use a generated resource id func
  * maps: moving validation into a validate package
  * maps/account: ditching the Maps prefix
  * managedapplications: switching to use a generated resource id func
  * managedapplications: ditching the prefix
  * logic: generating the Resource ID Formatter/Parser funcs
  * logic: renaming to integration account
  * kusto: switching to use generated resource ids
  * kusto/data_connection: making the resource id more generic since this isn't limited to EventHub
  * kusto_database_principal_assignment: ditching the Kusto prefix & updating the field names
  * kusto/database_principal: ditching the Kusto prefix & updating to use the generated field names
  * kusto/database: updating to use the generated field names
  * kusto_attached_database_configuration: renaming since this is a resource
  * kusto_attached_database_configuration: switching to use the generated field names
  * kusto_cluster_principal_assignment: updating to use the generated field names
  * kusto/clusterPrincipalAssignment: ditching the Kusto prefix
  * kusto/AttachedDatabaseConfiguration: removing the Kusto prefix
  * kusto/database: ditching the Kusto prefix
  * kusto/cluster: ditching the `Kusto` prefix on the Cluster ID
  * iottimeseriesinsights: fixing the refactor
  * keyvault: generating the `vault` id parser
  * keyvault: renaming `KeyVaultId` to `VaultId` since we're in this package
  * keyvault/certificate_issuer: renaming the resource id structs
  * iottimeseriesinsights: switching to use a generated resource id
  * iottimeseriesinsights/reference data set: ditching the `timeseriesinsights` prefix
  * timeseriesinsights/environment: ditching the 'timeseriesinsights' prefix
  * time_series_insights_access_policy: ditching the `timeSeriesInsights` prefix
  * iothub: switching to use a generated resource id
  * iothub: renaming to match the upcoming generated output
  * iotcentral/application: switching to use a generated resource id
  * iotcentral: updating to match the generated names
  * dependencies: updating to v0.15.0 of github.com/tombuildsstuff/giovanni
  * Update CHANGELOG.md for #9378
  * roleassignment: moving the tests up a level
  * New Resource: azurerm_app_service_managed_certificate (#9378)
  * Refactor role definition tests
  * refactor client config test
  * updating to include #9495
  * updating to include #9493
  * parsers: regenerating to add documentation
  * desktopvirtualization: switching to use the Insensitive option where appropriate
  * desktopvirtualization: removing the dependency on SubscriptionId
  * desktopvirtualization: generating the insensitive resource id funcs
  * generator/resource-id: support for conditionally generating insensitive parsing functions
  * desktopvirtualization: patching the Resource ID's
  * updating to include #9261
  * Update CHANGELOG.md for #9485
  * cosmosdb: DatabaseAccounts -> databaseAccounts
  * Fix Cosmos zone redundant update (#9485)
  * New Data Source azurerm_virtual_wan (#9382)
  * teamcity: limiting the appplatform concurrent runs to 5
  * Refactor: Migrate cdn tests (#9433)
  * spring_cloud: exposing the IP's at the top level `outbound_public_ip_addresses`
  * check all fields nil and return `[]interface{}{}` in flatten func
  * move "outbound_ip" to the top level
  * azurerm_spring_cloud_service - support computed `outbound_ips` block
  * Update validation rule for allowed_ips of azurerm_search_service
  * update CHANGELGO.md for #9432
  * Update `azurerm_windows_virtual_machine` - Default value of `patch_mode` no longer requires feature enabling (#9432)
  * update CHANGELOG.md for #9382
  * update CHANGELOG.md for #9330
  * add field for virtual network gateway and virtual network gateway connection (#9330)
  * Updates Zone redundancy default value (#9486)
  * hsm: switching to use a generated id formatter
  * hpccache: switching to use a generated resource id func
  * hpccache: updating to match the generated names
  * healthcare: generating the resource id funcs
  * healthcare: ditching the healthcare prefix
  * eventhub: switching to use generated resource id funcs
  * eventgrid: switching to use the generated resource id funcs
  * eventgrid: ditching the EventGrid prefix
  * dns/ns: fixing a missing refactor
  * dns/a: switching to use a generated resource id func
  * dns/a: updating to use the generated property names
  * dns/aaaa: switching to use the generated resource id funcs
  * dns/aaaa: updating to use the generated names
  * dns/caa: switching to use the generated id funcs
  * dns/caa: updating to use the generated property names
  * dns/cname: switching to use a generated id func
  * dns/cname_record: switching to use the generated property name
  * dns/mx_record: switching to use the generated id funcs
  * dns/mx_record: switching to use the generated property names
  * dns/ns_record: generating the resource id functions
  * dns/ns_record: updating to use the generated property names
  * dns/ptr_record: switching to use a generated id func
  * dns/ptr_record: updating to use the generated property names
  * dns/srv_record: switching to use a generated id formatter/parser
  * dns/srvRecord: renaming to match the upcoming generated approach
  * dns/txt: switching to use a generated resource id
  * dns/txt_record: refactoring to use the new names
  * dns/zone: switching to use a generated resource id formatter/parser
  * digitaltwins: switching to use a generated ID Formatter/Parser
  * desktopvirtualization: fixing the build
  * devtestlabs/schedule: switching to use the generated resource id formatter/parser
  * devtestlabs: global schedule -> schedule
  * devtestlabs: consolidating to a single Virtual Machine ID parser
  * devspace: switching to use the generated Controller Resource ID formatter/parser
  * devspace: ditching the `DevSpace` prefix
  * desktopvirtualization: generating the Resource ID's
  * desktopvirtualization: ditching the `Desktop Virtualization` prefix
  * datashare: fixing the build
  * datashare/shares: generating the Resource ID Funcs
  * datashare/data_set: switching to use a generated ID Format
  * datashare/account: switching to use the generated ID Func
  * datashare: ditching the `DataShare` prefix on Resource ID's
  * datalake_account: switching to use a generated resource id
  * datalake: renaming to be `Account` since that's what it is
  * datafactory/integrationRuntime: updating to use a generated id
  * datafactory/integration_runtime: updating to use the generated field names
  * datafactory/linked_service: generating the resource id functions
  * datafactory/linkedservice: updating to use the generated terminology
  * compute: updating `GalleriesName` to `GalleryName`
  * generator/resource-id: fixing the `ies` -> `y` problem
  * databricks/workspace: switching to use a generated resource id formatter/parser
  * databricks: renaming the workspace struct/file
  * databasemigration: switching to use a generated Resource ID Formatter/Parser
  * databasemigration: ditching the `DatabaseMigration` prefix, since we're in that package
  * customproviders/resource-provider: switching to use a generated resource id formatter/parser
  * customproviders/resource-provider: renaming the id struct to match the type
  * cosmosdb: fixing the method name, apparently refactor missed it
  * cosmosdb/table: switching to use a generated resource id formatter/parser
  * cosmosdb/table: updating to use the upcoming generated field names
  * cosmos/sql_stored_procedure: switching to use a generated resource id formatter/parse function
  * cosmos/sql_stored_procedure: updating to use the upcoming generated field names
  * cosmos/sql_container|database: switching to use a generated Resource ID Formatter/Parser
  * cosmosdb: updating the property names for cosmosdb_sql_database & container
  * cosmos/mongodb_database: switching to use a generated Resource ID Formatter/Parser
  * cosmos/mongodb_database: updating to use the upcoming generated field names
  * cosmos/mongodb_collection: generating the MongoDB Collection ID Formatter/Parser
  * Update changelog for #7603
  * cosmos/mongodb_collection: switching to use the upcoming generated field names
  * `azurerm_api_management` fix to pass all acctests (#7603)
  * cosmosdb/gremlin_graph: switching to use a generated resource id formatter/parser
  * cosmosdb/gremlin_graph: renaming the fields to match the upcoming generated version
  * cosmosdb/gremlin_database: switching to use a generated id formatter/parser
  * cosmosdb/cassandra_keyspace: switching to use a generated id formater/parser
  * cosmos: generating the ID Format/Parse functions for Database Account
  * cosmos: renaming `databaseAccount` to match the filename
  * maintainence: fixing the test case
  * missed a couple of indirect references
  * virtualMachineScaleSetExtension: switching to use a generated resource id formatter/parser
  * virtualMachineScaleSet: switching to use a generated resource id formatter/parser
  * virtual_machine_extension: switching to use a generated resource id formatter/parser
  * virtual-machine: switching to use a generated id formatter/parser
  * shared_images: switching to use generated resource id formatters/parsers
  * proximity_placement_group: switching to use a generated resource formatter/parser
  * managed_disk: switching to use a generated id formatter/parser
  * images: switching to use a generated id formatter/parser
  * disk_encryption_sets: switching to use a generated id formatter/parser
  * dedicated_host_group: switching to use the generated ID Formatters/parsers
  * dedicated_host: switching to use a generated resource id formatter/parser
  * availability_set: generating the id formatter/parser
  * sdk/console: prefixing the debug lines with info/warn
  * Update azurerm/internal/sdk/resource_encode.go
  * Update to include #9430
  * build: missed a reference in batch application
  * Fix for #9212
  * cognitive: regenerating & updating
  * cdn: regenerating & updating
  * batch: regenerating & fixing up
  * automation: regenerating & updating to match
  * applicationinsights: regenerating & updating
  * appconfiguration: regenrating & updating
  * analysisservices: regenerating & updating
  * generator/resource-id: using `Name` when the type name matches the key name
  * updating to include #9446
  * removing an unused param
  * containers: switching to use the generated ID Formatter/Parser
  * r/kubernetes_cluster: renaming the cluster id validate helper too
  * r/kubernetes_node_pool: switching to use the terms used by the generated id
  * r/kubernetes_cluster: switching to use the terms used by the Generated Resource ID Formatter/Parser
  * cognitive: switching to use a generated Resource ID Formatter/Parser
  * cognitive: switching to use the upcoming generated terminology
  * refactor missed a couple of constructors
  * cdn: generating the resource id formatters/parsers
  * endpoint: refactoring to use the upcoming generated terms
  * cdn_profile: renaming to match the upcoming generated terms
  * batch: generating the resource id formatters/parsers
  * r/batch_pool: switching to use the generated terms
  * r/batch_certificate: switching to use the generated terms
  * r/batch_application: updating the id formatter/parser to use the generated terms
  * r/batch_account: updating the formatter to matching the generated terms
  * r/automation_connection: generating the resource id formatter/parser
  * r/application_insights_web_test: fixing the build now the generator is fixed
  * generator/resource-id: fixing an issue when a type name ends in '_test'
  * automation_connection: updating to use the generated field names
  * r/application_insights_web_test: generating the resource id formatter/parser function
  * applicationinsights: generating the web test id parser/formatter
  * attestation: switching to use generated Resource ID Formatters/Parsers
  * d/application_insights: switching to use the id formatter
  * r/application_insight: adding enhanced import validation
  * r/application_insights: generating the ID formatter and parser
  * appconfiguration: switching to use the generated ResourceID formatters/parsers
  * springcloud: switching to use the id formatters directly
  * r/spring_cloud_service: switching to use the generated ID formatters/parsers
  * r/spring_cloud_certificate: switching to use a generated resourceId formatter/parser
  * r/spring_cloud_app: generating the resource id formatters/parsers
  * generator/resource-id: ensuring the argument is always snakeCased
  * tooling: adding a 'this is generated' notice and changing 'expect' to 'expected'
  * analysisservices: generating the resource id parsing funcs
  * toolins: adding a generator for Resource ID Formatters and Parsers
  * Update CHANGELOG.md for #9409
  * Update to API version `2020-06-01` for App Service (#9409)
  * Update app_service.html.markdown
  * refactor custom provider tests
  * rename hcl tag to tfschema tag
  * Update cosmosdb_account.html.markdown
  * update CHANGELOG.md for #9235
  * Add support ipv6 configuration in azurerm_express_route_circuit_peering (#9235)
  * dependencies: adding go-cmp since it's used in the test framework
  * tags: adding support for parsing to/from a typed object
  * provider: hooking up the Typed and Untyped resources
  * SDK: introducing support for Types Data Sources and Resources
  * refactor: moving service registration into the sdk package
  * refactor: moving the Resource Group ID parser/validator into their own package
  * refactor: moving locations out of the SDK package
  * Update to include #9212
  * fix for #9211
- from version 2.37.0
  * update CHANGELOG.md for #9160
  * New resource: azurerm_vpn_gateway_connection (#9160)
  * update CHANGELOG.md for #9236
  * azurerm_cosmosdb_account - support for `public_network_access_enabled` (#9236)
  * updating to include #8894
  * tests: requiresimport doesn't need a provider block
  * storage_encryption_scope: fixing the tests
  * fixing the build
  * tests: refactoring top use types
  * refactor: splitting the tests
  * d/storage_encryption_scope: refactoring from PR review
  * r/storage_encryption_scope: refactoring from PR review
  * storage: switching AccountID to AccountID and ParseAccountID to ParseAccountId to match other resources
  * Update changelog for #9117
  * azurerm_container_group: support for secret volumes (#9117)
  * updating to include #9227
  * r/kubernetes_cluster|node_pool: fixing the tests
  * updating to include #9296
  * updating to include #9272
  * Docs: Change wrong resource name in import section
  * including azurerm_cosmosdb_sql_container for #9050
  * d/servicebus_subscription: fixing a couple of typos in the docs
  * Docs: Use proper resource names in import section
  * d/attestation_provider: fixing the tests
  * updating to include #7521
  * detailing the specific changes
  * updating to include #7786
  * updating to include #8470
  * fixup permissions for individual tests
  * r/storage_blob: force-enabling allow_blob_public_access for now
  * r/storage_blob: changes from code review
  * removed dead code
  * Update website/docs/index.html.markdown
  * Support graceful Linux/Windows VM shutdown
  * Use Rawxml format for global API policies string
  * Update changelog for #9388
  * `azurerm_mssql_virtual_machine` - Fix crash when setting `auto_patching` #9388
  * Add validation for virtual_hub_id/remote_virtual_network_id of azurerm_virtual_hub_connection (#9256)
  * update CHANGELOG.md for #9332
  * azurerm_firewall_policy - deprecate `dns.network_rule_fqdn_enabled` (#9332)
  * Migrate set definition tests
  * update CHANGELOG.md for #9319
  * azurerm_dns_zone & azurerm_private_dns_zone - support for the `soa_record` block (#9319)
  * update CHANGELOG.md for #9259
  * Update `azurerm_policy_set_definition` - Support `policy_definition_group` (#9259)
  * update CHANGELOG.md for #9262
  * Update `azurerm_linux|windows_virtual_machine_scale_set` - Support `platform_fault_domain_count`, `disk_iops_read_write` and `disk_mbps_read_write` (#9262)
  * fixed format issue
  * changes incorporated based on feedback
  * Kt/test shim appinsight (#9303)
  * attestation: test shim
  * Fix heading formatting in service principal with secret documentation (#9384)
  * updating to include #9358
  * Test data for azurerm_api_management_policy resource`
  * Update CHANGELOG.md for #9373
  * `azurerm_postgresql_server` increase max storage to 16TiB (#9373)
  * updating to include #9166
  * updating to include #9364
  * doc/r/vd-hostpool: fix typo in BreadthFirst and DepthFirst
  * fix accp test lint
  * Added accp test
  * updating to include #9355
  * apimanagement: fixing the lintignore for now
  * kubernetes: running tests individually by default
  * Update CHANGELOG.md for # 9311
  * `azurerm_cosmosdb_sql_container` doesn't call get throughput api when cosmos account is serverless (#9311)
  * Migrate msi test
  * Resolve comments
  * Update changelog for #9370
  * `azurerm_mssql_database` - `sku_name` supports more `DWxxxc` options #9370
  * Fix of acctest
  * update CHANGELOG.md for #8879
  * azurerm_firewall: support for firewall manager (firewall policy) (#8879)
  * try to retrieve apiVersion for all sub-resources
  * Update CHANGELOG.md for #9257
  * Update `azurerm_linux|windows_virtual_machine` - Support `extensions_time_budget` (#9257)
  * http_application_routing ForceNew removed
  * whitespace commit to check mvn caching works
  * Update CHANGELOG.md for #8946
  * New resources: `azurerm_log_analytics_cluster` and `azurerm_log_analytics_cluster_customer_managed_key` (#8946)
  * fix workflow yaml
  * r/key_vault_certificate: fixing a crash when the certificate policy block is nil
  * d/key_vault_certificate: fixing a crash when the certificate policy block is nil
  * Update CHANGELOG.md for #8781
  * Adds new resource azurerm_security_center_automation for automation and data export (#8781)
  * add cache for mvn
  * fix path filtering
  * add target and workflow to check tc
  * Some fix for data source
  * update CHANGELOG.md for #9258
  * Update `azurerm_windows_virtual_machine` - Support `patch_mode` (#9258)
  * Migrate acceptance tests of ML
  * Update of exists and migrate remediation tests
  * Resolve cyclic reference issue
  * Migrate policy definition resource and data source test
  * A try on migrating to new style of acceptance tests
  * Migrate test of policy assignment
  * updating to include #9050
  * adding #9050
  * update CHANGELOG.md for #9264
  * Update `azurerm_linux|windows_virtual_machine` - make `dedicated_host_id` updatable (#9264)
  * storage: fixing changes since the shim layer was merged
  * Fixup references
  * rebase, storage SDK bump and remove unused function
  * Initial PR feedback
  * Run  for new dependencies
  * Update docs for ACLs
  * Fixup test destroy check
  * make terrafmt
  * Initial Update implementation
  * Add more ACL tests
  * Add owner,group,ace properties
  * Add docs
  * Add import
  * Add delete
  * Add skeleton
  * updating to include #9314
  * This line can be removed now that the service is GA as of 14/02/20
  * run code through gofumpt and add makefile step (#9275)
  * Typo fix #9172
  * Tidy changelog entry for #9172
  * Update changelog for #9172
  * Support for additional arguments on azurerm_api_management_api_diagnostic (#9172)
  * Updates time zone description (#9324)
  * updated with possible values for time zone (#9325)
  * Update thirty-two-bit.yaml
  * `azurerm_api_management_custom_domain` - Add exception for R001 lint rule (#9298)
  * Fix typo in azurerm_redis_linked_server docs (#9299)
  * make fmt
  * fix tests
  * minor titdying
  * datasource
  * resource
  * move tests
- from version 2.36.0
  * build: fixing the build on 32 bit systems (#9293)
  * fixing a missing _azurerm
  * Rebase, resolve conflicts
  * Really set default now
  * Add os_disk_type to main nodepool resource
  * rename for consistency
  * Update website/docs/r/kubernetes_cluster_node_pool.html.markdown
  * Update azurerm/internal/services/containers/kubernetes_nodepool.go
  * Update azurerm/internal/services/containers/kubernetes_nodepool.go
  * Update azurerm/internal/services/containers/kubernetes_cluster_node_pool_data_source.go
  * Rebase, resolve conflicts
  * storage: removing the resourcemanager shim for now, until the API is compatible
  * r/storage_table: fixing a crash
  * updating to include #9195
  * updating to include #9281
  * updating to include #9279
  * Update CHANGELOG.md for #9233
  * Add health_check_path to function_app site_config (#9233)
  * Fix formatting (add missing backtick)
  * Fix documentation: link to App Service Certificate examples
  * r/storage_table: introducing a shim layer
  * Update CHANGELOG.md for #9282
  * `azurerm_logic_app_workflow` added logicapp name validation (#9282)
  * r/storage: adding a shim for Shares
  * Update index.html.markdown
  * r/storage_share: adding a shim layer
  * refactor: removing duplicated code
  * r/storage_share: moving the validate function to the validate package
  * r/storage_queue: adding a shim layer
  * r/storage_container: switching to use the new parse function everywhere
  * r/storage_queue: moving the validation function out
  * renaming the package
  * added validation for eventgrid resources
  * added vvset name validation
  * testshim: analysisservices (#9274)
  * renaming the parsers package to parse to match the other services
  * storage/containers: adding a shim covering resource manager and data plane
  * storage: renaming the parsers
  * Update CHANGELOG.md
  * linting: remove old travis config & make steps (#9273)
  * fixed format issues
  * fix format issue
  * rebase and small tweaks from manual testing
  * fixed format issues
  * string termination fixed
  * modified azurerm.erb file
  * added data source azurerm_servicebus_subscription
  * Updated the storage container access from private to blob
  * Added test
  * Removed Computed from the content_md5 field
  * Updated doc and added validation for blob type page and append
  * Adds functionality to update blob based on content_md5 property
  * Update CHANGELOG.md for #8919
  * Adds CMK for CosmosDB Account (#8919)
  * Update changelog for #8228
  * New resource: `azurerm_api_management_custom_domain` (#8228)
  * Update the example of azurerm_powerbi_embedded
  * update CHANGELOG.md for #9033
  * add fields to loganalytics workspaces (#9033)
  * update CHANGELOG.md for #9229
  * New datasource `azurerm_traffic_manager_profile` (#9229)
  * update CHANGELOG.md for #9251
  * Add v5.0 dotnet_framework_version to app_service validation (#9251)
  * Remove the preview information for managed property of azurerm_kubernetes_cluster
  * spelling (#9250)
  * Docs overview grammatical changes (#9242)
  * update CHANGELOG.md for #8640
  * Guides-2.0-upgrade-guide grammatical changes (#9249)
  * Guides-migrating-between-renamed-resources grammatical changes (#9248)
  * Guides-Azure CLI grammatical changes (#9247)
  * Guides-service_principal_client_secret grammatical changes (#9246)
  * Guides-service_principal_client_certificate grammatical changes (#9244)
  * Guides-Azure Active Directory-Migrating to the AzureAD Provider grammatical changes (#9243)
  * Upgrade network connection monitor from v1 to v2 (#8640)
  * update CHANGELOG.md for #9158
  * azurerm_point_to_site_vpn_gateway - support `route` block (#9158)
  * update CHANGELOG.md for #9035
  * azurerm_vpn_gateway - support block "bgp_peering_addresses" (#9035)
  * update CHANGELOG.md for #9228
  * `log_analytics_workspace` - exclude `Free` from `daily_quota_gb` settings (#9228)
  * update CHANGELOG.md for #9032
  * new resource "azurerm_monitor_smart_detector_alert_rule" (#9032)
  * Update CHANGELOG.md for #9014
  * New Resource: `azurerm_log_analytics_storage_insights` (#9014)
  * Update CHANGELOG.md for #9187
  * `azurerm_cosmosdb_sql_database` doesn't call get throughput api when cosmos account is serverless (#9187)
  * Raise limits for max_count/min_count/node_count of azurerm_kubernetes_cluster_node_pool/azurerm_kubernetes_cluster
  * Add proximity_placement_group_id to main resource as well
  * update CHANGELOG.md for #9210
  * Update `azurerm_policy_remediation` - support `resource_discovery_mode` (#9210)
  * update CHANGELOG.md for #8959
  * New resource: `azurerm_virtual_hub_bgp_connection` (#8959)
  * update CHANGELOG.md for #8544
  * New resource/data source `azurerm_data_share_dataset_kusto_database` (#8544)
  * updating to include #9213
  * dependencies: upgrading to v48.1.0 of github.com/Azure/azure-sdk-for-go
  * updating to include #9182 & formatting
  * updating to include #9202
  * docs: add ip_address property to azurerm_public_ips
  * Allow OS disks up to 4095GB
  * updating to include #8814
  * allow azurerm_linux_virtual_machine_scale_set computer_name_prefix to end with dashes
  * update CHANGELOG.md for #8979
  * azurerm_virtual_network: support for `bgp_community` and `vnet_protection_enabled` (#8979)
  * updating to include #9192
  * Fix acceptance test
  * r/storage_share: updating to use the new input struct
  * dependencies: vendoring API version 2019-12-12 of github.com/tombuildsstuff/giovanni
  * storage: bumping the tombuildsstuff/giovanni api version to 2019-12-12
  * Update website/docs/d/kubernetes_cluster_node_pool.html.markdown
  * Update website/docs/r/kubernetes_cluster_node_pool.html.markdown
  * Update azurerm/internal/services/containers/kubernetes_nodepool.go
  * Update azurerm/internal/services/containers/kubernetes_cluster_node_pool_data_source.go
  * Update azurerm/internal/services/containers/kubernetes_nodepool.go
  * updating to include #9191
  * Add `proximity_placement_group_id` to AKS node pools
  * build: missed the test path
  * provider: code changes needed for the go-azure-helpers upgrade
  * dependencies: upgrading github.com/hashicorp/go-azure-helpers to v0.13.0
  * updating to include #9189
  * dependencies: vendoring v0.14.0 of github.com/tombuildsstuff/giovanni
  * updating to include #9168
  * updating to include #9167
  * dependencies: upgrading github.com/Azure/go-autorest/autorest/azure/cli to v0.4.2
  * dependencies: upgrading to v48.0.0 of github.com/Azure/azure-sdk-for-go
  * updating to include #9165
  * update CHANGELOG.md for #8978
  * New resource: `azurerm_virtual_hub_security_partner_provider` (#8978)
  * update CHANGELOG.md for #8917
  * Update `azurerm_linux|windows_virtual_machine` and `azurerm_linux|windows_virtual_machine_scale_set`
  - Support managed boot diagnostics (#8917)
  * dependencies: upgrading to v47.1.0 of github.com/Azure/azure-sdk-for-go
  * updating to include #9163
  * Update validation rule for route_table_ids of azurerm_virtual_hub_connection (#9159)
- from version 2.35.0
  * dependencies: vendoring the remaining changes from v47.0.0 of github.com/Azure/azure-sdk-for-go
  * servicefabric: vendoring the rename
  * policyinsights: vendoring the rename
  * hdinsight: vendoring the rename
  * cosmosdb: vendoring the rename for v47.0
  * hdinsight: handling the breaking change in v47.0 of the Azure SDK
  * policyinsights: handling the breaking change in v47.0 of the Azure SDK
  * servicefabric: handling the breaking change in v47.0 of the Azure SDK
  * cosmosdb: updating the import path to match the breaking change in v47.0 of the Azure SDK
  * dependencies: upgrading to v47.0.0 of github.com/Azure/azure-sdk-for-go
  * updating to include #8982
  * Update CHANGELOG.md for #9100
  * fix synapse endpoint not available issue in other cloud (#9100)
  * update CHANGELOG.md for #8963
  * `azurerm_postgresql_firewall_rule` - add validation for `start_ip_address` and `end_ip_address` (#8963)
  * Update changelog for #8878
  * Update CHANGELOG.md for #8673
  * `azurerm_cosmosdb_mongo_database` doesn't call get throughput
    api when cosmos account is serverless (#8673)
  * add default value for node_taints back
  * updating to include #9129
  * updating to include #9057
  * r/iot_time_series_insights_access_policy: adding missing schema version
  * iottimeseriesinsights: adding a state migration
  * timeseriesinsights: fixing the build
  * dependencies: upgrading timeseriesinsights to 2020-05-15 GA
  * d|r/data_share: fixing a stackoverflow issue
  * Revert Computed for availability_zones for now
  * d/data_share: handling a crash when item is nil
  * r/data_share: handling a crash when the item is nil
  * update CHANGELOG.md for #8939
  * Add new resource azurerm_virtual_hub_route_table (#8939)
  * Update CHANGELOG.md for #9125
  * `azurerm_key_vault_access_policy` - check access policy consistency
    before committing to state (#9125)
  * Remove obsolete property from a test
  * d/data_share: fixing tests:
  * linting: updating the todo
  * r/resource_group: updating the existing syntax
  * d/advisor_recommendations: updating the existing syntax
  * test-framework: introducing a shim layer for Binary Testing
  * r/virtual_desktop_workspace_application_group_association: case insensitivity bug
  * r/data_share: exporting all of the schedules
  * d/data_share: removing the limitation that a schedule has to exist
  * desktopvirtualization: fixing the host pool id/adding validation
  * r/storage_sync_group: fixing the data source to error when missing
  * d/data_share: fixing the data source
  * r/virtual_desktop_workspace_application_group_association: fixing the format string
  * r/virtual_desktop_workspace: refactoring to use the correct timeouts and locking to match the association resource
  * r/virtual_desktop_workspace_application_group_association: refactoring and adding an ID parser
  * r/virtual_desktop_host_pool: refactoring
  * r/virtual_desktop_application_group: switching to use the ID formatter
  * update CHANGELOG.md for #8912
  * New resource:  `azurerm_virtual_hub_ip_configuration` (#8912)
  * `azurerm_devspace_controller` - Adding note that Microsoft is retiring the Dev Space resource (#9148)
  * update CHANGELOG.md for #8950
  * azurerm_virtual_hub_connection - support the `routing` block (#8950)
  * Address feedback part 1
  * Update role definition docs to include `role_definition_resource_id` (#9131)
  * Update changelog for #8938
  * `azurerm_data_factory_linked_service_data_lake_storage_gen2` - Supports managed identity auth through `use_managed_identity ` (#8938)
  * remove throttling from go linting (#9109)
  * Update changelog for #8629
  * New data source `azurerm_images` (#8629)
  * Update azurerm/internal/services/containers/kubernetes_addons.go
  * Update azurerm/internal/services/containers/kubernetes_addons.go
  * remove last use of NoEmptyStrings (#9089)
  * Update changelog for #8603
  * new resource: azurerm_firewall_policy_rule_collection_group (#8603)
  * reduce triggers to open and change to PR source branch (#9108)
  * resolving linting issues (#9106)
  * better explaination on auto_provision setting
  * adds docs for security_center_auto_provisioning
  * Update CHANGELOG.md
- from version 2.34.0
  * r/vpn_site: fixing the build on 32 bit platforms
  * update CHANGELOG.md for #8773
  * New data source: azurerm_cognitive_account (#8773)
  * update CHANGELOG.md for #9077
  * Update CHANGELOG.md for #9078
  * `azurerm_policy_definition` resource and datasource can now look up builtin policy by name (#9078)
  * Update CHANGELOG.md for #8617
  * Update private_dns_zone_virtual_network_link_resource.go (#8617)
  * Add tflint ignores (#9081)
  * Update CHANGELOG.md for #8829
  * Add timezone logic app recurrence (#8829)
  * Update CHANGELOG.md for #8822
  * `azurerm_backup_policy_vm` support `instant_restore_retention_days` property (#8822)
  * Fixed bug when deleting a policy
  * Update CHANGELOG.md for #9068
  * `azurerm_private_endpoint` - fix crash when deleting private endpoint (#9068)
  * update CHANGELOG.md for #9048
  * `azurerm_log_analytics_solution` - add support of `tags` (#9048)
  * simplify the `dns_settings` to `dns_servers`
  * update CHANGELOG.md for #9030
  * ISSUE Fixed: azurerm_virtual_desktop_application_group name allowed length is 3-31, should be 1-260 #8980 (#9030)
  * Validate source_image_reference values (#9055)
  * remove travis
  * update CHANGELOG.md for #9034
  * Update website/docs/r/log_analytics_saved_search.html.markdown
  * Update azurerm/internal/services/loganalytics/tests/log_analytics_saved_search_resource_test.go
  * Update azurerm/internal/services/loganalytics/tests/log_analytics_saved_search_resource_test.go
  * update CHANGELOG.md for #8998
  * Update website/docs/r/local_network_gateway.html.markdown
  * Update website/docs/r/local_network_gateway.html.markdown
  * Update azurerm/internal/services/network/tests/local_network_gateway_resource_test.go
  * backfilling the changelog content from 0.1 - 1.6
  * Update log_analytics_saved_search_resource.go
  * change tag to use tags.ForceNewSchema()
  * change the test to verify updatability
  * Remove outboundUDR test, since UDR is not allowed on MIS-enabled clusters
  * Do not add route_table to a cluster with managed identity as it's no longer supported
  * Disable check for azure_policy.version as it seems to not be returned anymore
  * Remove docs about enable_pod_security_policy as it has been deprecated on Oct 15, 2020
  * Make a few fields computed
  * Fixing some of the tests, removed node_taints from default node pool
  * go mod tidy
  * Upgrade containerservice API to 2020-09-01
  * update CHANGELOG.md for #9002
  * New Resource: `azurerm_log_analytics_linked_storage_account` (#9002)
  * update CHANGELOG.md for #8896
  * new resource: azurerm_vpn_site (#8896)
  * fixed Destop Virtualization refs (#9041)
  * Add GH Actions for linting and unit testing (#9036)
  * update CHANGELOG.md for #8863
  * new resource for `azurerm_synapse_role_assignment` (#8863)
  * update CHANGELOG.md for #8498
  * azurerm_automation_module - expose error message (#8498)
  * update CHANGELOG.md for #8937
  * azurerm_key_vault - supports "contact" block (#8937)
  * updating to include #8993
  * Update CHANGELOG.md for #8595
  * Adds new resource for azurerm_security_center_auto_provisioning (#8595)
  * add fields to loganalytics saved search
  * Bump junit from 4.13 to 4.13.1 in /.teamcity
  * Update changelog for #7924
  * `azurerm_container_group` - add support for `volume.x.git_repo`  (#7924)
  * update CHANGELOG.md for #8032
  * azurerm_iothub - support for the `endpoint.resource_group` property (#8032)
  * Update api_management_authorization_server.html.markdown
  * r/virtual_desktop_host_pool: `validation_environment`-> `validate_environment`
  * Doc Fix: Front Door names must be globally unique and hostname reqs are accurately defined (#9017)
  * Updating to include #8610
  * fixes #1109
  * updating to include #8995
  * adding support for log analytics data export #8995
  * `azurerm_cosmosdb_account` support `EnableAnalyticalStorage` for the `capabilities` property (#9010)
  * update CHANGElog.md for #8997
  * Fix azurerm_databricks_workspace.name validation (#8997)
  * Update changelog for #8983
  * r/key_vault: ensuring the casing on the sku is consistent (#8983)
  * Fix subcategories in docs
  * Update role_definition.html.markdown
  * azurerm_local_network_gateway: support for `gateway_fqdn`
  * Update data_factory_integration_runtime_managed.html.markdown
  * Update changelog for #8619
  * `azurerm_kubernetes_cluster` - `min_count` can be updated when `enable_auto_scaling` is set to true (#8619)
  * update CHANGELOG.md for #7963
  * `azurerm_api_management_api`  `subscription_required` default to `true` (#7963)
  * update CHANGELOG.md for #8861
  * log_analytics_workspace: support for the `daily_quota_gb` property (#8861)
  * update CHANGELOG.md for #8815
  * Update the value property in features block as TypeSet for SignalR Service (#8815)
  * Update changelog for #8957
  * `azurerm_kubernetes_cluster` - Fix issue where `min_count` and `max_count` couldn't be the same (#8957)
  * r/app_service: fixing a crash when provisioning an app service inside an ASE which doesn't exist yet
- from version 2.33.0
  * generator: running make generate
  * updating to include #8975
  * refactor: cleaning up an overzealous aliasing
  * mssql_(database|server): sending the workaround during delete too
  * r/mssql_database_extended_auditing_policy: working around an API regression
  * r/sql_database: working around a broken API
  * r/mssql_database: working around a broken API
  * r/mssql_server_extended_auditing_policy: working around the broken api
  * hpc-cache: splitting out into their own service package
  * r/sql_server: working around a broken api
  * r/mssql_server: working around a broken API
  * Update dns_cname_record FQDN - note: trailing dot
  * Update changelog for #8933
  * New resource: `azurerm_service_fabric_mesh_secret` `azurerm_service_fabric_mesh_secret_value` (#8933)
  * updating to include #8904
  * Now working in dash shell
  * https://github.com/terraform-providers/terraform-provider-azurerm/issues/8942
  * updating to include #8875
  * Simplify identity handling
  * updating to include #8948
  * added mysql firewall start and end IP address validation
  * Added IP address validations for both start and end addresses
  * Send identity type None when clearing it, since API wants it that way
  * update flatten logic in network_rule_collection
  * Remove unused code from flatten
  * Update CHANGELOG.md for #8882
  * Update `azurerm_policy_set_definition` - Fix updates for `parameters` and `parameter_values` (#8882)
  * updating to include #8935
  * Update CHANGELOG.md for #8792
  * Add composite indexes support to CosmosDB SQL container (#8792)
  * Update CHANGELOG.md for #8761
  * Fix ignore_changes behavior for AGW (#8761)
  * DesktopVirtualization replaced with DesktDesktop Virtualization
  * removed extended auditing policy configuration from sql mssql firewall test file
  * Update azurerm/internal/services/appconfiguration/app_configuration_resource.go
  * replacing os_disk_image_size with os_disk_image_size_gb as per Hashicorp's suggestion... Defaulting osDiskImageSize to 0
  * added validation to SQL firewall start and end IP address
  * Adds docs ref for azurerm_eventgrid_system_topic
  * Update changelog for #8838
  * New Resource: `azurerm_service_fabric_mesh_local_network` (#8838)
  * Fix the fixes. Eeturn empty identity block?
  * Update azurerm/internal/services/appconfiguration/app_configuration_resource.go
  * Update azurerm/internal/services/appconfiguration/app_configuration_resource.go
  * Update azurerm/internal/services/appconfiguration/app_configuration_resource.go
  * Update azurerm/internal/services/appconfiguration/app_configuration_resource.go
  * Update azurerm/internal/services/appconfiguration/app_configuration_resource.go
  * fix `container_registry` policy docs
  * Update changelog for #8907
  * `azurerm_search_service` - add support for `identity` #8907
  * update CHANGELOG.md for #8899
  * azurerm_mssql_database - do not set longterm and shortterm retention policies when using the `DW` SKUs (#8899)
  * Example: `azurerm_virtual_desktop_*` (#8844)
  * Fixing the formatting with make fmt now
  * Fixing the formatting...
  * Adding support for os_disk_image_size to get the disk size of the image
  * Actually check for identity present
  * Add more tests
  * azurerm_firewall: supports `dns_setting`
  * Switch identity test to standard sku
  * - add support for identity
  * azurerm_kubernetes_cluster, azurerm_kubernetes_cluster_node_pool
  - make "availability_zones" force new
  * Fix CI
  * Fix typo
  * Enable key rotation for des
* Wed Nov 11 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add symbolic link to comply with new filesystem layout for local provider copies
* Mon Oct 19 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Define and use common Go spec file variables
- Update to version 2.32.0:
  * Update CHANGELOG.md for #8735
  * New Resource: `azurerm_eventgrid_system_topic` (#8735)
  * update CHANGELOG.md for #8698
  * update CHANGELOG.md for #8774
  * Fix azurerm_mysql_server example
  * Update changelog for #8787
  * New data source: azurerm_mysql_server (#8787)
  * Update changelog for #8783
  * New resource: azurerm_security_center_setting (#8783)
  * Fix error when creating security center contact
  * Update CHANGELOG.md for #8826
  * Update stamp_id of azurerm_dedicated_hardware_security_module as optional property (#8826)
  * update
  * Update changelog for #8859
  * `azurerm_search_service` - `sku` now supports `storage_optimized_l1` and `storage_optimized_l2` (#8859)
  * Update changelog for #8860
  * `azurerm_cognitive_account` - `kind` now supports `Personalizer` #8860
  * Update changelog for #8811
  * `azurerm_storage_share` - set `metadata` to `Computed` and set `acl` `start` and `expiry` to `Optional` (#8811)
  * typo in comment
  * fix tests failing due to quota restrictions
  * update
  * update
  * Update changelog for #8807
- from version v2.31.1
  * Update changelog for #8807
  * `azurerm_storage_account`- add Computed to `large_file_share_enabled` #8807
  * spelling
  * log analytics data sources: should not have been merged comment
  * Cleanup after v2.31.0 release
- from version 2.31.0
  * misc cleanup of CHANGELOG.md
  * address pr comments
  * updating the changelog
  * r/windows_virtual_machine_scale_set: documenting the plan block
  * Update error message
  * Update changelog for #8666
  * `azurerm_storage_share` allow large quotas to be specified.  (#8666)
  * Update changelog for #8789
  * `azurerm_storage_account` - add support for `large_file_share_enabled` (#8789)
  * Update CHANGELOG.md for #8795
  * Validate policy mode value (#8795)
  * Update CHANGELOG.md for #8668
  * Update `azurerm_policy_set_definition` - Fix #8663 (#8668)
  * Add `plan` block argument to scale set
  * update CHANGELOG>md for #8605
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_workspace_application_group_association_resource_test.go
  * Update website/docs/r/virtual_desktop_workspace_application_group_association.html.markdown
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_workspace_resource_test.go
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_workspace_resource_test.go
  * Update data_factory_dataset_http.html.markdown (#8784)
  * Update CHANGELOG.md for #8765
  * `azurerm_mssql_database` - add support for `long_term_retention_policy` and `short_term_retention_policy` (#8765)
  * `azurerm_mssql_server` - update doc and test for sql server min tls (#8769)
  * add `s` tk
  * fix: Change serivce to service in private_endpoint.html.markdown
  * fix failing tests for wvd resources
  * Update application_gateway.html.markdown (#8759)
  * Update CHANGELOG.md for #8549
  * Update `azurerm_security_center_subscription_pricing` (#8549)
  * Update changelog for #8300
  * `azurerm_kubernetes_cluster_node_pool` - `node_count`, `min_node`, and `max_node` can now be set to `0` (#8300)
  * some misc code cleanup and organization (#8750)
  * recommit standard sku
  * ACR formatting
  * remove policies block
  * sku block has been deprecated (#8747)
  * Removed azuread dependency wherever applicable for AAD Diagnostic settings (#8580)
  * Corrected the example given
  * update CHANGELOG.md for #8308
  * `azurerm_mssql_database` support 0 for  `min_capacity` (#8308)
  * update CHANGELOG.md for #8682
  * [azurerm_function_app] App Settings should be Computed (#8682)
  * update CHANGELOG.md for #7898
  * Update CHANGELOG-v2.md
  * Update `azurerm_backup_policy_vm` -  check for <7 daily backups (#7898)
  * CI fixes
  * update/move function to utils. Change name of application_group_reference_id to application_group_id
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_host_pool_resource.go
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_application_group_resource.go
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_host_pool_resource_test.go
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_application_group_resource_test.go
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_workspace_resource_test.go
  * Update azurerm/internal/services/desktopvirtualization/virtual_desktop_workspace_resource_test.go
  * Update website/docs/r/virtual_desktop_workspace.html.markdown
  * Example of AKS cluster with virtual nodes (Azure Container Instances) (#8722)
  * Example for deploying a Python based Azure Functions App. (#8724)
  * Documentation updates (#8734)
  * switch to secondary location for tests
  * Update changelog for #8623
  * UPDATE azurerm_subnet documentation example (#8729)
  * `azurerm_mssql_virtual_machine` - Add support for `storage_configuration_settings` (#8623)
  * Update changelog for #8699
  * `azurerm_appplication_insights` - Add support for `connection_string` #8699
  * Update changelog for #8361
  * mssql_server: add minimal_tls_version property (#8361)
  * Update changelog for #6761
  * New Resource: `azurerm_service_fabric_mesh_application` (#6761)
  * Update changelog for #8586
  * `azurerm_iothub` - Support for `public_network_access_enabled` (#8586)
  * update CHANGELOG.md for #8599
  * azurerm_app_service  - allow v6 IPs for the webapp ip_restriction property (#8599)
  * [template_deployment] Documentation typo fix (#8732)
  * make terrafmt
  * hotfix documentation should be "Pooled" for host pool
  * hotfix documentation should be "Pooled" for host pool
  * cleanup + move to latest sdk api version + website build
  * moving 2.30 - 2.21 into this file
  * splitting the changelog
  * updating to include #8642
  * Update changelog for #8718
  * `azurerm_dedicated_host` - add support for `DSv4-Type1` `sku_name` #8718
  * Updated README.
  * Updated README.
  * Fixed variables file.
  * Fixed example to actually use Calico Network policy.
  * scaffold azurerm_data_factory data documentation
  * Update changelog for #8687
  * `azurerm_key_vault_certificate_issuer` - `org_id` is now optional #8687
  * Cleanup after v2.30.0 release
- from version 2.30.0
  * update CHANGELOG.md for #8667
  * Add waiting logic for azurerm_monitor_metric_alert (#8667)
  * Doc Fix: `azurerm_postresql_virtual_network_rule`  replace Basic with GeneralPurpose for sku_name #8713
  * updating to include #8672
  * Update CHANGELOG.md for #8670
  * `azurerm_key_vault` - add support for `enable_rbac_authorization` (#8670)
  * updating to include #8707
  * Update website/docs/r/resource_group_template_deployment.html.markdown
  * Add two new SKUs to azurerm_analysis_services_server
  * scaffold azurerm_app_service_environment data docs
  * fmt container registry tests
  * add support for container registry policies
  * container registry update sku and sku-dependent attributes at the same time
  * update changelog for #8556
  * terrafmt
  * updating to include #8688
  * go mod tidy
  * tests for the features block
  * gosimple
  * features: documenting the new template_deployment features block
  * r/template_deployment: documenting that this resource has been superseded
  * website: adding to the sidebar
  * New Resource: `azurerm_subscription_template_deployment`
  * New Resource:
  * r/template_deployment: adding a common file containing common logic
  * r/template_deployment: adding validation for the template deployment name
  * r/template_deployment: adding ID Parsers/Formatters for Resource Group/Subscription ID's
  * features: adding a toggle for purging nested items during deletion
  * features: adding a feature toggle (and deprecation wrapper) for 3.0
  * resources: updating to use API version 2020-06-01
  * use API version 2020-03-01 instead 2019-03-22-preview
  * Update changelog for #8627
  * Update `azurerm_linux|windows_virtual_machine_scale_set` - Fix #8422 (#8627)
  * update CHANGELOG.md for #8659
  * storage_management_policy - support appendBlob for blob_types (#8659)
  * update CHANGELOG.md for #8646
  * azurerm_servicebus_subscription_rule - support `correlation_filter.properties` (#8646)
  * Update CHANGELOG.md
  * Inclusive language updates (#8638)
  * Added vm role assignment example
  * azurerm_container_group: change `nameservers` type to list to keep order (#8651)
  * Typo fix (#8664)
  * cleanup
  * update CHANGELOG.md for #8078
  * azurerm_hpc_cache: update API version to 2020-03-01 and support `mtu` and `root_squash_enabled` properties (#8078)
  * Update azurerm/internal/services/desktopvirtualization/tests/virtual_desktop_workspace_resource_test.go
  * Update azurerm/internal/services/desktopvirtualization/tests/virtual_desktop_host_pool_resource_test.go
  * Update azurerm/internal/services/desktopvirtualization/tests/virtual_desktop_application_group_resource_test.go
  * Update website/docs/r/virtual_desktop_application_group.html.markdown
  * move test files and remove multiline comment
  * Fix typo in cosmosdb_account.html.markdown
  * Update `address_space` attribute description (#8641)
  * `azurerm_subnet_network_security_group_association` error message update (#8644)
  * update CHANGELOG.md for #8648
  * Validate Service Bus Topic and Queue max_size_in_megabytes (#8648)
  * fist => first typo correction (#8650)
  * update CHANGELOG.md for #7912
  * `azurerm_container_group` - Support of `dns_config` (#7912)
  * upgrade sdk
  * update CHANGELOG.md for #8639
  * Add support for sku S for azurerm_cognitive_account (#8639)
  * cosmosdb - move tests to cosmos_test package (#8637)
  * update CHANGELOG.md for #6189
  * New Resource `azurerm_cosmosdb_sql_storedprocedure` (#6189)
  * update CHANGELOG.md for #8295
  * Update `azurerm_cosmosdb_account` - support zone redundancy (#8295)
  * Azurerm role assignment doc (#8621)
  * update CHANGELOG.md for #8504
  * azurerm_logic_app_workflow - support for integration_service_environment_id (#8504)
  * Location was not described (#8635)
  * Refactor IotHub RP (#8622)
  * update CHANGELOG.md for #8602
  * `azurerm_cosmosdb_mongo_collection` order of  compound `keys` in `index` matters (#8602)
  * update CHANGELOG.md for #8601
  * Update validation for scope of azurerm_lighthouse_assignment (#8601)
  * doc: Add querystring caching behaviour precision (#8612)
  * update CHANGELOG.md for #8556
  * New resource: azurerm_ip_groups (#8556)
  * azurerm_app_service_virtual_network_swift_connection - prevent a panic (#8616)
  * Cleanup after v2.29.0 release
- from version 2.29.0
  * updating to include #8568
  * updating to include #7601
  * Fixed linting issues and documentation terraform code formatting. Still need to fix vendor issues
  * fix documentation association
  * Revert test package back to original
  * updating to include #8592
  * Revert "Update check-test-package.sh"
  * Update check-test-package.sh
  * Update network_interface_application_security_group_association_resource_test.go
  * F/wvd (#1)
  * Merge branch 'master' of github.com:terraform-providers/terraform-provider-azurerm
  * update
  * go mod tidy
  * Update changelog for #8290
  * vendoring the updated azure sdk
  * dependencies: updating to v46.3.0 of github.com/Azure/azure-sdk-for-go
  * update doc - azurerm_kubernetes_cluster
  * update
  * update doc - azurerm_role_definition and azurerm_role_assignment
  * API Manager: Support for virtual network mode with additional locations
  * support virtual network integration - azurerm_spring_cloud_service
  * r/storage: fixing the clients to be pointers
  * Update changelog for #8557
  * `azurerm_search_service` - Add support for `allowed_ips` (#8557)
  * go fmt
  * update CHANGELOG.md for #8270
  * Update `azurerm_policy_set_definition` - Support to use non-string typed parameter values in `policy_definition_reference` block (#8270)
  * update CHANGELOG.md for #7390
  * new resource: azurerm_firewall_policy (#7390)
  * update CHANGELOG.md for #8477
  * dependencies: update ACR client to 2019-05-01 (#8477)
  * explicitly set the deprecated proerpties to false
  * update CHANGELOg.md for #8125
  * New resource `azurerm_mysql_server_key` - Add CMK support (#8125)
  * update CHANGELOG.md for #8461
  * azurerm_cosmosdb_sql_container - support for `indexing_policy` (#8461)
  * update CHANGELOG.md for #8126
  * New resource `azurerm_postgresql_server_key` - Add CMK support (#8126)
  * update CHANGLOG.md for #8533
  * azurerm_cosmosdb_account - support the `Serverless` value for the `capabilities` property (#8533)
  * update CHANGELOG.md for #7917
  * New data source `azurerm_mssql_server` and new block `restorable_dropped_databases` in `azuerrm_mssql_server` (#7917)
  * updating to include #8541
  * fixing the tests
  * updating to include #8411
  * updating to include #8542
  * updating to include #8531
  * r/windows_virtual_machine: adding a dif suppressfunc when 'licenceType' is set to 'none'
  * updating to include #8503
  * r/signalr_service: adding missing features
  * windows_virtual_machine: Add test for updating license_type.
  * r/signalr: support for delta updates
  * r/api_management: sending an identity type of none on updates if unspecified
  * windows_virtual_machine: Allow updating license_type without recreation.
  * update CHANGEOG.md to include #8502
  * New data source: `azurerm_databricks_workspace` (#8502)
  * update CHANGELOG.md for #8464
  * New resource/data source `azurerm_data_share_dataset_kusto_cluster` (#8464)
  * address pr comments
  * Terrafmt test
  * Some test fixes
  * Doc Fix: `azurerm_service_fabric_cluster` - `client_certificate_thumbprint` #8536
  * Update changelog for #8521
  * `azurerm_service_fabric_cluster` - Remove two block limit for `client_certificate_thumbprint` #8521
  * gosimple
  * r/api_management: removing the `none` option to be consistent with other resources
  * Making notify set to false in apimanagement_user
  * Doc Fix: `azurerm_private_endpoint` Updating documentation for `private_ip_address` #8495
  * Example: `azurerm_kubernetes_cluster` with data source public ip #8499
  * Update changelog for #8462
  * New Resource/Datasource `azurerm_storage_sync_group` (#8462)
  * Cleanup after v2.28.0 release
- from version 2.28.0
  * formatting
  * Update kubernetes_cluster.html.markdown (#8505)
  * add source control special case for ADO controlled apps
  * Update CHANGELOG.md for #7836
  * r/storage_account_customer_managed_key - support for key rotation (#7836)
  * Update CHANGELOG.md for #8492
  * `azurerm_role_definition` - expose `role_definition_resource_id` (#8492)
  * find system node pool as a fallback
  * Refresh vendor
  * Fix for Type None
  * New logic for no identity
  * Fix create to have default identity type
  * Update doc for the usage of storage share
  * Update changelog for #8487
  * `data.azurerm_app_service_environment` - Expose vip information of an app service environment  (#8487)
  * Add fix for Identity = None
  * Update CHANGELOG.md for #6560
  * New resources: `azurerm_lighthouse_definition` and 'azurerm_lighthouse_assignment' (#6560)
  * update CHANGELOG.md for #8438
  * New Data Source: azurerm_servicebus_queue_authorization_rule (#8438)
  * switch to developerportal per service team's suggestions
  * Update changelog for #8447
  * New resource `azurerm_mssql_server_extended_auditing_policy`  (#8447)
  * Typo fix in postgresql_server_data_source_test.go (#8478)
  * Update main.tf (#8451)
  * azurerm_firewall_network_rule_collection: add doc/test to highlight dest addr service tag support (#8448)
  * Update changelog for #8235
  * azurerm_firewall: support management_ip_configuration block (#8235)
  * Update changelog for #7773
  * Support autoscaling Cosmos DB databases and containers  (#7773)
  * Update waiting logic for azurerm_cognitive_account (#8386)
  * correct the doco - the Self-hosted Integration Runtime resource is re… (#8444)
  * update CHANGELOG.md for #8374
  * azurerm_kubernetes_cluster - ensure OMS Agent log analytics workspace case is preserved after disabling/enabling (#8374)
  * update CHANGELOG.md for #8388
  * Adjust validation for EH consumer group datasource to accept $Default (#8388)
  * update CHANGELOG.md for #8370
  * support relay namespace in different resource group for "azurerm_app_service_hybrid_connection" (#8370)
  * update CHANGELOG.md for #8386
  * update CHANGELOG.md for #8389
  * data.function_app - export the identity block (#8389)
  * update CHANGELOG.md for #8024
  * Fixed parsing of management group id (#8024)
  * updating to include #8434
  * follow up of PR #8095
  * dependencies: updating automation to 2018-06-30-preview (#8400)
  * Update CHANGELOG.md for #8167
  * Update segment of resource id for network packet capture (#8167)
  * update CHANGELOG.md for #8095
  * new resource `azurerm_synapse_sql_pool` (#8095)
  * update CHANGELOG.md for #7843
  * New resource/data source `azurerm_storage_sync` (#7843)
  * update CHANGELOG.md for #7907
  * New resource/data source `azurerm_data_share_dataset_data_lake_gen2` (#7907)
  * Update changelog for #8430
  * data.azurerm_function_app_host_keys - Fix crash when no id is present (#8430)
  * Delete ISSUE_TEMPLATE.md
  * Cleanup after v2.27.0 release
- from version 2.27.0
  * Update CHANGELOG.md for #8357
  * r/cognitive_account: fixing a crash & supporting AnomalyDetector / QnAMaker (#8357)
  * Update CHANGELOG.md for #8384
  * azurerm_network_security_group: add the new resource check back as is in a CreateOrUpdate callback (#8384)
  * Fix GH link format for #8366
  * Update to include #8366
  * fixes #8341 #8168
  * update CHANGELOG.md for #7793
  * New resource `azurerm_mssql_database_extended_auditing_policy` (#7793)
  * updating to include #8412
  * Fixes #8402
  * Update SDK to v46.1.0
  * Update changelog for #8409
  * `api_management_x.y.api_name` - validation fix #8409
  * Update changelog for #8365
  * New data source: azurerm_lb_rule (#8365)
  * Update changelog for #8372
  * azurerm_application_insights_webtests: .Kind turns to null after editing in Portal (#8372)
  * Update CHANGELOG.md for #6107
  * Fixing destroy when role scope is a Management Group (#6107)
  * [Refactor] bring back the `SystemAssigned, UserAssigned` defined in go SDK to app service (#8404)
  * Update CHANGELOG.md for #7873
  * New Resource: `azurerm_api_management_api_diagnostic` (#7873)
  * updating to include #8322
  * Add support for `encryption_at_host_enabled` for `azurerm_windows_virtual_machine`, `azurerm_linux_virtual_machine`, `azurerm_windows_virtual_machine_scale_set` and `azurerm_linux_virtual_machine_scale_set` #8322
  * Updating changelog to include #8349
  * New Resource: `azurerm_data_factory_linked_service_azure_sql_database` (#8349)
  * updating to include #8383
  * Add delete WaitForState azurerm_windows_virtual_machine and azurerm_linux_virtual_machine #8383
  * Update test config func name
  * Change API to Api in tests
  * Fix resource name, myssql => mysql
  * update CHANGELOG.md for #7902
  * New Data Source: `azurerm_function_app_host_keys` (#7902)
  * r/cosmosdb_account: document example for capabilities block (#8369)
  * ordering
  * correct spelling and docs
  * Fix format for changelog
  * Move attestation to correct release v2.27
  * updating to include #7885
  * Add support for Azure Attestation Provider #7885
  * updating to include #8336
  * updating to include #8294
  * updating to include #8335
  * Cleanup after v2.26.0 release
- from version 2.26.0
  * Updating firewall_network_rule_collection docs
  * Update changelog for #8253
  * New Resource: `azurerm_log_analytics_saved_search` (#8253)
  * ordering
  * mentioning Function App in the description, rather than as a separate callout
  * Update api_management.html.markdown
  * update
  * update
  * update
  * support managed identity for "azurerm_spring_cloud_app"
  * Add AllowSelfServeUpgradeToMongo36 to cosmosdb_account's capabilities
  * Update code
  * Update doc for app_service_name of azurerm_app_service_custom_hostname_binding
  * removing an unnecessary explicit depends_on
  * Update function_app.html.markdown
  * updating to include #7983
  * updating to include #8237
  * Updated CHANGELOG.md for #8222
  * Support for VMSS in-line extensions behind feature flag (#8222)
  * fix tests
  * document azuread auth for data.virtual_network_gateway
  * add virtual_network_gateway azuread auth tests
  * updating to include #8304
  * refactor: splitting Resource Providers out to their own package
  * lint
  * Remove deprecated ShouldResourcesBeImported
  * r/key_vault_key: updating the latest version during updates
  * r/key_vault_secret: updating the latest secret version during updates
  * fixing the build
  * sidebar: adding a link to the redis_linked_server resource
  * Add azuread auth to vnet gateway vpn client
  * rename param for `subscriptionId` to be consistent
  * Update changelog for #8278
  * `azurerm_application_gateway ` - Add support for `probe.properties.port` #8278
  * Update changelog for #7969
  * `azurerm_api_management_subscription` - Support `allow_tracing property` (#7969)
  * `azurerm_log_analytics_workspace` - Fix default value for sku #8287
  * updating to include #8272
  * updating to include #8001
  * linting
  * notificationhub: removing the unnecessary feature toggle
  * loganalytics: removing usage of the unused feature toggle
  * servicebus: removing usage of the old feature toggle
  * netapp: removing the unused feature toggle
  * r/kusto_eventhub_data_connection: removing the unused feature toggle
  * r/kusto_cluster: removing the unused feature toggle
  * Add tests for updating allow_extensions_operations if provision_vm_agent is false.
  * updating to include #8267
  * Doc Fix: `data. azurerm_hdinsight_cluster` #8274
  * Update changelog for #8234
  * Update `loganalytics` to `/preview/operationalinsights/mgmt/2020-03-01-preview/operationalinsights` (#8234)
  * Update code
  * Cleanup after v2.25.0 release
  * PIT C/P cdn profile schema & expand all function and remove validation in V0 schema
  * Update sku as optional for azurerm_log_analytics_workspace
- from version 2.25.0
  * updating to include #7822
  * ignore changes to deprecated attributes and set default for `internet_security_enabled`
  * linting
  * updating to include #8244
  * r/network_interface_network_security_group_association: handling the nic being gone during a read
  * r/network_interface_nat_rule_association_resource: handling the nic being gone during a read
  * r/network_interface_backend_address_pool_association: handling the nic being gone during read
  * r/network_interface_application_security_group_association: handling the nic being gone during read
  * r/network_interface_application_gateway_association: handling the nic being gone during read
  * Resolve comments
  * update
  * provide unique priority value for newly-created rule
  * Update website/docs/r/subnet.html.markdown
  * Update azurerm/internal/services/network/subnet_resource.go
  * Update website/docs/d/key_vault_certificate.html.markdown
  * updating the description for #8233
  * updating to include #8015
  * lint error
  * PIT copy paste the v0 schema
  * resolve review comment
  * Fix wrong title
  * Update CHANGELOG.md for #8067
  * refactor: removing usages of the deprecated `features.ShouuldResourcesBeImported()`
  * new resource `azurerm_spring_cloud_certificate` (#8067)
  * fix bug
  * introduce IDFormatter
  * go mod vendor & tidy (after merging master)
  * resolve review comment (except introducing IDFormtter)
  * added new service_delegations
  * Update changelog for #8233
  * `azurerm_*.*.zone` - can no longer be passed in as empty (#8233)
  * update docs
  * allow SocketAddr to be used as a match_variable
  * add source control special case for ADO controlled apps
  * Add tests for ultra_ssd_enabled.
  * fix build error...
  * updating to include #8240
  * remove migration from data source and resolve a self reference
  * Update code
  * add migration logic to cdn profile/endpoint, both managed and data resources
  * Refactor and add id formatters for compute RP
  * conform to the Formatter style
  * Add example for storage container
  * `azurerm_cnd_endpoint` - Standardize the resource ID to be case sensitive
  * Update code
  * Update doc for site property of azurerm_bot_channel_directline
  * Update changelog for #6667
  * `azurerm_*_virtual_machine_scale_set` - `upgrade_mode="Automatic"` no longer requires health probe (#6667)
  * sorting alphabetically
  * updating to include #8217
  * updating to include #8151
  * updating to include #8111
  * updating to include #8221
  * Update dedicated_host_resource.go
  * locations: patching the india location names
  * update
  * updating to include #8210
  * Omit redundant default attribute
  * updating to include #8212
  * Fix 'Invalid address to set' error with azurerm_app_service data source and subnet IP restriction (#8211)
  * Allow empty ip_addresses list for azurerm_application_gateway (#8209)
  * outline unit test possiblity to run with no azure acc
  * reduced entry barrier for vs csharp people #8093
  * Update code
  * Update code
  * removing bad example
  * Adding FQDN documentation for destination_address rule_collection
  * refactor: removing usages of the old feature toggle
  * Update changelog for #8189
  * Remove network configuration from update payload (#8189)
  * Update changelog for #8124
  * `azurerm_shared_image` - Support for `purchase_plan` #8124
  * Cleanup after v2.24.0 release
- from version 2.24.0
  * updating to include #7976
  * updating to include #8172
  * fixing #7886
  * Update azurerm/internal/services/network/lb_outbound_rule_resource.go
  * Update azurerm/internal/services/network/lb_rule_resource.go
  * Update azurerm/internal/services/network/lb_rule_resource.go
  * updating to include #8173
  * Update code
  * docs: removing ambiguous usages of 'Resource ID'
  * Update website/docs/r/cosmosdb_gremlin_graph.html.markdown
  * Update cosmosdb_gremlin_graph.html.markdown
  * update
  * update
  * Update website/docs/r/synapse_spark_pool.html.markdown
  * Update website/docs/r/synapse_spark_pool.html.markdown
  * Update website/docs/r/synapse_spark_pool.html.markdown
  * refactor bigdatapoolclient to sparkpoolclient
  * rename "azurerm_synapse_big_data_pool" to "azurerm_synapse_spark_pool"
  * Make update of allow_extensions_operations independent from provision_vm_agent.
  * Update code
  * Add example for vmss with loadbalancer probe
  * Update #7886
  * Updating to include #7886
  * part of #7406
  * `azurerm_network_connection_monitor` add resource document (#8155)
  * r/frontdoor_custom_https_configuration: setting `resource_group_name`
  * refactor: adding import time validation
  * refactor: adding validation it's a Load Balancer ID being passed in
  * refactor: passing ctx/client into the retrieveLoadBalancerById method
  * refactor: retrieveLoadBalancerById now takes the ID
  * refactor: removing the legacy parseID method
  * r/loadbalancer_rule: switching to use a consistent id parsing method
  * r/loadbalancer_probe: parsing using a consistent method
  * r/loadbalancer_outbound_rule: parsing using a consistent id func
  * r/lb_nat_rule: switching to use specific ID parsers
  * r/lb_nat_pool: switching to use specific ID parsers
  * r/loadbalancer_backend_address_pool: using a consistent ID parser
  * loadbalancers: adding an ID parser
  * updating to include #8146
  * updating to include #8006
  * linting
  * pr comments
  * fixing the assertion
  * frontdoor: moving the customizeDiff out
  * r/frontdoor_https_configuration: ensuring the Frontend Endpoint ID is consistent
  * typo
  * r/frontdoor: ensuring the ID is consistent at import time
  * r/frontdoor_custom_https_configuration: validating the ID is the correct case at import time
  * frontdoor: tests for the ID Parsers
  * r/frontdoor: rewriting the ID's to ensure they're consistent
  * r/frontdoor_firewall_policy: moving the validation tests over
  * docs: removing conflicting terms
  * r/frontdoor_firewall_policy: location is computed
  * r/frontdoor: renaming the test files to match the resources
  * r/frontdoor: helps if you set the field
  * WIP
  * r/frontdoor: adding a state migration to fix the I
  * r/frontdoor_firewall_policy: adding a state migration for the ID
  * resource-group: deprecated shouldn't be forcenew
  * r/frontdoor: exposing the correct resource id during a requires import error
  * r/frontdoor: fixing a bug in the id formatters
  * r/frontdoor_custom_https_configuration: adding a state migration to patch the ID
  * r/frontdoor_custom_https_configuration: fixing the docs
  * r/frontdoor_custom_https_configuration: ensuring CU calls Read and deprecating `resource_group_name`
  * r/frontdoor_firewall_policy: refactoring
  * r/frontdoor*: adding import-time validators to check the ID is in the correct format
  * r/frontdoor_custom_https_configuration: fixing the id parsing
  * firewall: placeholders to check the implementations are valid
  * refactor: making the helper methods private now this is within the package
  * r/frontdoor_firewall_policy: switching to use a consistent id formatter
  * r/frontdoor: fixing an issue where the checkdestroy function was checking the wrong resource name
  * r/frontdoor: switching to use the parser method for read/delete
  * r/frontdoor: refactoring to use the ID parsers/formatters
  * refactor: ditching the frontdoor prefix
  * r/frontdoor: removing dead code
  * r/frontdoor: refactoring the backend pool method
  * refactor: moving the frontdoor helpers into the frontdoor package
  * r/frontdoor: refactoring the backendpool flatten methods
  * r/frontdoor: switching the frontendEndpoints to use the custom parsers
  * r/frontdoor: adding parsing functions
  * internal/resourceid: adding an interface for Resource ID Rewriting
  * Update example for base64 of azurerm_automation_certificate
  * moving 2.20 - 2.11 into this file
  * moving 2.20 to the changelog-2 file
  * updating to include #8110
  * Fix rendering
  * Update code
  * updating to include #8152
  * fixes regression related to #7879
  * azurerm_lb: update document about `zones`
  * Use d.Get to set PRIVATE_EMPTY of azurerm_container_group
  * Update changelog for #8148
  * `azurerm_storage_account` - switch logic to be if not public cloud instead of if us government cloud #8148
  * Add example for vnet gateway
  * Updated for #7617
  * Add oauth2_authorization and openid_authentication (#7617)
  * Update docs
  * Add tests
  * Update doc for fqdn_tags of azurerm_firewall_application_rule_collection
  * Corrects placement of the `source_image_reference` argument block.
  * fixing unnecessarily aliased imports
  * Cleanup after v2.23.0 release
- from version 2.23.0
  * format
  * add doc and test for function app slot swift virtual network connection
  * updating to include #8092
  * fixes #7812 and #8083
  * update CHANGELOG.md for #8100
  * Remove mariadb virtual network rule subnet endpoint check (#8100)
  * `azurerm_servicebus_queue` - fix typo in documentation (#8098)
  * Update api-version
  * Update doc according to the latest documentation of azure
  * update CHANGELOG.md for #7904
  * new resource for `azurerm_synapse_firewall_rule` (#7904)
  * Test fix `TestAccDataSourceAzureRMImage_basic` (#8087)
  * update CHANGELOG.md for #7763
  * New resource - azurerm_integration_service_environment (#7763)
  * refactor: moving the automation validation functions into that package
  * subscription: duplicating/removing the missing schema
  * cosmosdb_account: switching to use the new method directly
  * refactor: moving the datalake validation helpers into the datalake validation package
  * kusto: refactoring the identity helpers
  * refactor: moving the container group ports schema into containers
  * refactor: moving the cors_settings into the web package
  * fixing the build
  * helpers/azure/hdinsight -> services/hdinsight
  * helpers/kubernetes -> internal/services/containers/kubernetes since this is the only usage
  * helpers/set: removing dead code
  * helpers/common/arrays -> internal/locks - since this is the only usage
  * Update CHANGELOG.md for #7945
  * App Service refactor and feature alignment (#7945)
  * Update code
  * updating to include #7894
  * Update code
  * Add example for azurerm_network_interface_application_security_group_association and azurerm_virtual_machine
  * Update additional capabilities.
  * update CHANGELOG.md for #8059
  * Update `azurerm_mysql_server` - Add `identity` support (#8059)
  * update CHANGELOG.md for #8026
  * New resource type: azurerm_redis_linked_server (#8026)
  * update CHANGELOg.md for #8028
  * Remove computed attribute for endpoint and route of azurerm_iothub (#8028)
  * update CHANGELOG.md for #7995
  * `azurerm_monitor_metric_alert_resource`: keep using SingleResourceMultiMetricCriteria for legacy metric alerts (#7995)
  * update CHANGELOG.md for #7981
  * `azurerm_mysql_server` `threat_detection_policy` refresh plan is not empty (#7981)
  * update CHANGELOG.md for #7953
  * `azurerm_data_factory_dataset_delimited_text` - fix issue with property `azure_blob_storage_account` (#7953)
  * update CHANGELOG for #8044
  * Update `azurerm_postgresql_server` - Add identity support (#8044)
  * app_service: adding functions with RBAC role assignment example to docs (#8075)
  * update CHANGELOG.md for #7846
  * Update `azurerm_traffic_manager_profile` - Updating of the profile no longer destroys all the endpoints (#7846)
  * update CHANGELOG.md for #8061
  * Remove case diff suppress for property rule_type of azurerm_application_gateway (#8061)
  * update CHANGELOG.md for #7821
  * Update `azurerm_orchestrated_virtual_machine_scale_set` - Remove the validation for `single_placement_group` (#7821)
  * updating to include #8065
  * app_service: adding functions basic example to docs
  * Fix SharedImage Tests
  * Upgrading containerservice API to 2020-04-01 to support new features
  * updating to include #8000
  * updating to include #7975
  * typo
  * updating to include #8045
  * features: moving the ShouldRequireResourcesToBeImported toggle into the deprecated file
  * r/kubernetes_cluster: removing use of a deprecated feature toggle
  * updating to include #8041
  * authorization: removing use of the requiresimport toggle
  * batch: removing usage of the requires-import toggle
  * apimanagement: removing usage of the requiresimport toggle
  * applicationinsights: removing the unused feature toggle
  * appconfiguration: removing the unused feature toggle
  * feature/require-imports: removing redundant feature-flags checks
  * updating to include #8062
  * Goimports
  * Identity cannot be removed
  * vhub creation wait for routing provision
  * Add test cases and docs
  * First implement of identity
  * Fix location of delivery rules in cdn_endpoint resource
  * Updates
  * Updates after review
  * Updated for #5688
  * Allow setting target subnet and static IP on failover (#5688)
  * updating to include #8042
  * formatting
  * allow "global" for enhanced location validation
  * update code
  * Add lock for iothub while operating iothub consumer group
  * update CHANGELOG.md for #7890
  * update CHANGELOG.md for #7890
  * `azurerm_storage_account` - Support `static_website` for `BlockBlobStorage` account type (#7890)
  * Cleanup after v2.22.0 release
- from version 2.22.0
  * update CHANGELOG.md for #8017
  * azurerm_iothub_shared_access_policy - prevent primary_connection_string & seconday_connection_string from regenerating (#8017)
  * update CHANGELOG.md for #8020
  * Add signed_version attribute to azurerm_storage_account_sas (#8020)
  * update CHANGELOG.md for #7990
  * update CHANGELOG.md for #8016
  * `azurerm_cosmosdb_account`  support `DisableRateLimitingResponses` for the `capabilities` property (#8016)
  * updating to include #8029
  * update CHANGELOG.md for #7879
  * `azurerm_storage_account` - Support for `min_tls_version` (#7879)
  * refactor flatten func for key vault certificate data source
  * azurerm_servicebus_queue - reorder schema
  * azurerm_servicebus_queue - format documentation
  * azurerm_servicebus_queue - sync variables with argument names
  * azurerm_servicebus_queue - add status argument
  * azurerm_servicebus_queue - add enable_batched_operations argument
  * azurerm_servicebus_queue - add forward arguments
  * Changed: note regarding ip rules for Azure service from the same region as storage account is was added.
  * Updatesdoc for resource_group_name property of azurerm_private_dns_a_record.
  * `azurerm_mysql_server` Sku Tier `Basic` doesn't support `infrastructure_encryption_enabled` (#7997)
  * Update doc for resource_group_name property of azurerm_private_dns_zone_virtual_network_link (#7998)
  * Fix teamcity diff that shows up every time build the provider (#8013)
  * Use API version 2020-03-01 for Loadbalancer
  * Improve VM stopping/deallocating before updating.
  * Update api-version from 2017-12-01 to 2020-01-01
  * Make
  * Change api-version from 2017-12-01 to 2020-01-01
  * A workaround for issue #7253 and #7957
  * Update doc for fqdn of azurerm_dns_a_record
  * Mode can be changed in-place
  * update CHANGELOG for #7933
  * dependencies: updating to v44.2.0 of github.com/Azure/azure-sdk-for-go (#7933)
  * Fix for #3967
  * Cleanup after v2.21.0 release
- from version 2.21.0
  * Test Fix: `data.azurerm_monitor_diagnostic_categories_acctest` #7970
  * azurerm_network_security_rule: adds a feature flag to disable locking (#7956)
  * update CHANGELOG.md for #7727
  * New resource: azurerm_dedicated_hardware_security_module (#7727)
  * Documentation: `azurerm_app_service_hybrid_connection` - `send_key_name` #7961
  * `azurerm_api_management_backend` fix acctest `TestAccAzureRMApiManagementBackend_serviceFabric` (#7939)
  * `azurerm_cosmosdb_account` fix all acctests (#7915)
  * update CHANGELOG.md to include #7916
  * Use getOK to get qna_runtime_endpoint for azurerm_cognitive_account (#7916)
  * `azurerm_advanced_threat_protection` fix acctests (#7919)
  * Update doc for default_ttl_seconds of azurerm_cosmosdb_mongo_collection (#7942)
  * Update all deprecated azurerm_subnet address_prefix examples (#7897)
  * monitor_diagnostic_setting: fix acctest (#7959)
  * Test Fix: `data.azurerm_batch_pool` #7940
  * Test Fix: `azurerm_action_group` #7941
  * Update changelog for #7943
  * `azurerm_app_service_plan` - update the relation between `kind` and `reserved` (#7943)
  * Doc fix: `azurerm_key_vault_access_policy` #7944
  * Updated changelog for #7901
  * `azurerm_api_management_identity_provider_aad` - Support for `signin_tenant` #7901
  * Update changelog for #7874
  * `azurerm_kubernetes_cluster` - Updates no longer fail when using managed AAD integration (#7874)
  * Update CHANGELOG.md for #7927
  * AKS - allow in-place upgrade from free to paid sku_tier (#7927)
  * Data source `azurerm_backup_policy_vm` fix acctests (#7920)
  * Update changelog for #7911
  * Dependency: update go-azure-helpers to v0.11.2 (#7911)
  * azurerm_virtual_network - update docs for address_space is no longer force new (#7893)
  * example for azure monitoring (#7701)
  * created securitygroup and  virtual network azure using terraform (#7884)
  * update CHANGELOG.md for #7555
  * `azurerm_automation_job_schedule` needs to be recreated after `azurerm_automation_runbook` is updated (#7555)
  * update CHANGELOG.md for #7817
  * Remove minItem for zone in firewall (#7817)
  * `azurerm_api_management_user` fix test `complete` (#7866)
  * Update doc for event_time_to_live property of azurerm_eventgrid_event_subscription (#7883)
  * update CHANGELOG for #7840
  * New data source `azurerm_data_share_dataset_data_lake_gen1` (#7840)
  * update CHANGELOG.md for #7311
  * `azurerm_app_service_slot`  - support `application_logs.file_system` (#7311)
  * update CHANGELOG.md for #7824
  * azurerm_automation_runbook  - allow invalid publish_content_links (#7824)
  * update CHANGELOG.md to include #7871
  * azurerm_eventgrid_event_subscription - deprecate topic_name (#7871)
  * update CHANGELOG.md for #7859
  * `azurerm_function_app_slot.site_config` - support for `auto_swap_slot_name` (#7859)
  * Add basic azurerm_servicebus_subscription_rule sql_filter validation (#7855)
  * update CHANGELOG.md to include #7852
  * azurerm_servicebus_subscription - support status property (#7852)
  * Update spacing for #7877 (#7878)
  * update CHANGELOG.md to include #7819
  * `azurerm_api_management_named_value` value to be sensitive (#7819)
  * add notes about `skip_credentials_validation` (#7823)
  * azurerm_web_application_firewall_policy  - Corrected exclusion "match_variable" (#7842)
  * update CHANGELOG.md to include #7847
  * Remove unsupported sku from iothub dps (#7847)
  * `azurerm_api_management_product_api` fix test `requiresImport` (#7863)
  * `azurerm_api_management_property` fix test `update` (#7864)
  * Update `azurerm_linux|windows_virtual_machine` - fix validation of the data disk size (#7816)
  * azurerm_storage_account_network_rules - Note regarding small /31 and /32 IP ranges in ip_rules was added. (#7869)
  * azurerm_storage_share - added note to clarify valid permission order in share ACL (#7872)
  * `azurerm_api_management_subscription` fix test `requiresImport` #7865
  * Update changelog for #7867
  * `azurerm_search_service` Add `publicNetworkAccess` and update api-version to `2020-03-13` #7867
  * Update changelog for #7838
  * `azurerm_monitor_scheduled_query_rules_alert` - Remove default from `action.0.custom_webhook_payload` (#7838)
  * Cleanup after v2.20.0 release
- from 2.20.0
  * Update website/docs/r/container_registry.html.markdown
  * Updated CHANGELOG.md for #7517
  * update
  * update
  * Update doc for georeplication_locations property of container registry
  * Make it clearer that request path is required for both http and https (#7860)
  * Doc Fix: `azurerm_mysql_firewall_rule` Allow access to Azure services example (#7850)
  * Update changelog for #7835
  * `azurerm_monitor_autoscale_setting` - Fix crash in `notification` #7835
  * updating to include #7511
  * fixes #6480
  * updating to include #7498
  * fixes #6057
  * update vendor
  * update
  * add `soft_delete_retention_days` support for `azurerm_key_vault`
  * update
  * update vendor
  * add support for setting aad admin
  * update based on Jeffrey's suggestion
  * update
  * update
  * update
  * new resource and data source for `azurerm_synapse_workspace`
  * Update changelog for #7814
  * `azurerm_cosmos_db_account` - add support for `enable_free_tier` (#7814)
  * update CHANGELOG.md to include #7784
  * azurerm_storage_account default allow_blob_public_access to false (#7784)
  * go mod tidy && go mod vendor
  * modify per review
  * upgrade network to 2020-05-01 for vhub(conn) & vwan
  * Copyediting: remove spurious aprostrophes in possessive "its" (#7806)
  * update CHANGELOG.md to include #7597
  * Update Azure Cosmos DB API to to 2020-04-01 from 2015-04-08 (#7597)
  * Update changelog for #7520
  * New Resource: `azurerm_kusto_cluster_customer_managed_key` (#7520)
  * `azurerm_storage_share_directory` - Update error message for invalid storage share directory name #7791
  * Update changelog for #7789
  * `azurerm_application_gateway` Fix crash with `gateway_ip_configuration` #7789
  * Updated CHANGELOG.md for #7774
  * update changelog for #7783
  * Fix crash in private dns zone data source (#7783)
  * updating to include #7737
  * Cleanup after v2.19.0 release
- from version 2.19.0
  * Updated CHANGELOG.md for #7754
  * Update CHANGELOG.md for #7680
  * correct tz string in update test
  * restored validation with correct values from reference source
  * Update CHANGELOG.md for #7753
  * added nil and empty check for id
  * Update for #7159
  * Updated for #7776
  * feedback updates
  * Update azurerm/internal/services/network/express_route_circuit_peering_resource.go
  * nil check route filter before set
  * Update for #7725
  * Fix for #2880
  * update
  * make goimports
  * update policy assignment resource for PR #7725
  * Update azurerm/internal/services/policy/policy_assignment_resource.go
  * update changelog for #6341
  * Support route filters for Microsoft peering (new resource azurerm_route_filter) (#6341)
  * Update changelog for #7768
  * provider: no longer auto register the Microsoft.StorageCache RP (#7768)
  * Test Fix: Change `CdnEndPoint` host_name (#7755)
  * Update doc for ip_rules of storage account (#7660)
  * bump go version to 1.14.5
  * drop back one point release for goenv support
  * Update validation for timezone of azurerm_automation_schedule
  * azurerm_express_route_circuit: fix acctest (actually a bug)
  * typo
  * Rename/complement test for application insight web test criteria
  * update policy assignment test
  * fix policy assignment markdown
  * fixing linter errors for policy assignments
  * minor code/doc change
  * update
  * Update changelog for #7745
  * `azurerm_local_network_gateway`- `address_space` order can now be changed #7745
  * Update changelog for #7749
  * `azurerm_*_virtual_machine` - `allow_extensions_operations` can now be updated #7749
  * go: bumping to 1.14.5 (#7746)
  * update as per feedback from the PR
  * updating to include #7740
  * updating to include #7739
  * provider: metadata_url -> metadata_host
  * update
  * fix consistent naming allow_blob_public_access
  * updating to include #7703
  * Add property allow_blob_public_access to azurerm_storage_account
  * sas_token is not returned, ignore it in verify state test step
  * feature/enhanced-validation: reusing the value
  * docs: updating to say 2.20
  * feature/enhanced-validation: enabling by default
  * s/high_business_impact_workspace/high_business_impact/
  * 1. fix TC bug 2. check whether two dns zone have the same name
  * updating to include #7706
  * updating to include #7734
  * updating to include #7731
  * refactor expand method. fix TC: `withoutAuth`
  * update
  * Update policy assignment for PR 7725
  * Fix TC for NetApp (#7693)
  * azurerm_private_link_service_endpoint_connections: fix acc test (#7728)
  * azurerm_vpn_server_configuration: fix acctest (#7730)
  * update CHANGELOG.md to include #7510
  * Update `azurerm_orchestrated_virtual_machine_scale_set` - Add proximity placement group support (#7510)
  * azurerm_virtual_hub_connection: fix acctest
  * s/hbi_workspace/high_business_impact_workspace/
  * Update Changelog for #7628
  * `azurerm_mssql_database` `elastic_pool_id` remove forcenew (#7628)
  * azurerm_network_interface_application_security_group_association fix documentation example (#7719)
  * Add metadata_url support for acceptance testing (#7721)
  * updating to include #7690
  * updating to include #7713
  * Fir message formatting
  * update changelog for #6586
  * Update iot_time_series_insights_access_policy.html.markdown (#7705)
  * virtual_network_gateway_connection: add traffic_selector_policy block and tests (#6586)
  * Fixed string interpolation syntax to new version (#7718)
  * Update for #7179
  * Deprecation doc
  * Deprecation doc
  * Deprecation doc
  * Deprecation messages
  * Deprecation messages
  * Deprecation messages
  * grouping changes
  * updating to include #7714
  * tweaked polling intervals for retry
  * switch share create retry to custom poller
  * switch containter create retry to custom poller
  * Updated CHANGELOG.md for #7307
  * disable Kubernetes Dashboard addon configuration in Azure China
  * hbi_workspace with integration tests
  * azurerm_virtual_hub: fix acc test and make the `address_prefix` as `ForceNew`
  * updated policy_assignment test for metadata
  * Make changes to compile
  * Malr RServer and MLService as deprecated
  * Mark Storm as deprecated. Fix  requireImports test
  * Property for hbi_enabled with ML Workspace
  * Move Spark tests to 4.0
  * Move Kafka tests to 4.0
  * modify per review
  * update
  * update import func
  * Move Interactive Hive tests to 4.0
  * update CHANGELOG.md for #7635
  * `azurerm_machine_learning_workspace`: fix acctests (#7635)
  * update CHANGELOG.md to include #7616
  * dependencies: updating to v44.0.0 of github.com/Azure/azure-sdk-for-go (#7616)
  * update CHANGELOG.md to for #7689
  * azurerm_managed_disk - increase the maximum disk_size_gb to 65536 GB. (#7689)
  * fix tests for DNS records (#7679)
  * Data source `azurerm_shared_image_version` - Fix acc tests (#7684)
  * Move HBase tests to 4.0
  * `azurerm_api_management_openid_connect_provider` fix to pass all acctests (#7675)
  * `azurerm_api_management_product_policy` fix to pass all acctests (#7674)
  * Fix TC for TestAccAzureRMAutomationModule_multipleModules (#7678)
  * `azurerm_api_management_authorization_server` fix acctest complete (#7683)
  * update changelog for #7018
  * azurerm_policy_set_definition: support `policy_definition_reference_id` (#7018)
  * Move Hadoop tests to 4.0
  * add validation for notification Hub Id
  * updating to include #7612
  * update tests
  * azurerm_route: fix acctest
  * lint fix in doc
  * Fix CI
  * update
  * add metadata to policy assignment resource
  * Fix managed disk data source tests
  * update
  * Cleanup after v2.18.0 release
- from version 2.18.0
  * Update automation_credential.html.markdown (#7671)
  * update CHANGELOG.md for #6943
  * Update `azurerm_policy_set_definition` - deprecate `management_group_id` in favour of `management_group_name` to align behaviour in `azurerm_policy_definition` (#6943)
  * update CHANGELOG.md to inclue #7621
  * new resource: azurerm_mysql_active_directory_administrator (#7621)
  * update CHANGELOG.md for #7348
  * azurerm_cosmosdb_account - support ignore_missing_vnet_service_endpoint (#7348)
  * update CHANGELOG.md to include #7622
  * r/eventhub_namespace_authorization_rule: adding a second state migration (#7622)
  * Update changelog for #7664
  * `metadata_url` can be used to obtain an environment from a specific url (#7664)
  * Refactor - Update disk encryption set related tests on `azurerm_linux|windows_virtual_machine_scale_set` (#7552)
  * Fix TC for TestAccDataSourceAzureRMManagedDisk_basic_withUltraSSD (#7624)
  * azurerm_template_deployment: fix test (#7629)
  * azurerm_loadbalancer_outbound_rule: fix acctest (#7630)
  * azurerm_express_route_gateway: fix acctest (#7632)
  * `azurerm_sql_database` fix to pass all acctests (#7633)
  * azurerm_stream_analytics_job: fix data source test (#7634)
  * Fix TC for Application Insights (#7631)
  * azurerm_network_service_tag: fix acctest (#7649)
  * Update doc for destination_address_prefix property of network security rule (#7659)
  * `azurerm_image` - Fix acc tests (#7654)
  * `azurerm_api_management_identity_provider_twitter` fix to pass all acctests (#7653)
  * `azurerm_api_management_identity_provider_google` fix to pass all acctests (#7648)
  * `azurerm_api_management_identity_provider_microsoft` fix to pass all acctests (#7647)
  * `azurerm_api_management_identity_provider_facebook` fix to pass all acctests (#7646)
  * `azurerm_virtual_machine_scale_set_extension` - Fix acc tests (#7644)
  * Test Fix: `azurerm_application_gateway`: remove checks for set attributes #7627
  * Resource `azurerm_shared_image_version` - Fix acc tests (#7643)
  * fix the rest `requiresImport` test for RP: streamAnalytics (#7641)
  * `azurerm_sql_virtual_network_rule` fix acctest `TestAccAzureRMSqlVirtualNetworkRule_multipleSubnets` (#7640)
  * update CHANGELOG.md to include #7345
  * `azurerm_api_management_api_operation_policy` fix to pass all acctests and fix raw xml issue (#7639)
  * fix test for `azurerm_stream_analytics_stream_input_blob` (#7638)
  * fix test for `azurerm_stream_analytics_reference_input_blob` (#7637)
  * Fix requiresimport test for RP: stream analytics (#7636)
  * Update doc for the reserved field of app service plan (#7661)
  * update CHNGELOG.md to include #7650
  * Fix TC for TestAccAzureRMApplicationInsightsAPIKey_requiresImport (#7650)
  * Updated CHANGELOG.md for #7363
  * Updated CHANGELOG.md for #7045
  * Update CHANGELOG.md for #7484
  * Update monitor_diagnostic_setting.html.markdown
  * linting
  * fix duplicate lines from rebase
  * Added deprecation note to old version of resource
  * Kusto Database Principal Assignment Support
  * Update changelog for #7377
  * New Resource: `azurerm_kusto_attached_database_configuration` (#7377)
  * azurerm_application_security_group: fix import test (#7626)
  * [Test Fix] azurerm_network_security_group: fix import test (#7625)
  * Actually, former version of validation just worked
  * Update changelog for #7374
  * `azurerm_kusto_cluster` - Support `trusted_external_tenants` (#7374)
  * Fix bad merbge and move extensionsClient
  * Validation for log_analytics_workspace_id
  * whitespace fixes
  * post conflict rebase cleanup and catchup for hdinsight service
  * Error messages
  * Error messages
  * Error messages
  * Error messages
  * Error messages
  * Return error if disabling monitor fails
  * Moved extensionsClient
  * Fix typo in debug output
  * Fixing linter errors
  * Ensure that basic and monitor tests use the same roles
  * Azure monitor doc  for all hdinsight resources
  * Azure monitor for Storm
  * Azure monitor for Spark
  * Azure monitor for Kafka
  * Azure Monitor for InteractiveQuery cluster
  * Aze monioor HBase cluster
  * A bit of refactoring
  * Documentation for hadoop
  * Error message clean up
  * Implement monitor changes
  * Enable monitor on create
  * Update CHANGELOG.md for #6969
  * deps
  * merge conflict resolution and minor change for metastoreraw
  * Get rid of GetOkExists in all hdinsight resources
  * Fix typo in hbase
  * Remove GetOkExists
  * Documentation for external metastores
  * Revert "External metastores for MLServices"
  * Revert "External metastores for RServer"
  * Revert "Fix for msservices / rserver"
  * Fix for msservices / rserver
  * External metastore for Storm
  * Error message fixes
  * EXternal metastores for Spark
  * External metastores for RServer
  * External metastores for MLServices
  * External metastores for Kafka
  * External metastores for Interactive Hive
  * External metastores for HBase
  * `make lint`
  * r/postgresql_server: requiring the use of `ssl_enforcement` since `d.GetExistsOk` is going away
  * Mark Application Gateway identity as not Computed (#7355)
  * update CHANGELOG.md to include #6847
  * new resource "azurerm_automation_connection", azurerm_automation_connection_certificate`,`azurerm_automation_connection_classic_certificate`and`azurerm_automation_connection_service_pricipal` (#6847)
  * Updated for #7074
  * update CHANGELOG.md to include #6366
  * New Resource - azurerm_data_factory_linked_service_blob_[blob|storage|sfpt] (#6366)
  * update CHANGELOG.md to include #7156
  * azurerm_mysql_server - support for `threat_detection_policy` (#7156)
  * Add example for the usage of creating eventhub with dedicated cluster (#7614)
  * Fixup giovanni v0.11.0 update (#7610)
  * Remove redundant ForceNew
  * Fix the math in my head too
  * Fix eventhub validations along the way
  * Update docs
  * go mod tidy
  * Eventhub: force new resource on zone_redundant change
  * Error messages
  * Error messages
  * Error messages
  * Error messages
  * Error messages
  * Error messages
  * update changelog for #7469
  * New data source azurerm_web_application_firewall_policy (#7469)
  * update changelog for #7529
  * azurerm_api_management_identity_provider_aad: fix perpetual diff due to client_secret (#7529)
  * updating to include #7608
  * fix arg count in disappears test error message
  * Update giovanni to v0.11.0
  * update changelog for #7545
  * azurerm_web_application_firewall_policy: `custom_rules.match_conditions` support `transforms` (#7545)
  * Group OrganizationDetails data source Set()s
  * Remove error return value from flattenKeyVaultCertificateIssuerAdmins
  * Password will always be nil when read, so no use in setting it
  * Also let flatten handle nil check in resource
  * Apply suggestions from code review
  * flattenKeyVaultCertificateIssuerAdmins handles nil check
  * fixed disappears test
  * refactor and rework for missing validation in API
  * Introduce type KeyVaultCertificateIssuerID and add more nil checks
  * Apply suggestions from code review
  * Add acceptance test for azurerm_key_vault_certificate_issuer data source
  * Remove unnecessary trailing newline
  * Expand AdministratorDetails
  * Use id from state except during create
  * Nil checks
  * Reword error messages
  * Apply suggestions from code review
  * Fix bad merge of datasources list
  * Document account_id and org_id as Optional
  * Mark account_id and org_id `Optional`
  * Remove unused test method
  * Fix Sprintf args in test case
  * Add timeouts and clean up a bit
  * Add basic acceptance test for azurerm_key_vault_certificate_issuer
  * terrafmt docs
  * Add missing side navigation links
  * Add initial docs for azurerm_key_vault_certificate_issuer data source and resource
  * Password is not read back, so exclude from data source
  * Wait rather long on certificate issuance when not using self-signed certificates
  * Make password Optional
  * Add azurerm_key_vault_certificate_issuer
  * updating to include #7600
  * Update syntax for address_prefix (#7605)
  * Further clarify docs
  * Update CHANGELOG.md
  * `azurerm_kusto_cluster` - Support for `optimized_auto_scale` (#7371)
  * Clarify documentation
  * Remove incorrect validatefunc
  * update changelog for #7580
  * azurerm_application_gateway: Associate WAF policy to Application Gateway listener (#7580)
  * updating to include #7579
  * Update doc for the usage of network_rule_set of container registry (#7258)
  * dependencies: updating `github.com/hashicorp/terraform-plugin-sdk` to `v1.13.1`
  * Docs - Scale set overprovision default is true (#7592)
  * missing comma from settings list
  * update changelog for #7559
  * updating to include #7548
  * Reverted back 1.0 and updated docs
  * update
  * updating to include #7585
  * acctest: using the root/checkout, rather than working directory
  * updated for #5916
  * fix slot import test data
  * fix slot import test config
  * typo in test name prefix
  * virtualwan related resource still uses 2020-03-01 version
  * Docs fixes for AzureAD migration guide (#7576)
  * virtualhub related resource still uses 2020-03-01 version
  * acctest: specifying the full path to terraform
  * Update eventgrid_event_subscription.html.markdown (#7575)
  * testing: downloading terraform core prior to test runs
  * Removed 1.0 version
  * Added new 0.1 version to WAF managed_rule_set to support Microsoft_BotManagerRuleSet creation in tf
  * update import path
  * Fix typo in SlotVirtualNetworkSwiftConnectionId type's name
  * update CHANGELOG>.md to include #7421
  * azurerm_kusto_cluster  - support for language_extensions (#7421)
  * update CHANGELOG.md to include #7378
  * Fix #7376 - azurerm_storage_data_lake_gen2_filesystem crashes during plan if SA deleted (#7378)
  * fix ci
  * Cleanup after v2.17.0 release
- from version 2.17.0
  * tweaked slot example, updated arg order to alphabetical
  * added validation to slot name
  * fixup resources and tests
  * update
  * Return error if disabling monitor fails
  * Moved extensionsClient
  * Change eventhub limits validation and update docs
  * updating to include #7513
  * Typo in property name, remove unnecessary if
  * Update website/docs/d/eventhub_namespace.html.markdown
  * Update website/docs/r/eventhub_namespace.html.markdown
  * Update azurerm/internal/services/eventhub/eventhub_namespace_data_source.go
  * Update datasource, update docs
  * Update azurerm_eventhub_namespace with optional dedicated_cluster_id property
  * updating to include #7531
  * Update changelog for #7533
  * New Resource: `azurerm_kusto_cluster_principal_assignment` (#7533)
  * updating to include #7534
  * updating to include #7547
  * Set property during read too
  * updating to include #7546
  * formatting
  * clarifying where the enabled property lives
  * updating to include #7387 & formatting the changelog
  * fixes not waiting for createOrUpdate #7539
  * dependencies: updating to v43.2.0 of github.com/Azure/azure-sdk-for-go
  * Refined docs for shared image
  * Update Migrating to AzureAD Provider guide for Terraform v0.12 (#7526)
  * Fix typo in debug output
  * Indentation.
  * Update website/docs/r/web_application_firewall_policy.html.markdown
  * Update website/docs/r/web_application_firewall_policy.html.markdown
  * Removed settings values.
  * Changed intervals for validation.
  * Update code
  * Update code
  * update based on suggestion
  * Add tests
  * Update website/docs/r/eventhub_namespace.html.markdown
  * Update website/docs/d/eventhub_namespace.html.markdown
  * fmt
  * Update eventhub_namespace for `ZoneRedundant` property
  * update
  * add doc and format test file
  * add support for `sku_name` and `trace` for `azurerm_spring_cloud_service`
  * update CHANGELOG.md to include #7277
  * Update `azurerm_shared_image` - flip `generalized` to `specialized` (#7525)
  * Update changelog for #7515
  * `azurerm_marketplace_agreement` - fix issue around import #7515
  * Improve example of the usage of network_profile_id of azurerm_container_group
  * Improve doc for the description of requested_service_objective_name
  * Update changelog for #7523
  * `data.azurerm_postgresql_server` - expose `sku_name` (#7523)
  * `azurerm_shared_image` & `azurerm_shared_image_version` - support for specialized images by setting generalized to false (#7277)
  * update CHANGELOG.md to include #7111
  * azurerm_hdinsight_*_cluster - fix broken updaten due to api not allowing cluster to be disabled (#7111)
  * Update doc example for request_timeout of application gateway (#7512)
  * Initial commit
  * Update code
  * update test case
  * update CHANGELOG.md to include #7499
  * refactor: cleanup some property names (#7499)
  * tweak some examples (#7507)
  * cleanup some example naming (#7500)
  * Cleanup after v2.16.0 release
- from version 2.16.0
  * ordering
  * removing #7408 since it's been reverted
  * triggering travis one more time
  * Replace underscores with hyphens in example service bus namespace names as underscores are not valid
  * r/frontdoor: removing an unused param
  * updating to include #7480
  * Link to 'Microsoft Time Zone Index Values ' was changed to up to date one.
  * updating to include #7473
  * updating to include #7411
  * updating to include #7478
  * provider: adding a warning about bugs if the read timeout is over 5 minutes
  * r/frontdoor: using a consistent read-timeout of 5 minutes
  * updating to include #7458
  * update CHANGELOG.md for #4885
  * azurerm_api_management_api - support for `subscription_required` (#4885)
  * fixes issue-3328
  * Add test for api_management path validation
  * Update path validation for api management api
  * fixup comments
  * add retry logic on managementgroup create for roleassignment consistency issue on read
  * fix linted fmt errors
  * fmt
  * provide more fields to test
  * updating to include #7433
  * fix activity log alert for Recommendation category
  * Update website/docs/r/web_application_firewall_policy.html.markdown
  * update CHANGELOG.md to include #7373
  * azurerm_kusto_cluster - supoport for zones (#7373)
  * update CHANGELOG.md to include #7459
  * `azurerm_network_interface_security_group_association` remove itself when NIC not found (#7459)
  * update CHANGELOG.md to include #7456
  * `azurerm_postgresql_server` - force new if `sku_name` changes tier (#7456)
  * update CHANGELOG.md to include #7457
  * azurerm_mssql_database - support min_capacity up to 5 (#7457)
  * azurerm_monitor_activity_log_alert: support `properties.recommendationType` for recommendation alerts
  * update CHANGELOG.md entry for #7346
  * update CHANGELOG.md to include #7453
  * azurerm_mssql_database - support `GP_S_Gen5` SKUs up to `GP_S_Gen5_40` (#7453)
  * update CHANGELOG.md to include #7385
  * make `ip_rules`, `virtual_network_subnet_ids` could become zero - `azurerm_storage_account_network_rules` (#7385)
  * updateing CHANGELOG.md entry for #7430
  * update CHANGELOG.md toinclue #7408
  * `azurerm_frontdoor` - Fix timeout for read operation to match documentation (#7408)
  * azurerm_marketplace_agreement: update doc for importing ID (#7438)
  * Update dev_test_global_vm_shutdown_schedule.html.markdown (#7442)
  * azurerm_frontdoor - Update documentation of redirect_type (#7449)
  * updating to include #7437
  * Updated for #7440
  * Doc Fix: private_endpoint.html.markdown #7450
  * Update changelog for #7369
  * `azurerm_kusto_cluster` - Support for `virtual_network_configuration` #7369
  * Updated for #7430
  * Updated for #7346
  * Removal of possible deprecation note, moving test definition to match code layout
  * update doc
  * firewall_resource: support `threat_intel_mode`
  * Update code
  * fix typo
  * Added unit test for internal_load_balancing_mode attribute
  * Update changelog for #7424
  * `azurerm_role_definition` - terraform import now sets scope to prevent a force recreate #7424
  * Update changelog for #7367
  * `azurerm_kusto_cluster` - Support for `identity` (#7367)
  * Added - ForceNew: true for internal_load_balancing_mode
  * Bump autorest/azure/cli to 0.3.1 so AZURE_CONFIG_DIR is honoured
  * Update doc for network_rules of storage account
  * azurerm_hdinsights_*_cluster: loosen work node count validation
  * private_endpoint: fix miswordings in private_dns_zone_group section
  * mysql resources: update documentation
  * docs(application_gateway): clarify use of PathBasedRouting
  * Added three examples for AKS: egress with UDR with Azure CNI; egress with UDR with Kubenet; private API Server.
  * serverAdministratorsClient added
  * fix client name
  * fix resource client name
  * fix ServerAdministratorResource reference
  * navigation link added
  * add aad admin for azurerm_postgresql_server
  * Formatted doc.
  * Formatted files.
  * typo
  * Cleanup after v2.15.0 release
- from version 2.15.0
  * revert to Unreleased state
  * v2.15.0
  * update chANGELOG.md toinclude #7188
  * Update CHANGELOG.md
  * Doc Fix: Add note for Storage Documentation when Creating HNS Enabled (#7400)
  * Update changelog for #7372
  * `azurerm_kusto_cluster` - Support for extended Kusto Cluster SKUs #7372
  * updating to include #7246
  * fixes #6571
  * Update the compute service api-version from 2019-07-01 to 2019-12-01 (#7101)
  * Update changelog for #7375
  * `azurerm_kusto_cluster` - Support for `enable_purge` #7375
  * Doc Fix: use proper url for importing azure virtual machine #7399
  * Updated for #7107
  * Updated for #6713
  * Support for certificate attributes
  * Update for #6955
  * update
  * Update changelog for #7382
  * `azurerm_storage_share_directory ` - `name` can now contain one nested directory #7382
  * update CHANGELOG.md to include #6845
  * Update data source `azurerm_management_group` - support get data source of mgmt group by using `display_name` (#6845)
  * Update interpolation syntax (#7361)
  * "state" only allows "Disabled" or "Enabled". (#7364)
  * Updated the example SQL DB name to not say "mysql" (#7362)
  * Rename to azurerm_app_service_slot_virtual_network_swift_connection
  * Extract ID parsing into a function
  * Fix acceptance test
  * Retain correct slot name
  * Rename Tests for TestAccAzureRMAppServiceVirtualNetworkSwiftConnectionSlot
  * Add missing side navigation link
  * Fix sprintf number of args
  * Nicer examples
  * Remove CHANGELOG entry
  * Adds Resource azurerm_app_service_virtual_network_swift_connection_slot
  * add retry and update some documents
  * app_service_environment resource - allow  for the  argument
  * Add link to `app_settings` values reference (#7304)
  * Update changelog for #7331
  * `azurerm_policy_assignment` - added support for `enforcement_mode`  (#7331)
  * update CHANGELOG.md to include #7154
  * `azurerm_network_watcher_flow_log` destroy fails (#7154)
  * uppdate CHANGELOG/md to include #7324
  * azurerm_app_service_environment - support for user_whitelisted_ip_ranges (#7324)
  * update CHANGELOG.md to include #7087
  * azurerm_app_service_certificate - support for hosting_environment_profile_id (#7087)
  * Documentation Fix: `azurerm_virtual_network_peering` #7335
  * Update changelog for #7306
  * New Resource: `azurerm_eventhub_cluster` (#7306)
  * update CHANGELOG.md to include #6535
  * New resource - azurerm_data_factory_integration_runtime_self_hosted (#6535)
  * update CHANGELOG.md to include #7272
  * `azurerm_hdinsight_cluster` deprecate `min_instance_count` (#7272)
  * update CHANGELOG.md to include #6838
  * Upgrade Kusto SDK to 2020-02-15 from 2019-05-15 (#6838)
  * Tabs2spaces.
  * Indentation.
  * Removed local build stuff.
  * Added three attributes to waf_policy
  * Merged build files.
  * Update app service example main.tf (#7332)
  * Update logic_app_action_http.html.markdown (#7330)
  * Fix to one missed comment.
  * Updates to comments
  * split into two different resources
  * update CHANGELOG.md to include #7296
  * Declare azurerm_healthcare_service argument access_policy_object_ids as optional (#7296)
  * Fix incorrect rendering of h2 after stray codeblock (#7323)
  * Azure IoT Time Series Insights Reference Data Set  - Correct the title in the docs (#7322)
  * update CHANGELOG.md to include #7263
  * update CHANGELOG.md to include #7273
  * `azurerm_api_management_api` createUpdate change (#7273)
  * Add developer_portal_url attribute on azurerm_api_management (#7263)
  * acctest: fixing the compilation issue
  * acctest: dynamically updating the build directory
  * azurerm_network_interface: change case in import
  * clear code
  * ri
  * updating to include #7279
  * updating to include #7188
  * dependencies: updating to v43.1.0 of github.com/Azure/azure-sdk-for-go
  * dependencies: updating to v43.0.0 of github.com/Azure/azure-sdk-for-go
  * Cleanup after v2.14.0 release
- from version 2.14.0
  * updating to include #7294
  * Typo in GH ref #7285
  * Updated for #7825
  * additional doc fixes
  * updating to include #7207
  * doc fixes
  * when callingWebHook is empty, make the field be nil, not a pointer of empty string
  * updated schema sets to lists
  * update
  * update CHANGELOG.md to include #7076
  * azurerm_api_management_api``wsdl_selector` is required when content_format = "wsdl" (#7076)
  * additional test for generated cert
  * ignoring lockfiles
  * kubernetes-cluster: removing the old examples
  * kubernetes-cluster: adding an example for a cluster with monitoring enabled
  * kubernetes-cluster: adding an example of using the network policy calico
  * kubernetes-cluster: example for nodes on an internal network
  * kubernetes-cluster: example for using a spot node pool
  * kubernetes-cluster: updating the basic-cluster example
  * adding a note covering Azure Policy
  * updating to include #7233
  * r/kubernetes_cluster_node_pool: making the CheckDestroy test support both the Data Source & Resource
  * added kv cert ds, tests and docs
  * d/kubernetes-cluster: removing the `version` field from the `azure_policy` block
  * Documentation for app_service_environment resource was missing description of internal_load_balancing_mode argument
  * update
  * Update code
  * Update code
  * update
  * add documentation for base_url
  * Update azurerm/internal/services/bot/bot_connection_resource.go
  * Update azurerm/internal/services/bot/bot_connection_resource.go
  * add check for available service provider - `azurerm_bot_connection`
  * Update azurerm_subnet_nat_gateway_association document example usage.
  * Remove preview statement
  * update
  * Error creating the example. (#7266)
  * context fixes for state migration test panics (#7264)
  * Update changelog for #7217
  * `azurerm_cosmosdb_account` modifying `geo_location` no longer triggers a recreation of the resource #7217
  * Update changelog for #7202
  * New Resource: `azurerm_iot_time_series_insights_access_policy` (#7202)
  * updating to include #7248
  * Updated for #6930
  * gosimple
  * review fixes and amendments
  * r/kubernetes_cluster: conditionally nil-ing the load balancer profile
  * Update doc for resource group property of traffic manager endpoint
  * Updated for #7224
  * Update changelog for #7112
  * New Resource: `azurerm_iot_time_series_insights_reference_data_set` (#7112)
  * update CHANGELOG.md #7211
  * Azure policy rest version bump to 2019-09-01 (#7211)
  * (d|r)/kubernetes_cluster: `version` is no longer applicable for `azure_policy`
  * review comment changes
  * r/kubernetes_cluster_node_pool: fixing the test `TestAccAzureRMKubernetesClusterNodePoolDataSource_basic`
  * r/kubernetes_cluster: conditionally setting the `managed_outbound_ip_count`, `outbound_ip_address_ids` and `outbound_ip_prefix_ids` fields"
  * linting
  * r/kubernetes_cluster: supporting delta-updates for the `load_balancer_profile` block within the `network_profile` block
  * r/kubernetes_cluster: fixing the key vault test
  * r/kubernetes_cluster: fixing pr comments
  * r/kubewrnetes_cluster: keeping the linter happy
  * terrafmt
  * cleanup
  * New Data Source: `azurerm_kubernetes_cluster_node_pool`
  * r/kubernetes_cluster: fixing the broken assertion
  * r/kubernetes_cluster: fixing a test assertion
  * r/kubernetes_cluster: only searching for system node pools
  * d/kubernetes_cluster: fixing a test compilation issue
  * r/kubernetes_cluster: always setting the `idle_timeout_in_minutes` field
  * r/kubernetes_cluster: fixing the test TestAccAzureRMKubernetesCluster_diskEncryption
  * r/kubernetes_cluster: updating the versions being used for testing
  * r/kubernetes_cluster: fixing the test TestAccAzureRMKubernetesCluster_addonProfileAzurePolicy
  * r/kubernetes_cluster: updating the field name to match the schema
  * r/kubernetes_cluster: test for azure policy v1 to v2 is combined
  * r/kubernetes_cluster: node_labels and node_taints within the default_node_pool are ForceNew
  * r/kubernetes_cluster_node_pool: changing node_labels/node_taints forces a new resource
  * r/kubernetes_cluster_node_pool: fixing the test
  * validating the `spot_max_price` and `max_bid_price` fields
  * r/kubernetes_cluster: support for spot node pools
  * r/kubernetes_cluster: raising an error when trying to upgrade the kubernetes version for spot node pools
  * r/kubernetes_cluster: azure policy is not supported in China
  * r/kubernetes_cluster: `kubernetes_dashboard` is not supported in US Government
  * r/kubernetes_cluster: support for v2 of the azure policy addon
  * r/kubernetes_cluster_node_pool: allowing updating of the `mode` field
  * Enable AKS AAD integration v2 + SDK version bump
  * d|r/kubernetes_cluster: comments from the pr
  * Add support for encrypted disks in aks
  * r/kubernetes_cluster_node_pool: support for configuring `mode`
  * r/kubernetes_cluster: exposing the `balance_similar_node_groups` field now it's available
  * fixing broken tests from merge conflicts
  * r/kubernetes_cluster: support for the Paid SKU (a.k.a. Uptime SLA)
  * dependencies: updating to use 2020-03 of the containerservice api
  * r/kubernetes_cluster: grouping optional fields
  * r/kubernetes_cluster: fixing pr comments
  * init kubernetes_cluster auto_scale_profile
  * r/kubernetes_cluster: Azure Policy is not supported in US Government. Fixes #6702.
  * r/kubernetes_cluster_(node_pool): adding a note covering the version constraints for AKS
  * r/kubernetes_cluster: mapping `spot_max_price` for the default node pool
  * r/kubernetes_cluster_(node_pool): validating the orchestrator version prior to deployment
  * r/kubernetes_cluster: comments from PR review
  * tests: splitting the test dictionaries amongst the files to reduce conflicts going forward
  * Add Orchestrator version for Kubernetes Cluster and Node Pool
  * d/kubernetes_cluster: making all read-only properties read-only
  * r/kubernetes_cluster: support for load balancer settings
  * updating to include #7095
  * r/eventhub_namespace_authorization_rule: adding a state migration
  * Update code
  * Found two typos in the examle code.
  * subnet_id can't take the subnet name.
  * GH-7227 Fix the descriptions for the subnet ID parameters in the frontend_ip_configuration and gateway_ip_configuration for the application_gateway resource.
  * Extended EventGrid webhook support
  * Update changelog for #7181
  * `azurerm_web_application_firewall_policy` - Add support for `GeoMatch` operator in request filter #7181
  * Updated for #7230
  * updating to include #6971
  * Update doc for max_size_gb of sql elastic pool
  * Fix Linux Consumption Function Apps
  * updating to include #7216
  * updating to include #7182
  * updating to include #7222
  * update doc for `azurerm_key_vault_certificate`
  * tidied requiresImport test
  * updated resource file name
  * udpated docs, schema ordering
  * remove useless
  * use correction subscriptionId
  * rework of PR 5330
  * Cleanup after v2.13.0 release
- from version 2.13.0
  * Fix nil pointer refernce for subject_filter of eventgrid
  * fixed test config
  * fixed PR notes and optionals
  * updating to include #7141
  * updating to include #7204
  * refactor, tests, linting, docs
  * updating to include #7203
  * updating to include #7205
  * formatting
  * r/role_assignment: support for assigning Preview roles
  * r/key_vault_certificate: always setting the `certificate_data` and `thumbprint` fields
  * remove useless
  * r/eventgrid_event_subscription: setting the correct field
  * kt's review
  * update CHANGELOG.md to include
  * new resource `azurerm_monitor_action_rule_action_group`, `azurerm_monitor_action_rule_suppression` (#6563)
  * gofmt
  * refactor for IDs
  * logic fix
  * fix error msg
  * goimports lint fix
  * SetId empty checks
  * moved User MSI validation to msi package
  * deps fix
  * Added missing RP entry
  * acctest cleanup
  * lint fixes
  * moved ua-msi parsing as per review
  * tidy and fixes
  * serialise assignment resource tests, fix datasource tests
  * updated test for new artifacts
  * updated test for new values in ds
  * Added mg level test
  * Update data source for consistent schema values to resource
  * Subscription tests passing
  * Added tests and docs
  * updates
  * commit for testing
  * new DS, modules and some tests
  * adding orchestrated vmss test
  * Updated for #7189
  * comment update
  * alt sub for acctests client data
  * re-added 500 Response workaround for CosmosDB CheckNameExists bug that has resurfaced
  * Update web_application_firewall_policy.html.markdown
  * Remove resource_group_name in storeage_container
  * The title said "mssql" but this is sql page
  * add retry if 409 && beingdeleted
  * Update CHANGELOG.md
  * `azurerm_cdn_endpoint` - `origin_host_header` can now be set to empty (#7164)
  * `azurerm_role_assignment` - add notes for different id format #7166
  * Update changelog for #7168
  * `azurerm_virtual_network_gatway` - `vpn_client_protocols` is now also computed to prevent permanent diffs #7168
  * fix var name
  * typo in readme, check if id is null before setting
  * Update changelog for #7099
  * New resource/data source `azurerm_logic_app_integration_account`  (#7099)
  * Updated for #7157
  * Update changelog for #6224
  * `azurerm_data_factory_pipeline`: Support for `activities` (#6224)
  * Added example for linux function apps (#7146)
  * update CHANGELOG.md to include #6861
  * Update Resource: Add advanced filter support to `azurerm_eventgrid_event_subscription` (#6861)
  * update docs
  * Updates Changelog for #7094
  * `r/signalr` - adds support for `EnableMessagingLogs` feature (#7094)
  * Update Changelog for #7122
  * `azurerm_eventhub_authorization_rule` - Fix intermittent 404 errors (#7122)
  * Update for #7059
  * fix scope of name availability check in ASE hosted app services
  * resolve review comment
  * Azure Function Support for Event Grid Subscription
  * Fix CI
  * `azurerm_monitor_metric_alert` supports multiple scopes and different criterias
  * updaate CHANGELOG.md to include #7140
  * azuerm_function_app - correctly set kind when os_type is `linux` (#7140)
  * terrafmt markdown
  * add to website.erb
  * add scale set data source with identity
  * Update docs for azurerm_disk_encryption_set
  * r/dev_test_global_vm_shutdown_schedule fix doc example (#7126)
  * Cleanup after v2.12.0 release
- from version 2.12.0
  * update CHANGELOG.md to include #7080
  * `azurerm_storage_account` - Support RAGZRS and GZRS `account_replication_type` (#7080)
  * azurerm_public_ip - update docs wrt zone redundant IPs (#7124)
  * Update `azurerm_policy_assignment` - `location` should be required when `identity` is assigned (#7075)
  * Update public_ip.html.markdown (#7119)
  * fix duplicate underscore
  * ci
  * r/nat_gateway_public_ip_association: using a custom ID / support for delta updates in `azurerm_nat_gateway` (#7106)
  * fmt
  * docs: fix monitor_action_group azure_function_receiver function_app_resource_id typo (#7091)
  * Update CHANGELOG.md
  * `azurerm_shared_image_version` - `target_region.x.storage_account_type` is now defaulted and multiple `target_region`s can be added/removed (#6940)
  * r1
  * split blob
  * acctests: fixing a missing `%%`
  * add 1.x and 2.x changelog files back into master
  * update CHANGELOG.md to include #6450
  * Add virtual resource association: azurerm_nat_gateway_public_ip (#6450)
  * Fix typo in docs (#7096)
  * versionless cert for agw
  * Update changelog for #6858
  * `azurerm_eventgrid_topic` - support for `input_schema`, `input_mapping_fields`, and `input_mapping_default_values` (#6858)
  * Removes preview note
  * update CHANGELOG.md to include #6867
  * New data source: `azurerm_advisor_recommendations` (#6867)
  * update CHANGELOG.md to include #7079
  * azurerm_logic_app_action_http: add `run_after` (#7079)
  * Updated import example for EventGrid Event Subscriptions (#7088)
  * updating to include #7027
  * acctest: moving off the built-in test parser for now
  * acctest: using teamcity-go-test for service packages
  * acctest: updating the build config definition to 2020.1
  * Update code
  * Update code
  * Update doc for access_tier of storage account
  * update CHANGELOG.md to include #6527
  * d/azurerm_kubernetes_cluster extended with kubelet_identity and identity (#6527)
  * update CHANGELOG.md to include #7071
  * r/api_management_api_version_set: handling changes to the Azure Resource ID (#7071)
  * Use address_prefixes in azurerm_application_gateway (#7072)
  * updating to include #6979
  * updating to include #6968
  * updating to include #7056
  * Update code
  * Update code
  * Update code
  * Fixed 'Unknown' issuer not working
  * update CHANGELO.md to include #5536
  * New resource: azurerm_dev_test_global_shutdown_schedule (#5536)
  * update CHANGELOG.md to include #6689
  * azurerm_batch_pool - support `container_image_names` property (#6689)
  * Update code
  * Fix validation for serivce bus topic name
  * update CHANGELOG.md to include #6860
  * Update Resource: `azurerm_eventgrid_event_subscription` (#6860)
  * update CHANGELOG.md to include #7057
  * Fix `azurerm_orchestrated_virtual_machine_scale_set` - `azurerm_linux|windows_virtual_machine` should allow to assign `virtual_machine_scale_set_id` in non-zonal deployment (#7057)
  * update CHANGELOG.md to include #7061
  * azurern_[linux|windows]_virtual_machine - Correctly check the length of the rsa ssh `public_key` property (#7061)
  * Clarify the content of the parameters_body argument (#7060)
  * formatting
  * make app_service ip_restriction priority default to 65000
  * OMS Agent Identity Export
  * Add note about certificate format (#7054)
  * Cleanup after v2.11.0 release
- from version 2.11.0
  * update CHANGELOG.md to include #6789
  * New resource/Data Source `azurerm_data_share` (#6789)
  * Update changelog for #7012
  * New Resource: `azurerm_time_series_insights_environment`  (#7012)
  * update CHANGELOG.md to include #6626
  * New resource: `azurerm_orchestrated_virtual_machine_scale_set` (#6626)
  * Update storage account syntax for Azure Function App (#7040)
  * Fix deprecated interpolation syntax in docs (#7038)
  * Fixing linter errors
  * mariadb_server: add missing 'public_network_access_enabled' argument (#7037)
  * updating to include #7036
  * update CHANGELOG.md to include #7015
  * azurerm_postgresql_server - do not attempt to get the threat protection with the basic SKU (#7015)
  * fixes #7035
  * Ensure that basic and monitor tests use the same roles
  * Updated for #6668
  * test fixes, status-403 bug changes
  * update CHANGELOG.md to include #7031
  * azurerm_redis_cache: support new maxmemory policies `allkeys-lfu' & 'volatile-lfu` (#7031)
  * update cHANGELOG.md to include #5526
  * azurerm_netapp_volume - support mount_ip_addresses (#5526)
  * Update for #6948
  * `azurerm_platform_image` - support for `version` filter (#6948)
  * updating to include #6958
  * updating to include #7024
  * fixing the type
  * updating to include #7023
  * tooling: raising an error when d.SetId('') is found in a data source
  * d/maintenance_configuration: raising an error when not found
  * healthcare: ensuring all blocks are set
  * d/hdinsight_cluster: raising an error when not found
  * d/data_share_account: raising an error when not found
  * d/image: raising an error when not found
  * d/shared_image_version: raising an error when not found
  * d/shared_image_versions: erroring when not found
  * d/api_management_group: raising an error when not found
  * d/private_endpoint_connection: raising an error when not found
  * d/firewall: erroring when not found
  * d/user_assigned_identity: erroring on a 404
  * Test cases added
  * Resolve comments
  * azurerm_public_ip  - Basic SKU in public ip does not support Availability Zone (#7017)
  * Fix #6920
  * update CHANGELOG.md to include #6967
  * `azurerm_app_service` Added support for Action of Allow or Deny in ip_restriction. (#6967)
  * move analysis server tests out of tests package
  * update CHANGELOG.md to include #6938
  * `azurerm_api_management_subscription` get Primary/Secondary Key (#6938)
  * Azure monitor doc  for all hdinsight resources
  * Azure monitor for Storm
  * Azure monitor for Spark
  * Azure monitor for Kafka
  * Azure Monitor for InteractiveQuery cluster
  * Aze monioor HBase cluster
  * azurerm_mssql_server - add public network access todocs (#7011)
  * Fix example in doc for firewall nat rule (#6941)
  * Update doc for access policy of storage share (#6942)
  * A bit of refactoring
  * Documentation for hadoop
  * Error message clean up
  * Implement monitor changes
  * Enable monitor on create
  * Update code
  * base_url->key_vault_id, documentation cleanup
  * mariadb_database: fix deprecated warnings in example code
  * Fix spelling of namespace
  * Fix documentation storage_account_name + storage_account_access_key
  * whitespace fix
  * fixed constructor ordering
  * updating to include #6927
  * updated val ordering for ClientConfiguration
  * Updating repositories for mvn / teamcity
  * updating to include #6964
  * Added alt subscription to tc config
  * updating to include #6947
  * truncating the changelog
  * updating to include #6973
  * Update dev_test_schedule.html.markdown
  * Update code
  * Update code
  * Fix typo in eventgrid_event_subscription.html.markdown
  * databricks workspace test workspaceurl with regex
  * Update doc for rule_set_type of app gateway
  * Update doc for rule_set_type of app gateway
  * databricks add workspace_id and url
  * Update api_management_logger_resource_test.go
  * fmt
  * update
  * Update api_management_logger_resource_test.go
  * mariadb_server: remove deprecated interpolation syntax in docs (#6970)
  * update CHANGEOG.md to include #6727
  * upgrade network to 2020-03-01 (#6727)
  * New Feature: Data Factory Linked Service Key Vault Resource
  * Test fix - name too short error returned for empty name
  * update CHANGELOG.md to include #6725
  * provider: upgrade azure-sdk-for-go to v42.1.0 & azuread to v0.9.0 (#6725)
  * Update doc for custom_domain in storage_account (#6947)
  * Update eventgrid_event_subscription.html.markdown (#6953)
  * Update doc for cosmosdb account GlobalDocumentDB connection string (#6965)
  * Fix typo in resource "azurerm_application_insights": application_type "Other" -> "other" (#6946)
  * `azurerm_postgresql_server` - Update documentation per request from service team (#6963)
  * minor test fixes
  * Align azurerm_sql_virtual_network_rule name validation with azure validation
  * Updates
  * added functionality for scm_ip_restriction - allow or deny & added to data source.
  * Support 'PATCH' method in corsRule with blob properties
  * fix: eventgrid id parsers
  * Added support for scm ip restrictions.
  * Cleanup after v2.10.0 release
- from version 2.10.0
  * update CHANGELOG.md to include #6682
  * `azurerm_api_management_diagnostic` - support required property `api_management_logger_id` (#6682)
  * Address PR comments
  * Fix duplicate provider configuration in storage tests (#6748)
  * update CHANGEloG.md to include #6721
  * azurerm_postgres_server - support for threat_detection_policy (#6721)
  * azurerm_api_management - support key_vault_id's without a version (#6723)
  * update CHANGELOG.md to include #6723
  * updating to include #6917
  * Update for #6925
  * feature: optionally enhanced validation
  * Update azurerm/internal/services/authorization/role_assignment_resource.go
  * Added poller to check for consistency on role assignment creation
  * Fix azurerm_subnet_nat_gateway_association documentation title
  * updating to include #6580
  * fixes #5758
  * updating to include #6916
  * Fixes #6741
  * add documentation for the source_image_reference block
  * update CHANGELOG.md to include #6833
  * mysql_server: New attributes, flatten `storage_profile` block (#6833)
  * update CHANGELOG.md to include #6865
  * mariadb_server: New attributes, flatten `storage_profile` block (#6865)
  * update CHANGELOG.md to include #6859
  * New Resource: `azurerm_eventgrid_domain_topic` (#6859)
  * update CHANGELOG.md to include #6911
  * `azurerm_monitor_diagnostic_setting` - Fix crash around `retention_policy` (#6911)
  * Update doc for validation of aks (#6884)
  * update CHANGELOG.md to include #6783
  * api_managment - support user assigned managed identities (#6783)
  * update CHANGELOG.md to include #6850
  * azurerm_api_management - Only set `hostname_configuration` properties if not empty (#6850)
  * fixes #5864 and #6763
  * update CHANGELOG.md to include #6601
  * azurerm_express_route_circuit - de-provision and re-provision circuit when changing bandwidth reduction (#3983) (#6601)
  * update CHANGELOG.md to include #6724
  * Support the Developer Portal type of hostname_configuration in azurerm_api_management (#6724)
  * update CHANGELOG.md to include #6105
  * azurerm_application_gateway  - support WAF Policies (#6105)
  * Update changelog for #6910
  * `data.azurerm_security_group` - fixing crash where id is nil #6910
  * size property must not be defined if source_uri is used (#6897)
  * tool: adding a check for gradually deprecated functions
  * Update for #6821
  * update
  * update doc for `azurerm_role_assignment`
  * Update import command in eventhub ns doc
  * update CHANGELOG.md to include #6834
  * azurerm_api_management_named_value - fix the non empty plan when `secret` is true (#6834)
  * Update doc for network profile of aks (#6810)
  * Update changelog for #6844
  * `azurerm_log_analytics_workspace` - Support `rentention_in_days` for Free Tier (#6844)
  * update CHANGELOG.md to include #6534
  * Bug: azurerm_kubernetes_cluster errors out with InvalidLoadbalancerProfile on changes (#6534)
  * updating to include #6875
  * Fix case on AuthorizationRules to match Azure API
  * updating to include #6871
  * align on versin 41.2 of SDK
  * update
  * Fix fmt flag
  * Fix #6830
  * add type PipelineReference in trigger res
  * Update per review
  * ordering
  * updating to include #6862
  * updating to include #6864
  * Update doc for traffic manager endpoint
  * `SchemaResourceGroupNameForDataSource` Add `ValidateFunc`
  * update CHANGELOG.md to include #6846
  * `azurerm_windows_virtual_machine` - Allow update of OS disk encryption settings (#6846)
  * Update changelog for #6851
  * `azurerm_application_insights` - `retention_in_days` defaults to 90 #6851
  * fmt
  * Fix typo in terraform state mv command (#6856)
  * Fix crash
  * update CHANGELOG.md to include #6837
  * Upgrade EventGrid SDK to 2020-04-01-preview (#6837)
  * Updates doc for aks node pool (#6825)
  * updating to include #6841
  * Update changelog for #6826
  * `data.azurerm_virtual_machine` - export `identity` attribute (#6826)
  * Changed partition_ids from TypeSet to TypeList
  * updating to include #6848
  * tf format in website docs
  * Added azurerm_eventhub data source to website navigation
  * Fixed tflint errors
  * modify regexp: escape dot
  * Removed space from Event Hub in docs
  * New data source azurerm_eventhub
  * Fix load-balancer example with new syntax for v2.0 (#6836)
  * `azurerm_automation_account` DS set its own ID
  * docs: added note to `infrastructure_encryption_enabled` property (#6831)
  * Update for #6822
  * `azurerm_mssql_server`  - Add support for `azuread_administrator` (#6822)
  * Update express_route_circuit_peering.html.markdown (#6824)
  * Cleanup after v2.9.0 release
- from version 2.9.0
  * update CHANGELOG.md to include #6819
  * [BUG] azurerm_redis_cache backup requires connection string (#6819)
  * update CHANGELOG.md to include #6813
  * `azurerm_automation_runbook` - add support for create runbook as draft and then publish  (#6813)
  * update CHANGELOG.md to include #6792
  * update `azurerm_policy_assignment` - allow scopes of policy set definition without `subscription/<id>` (#6792)
  * update doc for "azurerm_redis_cache" (#6807)
  * updating to include #6817 / formatting
  * update CHANGELOG.md to include #6708
  * support alias connection strings for eventhub resources (#6708)
  * builder: raising an error if environment is unintentionally set to "AZURESTACKCLOUD"
  * Update for #6650
  * New resource: `azurerm_sentinel_alert_rule_scheduled` #6650
  * Update for #6705
  * Update for #6661
  * Note that App Service Health Check is in Preview
  * Document health_check_path on azurerm_app_service
  * Add acceptance test for health_check_path
  * Add health_check_path to site_config
  * added todo
  * update validation for new value in remoteDebuggingVersion
  * fixes some broken tests
  * fix broken test param for remoteDebugging
  * updating to include #6786
  * add note that analysis services server is started and stopped during update
  * Update doc for property sku of servicebus namespace
  * Update website/docs/r/virtual_hub_connection.html.markdown
  * formatting
  * formatting
  * formatting
  * address review
  * updates `privatedns`
  * updates `powerbi`
  * updates `postgres`
  * updates `portal`
  * updates `policy`
  * updates `network`
  * updates `notificationhub`
  * updates `netapp`
  * updates `mysql`
  * updates `mssql`
  * updates `msi`
  * updates `monitor`
  * updates `mixedreality`
  * updates `media`
  * updates `mariadb`
  * updates `maps`
  * updates `managementgroup`
  * updates `maintenance`
  * updates `machinelearning`
  * updates `logic`
  * updates `loganalytics`
  * updates `kusto`
  * Updates `keyvault`
  * updates `iothub`
  * updates `iotcentral`
  * updates `healthcare`
  * updates `hdinsight`
  * updates `frontdoor`
  * updates `eventhub`
  * updates `eventgrid`
  * Update for #6769
  * `azurerm_monitor_diagnostic_setting` - `log_analytics_destination_type` supports `AzureDiagnostics` #6769
  * update CHANGELOG.md to include #6701
  * azurerm_eventhub_namespace_authorization_rule  - lock so multiple resource updates won't clash (#6701)
  * fmts & builds
  * Updates `dns`
  * Updates `devtestlabs`
  * Updates `devspace`
  * Updates `datashare`
  * Updates `datalake`
  * updates `datafactory`
  * Updates `databricks`
  * Updates `databasemigration`
  * Updates `customproviders`
  * Updates `costmanagement`
  * Updates `cosmos`
  * Updates `containers`
  * Updates `compute`
  * Updates `cognitive`
  * Updates `cdn`
  * Updates `bot`
  * Updates `batch`
  * Updates `automation`
  * Updates `authorization`
  * Updates `appplatform`
  * Updates `applicationinsights`
  * Updates `apimanagement`
  * add test for updating a paused analysis services server
  * Update for #6435
  * updating to include #6747
  * Update for #6774
  * fix PR recommendations
  * Update for #6624
  * Changed: notes regarding configuring 'TLS termination with Key Vault certificates' for App Gateway were added.
  * Update doc for property default_action of eventhub namespace
  * fix lintrest problem
  * start server when it was stopped before updating it
  * Update code
  * add pre_warmed_instance_count
  * fix comments 2nd round
  * fix comments
  * extra function version test
  * rename filename
  * init
  * fix imports
  * use custom hash function to not distinguish between upper- and lowercase name of a analysis services server ipv4 fw rule
  * fixes panic on nil value for
  * vhub_conn add doc note
  * update CHANGELOG.md to include #6575
  * New resource/Data source `azurerm_data_share_account` (#6575)
  * Added reference to bug reported on azure-sdk-for-go.
  * Update for #6145
  * acctests: switching to use the native runner
  * minor docs update
  * updating to include #6742
  * r/application_gateway: ignoring an import diff with cert data/password
  * updating the changelog for #6716
  * updating to include #6744
  * updating to include #6734
  * Update resource_arm_stream_analytics_function_javascript_udf_test.go
  * make dfault explicit
  * Workaround for strange response code in recovery services network mappings API. Fixes issue #6026
  * terrafmt for tflint compliance
  * Tests for custom DiffSuppressFuncs
  * Custom DiffSuppressFunc for policy definition
  * support create option
  * fix gofmt
  * Remove empty string password check
  * Add test for cert with empty password
  * update max allowed priority
  * changes for review feedback
  * Custom metadata DiffSuppressFunc - issue #5014
  * Updated for #6716
  * missed a fix
  * fix purge_protection keyvault tests
  * acctests: hooking up ARM_CLIENT_ID_ALT and ARM_CLIENT_SECRET_ALT
  * acctest: updating to v0.2.0 of tombuildsstuff/teamcity-go-test-json
  * acctests: boosting the default concurrency to 20
  * Cleanup after v2.8.0 release
- from version 2.8.0
  * Update resource doc for postgresql server (#6711)
  * Update for #6707
  * `data.azurerm_shared_image_version` - `name` supports `latest` and `recent`  (#6707)
  * Update CHANGELOG.md to include #6639
  * VM and VMSS validation fixes (#6639)
  * simplified recovery logic
  * added certificate soft-delete recovery support
  * added key soft-delete recovery support
  * added recovery capabilty for secrets
  * update parse function
  * app_service_environment: explicit resource group
  * make priority computed
  * update CHANGELOG.md to include #6678
  * azurerm_mssql_server -support `public_network_access_enabled` (#6678)
  * Update changelog for #6700
  * New DataSource: `azurerm_shared_image_versions` (#6700)
  * managed app: managed_app_outputs -> outputs (#6704)
  * add name and priority to ip_restriction for app_service
  * update CHANGELOG.md to include #6386
  * New resource: azurerm_managed_application (#6386)
  * provider: removes the import feature flag [A-D] (#6643)
  * update CHANGELOG.md to include #6260
  * azurerm_key_vault - can now be created without subscription level permissions (fixes #6059) (#6260)
  * update CHANGELOG.md to include #6677
  * New Resource - azurerm_mssql_server (#6677)
  * Add doc/test for `O+C` && `ConfigModeAttr` attr (#6651)
  * update CHANGELOG.md to include #6635
  * `azurerm_redis_cache` - correctly build connection strings when SSL is disabled (#6635)
  * Update website/docs/r/postgresql_server.html.markdown
  * fixing Argument reference in postgresql_server and Example Usage in postgresql_configuration and postgresql_database
  * tooling: Provider Defined Builds
  * updating to include #6604
  * fixes #4558
  * update CHANGELOG,md to include #6631
  * mssql_elasticpool - support license_type (#6631)
  * fixing example usage accodring to documentation and changes in version 3.0 of the provider
  * Update doc of event namespace auth rule (#6640)
  * azurerm_function_app - update example (#6653)
  * Change response not found to response forbidden
  * update
  * healthcare: fixing TestAccAzureRMDataSourceHealthCareService_basic
  * search: fixing TestAccAzureRMSearchService_complete
  * signalr: fixing TestAccAzureRMSignalRService_serviceMode
  * msi: fixing the broken test
  * update
  * update import doc for "azurerm_network_interface_security_group_association"
  * new resource "azurerm_maintenance_assignment"
  * Update resource_arm_mssql_database_test.go
  * Update CHANGELOG.md
  * New resource/data source: `azurerm_sentinel_alert_rule_ms_security_incident` (#6606)
  * Update changelog for #6493
  * `azurerm_subnet`: Support for multiple prefixes with `address_prefixes` #6493
  * update CHANGELOG.md to include #6630
  * azurerm_application_gateway  - support `host_names` property (#6630)
  * Adding acctest for #3996 (#6600)
  * update CHANGELOG.md to include #6603
  * azurerm_monitor_diagnostic_setting  - mark retention_policy & retention_policy  as optional (#6603)
  * update import resource id for `azurerm_network_interface_security_group_association` (#6625)
  * update CHANGELOG.md to include #6596
  * azurerm_express_route_circuit_peering  - support  customer_asn & routing_registry_name #1084 (#6596)
  * update CHANGELOG.md to include #6565
  * azurerm_virtual_network_gateway_connection  - shared_key is optional when type is IPSec (#6565)
  * update CHANGELOG.md to include #6126
  * azurerm_web_application_firewall_policy - support managed_rules (#6126)
  * update CHANGELOG.md to include #6402
  * Fix `azurerm_sql_database` blob auditing error under online secondary create mode (#6402)
  * Update tests
  * Update servicebus name validation (#6607)
  * Update CHANGELOG.md
  * `azurerm_api_management_api` - support for openapi v3 content formats #6618
  * Added test for hive only and check in reading code
  * provider: pinning to Go 1.14.2
  * Fix typo
  * ...
  * ...
  * Revert "CDN Endpoint: make origin_host_header required " (#6583)
  * Updating instead of foo to example (#6591)
  * updating to include #6574 and #6589
  * `azurerm_public_ip_prefix`: Update `prefix_length` validation to accept all valid IPv4 address ranges (#6589)
  * `azurerm_private_endpoint`: Add support for tags (#6574)
  * update CHANGELOG.md to include #6479
  * provider: upgrade API Management to 2019-12-01 (#6479)
  * Update for #6569
  * `azurerm_linux_virtual_machine_scale_set` - fixes crash with `boot_diagnositics` #6569
  * Update for #6570
  * `azurerm_iothub_dps` - fix crash when path isn't cased correctly #6570
  * update for #6304
  * `azurerm_function_app` - Added `storage_account_id` and `storage_account_access_key` (#6304)
  * provider tests: removes the requires import feature flag [L-W] (#6573)
  * provider: pin golangci to 1.24 (#6577)
  * provider: update terrafmt checks with make terrafmt command (#6567)
  * Update for #6602
  * `azurerm_api_management` - `sku_name` supports Consumption  (#6602)
  * Cleanup after v2.7.0 release
- from version 2.7.0
  * cleanup CHAGELOG.md prior to release
  * update CHANGEOG.md to include #5769
  * azurerm_api_management - support for  virtual network integrati… (#5769)
  * update CHANGELOG.md to include #6576
  * policy_assignment - allow scopes without `subscription/<id>` (#6576)
  * update CHANGELOG.md to include #6590
  * azurerm_mysql_server - support `public_network_access_enabled`… (#6590)
  * Update `r/azurerm_(linux|windows)_virtual_machine_scale_set`: a… (#6346)
  * update CHANGELOG.md to include #6346
  * update CHANGELOG.md to include #6578
  * azurerm_notification_[hub|hub_namespace] - support tags (#6578)
  * Updated for #6055
  * Updated for #6384
  * minor PR fixups for merge
  * Updated for #6476
  * Update for #6511
  * Use Terraform notation to improve visibility of this attribute
  * Improve attribute description in docs
  * Update code
  * Support HyperVGeneration for shared images
  * Revert "CDN Endpoint: make origin_host_header required " (#6583)
  * Updating instead of foo to example (#6591)
  * updating to include #6574 and #6589
  * `azurerm_public_ip_prefix`: Update `prefix_length` validation to accept all valid IPv4 address ranges (#6589)
  * `azurerm_private_endpoint`: Add support for tags (#6574)
  * new resource `azurerm_spring_cloud_app`
  * Fix update scenario for network interface
  * update CHANGELOG.md to include #6479
  * provider: upgrade API Management to 2019-12-01 (#6479)
  * Update for #6569
  * `azurerm_linux_virtual_machine_scale_set` - fixes crash with `boot_diagnositics` #6569
  * Update for #6570
  * `azurerm_iothub_dps` - fix crash when path isn't cased correctly #6570
  * update for #6304
  * `azurerm_function_app` - Added `storage_account_id` and `storage_account_access_key` (#6304)
  * provider tests: removes the requires import feature flag [L-W] (#6573)
  * Make request_routing_rule TypeSet
  * Make redirect_configuration TypeSet
  * provider: pin golangci to 1.24 (#6577)
  * provider: update terrafmt checks with make terrafmt command (#6567)
  * Fix #6452
  * add #6548 back into CHANGELOG.md
  * update CHANGELOG.md to include #6459
  * Update to include #6548
  * `azurerm_virtual_network_gateway` - per api requirements, `public_ip_address_id` is required  (#6548)
  * azurerm_postgres_server - fix #2819, #5121, #5865, #6180, #6216 (#6459)
  * New resource - `azurerm_servicebus_namespace_network_rule_set` (#6379)
  * updating to include #6541
  * updating to include #6550
  * add missing request_header_condition flatten part
  * updating to include #6512
  * update CHANGELOG.md to include #6379
  * update CHANGELOG.md to include #6538
  * app_service_environment - support for `location` property (#6538)
  * azurerm_image  - improve not found error message (#6515)
  * provider tests: removes the requires import feature flag [A-K] (#6558)
  * update cHANGELOG.md to include #6426
  * cosmosdb_mongo_collection - support `index` & `system_index` (#6426)
  * update readme.MD to include #6038
  * New Resource `azurerm_maintenance_configuration` (#6038)
  * Fix title for azurerm_bot_channel_* resources (#6553)
  * update CHANGELOG.md to include #6549
  * `resource_arm_application_gateway` - Fix crash in `backend_addr… (#6549)
  * `azurerm.erb` - Add migrating to renamed resource guide to side… (#6552)
  * `azurerm_virtual_network_gateway` - update docs around `sku` su… (#6556)
  * make origin_host_header a required field. Validation is skipped as it is done by the API/backend
  * tooling/website-scaffold: inlining the usage of tags
  * tooling/website-scaffold: making the tooling self-contained
  * tooling/website-scaffold: fixing the build
  * Fixed data source managed_disk example
  * updating to include #6509
  * updating to include #6504
  * updating to include #6431
  * remove inner check
  * go mod tidy
  * Linting fixes
  * nameservers not returned for private zones
  * New data source azurerm_private_dns_zone
  * nil check all properties
  * dependencies: updating the fork of Azure/go-autorest
  * Cleanup after v2.6.0 release
- from version 2.6.0
  * updating to include #6393
  * updating to include #6496
  * Update azurerm/internal/services/eventhub/data_source_eventhub_namespace_authorization_rule.go
  * update nat documentation
  * Update azurerm/internal/services/network/validate.go
  * Update azurerm/internal/services/network/validate.go
  * tests: ensuring that the assertions are valid/useful
  * data sources: ensuring an ID is always set
  * d/mariadb_server: ensuring the ID is always set
  * spacing
  * updating to include #5847
  * updating to include #6163
  * updating to include #4690
  * formattting
  * updating to include #6492
  * ID not set when retreiving data factory fix #4827
  * fix lintrest problems
  * Update resource_arm_managed_disk.go
  * r/cdn_endpoint: fixing up the docs
  * r/cdn_endpoint: making the schema internal
  * r/cdn_endpoint: ensuring the nested blocks are always set
  * refactoring from PR / ensuring fields are always set
  * r/cdn_endpoint: reusing the same ctx
  * Fix test name conflict in resource_arm_hpc_cache_test.go (#6478)
  * azurerm_mariadb_server - fix incorrect example code (#6475)
  * provider: add terrafmt target to makefile to fix terraform blocks
  * update CHANGELOG.md to include #6455
  * azurerm_network_interface: expose internal_domain_name_suffix (#6455)
  * Registering the Resource Provider `Microsoft.DBforMariaDB` (#6461)
  * update CHANGELOG.md to include #6333
  * `azurerm_function_app` - support for `pre_warmed_instance_count` (#6333)
  * cdn: removing the profile
  * azurerm_virtual_network - revert #6443 (#6446)
  * Update data_source_api_management_test.go
  * update CHANGELOG.md to include #6437
  * azurerm_hdinsight_* - support for `tls_min_version ` (#6440)
  * update CHANGELOG.md to include #6445
  * 'azurerm_virtual_network' - add guid attribute (#2325) (#6445)
  * update CHANGELOG.md to include #6437
  * Update CHANGELOG.md to include #6443
  * azurerm_virtual_network - make dns_servers TypeSet (#6443)
  * mssql_database - support the `threat_detection_policy` property (#6437)
  * fix based on suggestion
  * update ChANGELOG.md to include #6442
  * azurerm_function_app - prevent a panic from an empty IPSecurity… (#6442)
  * Update CHANGELOG.md to include #6438
  * azurerm_sql_server - support for `connection_policy` property (#6438)
  * documentation: ensure all data sources and resources include th… (#6433)
  * update CHANGELOG.md to include #6354
  * azurerm_application_insights - add disable_ip_masking property (#6354)
  * Fix: add document for Support for `azurerm_sql_database` audit… (#6434)
  * update CHANGELOG.md to include #6305
  * New data source: `azurerm_policy_set_definition` (#6305)
  * provider: enable gocritic & unparam linters (#6432)
  * Deprecation of private_link_enabled for enable_private_cluster
  * update CHANGELOG.md to include #6397
  * azurerm_machine_learning_workspace - fix: #6339 sku_name (#6397)
  * tests: fix various failing tests from CI (#6420)
  * update CHANGELOG.md to include #6275
  * Update data source `azurerm_policy_definition`: Make `name` as… (#6275)
  * Refactor - move the ID parsing function of VM, VM extension, VM… (#6405)
  * update CHANGELOG.md to include #6419
  * dependancies - upgrade `Azure/azure-sdk-for-go` to `v41.2.0` (#6419)
  * Cleanup after v2.5.0 release
- from version 2.5.0
  * terrafmt service_principal_client_secret.html.markdown
  * Apim example (#6414)
  * Update service_principal_client_secret.html.markdown (#6408)
  * Update CHANGELOG.md to include #6230
  * [linux|windows]_virtual_machine - Allow update of OS disk encry… (#6230)
  * Fixes title for azurerm_storage_account_network_rules
  * remove identity_profile nest
  * resolve comments
  * updating to include #6309
  * Add space between arguments in the import example
  * r/kubernetes_cluster: fixing the build
  * Mark identity required in the doc
  * docs
  * kubelet_profile added
  * updating to include #6120
  * small refactor of the tests
  * linting
  * Update sql_server.html.markdown
  * r/kubernetes_cluster: fixing the userDefined test
  * r/kubernetes_cluster: userDefinedRouting requires a Standard LB
  * nil check for txt record values
  * Add some missing `ImportStep()`s
  * More thorough testing on resource update
  * Improve error reporting
  * Drop unnecessary var assignments
  * Add navigation link for azurerm_private_dns_txt_record page
  * Fix errant indent
  * New resource: azurerm_private_dns_txt_record #5012
  * r/kubernetes_cluster: adding a test/documentation covering `outbound_type`
  * updating to include #6370
  * Update data_source_subnet_test.go
  * update CHANGELOG.md to include #6301
  * azurerm_[linux|windows]_virtual_machine - if the `priority` pro… (#6301)
  * Update docs for configuring an app registration/service principal with client certificate
  * Update docs for configuring an app registration/service principal with client secret
  * sidebar: fixing the frontmatter
  * spelling
  * remove check suppression
  * Bare minimal go changes to add feature for AKS outboundType
  * fixing the sidebar
  * r/kubernetes_cluster: making the `aci_connector_linux` & `http_application_routing` blocks cloud specific
  * clarifying #6095
  * updating to include #6095
  * linting
  * r/kubernetes_cluster: moving the `service_principal` block with the other optional props
  * r/network_interface: deprecation of network_security_group_id
  * r/kubernetes_cluster(_node_pool): updating the docs to handle `min_count`/`max_count` being null
  * r/kubernetes_cluster: fixing the docs for the `vnet_subnet_id` field
  * r/kubernetes_cluster_node_pool: explicitly requiring `null` rather than `0`
  * docs: update string to replace to make example correct
  * r/kubernetes_cluster: raising a "you must update" only when an SP & MSI are used
  * r/kubernetes_cluster(_node_pool): ensuring that tags are set on the default node pool
  * r/kubernetes_cluster(_node_pool): documenting an api bug around node pool tags
  * dependencies: updating to `2020-02-01` of the Containers API
  * Cleanup after v2.4.0 release
  * r/kubernetes_cluster: flattening `tags` for the `default_node_pool`
  * r/kubernetes_cluster: messaging the behavioural differences in the AKS API
  * Update README.md
  * r/kubernetes_cluster(_node_pool): requiring that `min_count` and `max_count` are set to `null` not 0 when undefined
  * test cleanup
  * r/kubernetes_cluster: tests for updating the node count with it ignored
  * r/kubernetes_cluster: fixing tests
  * r/kubernetes_cluster: moving the rest of the functions into parse/validate since these now exist
  * r/kubernetes_cluster_node_pool: moving the Node Pool ID to the parse package
  * r/kubernetes_cluster: updating the docs
  * r/kubernetes_cluster: updating the tests to use MSI by default
  * r/kubernetes_cluster: conditionally specifying either the service_principal or MSI blocks
  * Removing word error for error msgs
  * Add validation check to destroy
  * Moved CustomDiff add/fix test cases and docs
  * Fix for #6235
  * Update to fix 7 new test failures
  * update lower bound in docs
  * Added more tests
  * Add test case to test list
  * Updates due to API upgrade
  * always set count
  * Potential fix for #6020
  * Modify per review
  * go mod tidy && go mod vendor
  * Argument block only treat argument with element of resource as block
  * Fix doc
  * Fix AzureRMHDInsightHadoopCluster_requiresImport
  * Make metastores optional
  * Support for Oozie and Ambari
  * typo
  * remove unnecessary changes
  * cleanup
  * Change of plans, improved solution
  * Bonus: update of README
  * Implementation of suggestions
  * fix tflinter problems
  * fix linter problems
  * add test for delivery_rule
  * add test for global_delivery_rule
  * fix profile sku naming in error message
  * prevent user from using delivery_rule oder global_delivery_rule in combination with a CDN profile sku other than Microsoft_Standard
  * adjust documentation
  * add documentation for delivery rule and global delivery rule; fix minor bugs
  * Fix for terrafmt
  * Add new test to aks combined tests
  * Update of testcheck and linter problem
  * Fix formatting
  * add global delivery rule
  * Support for external Hive metastore
  * ad url path condition
  * add url file name condition
  * add url file extension condition
  * add request uri condition
  * add request method condition
  * add request header condition
  * add request body condition
  * add remote address condition
  * add query string condition
  * convert operator to string
  * add post arg condition
  * allow transforms to be a list instead of single value
  * add device condition
  * allow multiple values for request scheme
  * allow multiple values for cookies condition
  * add HTTP version condition
  * add cookies condition
  * refactor/shorten ExpandArmCdnEndpointConditionRequestScheme function
  * I hope nobody sees how I'm fiddling around here /o\
  * Fixing test failures
  * add URL Rewrite action
  * Mistake in test fixed
  * extract delivery rule actions and conditions into own function
  * add modify response header action
  * add modify request header action
  * remove obsolete files
  * add cache key query string action
  * rename packages without underscores
  * remove obsolete policy layer; make removing of rules working as well
  * disable adding of duration when using BypassCache behavior
  * fix not working build
  * add cache expiration action to delivery_rule
  * add cache expiration action
  * shorten names of conditions and actions
  * add method to test cache expiration duration
  * fix rename of match_values to match_value; rename endpoint_delivery_policy.go
  * fix problems in order to apply correctly
  * fix basic issues in order to run `terraform plan`
  * move actions and condition into own dir; add flatten functions for url redirect action and request scheme condition
  * implement rad & update for delivery_policy
  * rename delivery_rule to rule; allow max 4 rules (leave one spot for global rule)
  * allow max 5 rules per delivery policy
  * add endpoint delivery policy, rule, request schema condition and url redirect action
  * add delivery policy rule name validation function
  * bump CDN api version
  * Optimize test
  * changingLoadBalancerProfileConfig test added
  * Adding validation function routing table name and route name (see #6053)
  * Update CHANGELOG.md to include #5851
  * azurerm_network_watcher_flow_log  - support for the`interval_in… (#5851)
  * Update CHANGELOG.md to include #5036
  * `azurerm_sql_server` - support for the `extended_auditing_polic… (#5036)
  * tidying
  * features: removing the unused "two point oh" feature
  * tests: clarifying the features block is required going forward
  * r/search_service: the fields `partition_count` and `replica_count` are no longer forcenew
  * tools/website-scaffold: fixing a typo
  * linting
  * tools: fixing an issue when scaffolding the example for a data source
  * r/search_service: updating the docs
  * tooling: adding the scaffold-website tool to the makefile
  * d|r/resource_group: generating updated documentation
  * New Tool: website-scaffolder
  * wip: adding a scaffolder for resources/data sources
  * Updated virtual_hub.html.markdown (#6033)
  * remove obsolete policy layer; make removing of rules working as well
  * disable adding of duration when using BypassCache behavior
  * fix not working build
  * add cache expiration action to delivery_rule
  * add cache expiration action
  * shorten names of conditions and actions
  * add method to test cache expiration duration
  * fix rename of match_values to match_value; rename endpoint_delivery_policy.go
  * fix problems in order to apply correctly
  * fix basic issues in order to run `terraform plan`
  * move actions and condition into own dir; add flatten functions for url redirect action and request scheme condition
  * implement rad & update for delivery_policy
  * rename delivery_rule to rule; allow max 4 rules (leave one spot for global rule)
  * allow max 5 rules per delivery policy
  * add endpoint delivery policy, rule, request schema condition and url redirect action
  * add delivery policy rule name validation function
  * bump CDN api version
  * Computed: false removed as it is default
  * Changing load_balancer_profile settings to computed=false
* Wed Apr  8 2020 jmason@suse.com
- Update to version 2.4.0 (bsc#1168921):
  * v2.4.0
  * Changelog for #6321
  * New Resource: `azurerm_log_analytics_datasource_windows_event ` (#6321)
  * tests: fix them (#6342)
  * update CHANGELOG.md to include #4928
  * New Resource: `azurerm_spring_cloud_service` (#4928)
  * Update CHANGELOG.md to include #6175
  * azurerm_application_gateway: can combine include_path with targ… (#6175)
  * formatting
  * Update CHANGELOG.md to include #6191
  * New resource: azurerm_hpc_cache_nfs_target (#6191)
  * 0.12: adding a tfproto5 file for releases
  * miss one Name...
  * lowercase name
  * update CHANGELOG.md to include #6276
  * azurerm_management_group - deprecated and rename `group_id` to… (#6276)
  * Update changelog for #6274
  * azurerm_mssql_virtual_machine appeared twice
  * update CHANGELOG.m to include #6266
  * Update `azurerm_policy_set_definition`: Make metadata Computed… (#6266)
  * Update azurerm_lb resource output docs (#6290)
  * Modify code per review
  * update CHANGELOG,md to include #6289
  * azurerm_network_interface - always send enable_accelerated_netw… (#6289)
  * update CHANGELOG.md to include #6211
  * New resource & data source: azurerm_managed_application_definit… (#6211)
  * Remove api_server_authorized_ip_ranges note from kubernetes_cluster docs
  * Cleanup after v2.3.0 release
  * v2.3.0
  * formatting
  * Update CHANGELOG.md to include #5746
  * New resource `azurerm_policy_remediation` (#5746)
  * Update CHANGELOG.md to include #5263
  * New Resource: `azurerm_mssql_virtual_machine` (#5263)
  * update CHANGELOG.mc to include #6229
  * New data source: azurerm_network_service_tags (#6229)
  * updating to include #6250
  * `mprop`->`props`
  * validate func
  * terrafmt
  * new resource: azurerm_log_analytics_datasource_windows_performance_counter
  * Support cluster client cert common name (#6263)
  * update CHANGELOG.md to include #6083
  * New resource/data source: `azurerm_mssql_database` (#6083)
  * tests: fix some resourcegroup names (#6247)
  * Changed management policy to only send set properties
  * updating to include #6242
  * Update iothub_dps.html.markdown
  * Remove private_link preview warning from kubernetes_cluster docs
  * location: removing the duplicate Location suffix
  * r/resource_group: switching over to the new Location func
  * location: moving to it's own package/making this strongly typed
  * updating to include #6162
  * updating to include #6225
  * updating to include #6237
  * Update Changelog for #6234
  * update CHANGELOG.md to include #6097
  * azurerm_service_fabric_cluster - support for Client Certificate… (#6097)
  * Update CHANGELOG.md to include #5778
  * azurerm_cognitive_account - support for the `qna_runtime_endpoi… (#5778)
  * goimports
  * Addressing review
  * r/virtual_machine_data_disk_attachment: handling the VM being deleted
  * Linting
  * linting
  * r/managed_disk: conditional shut-down if it's attached & fixing tests
  * r/managed_disk: conditionally restarting the vm as needed
  * Update website/docs/r/managed_disk.html.markdown
  * reboot a VM only on managed disk resize
  * Various fixes
  * Custom Resource Provider
  * update CHANGELOG,md to include #5696
  * New Resource: azurerm_machine_learning_workspace (#5696)
  * update CHANGELOG,md to include #6233
  * azurerm_sql_database  - use the correct base URI for the Extend… (#6233)
  * update CHANGELOG.md to include #6228
  * netapp_volume: allow up to 102400 MB for the storage_quota_in_g… (#6228)
  * updated git diff target for linting
  * make azurerm_linux_virtual_machine custom_data sensitive
  * updating to include #6207
  * updating to include #6214
  * Update website/docs/r/hpc_cache.html.markdown
  * azurerm_sql_database: extended_auditing_policy is for azurerm_sql_server
  * hpc export `mount_addresses`
  * update CHANGELOG.md to include #5923
  * azurerm_traffic_manager_profile  - support for custom_header (#… (#5923)
  * add test for disk_encryption_set_id modification, update docs
  * provider change some more tests to .12 syntax (#6208)
  * azurerm_dns_zone doc example - You can't have 2 public zones of… (#6165)
  * Private link is now in GA (#6192)
  * Update CHANGELOG.md to include #6125
  * azurerm_lb: Don't assume IPv4 IP addresses (#6125)
  * tests: fix various issues found in CI (#6206)
  * implement disk_encryption_set_id modification for resourceArmManagedDiskUpdate
  * update CHANGELOG.md toinclude #6140
  * arm_public_ip: public_ips can be dynamic for ipv6 addresses (#6140)
  * remove ForceNew from disk_encryption_set_id schema
  * fix typo in run-lint-rest.sh (#6197)
  * travis: conditionally running the `make lintrest` step
  * update CHANGELOG.md to include #6035
  * new resource: azurerm_hpc_cache_blob_target (#6035)
  * updating to include #6179
  * Update versions of AKS in use for tests
  * updating to include #6170
  * use schema.TypeSet instead of schema.TypeList for ipv4_firewall_rule
  * Update to reflect node pool management changes
  * formatting
  * updating to include #6064
  * d/storage_container: using the right properties
  * r/storage_share: exposing the `resource_manager_id` field
  * r/storage_container: exposing the resource_manager_id field
  * d/storage_container: exposing the resource manager id
  * updating to include #6169
  * removing the beta feedback issue now the beta has been completed
  * go mod tidy
  * travis: conditionally running the test, lint and tflint steps
  * dependencies: updating to v0.10.0 of github.com/tombuildsstuff/giovanni
  * updating to include #5759
  * updating to include #5981
  * update CHANGELOG.md to include #6134
  * Updating the Azure SDK to v40.3.0 / AzureAD to v0.8.0 (#6134)
  * Cleanup after v2.2.0 release
  * v2.2.0
  * azurerm_servicebus_subscription : Fixed default_message_ttl for… (#6127)
  * update CHANGELOG.md to include #5862
  * azurerm_logic_app_workflow  - expose computed field: `endpoint_… (#5862)
  * update CHANGELOG.md to include #4366
  * Application Gateway support for Key Vault SSL certificate ids (#4366)
  * Update database resource firewall rule docs (#6159)
  * ordering
  * updating to include #6133
  * Update CHANGELOG.md
  * Update CHANGELOG.md to include #5761
  * azurerm_function_app - Add WEBSITE_CONTENT & WEBSITE_CONTENTAZU… (#5761)
  * Update Changelog for #6131
  * Addressing review
  * Fix provider "kubernetes" link documentation for azurerm_kubern… (#6136)
  * test fixes for resources in configs that were affected by 2.0 c… (#6144)
  * split CHANGELOG.md entry for #5391 into two lines
  * update CHANGELOG,md to include #5152
  * Add new resource & data source: azurerm_powerbi_embedded (#5152)
  * Fix sidebar
  * Updated for #5391
  * Allowed subcategories
  * The argument retention_daily is required
  * lint
  * Fix typo in the version of the Azure Provider
  * probe_name is optional in backend_http_settings
  * Remove resource_group_name from azurerm_storage_container
  * sidebar: adding an entry for the new data source
  * linting
  * fixed imports post rebase
  * removed deprected schema entry.  Added timezone string validation
  * New Data Source: `azurerm_app_configuration`
  * r/app_configuration: refactoring to the split-out package structure
  * Updated for #5803
  * updating to include #5966
  * Finishing documentation
  * Testing
  * update CHANGELOG.md to include #5951
  * New Resource: azurerm_virtual_hub_connection (#5951)
  * Update CHANGELOG.md to include #5049
  * `azurerm_sql_database` - support for the `extended_auditing_pol… (#5049)
  * fixed rule actions behaviour and added sinngle action tests
  * updating to include #6108
  * updating to include #6100
  * linting: updating to account for the gosimple linter
  * Fix azurerm_iothub_dps_shared_access_policy 'primary_connection_string' and 'secondary_connection_string'
  * Continuation
  * Changes `database` to `container`
  * Working basic test
  * add daily_memory_time_quota option to azurerm_function_app
  * Goimports
  * Refine availability set
  * Start of cost management
  * Update servicebus.go
  * Delete servicebus_namespace.go
  * Updates with TF 0.12 & Azure 2.0 requirement
  * moves current namespace validation into new file
  * Cleanup after v2.1.0 release
  * v2.1.0
  * Update CHANGELOG.md
  * provider: registering the Microsoft.MixedReality RP (#6071)
  * gofmt
  * Add required features field to the azurerm provier
  * align the validation rule with the portal
  * updating to include #6050
  * Fix typo in acc test
  * dependencies: fixing broken Nested Go Modules
  * removing dead vendor links
  * storage: removing the unused accounts client
  * r/storage_blob: fixing the AAD tests having a duplicated provider block
  * storage: switching to use the SharedKeyForAccount implementation
  * dependencies: updating to:
  * Update CHANGELOG.md to include #5961
  * azurerm_mariadb_server  - mark geo_redundant_backup as ForceNew (#5961)
  * Update AKS network_policy documentation (#5826)
  * Cannot set max_count and min_count to zero when autoscaling is… (#6020)
  * Update CHANGELOG.md to include #5931
  * Add tags to cluster node pools (#5931)
  * Update changelog for #5531
  * Update resource_arm_kubernetes_cluster_test.go
  * Fix format of notes section
  * Updated to include #6015
  * `azurerm_frontdoor`: Upcoming RP change forces all new front door resources to be created in the `Global` location (#6015)
  * Update CHANGELOG.md to include #5590
  * azurerm_lb - support for the `private_ip_address_version` prope… (#5590)
  * Update CHANGELOG.md to include #6017
  * Added new data source `azurerm_servicebus_topic_authorization_r… (#6017)
  * Update CHANGELOG.md to include #5851
  * azurerm_network_watcher_flow_log  - support for the`interval_in… (#5851)
  * Update CHANGELOG.md to include #5036
  * `azurerm_sql_server` - support for the `extended_auditing_polic… (#5036)
  * r/storage_account: casting to a string
  * r/storage_account: handling an empty `static_website` block being defined
  * r/storage_account: accessing the data plane api's using Giovanni
  * tidying
  * Fix tests
  * features: removing the unused "two point oh" feature
  * tests: clarifying the features block is required going forward
  * r/search_service: the fields `partition_count` and `replica_count` are no longer forcenew
  * tools/website-scaffold: fixing a typo
  * linting
  * tools: fixing an issue when scaffolding the example for a data source
  * r/search_service: updating the docs
  * tooling: adding the scaffold-website tool to the makefile
  * d|r/resource_group: generating updated documentation
  * New Tool: website-scaffolder
  * wip: adding a scaffolder for resources/data sources
  * Updated virtual_hub.html.markdown (#6033)
  * Update Changelog for #6011
  * Update CHANGELOG.md to include #5446
  * New Resource: IoTCentralApplocation (#5446)
  * Fix sidebar link
  * docs: Updated `traffic_manager_profile` arguments (#6024)
  * Address review
  * Update CHANGELOG.md to include #5995
  * `azurerm_netapp_*` - support for `tags` & add ID parsing functi… (#5995)
  * provider: remove deprecated functions and other misc cleanup (#6009)
  * docs: `Updates dev_test_windows_virtual_machine` example (#6013)
  * Website and testing
  * Start of spatial anchor accounts
  * Update CHANGELOG.md to include #5993
  * New Resource & Data Source: azurerm_database_migration_project (#5993)
  * provider: remove unnecessary locals (#6008)
  * Update CHANGELOG.md to include #5528
  * New Resource: `azurerm_hpc_cache` (#5528)
  * azurerm_network_interface_application_gateway_backend_address_p… (#5999)
  * Adds a Missing Whitespace (#5997)
  * azurerm_cosmosdb_mongo_collection: Remove deprecated and remove… (#5996)
  * rename "Data Migration" into "Database Migration" (#5994)
  * Update CHANGELOG.md
  * azurerm_netapp_[pool|snapshot|volume] - fix import test (#5992)
  * Update CHANGELOG.md to include #5485
  * azurerm_netapp_volume  - support NFSv4.1, vol sizing issue (#5485)
  * Update to reflect batch API version change in #5967
  * Update resource_arm_kubernetes_cluster_node_pool_test.go
  * Update CHANGELOG.mdto include #5258
  * New Resource & Data Source: azurerm_data_migration_service (#5258)
  * Update resource name for ASE in data docs (#5989)
  * Update CHANGELOG.md to include #5958
  * 'azurerm_redis_cache' - Support for 'primary_connection_string'… (#5958)
  * Update CHANGELOG.md to include #5967
  * support `public_ips` for resource `azurerm_batch_pool` (#5967)
  * azurerm_managed_disk - DOC: Update disk encryption attribute (#5987)
  * Refine doc of `azurerm_key_vault` (#5968)
  * Update Changelog for #5053
  * azurerm_api_management_product_group: fix import error resource… (#5978)
  * azurerm_windows_virtual_machine - Add WinRM protocol to documen… (#5982)
  * azurerm_linux_virtual_machine  - Fix broken link in documentati… (#5983)
  * docs: Fixed Typo in `r/subnet` (#5980)
  * Fixed regex to parse management groups correctly on import
  * Update changelog for 5915
  * Fix markdown formatting
  * `azurerm_kubernetes_cluster` - Address documentation typo #5964
  * example: `azurerm_application_insights` - Use location from resource group (#5970)
  * Address review comments
  * Update to include #5924 (fixes #5499 #5903)
  * azurerm_frontdoor fixes #5499 #5903
  * Some efforts to satify the linter
  * Fix format
  * Update validation rules for linux and windows vms
  * updated text for #5906
  * updating to include #5906
  * azurerm_application_gateway - support 125 for V2 sku capacity (#5906)
  * Update Changelog for #5941
  * `azurerm_batch_pool` - `frontend_port_range ` is now set correctly. (#5941)
  * Update CHANGELOG.md to include #5445
  * Some update to conform 2.0
  * Rebase to master and fix compiling error
  * Refinement
  * Update the doc a little bit
  * Fix CI failure
  * Add support for scale in policy and terminate notification
  * Update CHANGELOG.md to include #5949
  * Update CHANGELOG.md to include #5855
  * export fqdn attribute in private dns record resource
  * v0.12 changes
  * Enable syntax highlighting
  * Update CHANGELOG.md to include #5837
  * Updating to include #5943
  * Bug: `azurerm_frontdoor_firewall_policy` add validation for Frontdoor WAF Name Restrictions (#5943)
  * Update CHANGELOG.md to include #5942
  * Update CHANGELOG.md to include #5876
  * Schema for data source on "tags"
  * New Data Source: 'azurerm_kusto_cluster'
  * Update CHANGELOG.md to include #5934
  * allow proper key length
  * Update CHANGELOG.md to include #5935
  * updated for 5915
  * azurerm_search_service - the properties replica_count & partition_count are no longer force new
  * azurerm_storage_account - allow up to 50 tags
  * fix travis build
  * add addtional missing provider blocks
  * add provider block to acc tests
  * run upgrade012 on all acc tests
  * Update vmss extension type_handler_version docs
  * update
  * apply changes from code review
  * Updated for 5839
  * linting: terrafmt doesn't depend on terraform anymore
  * Update CHANGELOG.md to include #5827
  * Update CHANGELOG.md to include #5877
  * exclude app_service_environment_id from update when empty
  * Correct typo
  * Add tests for kubernetes cluster node labels
  * Add support for node_labels in azurerm_kubernetes_cluster and azurerm_kubernetes_cluster_node_pool resources #4968
  * Update CHANGELOG.md to include #5838
  * Fixes #5622 #5208
  * Update CHANGELOG>md to include #5901
  * fix source_image_id for linux scalesets
  * Improper import examples
  * Update cosmosdb_mongo_collection.html.markdown
  * remove reference to non-existing page
  * Add Type to Virtual WAN properties
  * remove duplicate set and undo changes from prettier
  * Add network interface and security group association
  * Cleanup after v2.0.0 release
  * v2.0.0
  * more fields support for `azurerm_kusto_cluster`
  * updating to include #5853
  * updating to include #5852
  * typo
  * add enable_disk_encryption to azurerm_kusto_cluster
  * examples: adding the provider block to each example
  * azurerm_cosmosdb_mongo_collection - remove deprecated property
  * r/frontdoor: updating the default values within the `forwarding_configuration` block
  * updating to include #5850
  * r/storage_account_customer_managed_key: adding args to the error
  * linting
  * updating to include #5668
  * updating to include #5773
  * d/storage_account: removing removed fields
  * d/key_vault_key: removing a dead field
  * quotes
  * removing `resource_group_name` from the storage_container resource
  * r/template_deployment: removing the deprecated resource_group_name field from `azurerm_storage_container`
  * r/network_interface_backend_address_pool_association - removing the deprecated location field
  * r/mariadb: fixing the sku block
  * r/maps_account: fixing the casing
  * switching from `service_principal_application_id` to `client_id`
  * switching from `service_principal_object_id` to `object_id`
  * r/hdinsight*: removing the `resource_group_name` argument from the test configs
  * changing storage account accout kind default to StorageV2
  * r/storage_account_customer_managed_key: fixing the example
  * r/key_vault_key: removing the unused `key_vault_access_policy_id` field
  * updating to include #5844
  * r/storage_account_customer_managed_key: adding validation
  * r/storage_account_customer_managed_key: comments from code review
  * updating to include #5842
  * r/storage_account: locking on the correct key during update
  * building: removing references to dead tests
  * sidebar: removing a dead link
  * updating to include #5508
  * r/(monitor_)metric_alert_rule: removing since these are EOL
  * r/app_service_environment: checking the ID's from the state
  * Add MaxItems for cross-resource query
  * Review updates
  * Fix type assertions; simplify cross-resource query example
  * r/app_service_plan: increasing the timeouts to 60m for ASE's
  * updating to include #5816
  * r/key_vault_key: formatting
  * recoveryservices: renaming the files
  * Updates to CMK
  * removing deprecated resources
  * Update domain regex to allow dash (-)
  * Change dns to dns_servers
  * deps: fixing the vendor file
  * refactor: switching to the same client
  * r/app_service_environment: fixing the plan test
  * r/app_service_environment: converting from the display to actual sku
  * r/app_service_environment: fixing the requires import test
  * r/app_service_env: fixing the import test
  * r/app_service_environment: fixing up linting
  * tests: adding in missing checkdestroys for the data source tests
  * r/app_service_environment: switching to use a custom update method/poller
  * r/app_service_environment: fixing comments from code review
  * d/app_service_environment: renaming the file to match the convention
  * web: removing todos
  * d/app_service_environment: fixing comments from code review
  * network: moving the virtual network parse/validaters into those packages
  * r/subnet: moving the subnet parser into the parse package
  * r/app_service_environment: fixing up the build errors
  * refactor validate to correct helper location
  * fmt fix
  * docs update
  * refactor tests, fix tflint issues
  * Refactor for 2.0
  * Added forgotten requiresImport test
  * Linter fixes
  * Adds new resource and datasource for App Serice Environment (v2 support only)
  * updating to include #5823
  * fixing comments from code review
  * updating to include #5831
  * updating to include #5344
  * linting
  * r/keyvault: fixing the soft delete disabled test
  * r/keyvault: removing dead code
  * Added 5833
  * adding gh marker for 5832
  * Adding 5832
  * Updated data source and docs
  * updating to include #5825
  * updated so os_type is always set
  * r/key_vault: removing a superflurious if statement
  * fix for linux function apps
  * r/key_vault: updating the docs
  * r/key_vault: outputting a warning rather than an error during the delete
  * Doc updates, test fixes
  * Updated validate to correct method for cidrs
  * r/key_vault: fixing up the tests
  * add support for long text record
  * docs: Adds `id` to r/resource_group Fixes #5686
  * add `tags` in doc
  * docs: updates cdn_endpoint `origin` attr to required Fixes #5750
  * Added Purge on Destroy back in
  * dns - add parse ID and func (#5779)
  * Add test case and txt to 2.0 guide
  * Test for blank path
  * allow_virtual_network_access defaults to true
  * Fix for #4868
  * Start adding purge on destroy back in
  * minor: committing some lingering test files
  * r/key_vault: updating the docs
  * r/key_vault: handling conditionally updating the key vault resource
  * More test fixes
  * Removed another redundant test and config
  * Removed redundant test and config
  * nil pointer fix
  * nil pointer fix and others
  * missed ip to cidr change
  * Missed removing virtual_network_name from function_app again
  * Missed removing virtual_network_name from function_app
  * r/key_vault: moving the migration code closer to the package
  * Removed multipleAssignedIdentities test as ManagedServiceIdentityTypeSystemAssignedUserAssigned type removed
  * excluded implicit Any rule from state for ipRestrictions
  * test fixes. Unused virtual_network_name field removed
  * (d|r)/key_vault: moving the name validation into that package
  * validate: removing the bool validators
  * add `tags` for resource `azurerm_automation_dsc_configuration`
  * lint and goimports
  * set tags in keyvault_certificate to ForceNewSchema as resource has no Update method
  * Updated app_service SDK version
  * Updated for 5817
  * updating to include #5815
  * r/network_interface_application_security_group_association: fixing the tests
  * PR suggestion fix
  * r/network_interface_application_security_group_association: missed the assertion
  * r/recovery_services_vault: using the requested cloud rather than the default
  * r/network_interface_application_security_group_association: fixing the tests
  * r/firewall: upping the timeouts to 90m
  * tooling: removing a panic
  * updating the readme
  * linting
  * removing deadcode
  * Final deprecations
  * 2.0-compute (#5811)
  * Update Changelog for #5775
  * Move log_analytics to 2.0 (#5775)
  * makefile: hooking up the categories generator
  * categories: adding a generator to output the categories list from the provider registration
  * website: moving FrontDoor into the Network category
  * provider: adding a `WebsiteCategories` list to each registration
  * Made application_type case sensitive.  Removed workaround for fixed SDK/API issue
  * Docs updates
  * r/network_interface_application_security_group_association: removing `ip_configuration_name`
  * updating to include #5725
  * removed deprecated recoveryservices resources. Updated datasource and docs
  * updating to include #5772
  * auth: using the correct authorizer for the service principals client
  * updating to include #5808
  * test fixes
  * Update changelog for #5792
  * Update the frontdoor package to 2.0 (#5792)
  * Update Changelog for #5790
  * Update iothub to 2.0 (#5790)
  * address review
  * Fix test case
  * Update azurerm/internal/services/sql/resource_arm_sql_database.go
  * Update azurerm/internal/services/sql/resource_arm_sql_database.go
  * Update test cases
  * updating to include #5781
  * docs: adding to the upgrade guide
  * r/storage_account: updating the default for `enable_https_traffic_only` to `true`
  * r/api_management_api_operation: support for Requires Import
  * updating to include #5801
  * r/express_route_gateway: tweaking the timeouts
  * updating to include #5805
  * updating to include #5743
  * updating to include #5794
  * website: removing link to a dead link
  * Linting
  * config typo fix
  * Test fixups
  * Remove computed from required
  * linting
  * New data source: 'azurerm_eventhub_authorization_rule'
  * r/express_route_gateway: fixes from #5523
  * updating to include #5523
  * linting
  * r/mysqL_server: fixing assertions
  * updating to include #5793
  * r/mysql_server: fixing the tests
  * updating to include #5795
  * dns: updating the tests to match the fields always being set
  * moving the bug fix to the bug fixes section
  * updating to include #5784
  * r/eventhub: updating the test config to account for the storage container no longer taking the rg name
  * r/dns_ns_record: fixing a bug during update
  * r/dns_zone: removing tests covering the deprecated fields
  * r/devspace: switching to use `default_node_pool`
  * r/api_management_api_(operation|schema): fixing the tests
  * linting
  * linting
  * Fixup tests
  * r/subnet: fixing the broken test
  * fixing the linting
  * linting
  * r/subnet: removing the old network_security_group_id field from the docs
  * r/route_table: removing an obsolete test
  * r/subnet: removing the inline `route_table_id` and `network_security_group_id` fields
  * updating to include #5797
  * Remove deadcode
  * 2.0-automation
  * 2.0-cognitive
  * 2.0-cosmos
  * 2.0-cosmos
  * 2.0-devspace
  * 2.0-dns
  * eventhub -> 2.0
  * Update ACR docs SKU and GeoRepl Note
  * Removed legacy tests no longer required
  * Remove deadcode
  * fix two more tests for attribute reference
  * fixup tests for sku_name
  * updating to include #5774
  * linting
  * r/keyvault: removing dead code
  * r/keyvault: updating the remaining tests
  * r/subnet: removing the `route_table_id` field from the examples/docs
  * r/key_vault_*: handling the parent key vault not being available once it's deleted
  * r/key_vault: removing the test expecting a complaint
  * automation: fixing the tests to account for the field being removed
  * Very minor consistency edits
  * docs: adding the `azurerm_network_interface_security_group_association` to the sidebar
  * updating to include #5693
  * updating to include #5624
  * d/network_interface: updating the tests
  * r/key_vault_access_policy: removing the unused assignment
  * linting
  * docs account_name to automation_account_name update
  * caught additional 2.0 todos
  * updating to include #5777
  * Update azurerm/internal/services/mariadb/resource_arm_mariadb_server.go
  * r/network_interface_application_gateway_association: fixing the tests
  * r/network_interface: conditionally updating the nics only for ipv4 configurations
  * r/network_interface: updating the tests / rewriting the docs
  * updating to include #5710
  * spelling
  * r/network_interface: applying properties managed in other resources to this resource
  * New Resource: `azurerm_network_interface_security_group_association`
  * updating to include #5764
  * Fix for update
  * updating to include #5753
  * r/app_service_plan: fixing a merge conflict
  * updating to include #5649
  * updating to include #5776
  * r/iothub_dps: fixing the test
  * updating to include #5721
  * Update azurerm/internal/services/storage/resource_arm_storage_account.go
  * Upgrade keyvault to 2.0
  * remove conflictswith
  * upgrade maps to 2.0
  * Update mariadb to 2.0
  * On metric alert rule creation, the 'autoMitigate' property should be set to true by default
  * updating to include #5744
  * updating to include #5768
  * Update website/docs/guides/2.0-upgrade-guide.html.markdown
  * add zone_redundant to azurerm_sql_database
  * Address review comments
  * r/compute - adds support for additional dedicated host SKUs Validation added for two additional SKUs: DSv3-Type2 and ESv3-Type2 Fixes #5700
  * Format doc hcl blocks
  * Updated doc
  * r/(linux|windows)_virtual_machine: using the Delete timeout during Deletion
  * Tweaked boolean logic for checkForNonDefaultStorageAccountNetworkRule
  * r/network_interface: loading the existing nic details during a delta update
  * r/network_interface_nat_rule_association: commiting the missing method
  * r/network_interface: removing the deprecated `load_balancer_backend_address_pools_ids` field
  * r/network_interface: removing the deprecated `load_balancer_inbound_nat_rules_ids` field
  * r/network_interface: removing the deprecated `application_security_group_ids` field
  * r/network_interface: removing the `application_gateway_backend_address_pool_ids` field
  * r/network_interface: introducing a separate update method
  * removing dead code
  * linting
  * removed unintended carets
  * Minor formatting update. Added azurerm_role_definition data source note
  * updating to include #5754
  * updating to include #5747
  * updating to include #5752
  * r/log_analytics_workspace_linked_service: removing the deprecated resource
  * iothub: removing the deprecated `azurerm_iot_dps` and `azurerm_iot_dps_certificate` resources
  * updating to include #5748
  * r/application_gateway: updating the default value for the `body` field within the `match` block
  * r/mssql_elasticpool: fixing the import tests
  * updating to include #5733
  * grouping the breaking changes together
  * tweaked import acctests
  * updating to include #5425
  * removing the AzureAD resources since they've been split out
  * d/batch_account: switching to use the azuread provider
  * r/mysql_server: removing reference to the old field
  * fixed clientconfig_basic test
  * r/kubernetes_cluster: updating the default for load_balancer_sku to `Standard`
  * updating to include #5737
  * updating to include #5722
  * updating to include #5719
  * Test fixes
  * Format private service connection
  * Update subnets options and add details for endpoint
  * update mssql to 2.0
  * Update mysql to 2.0
  * Updates
  * Fixed import issue
  * Fix whitespace
  * remove synthentic delays
  * Add SACMK doc to TOC
  * Rename resource
  * Correct typo
  * r/signalr_service: updates ID to correct case fixes #5715
  * Update main.tf
  * r/postgresql_server: missed a failing test condition
  * r/postgresql_server: fixing broken tests
  * notificationhub: fixing docs
  * r/app_service_plan: fixing a bad rebase
  * r/storage_account_network_rules: switching to use the networkruleset from props
  * r/storage: fixing broken tests
  * Remove unused method
  * Update resource_arm_app_service_plan.go
  * Revert web changes
  * Continue fixing tests
  * fix up tests
  * fix imports
  * Removed additional deprecated fields
  * Preparing the the storage package for 2.0
  * notificationhub: fixing the tests
  * r/notification_hub_namespace: making the `sku_name` field required
  * notificationhub to 2.0
  * r/relay_hybrid_connection: fixing the resource name
  * postgres service to 2.0
  * r/relay_hybrid_connection: fixing the import test
  * Update upgrade guide
  * moving relay_namepace to 2.0
  * Removed legacy check and updated test
  * Added Computed flag to TypeList resources with default values
  * added optional bool defaults for diff
  * 2.0 todos and associated tests
  * provider: making the features block optional during testing
  * provider: hooking into the test refresh to set default features
  * updating to include #5662
  * linting
  * provider: making the `features` block required
  * updating to include #5724
  * updating to include #5661
  * docs: continuing to remove references to the beta
  * updating to include #5712
  * updating to include #5709 and #5717
  * docs: updating the upgrade guide with the default value change for Availability Sets
  * r/availability_set: flipping the default value for `managed` to `true`
  * docs: removing the Beta signifier from docs
  * vendor: removing the scheduler package
  * 2.0: removing Scheduler since this is no longer supported
  * 2.0: Removing `azurerm_container_service`
  * resolve review comments
  * Fix lint newlint
  * Update servicebus queue import test
  * Remove properties from datasource tests
  * Prepare servicebus for 2.0
  * Updating web for 2.0
  * Update error conditional
  * Make error msg more user friendly
  * Documentation changed based on observed terraform and Azure API behavior.
  * Linking to the 1.44 release for older changelog entries
  * updating to include #5705
  * docs: removing the beta disclaimer for custom timeouts
  * 2.0: enabling the Requires Import functionality by default
  * 2.0: enabling the new resources feature toggle by default
  * 2.0: removing the feature toggle for Custom Timeouts
  * Cleanup after v1.44.0 release
  * v1.44.0
  * removing a duplicate section
  * r/storage_account: ensuring the `blob_properties` fields always have a value set
  * r/storage_account: ensuring default values are set when blob_properties is omited
  * fmt fix
  * updated Windows VM source_image_id validation
  * updated sysprep step for reliability. Tweaked test config. removed comments
  * Updated Windows image sysprep for image acctests
  * add recommendation for scope parameter value
  * minor changes
  * Fix example usage
  * Correct sidebar location
  * Add express_route_gateway to website sidebar
  * remove commented block
  * Requested changes to error handling & structure Documentation fixes
  * Update IP Prefix validation
  * Progress
  * format docs
  * fix site attributes
  * Format test TF code
  * docs: updating the "how to migrate between deprecated resorces" guide
  * 1.44 Doc Changes (#5684)
  * r/app_service: documenting at which level the `backup` block exists
  * Update kubernetes_service_versions.html.markdown
  * Update website/docs/d/kubernetes_service_versions.html.markdown
  * linter changes
  * Remove redundant nil check
  * Provide ability to set 'cors_rule' for blob properties
  * updating to include #5516
  * updating to include #5518
  * Add documentation for `include_preview` argument
  * Address PR comments
  * Validate metric_trigger query; add example to docs
  * adding notes for 1.44.0
  * Add an option to filter out preview aks releases when fetching versions
  * updating to include #5679
  * updating to include #5680
  * d/iot_hub_dps_shared_access_policy: fixing comments from code review
  * Remove (Required) from Argument Reference section
  * Fix formatting and update documentation
  * New Data Source: 'azurerm_iothub_dps_shared_access_policy'
  * Update documentation
  * Check for nil
  * Format files
  * New Data Source: 'azurerm_eventhub_consumer_group'
  * Add FormRecognizer account kind
  * r/loadbalancer: fixing a crash during a dropped response
  * Add form recognizer as a Cognitive account kind
  * updating to include #5676
  * r/function_app: grammar
  * r/virtual_machine_scale_set: adding a notice about the superseding
  * r/function_app: support for User Assigned Identities
  * updating to include #5440
  * r/function_app: ensuring the `ip_address` and `subnet_id` address fields are always set
  * Revert a change back due to API problem
  * updating to include #5430
  * updating to include #5522
  * completes parse ID func/files
  * Update Changelog for #5604
  * `azurerm_cognitive_account` - Add support for ImmersiveReader #5604
  * Update Changelog for #5652
  * `azurerm_databricks_workspace`: Doc Fix for Trial SKU #5652
  * `azurerm_databricks_workspace`: Support for Trial SKU #5652
  * adds parse ID functions/files
  * fixes ID error
  * tflint fix 2
  * tflint fixes
  * are -> is
  * address code review suggestions
  * Mostly working
  * Corrected Prefix Length
  * Apply suggestions from code review
  * Fixing load balancer file names
  * Got it to compile
  * Fixing sidebar links
  * Initial port to new code base
  * completes parse ID func/files
  * Update Changelog for #5593
  * `azurerm_api_management` - Add http2 protocol support for API Management (#5593)
  * completes parse ID func/files
  * r/(linux|windows)_virtual_machine_scale_set: conditionally updating the instances
  * Escape health probe when health probe is empty
  * Add health probe back to update to prevent any potential errors from the service
  * terrafmt
  * Updated CHANGELOG.md for 5640
  * updating to include #5614
  * fixed tf upgrade todo
  * Update website/docs/r/sql_database.html.markdown
  * r/storage: switching then name of the authorizer field
  * r/storage: authenticating to the Blob/Queues API's using AzureAD Auth
  * documentation: change resources to .12 (P-Z)
  * documentation: change resources to .12 (K-P)
  * documentation: change resources to .12 (D-K)
  * documentation: change resources to .12 (A-C)
  * documentation: change guides to .12
  * documentation: change datasources to .12
  * First pass address latest review
  * Add monitor helpers
  * update storage account static website docs
  * add support for static website to azurerm_storage_account
  * fixes extra segment error
  * fixes a few misses
  * Fix test case lint issue
  * Fixed two typos causing lint errors
  * Fix basic test
  * Remove depricated sku from tests
  * Add code to skip purge if not soft deleted
  * completes parse ID func/files
  * Fix spelling mistakes
  * creates parse func/files
  * Update CHANGELOG.md
  * `azurerm_key_vault_key` - support for `not_before_date` and `expiration_date` (#5619)
  * azurerm_sql_database: Correction to service objective docs (#5644)
  * Update Changelog for #5643
  * Improvement: Data Source Documentation Cleanup (#5643)
  * Update Changelog for #5642
  * New Data Source: 'azurerm_function_app' (#5642)
  * Update CHANGELOG.md to include #5565
  * azurerm_storage_account - fix hanging destroy caused by multipl… (#5565)
  * tflint whitespace fix
  * fixed linux vm shared image tests. added support for shared_image_id variants
  * Removed sku support  from datasource
  * goimports-ed
  * Fix features test cases
  * Use custom parse function in acctest
  * Custom disk encryption set parser and validation
  * updated or to and
  * Complete
  * Correct example, and clarify what is output
  * adds missing folder
  * completes parse ID functions/files
  * completes parse ID functions/files
  * adds missing value to WrongCasing test
  * adds missing value to WrongCasing test
  * Update .gitignore for tfvars files
  * removed tfvars file
  * Update examples/virtual-machines/linux/load-balanced/main.tf
  * Update examples/virtual-machines/linux/load-balanced/main.tf
  * Update examples/virtual-machines/linux/public-ip/README.md
  * Update examples/virtual-machines/linux/load-balanced/README.md
  * Update examples/virtual-machines/windows/vm-joined-to-active-directory/modules/domain-member/main.tf
  * Updated AD example to wait longer and more reliably for the domain to become available to join
  * Removed unneeded provisioner block
  * completes parse ID functions/files
  * deletes unneeded comments
  * completes parse ID functions/files
  * Add name validation for azurerm_role_assignment
  * Working soft delete and purge
  * databricks - add ID parsing function (#5621)
  * cognitive - add ID parsing function (#5620)
  * adds parse ID functions/files
  * Update CHANGELOG.md for 5610
  * Error message tweaks in SSH Key validation
  * Enhanced SSH key valiation
  * Added windows AD domain attached VM example
  * Update website/docs/r/virtual_machine.html.markdown
  * Fix documentation error
  * deletes commented code
  * fixes ID error
  * Update kubernetes_cluster documentation (#5406)
  * provider tests: enable more tfproviderlint checks (#5603)
  * adds parse func; need to fix subscription error
  * updated simple ssh validation to exclude key comments in checks
  * Added simple ssh public key validation
  * Cleanup after v1.43.0 release
  * Added linux_vm loadbalanced example
  * Added examples for linux vm with public IP, linux vm with managed disk attachment.  Tidied some HCL1 -> HCL2
  * Done except for purge on destroy
  * fix acc test
  * minor fix to directline tests
  * review fixes
  * Fix lint issues #3
  * Fix lint issues #2
  * Fix lint issues and minor typos
  * Fix code review items
  * WIP Get value from provider
  * Rename action to alert in docs
  * First pass at separating into two resources
  * First pass update docs post-review
  * Resize test to reasonable size
  * Resolve PR feedback
  * Extract `ip_restriction` expand and flatten methods
  * Fix tflint error
  * review feedback response
  * tflint fixes
  * Resolve linting errors
  * Update document
  * Remove `subnet_mask` property
  * Add documentation
  * gofmt changes
  * Add ExpressRoute Gateway resource and tests
  * Changed `virtual_network_subnet_id` property name
  * Changed test case method name
  * rename default transformation name from Transformation to main (like the portal does); enable import of not jobs which were not created in TF; keep backwards compatibility
  * Update azurerm/internal/services/keyvault/resource_arm_key_vault.go
  * Update website/docs/r/key_vault.html.markdown
  * Update website/docs/r/key_vault.html.markdown
  * Add sensitive flags to keys
  * Fix linting errors
  * fix tflint errors
  * Add Directline
  * Fix code formatting issue
  * azurerm_function_app - support for ip_restriction
  * fix lint errors
  * Key Vault: support for soft delete
  * Add moved tests to registration
  * Update tests and docs to pass checks
  * fix response import
  * Remove heredoc in docs example
  * Minor updates and bug fixes
  * Fix linting errors; minor cleanup
  * Acceptance tests passing
  * New Resource: `azurerm_monitor_scheduled_query_rules`
* Wed Mar  4 2020 Robert Schweikert <rjschwei@suse.com>
- Spec clean up
- Create required symlink
* Wed Feb  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.43.0
  NOTES:
  * **Opt-In Beta:** Version 1.43 of the Azure Provider introduces an opt-in Beta for
    some of the new functionality coming in 2.0 - more information can be found
    [in the Beta guide](https://terraform.io/docs/providers/azurerm/guides/2.0-beta.html).
  * **Terraform 0.10/0.11:** The upcoming version 2.0 of the Azure Provider will not support
    Terraform 0.10.x & Terraform 0.11.x - you will need to upgrade to Terraform 0.12 to
    use version 2.0 (and above) of the Azure Provider.
  FEATURES:
  * **New Data Source:** `azurerm_eventhub_namespace_authorization_rule`
    ([#5489](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5489))
  * **New Data Source:** `azurerm_mariadb_server`
    ([#5506](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5506))
  IMPROVEMENTS:
  * `azurerm_application_insights` - support for the `daily_data_cap_in_gb` &
    `daily_data_cap_notifications_disabled` properties
    ([#5480](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5480))
  * `azurerm_private_endpoint` - expose mapping between `group_id` and `subresource_names`
    ([#5571](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5571))
  * `azurerm_recovery_services_vault` - support for the `soft_delete_enabled` property
    ([#5586](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5586))
  BUGS:
  * `azurerm_databricks_workspace` - allow underscores in `name`
    ([#5548](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5548))
  * `azurerm_dns_aaaa_record` - normalize IPv6 addresses
    ([#5459](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5459))
  * `azurerm_frontdoor` - including required `minimum_tls_version` to the `custom_https_configuration`
    block ([#5539](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5539))
  * `azurerm_managed_disk` - correctly handles disk resizing when attached to a virtual machine
    ([#5579](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5579))
  * `azurerm_marketplace_agreement` - recreate agreement if not accepted
    ([#5582](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5582))
  * `azurerm_mysql_virtual_network_rule` - allow `subnet_id` to be in a different subscription
    then the database ([#5568](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5568))
  * `azurerm_virtual_network_gateway_connection` - increase `routing_weight` maximum to `32000`
    ([#5540](https://github.com/terraform-providers/terraform-provider-azurerm/issues/5540))
- For the changes between 1.15.0 and 1.43.0, see CHANGELOG.md included in this package
- Update _service file
- Move LICENSE to %%license section
- Include CHANGELOG.md in %%doc section
- Increase golang API in BuildRequires to > 1.12
- Increase terraform version dependency to > 0.12.0
- Invoke %%gobuild with -mod=vendor "" to disable network access
* Fri Sep 21 2018 ldevulder@suse.de
- Update to version 1.15.0:
  * v1.15.0
  * Updating to include #1627
  * New Resources: `azurerm_firewall` & `azurerm_firewall_network_rule_collection` (#1627)
  * Update CHANGELOG.md to include #1918
  * test: logic app http trigger allows params in url
  * Updating to include #1921
  * Update TimeSpan documentation in Service Bus Queue/Topic (#1921)
  * Log Analytics Solution: removing crash points/refactoring
  * Update resource_arm_logic_app_trigger_http_request.go
* Thu Jul  5 2018 opensuse-packaging@opensuse.org
- Update to version 1.8.0+git20180704.9c1edb08:
  * Updating to include #1172
  * Ensuring we always set the `vhd_containers` field (#1411)
  * Updating to include #1411
  * `azurerm_lb` - allow `private_ip_address` to be set to an empty value (#1481)
  * Updating to include #1481
  * fixed typo on vpn_client_protocols
  * Application Security Groups now GA
  * Updating to v18.0.0 of Azure/azure-sdk-for-go / v10.12.0 of Azure/go-autorest (#1487)
  * Updating to include #1487
* Thu Jul  5 2018 ldevulder@suse.com
- Initial release
